function [Status,value,CurrChain,PME,Lambda] = SequentialPredictiveMomentsDSGEVAR(DSGEModel,CurrINI,controls,value,CurrChain,PME,Lambda,RecomputeMoments)
% SequentialPredictiveMomentsDSGEVAR: Can be used for computing the marginal predictive moments of DSGE-VARs
%                                     sequentially.
%
% USAGE:
%
%       [Status,value,CurrChain,PME,Lambda] = SequentialPredictiveMomentsDSGEVAR(DSGEModel,CurrINI,controls,value,CurrChain,...
%                                                                                PME,Lambda,RecomputeMoments)
%
% REQUIRED INPUT:  DSGEModel (structure) whose fields contain all required information 
%                            about the model, such as input files, variable and sample
%                            data. Actual observations are not stored in this file.
%
%                  CurrINI (structure) with initialization information.
%
%                  controls (structure) whose fields provide handles to all the UI
%                            controls in YADA's main dialog.
%
%                  value (integer) with the selected position for the available lambda hyperparameter.
%
%                  CurrChain (integer) with the number of the selected Markov chain with posterior draws.
%
%                  PME (integer) that takes the value 1 if the DSGE model posterior mode estimates
%                            are used, 2 if the DSGE-VAR marginal posterior mode estimates were
%                            used, and 3 if the DSGE-VAR joint posterior mode estimates were used
%                            when generating the posterior draws.
%
%                  Lambda (vector) with the lambda hyperparameter values that can be used.
%
%                  RecomputeMoments (boolean) which takes the value 1 if the predictive moments
%                            should be recomputed and 0 if old calculations should be used.
%
% REQUIRED OUTPUT: Status (boolean) that takes the value 1 if the computations could be successfully
%                            carries out, and 0 otherwise.
%
%                  value (integer) with the selected position for the available lambda hyperparameter.
%
%                  CurrChain (integer) with the number of the selected Markov chain with posterior draws.
%
%                  PME (integer) that takes the value 1 if the DSGE model posterior mode estimates
%                            are used, 2 if the DSGE-VAR marginal posterior mode estimates were
%                            used, and 3 if the DSGE-VAR joint posterior mode estimates were used
%                            when generating the posterior draws.
%
%                  Lambda (vector) with the lambda hyperparameter values that can be used.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2025 European Central Bank.
%
%                       First version: February 6, 2015.
%                        This version: January 10, 2025.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 09-02-2015: Changed the name of the output files such that the prediction sample is used.
%
% * 10-02-2015: Made sure that "YData" is stored in the mat-file.
%
% * 18-02-2105: Updated the documentation.
%
% * 31-03-2015: Made sure that toc command is collected into a variable.
%
% * 21-01-2016: Updated the documentation.
%
% * 29-03-2017: Updated the documentation.
%
% * 26-06-2017: Corrected a typo for CurrChain and corrected log text output.
%
% * 17-08-2017: Removed command that checks if the data in the forecast sample are available or just NaNs.
%
% * 11-09-2017: Took into account that "LoadVARDSGEPosteriorDraws" provides the output variable "Weights",
%               and that "DSGEVARPredictiveMoments" requires the input variable "Weights".
%
% * 24-10-2017: Took into account that "PrintPredictiveMoments" can now print back- and nowcast results,
%               while DSGE-VAR models are (currently) not compatible with ragged edge data.
%
% * 16-05-2018: Updated the documentation.
%
% * 24-01-2019: Updated the documentation.
%
% * 21-01-2020: Updated the documentation.
%
% * 27-01-2021: Remember Shoah.
%
% * 18-05-2021: Took into account that "PrintPredictiveMoments" now requires the input variable
%               "IsAdaptiveLearning".
%
% * 06-01-2022: Updated the documentation.
%
% * 06-01-2023: Updated the documentation.
%
% * 13-03-2024: Updated the documentation.
%
% * 30-07-2024: Took into account that "PrintPredictiveMoments" takes the input variable "IsConditional".
%
% * 10-01-2025: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% initialize
%
Status = 0;
%
if isempty(value)==1;
   [value,CurrChain,PME,Lambda] = GetVARDSGEPostDrawsSelection('Marginal Predictive Moments - Posterior Distribution',DSGEModel,controls,CurrINI);
end;
if (isempty(value)==1)|(value==0);
   SetLogText('Unable to load posterior data. Aborting calculation.');
   value = [];
   CurrChain = [];
   PME = [];
   Lambda = [];
   return;
end;
lambda = Lambda(value);
%
% load the posterior draws
%
[PhiDraws,SigmaDraws,A0Draws,thetaPostSample,PostSample,Weights,PhiMode,SigmaModeEpsilon,A0Mode] = LoadVARDSGEPosteriorDraws(DSGEModel,CurrINI,lambda,PME,CurrChain,0);
UsedDraws = size(PhiDraws,1);
[NumDraws,NumParam] = size(thetaPostSample);
if UsedDraws<100;
   clear('PhiDraws','SigmaDraws','A0Draws','thetaPostSample','PostSample');
   SetLogText(strvcat('YADA requires at least 100 draws of the VAR parameters to compute the marginal predictive',['moments. You currently only have ' int2str(UsedDraws) ' draws of the these parameters with lambda=' num2str(lambda) '.']));
   return;
end;
%
% check if the posterior mode innovation covariance matrix is positive definite
%
if IsPositiveDefinite(SigmaModeEpsilon)~=1;
   clear('PhiDraws','SigmaDraws','A0Draws','thetaPostSample','PostSample');
   SetLogText(strvcat('The posterior mode estimate of the residual covariance matrix','is not positive semidefinite. Aborting calculation.'));
   return;
end;
%
% check if the number of VAR parameters matches the number of DSGE model parameters
%
if NumDraws~=UsedDraws;
   clear('PhiDraws','SigmaDraws','A0Draws','thetaPostSample','PostSample');
   SetLogText(strvcat('The number of posterior draws for VAR and DSGE model parameters don''t match.','Aborting calculation.'));
   return;
end;
%
% we don't need the posterior draws of A0
%
clear('A0Draws','PostSample','thetaPostSample');
%
% determine string with 1's and 0's for the selected shocks
%
%SelectedShockStr = ismember((1:length(DSGEModel.StateShockPositions)),DSGEModel.DSGEVARShocks);
%SelectedShockStr = strrep(num2str(SelectedShockStr),' ','');
%
% determine the historical sample
%
[FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
DSGEModel.FirstPeriod = FirstPeriod;
DSGEModel.LastPeriod = LastPeriod;
%
% check how many time periods to use for predictive distributions
%
MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
%
% check the maximum when we take NaNs into account
%
YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
%MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
[MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
MaxFH = min(MaxFH,MaxPH);
YData = YData(:,1:MaxFH);
%
% matrix with exogenous variables
%
X = [];
if DSGEModel.k>0;
   if NumPredX<MaxFH;
      X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
   end;
   if NumPredX>0;
      X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
   end;
end;
%
% need to compute certain values
%
n = DSGEModel.n;
p = DSGEModel.BVARLags;
DrawsStr = get(controls.posterior.draws,'String');
NumPostDraws = str2num(StringTrim(strrep(DrawsStr(DSGEModel.PosteriorDrawsValue,:),',','')));
BurninStr = get(controls.posterior.burnin,'String');
NumBurnin = str2num(strrep(StringTrim(BurninStr(DSGEModel.BurnInValue,:)),',',''));
%
% Determine the prediction sample
%
PredictionSampleStrMat = CreateFullSample(DSGEModel);
PredictionSampleStrMat = PredictionSampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
%
% check if older calculations exists given that such may be used
%
tic;
MatFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-VAR-PredictiveMoments-' num2str(lambda,'%0.4f') '-' int2str(p) '-' int2str(PME) '-' DSGEModel.NameOfModel '-' SmpStr '-' int2str(CurrChain) '-' int2str(MaxFH) '.' int2str(UsedDraws) '-' int2str(NumPostDraws) '.mat']);
if (RecomputeMoments==0)&(FileExist(MatFile)==1);
   DoneCalc = 1;
else;
   %
   % compute the predictive moments
   %
   SetLogText(strvcat('Estimating the marginal predictive mean and covariance','for the observed variables using a DSGE-VAR',['lambda =         ' num2str(lambda,'%0.4f')],['Number of lags = ' int2str(p)],' '));
   DoneCalc = DSGEVARPredictiveMoments(PhiDraws,SigmaDraws,PhiMode,SigmaModeEpsilon,lambda,n,p,X,MaxFH,1,Weights,SmpStr,CurrChain,PME,DSGEModel,CurrINI,controls);
end;
clear('PhiDraws','SigmaDraws');
if DoneCalc==0;
   SetLogText('Aborting calculation.');
   CompTime = toc;
   return;
end;
%
% load the results
%
CompTime = toc;
SetLogText(['Computation time: ' SecondsToHoursStr(CompTime) ' (hrs:min:sec)']);
MPM = load(MatFile);
PredY = MPM.MeanPredictY;
n = DSGEModel.n;
CovPred = zeros(n,n,MaxFH);
for i=1:MaxFH;
   CovPred(:,:,i) = MPM.ShockCov(:,:,i)+MPM.ParameterCov(:,:,i);
end;
%
if (RecomputeMoments==0)&(isfield(MPM,'CovPred')==0);
   save(MatFile,'CovPred','PredictionSampleStrMat','-APPEND');
end;
if isfield(MPM,'YData')==0;
   save(MatFile,'YData','-APPEND');
end;
%
% write the results to log text and to file
%
ResFile = strrep(MatFile,'.mat','.txt');
PrintPredictiveMoments(ResFile,PredY,CovPred,PredictionSampleStrMat,[],[],[],lambda,UsedDraws,NumPostDraws,NumBurnin,1,0,0,CompTime,DSGEModel,CurrINI);
%
% write results to screen
%
if FileExist(ResFile)==1;
   PrtStr = ['%s%s   %10.4f   %10.4f'];
   VarLength = size(DSGEModel.VariableNames,2);
   if VarLength<15;
      AddStr = SpaceStr(15-VarLength);
   else;
      AddStr = '';
   end;
   FirstStr = MultiCharStr('=',42);
   DivStr = MultiCharStr('-',42);
   ResultsStr = '';
   for i=1:MaxFH;
      ResultsStr = strvcat(ResultsStr,FirstStr);
      ResultsStr = strvcat(ResultsStr,sprintf('Forecast period %1.0f: %s',i,PredictionSampleStrMat(i,:)));
      ResultsStr = strvcat(ResultsStr,'Variable              Mean      St. Dev.',DivStr);
      for j=1:DSGEModel.n;
         ResultsStr = strvcat(ResultsStr,sprintf(PrtStr,DSGEModel.VariableNames(j,:),AddStr,PredY(j,i),sqrt(CovPred(j,j,i))));
      end;
      ResultsStr = strvcat(ResultsStr,FirstStr,' ');
   end;
   SetLogText(strvcat(' ',ResultsStr,'Output written to:',['Text file: ' GetFilename(ResFile)],['Mat file:  ' GetFilename(MatFile)],['Directory: ' GetPath(ResFile)],' '));
   Status = 1;
end;

%
% end of SequentialPredictiveMomentsDSGEVAR.m
%
