function DSGEModel = ReadDSGEModel(ModelFile)
% ReadDSGEModel: Reads the saved DSGE model from a text file.
%
% USAGE:
%
%       DSGEModel = ReadDSGEModel(ModelFile,DSGEModel)
%
% REQUIRED INPUTS: ModelFile (string), with full path plus name of the DSGE model file to be read.
%
% REQUIRED OUTPUT: DSGEModel (structure), with fields containing the DSGE model information that
%                            is stored in the ModelFile
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2025 European Central Bank.
%
%                       First version: August 1, 2006.
%                        This version: January 9, 2025.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 02-08-2006: Added reading the AIMDataFile entry. Also, if first character of file and directory entries is equal
%               to \ or the entry is empty, then pwd is prepended to the string.
%
% * 09-08-2006: Added reading the "UseDoublingAlgorithm", "DAMaximumIterationsValue", "ShowProgress", and
%               "ShowProgressClock" entries.
%
% * 18-08-2006: Changed the StrTrim function to StringStrim.
%
% * 22-08-2006: Added the field "InitializeKalman".
%
% * 30-08-2006: Added the fields "OverwriteDraws", "MarginalLikelihoodValue", "SequentialStartIteration",
%               "SequentialStepLength", "SequentialML", "CoverageStart", "CoverageIncrement", and "CoverageEnd".
%
% * 31-10-2006: Added the fields "DAToleranceValue", "RiccatiMaxIterations", and "RiccatiToleranceValue".
%
% * 17-11-2006: Changed the default value of "UseDoublingAlgorithm" reflecting that the number of options have increased
%               when computing the initial state covariance matrix for the Kalman filter. The field "StateCovConst" was
%               also added.
%
% * 20-11-2006: Added the fields "UseOwnInitialState" and "InitialStateValues".
%
% * 28-11-2006: Added the fields "PosteriorDrawsValue", "SampleBatchValue", "ParallelChainsValue", "BurnInValue",
%               "MHInitialScaleFactor", "MHScaleFactor", and "RandomWeightValue".
%
% * 30-11-2006: Changed the default value of "MarginalLikelihoodValue" from 1 to 2. This means that by default only Geweke's
%               modified harmonic mean estimator is used.
%
% * 04-12-2006: Added the fields "ShockGroupNames" and "ShockGroups".
%
% * 07-12-2006: Added the fields "OptMaxIterationsValue", "OptToleranceValue", "MaximizeAlgorithmValue", "StepLengthHessian",
%               "NumberOfGridPoints", "FiniteDifferenceHessian", "CheckOptimum", "CheckTransformedOptimum", "GridWidth",
%               "IRHorizon", "PriorKernel", "KernelDensityValue", and "KernelDensityEstimator".
%
% * 15-12-2006: Added the field "PosteriorDensityValue".
%
% * 18-12-2006: Added the field "RandomNumberValue".
%
% * 21-12-2006: The ranges of "MHScaleFactor" and "MHInitialScaleFactor" were changed in YADAGUI.m. The default values of
%               the field entries therefore needed to be adjusted. The field "MaxForecastHorizon" was also added.
%
% * 22-12-2006: Added the field "FreqParameterReest".
%
% * 05-01-2007: Added the field "ShockGroupColors".
%
% * 11-01-2007: Added the fields "BVARLags", "HarmonicLagDecayValue", "CrossEqTightnessValue", "OverallTightnessValue",
%               "PriorType", "PriorLevelMeanValue", and "PriorDiffMeanValue".
%
% * 12-01-2007: Added the fields "OmegaPriorType", "WishartType", "VarianceTightnessValue", "WishartDFValue",
%               "SteadyStatePriorFile", "BVARY", and "BVARX".
%
% * 22-02-2007: Added the fields "NumPredPathsValue" and "PostDrawsUsageValue".
%
% * 26-02-2007: Added the field "RandomizeDraws".
%
% * 28-02-2007: Added the field "ConfidenceBandBaseColor".
%
% * 01-03-2007: Made sure that the "ConfidenceBandBaseColor" vector has dimension 1x3.
%
% * 08-03-2007: Added the fields "ConditionalShocks" and "ConditionalVariables".
%
% * 16-03-2007: Made sure that the fields "ConditionalShocks" and "ConditionalVariables" are row vectors.
%
% * 03-04-3007: Added the field "PostDrawsPercentValue".
%
% * 10-04-2007: Added the field "InverseHessianEstimator".
%
% * 16-04-2007: Added the field "MaxCorrelationValue".
%
% * 25-04-2007: Added the fields "ScenarioShocks", and "ScenarioVariables".
%
% * 26-04-2007: Added the fields "AnnScenarioValue" and "ScenarioValue".
%
% * 02-05-2007: Added the field "ScenarioParameters".
%
% * 03-05-2007: Added the field "PredictionEvent".
%
% * 04-05-2007: The field "PredictionEvent" should now hold a matrix with 3 columns.
%
% * 07-05-2007: Made sure that "PredictionEvent" has the correct dimension.
%
% * 23-08-2007: Added the field "AdjustPredictionPaths".
%
% * 28-09-2007: Added the field "ObsVariableScenarioFile".
%
% * 25-10-2007: The field "FreqParameterReest" is no longer supported.
%
% * 26-10-2007: Added the field "ParameterScenario".
%
% * 31-10-2007: Added the field "OVSComparisonFile".
%
% * 06-11-2007: Updated the documentation.
%
% * 17-12-2007: Added the field "ShockControlMethod".
%
% * 20-12-2007: Added the field "UnitRootStates".
%
% * 02-01-2008: Added the field "KalmanFirstObservation".
%
% * 22-01-2008: The field "OVSComparisonFile" is no longer supported.
%
% * 23-01-2008: The default value of "MaxForecastHorizon" is now 1.
%
% * 24-01-2008: Added the field "KsiUseCondData".
%
% * 31-01-2008: Added the fields "OrigScenarioVariables", "OrigScenarioShocks", "ShockColorStart", and "ShockColorEnd".
%
% * 18-02-2008: Added the field "ModifiedHessian".
%
% * 16-05-2008: Added the field "AIMTolerance".
%
% * 23-05-2008: Updated the documentation.
%
% * 26-05-2008: The "SequentialML" variable now has the default value 0. The "PostDrawsUsageValue" variabel now has
%               default value 1. The "MHInitialScaleFactor" variable now has default value 1.
%
% * 02-07-2008: Added the field "AllowUnitRoot".
%
% * 03-07-2008: Made sure that "SubBeginYear", "SubBeginPeriod", "SubEndYear", and "SubEndPeriod" by default are
%               equal to "BeginYear", "BeginPeriod", "EndYear", and "EndPeriod", respectively, when the information
%               is the dsge-file gives empty strings.
%
% * 28-07-2008: Added the field "ParameterScenarioValue".
%
% * 19-12-2008: Updated the documentation.
%
% * 29-01-2009: Added the field "InitializeHessian".
%
% * 12-02-2009: Added the field "ParameterCovMatrix".
%
% * 08-04-2009: The base directory for files and directories no longer need to be "pwd", but can be
%               determined from the path of the "ModelFile".
%
% * 14-04-2009: Added the fields "ScenarioStateValue" and "AnnScenarioStateValue".
%
% * 15-04-2009: Added the fields "StateScenarioShocks" and "StateScenarioVariables".
%
% * 14-07-2009: Added the fields "ZetaConditionalShocks" and "ZetaConditionalVariables".
%
% * 24-09-2009: Added the fields "ObsVarGroups", "ObsVarGroupNames", and "ObsVarGroupColors".
%
% * 09-11-2009: Added the field "PosteriorSampler".
%
% * 05-01-2010: Updated the documentation.
%
% * 26-01-2010: Added the field "DSGEVARShocks".
%
% * 08-03-2010: Added the fields "MarginalLambda" and "JointLambda".
%
% * 04-08-2010: Added the field "ConstrainedStateVariables".
%
% * 05-08-2010: Added the field "ConstrainedStateValue".
%
% * 14-12-2010: Added the fields "CsminwelExtraRuns", "ModelSolver" and "KalmanAlgorithm".
%
% * 04-01-2011: Updated the documentation.
%
% * 12-01-2011: Added some support for unix and mac paths.
%
% * 13-01-2011: The function now supports the BaseDir* values for unix and mac paths.
%
% * 28-01-2011: The code now applies "FixFilePath" to file-info stored in the dsge model file.
%
% * 21-03-2011: Added the fields "MixedConditionalShocks" and "ZetaMixedConditionalShocks".
%
% * 05-04-2011: Removed reading the "ShockColorStart" and "ShockColorEnd" variables. Replaced these
%               fields with "ShockColors". Added the field "ShockAliases".
%
% * 15-04-2011: Made sure that "ShockAliases" and "StateShockNames" have the same number of rows.
%
% * 05-07-2011: Made sure that "MaximizeAlgorithmValue" can deal with the newly supported values.
%
% * 06-07-2011: Fixed a bug with "MaximizeAlgorithmValue" such that it is read from disk before the
%               code checks if the value is valid.
%
% * 07-07-2011: Changed the upper bound for "MaximizeAlgorithmValue" from 2 to 4 since newrat has
%               been added.
%
% * 12-07-2011: Changed the upper bound for "MaximizeAlgorithmValue" to 6 with gmhmaxlike on board.
%
% * 17-10-2011: Made sure that diffuse initialization of the state variable covariance matrix method
%               can't be selected with the square-root filter.
%
% * 18-10-2011: Reverted the last change. These methods should be able to work together.
%
% % 15-12-2011: Added the field "MonteCarloFilterDraws".
%
% * 03-01-2012: Updated the documentation.
%
% * 09-02-2012: Added the field "StationaryVAR".
%
% * 22-03-2012: Added the field "PredictionVariables".
%
% * 05-06-2012: Added the field "StateEquationPositions".
%
% * 20-08-2012: Added the field "ConfidenceRegionMethod".
%
% * 24-08-2012: Fixed a bug when reading "ConfidenceRegioMethod".
%
% * 02-01-2013: Updated the documentation.
%
% * 30-04-2013: Took into account that Sims' gensys is now the default model solver.
%
% * 28-08-2013: Added the fields "PosteriorDraws" and "BurnIn" to allow for user selected number of posterior draws
%               and number of burnin draws.
%
% * 24-01-2014: Updated the documentation.
%
% * 18-08-2014: Added the fields "RhatPosition" and "ZLBSampleT".
%
% * 26-08-2014: Added the field "REqPosition".
%
% * 04-09-2014: Added the field "AdditionalDraws".
%
% * 11-09-2014: Changed the field "RhatPosition" to "RtildePosition".
%
% * 15-09-2014: Updated the documentation.
%
% * 05-01-2015: Updated the documentation.
%
% * 24-08-2015: Added the field "StudenttDegFree".
%
% * 20-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
% * 01-04-2017: Added the field "FixedNumParamBlocks".
%
% * 13-04-2017: Added the field "BlockSize".
%
% * 12-05-2017: Added the field "SystemPriorFile".
%
% * 10-08-2017: Added the fields "TemperingStagesValue" and "TemperingLambdaValue".
%
% * 11-08-2017: Added the fields "NumParamBlocks", "MixedDistWeightValue", "SMCInitialScaleFactor",
%               "TargetAcceptanceRateValue", and "ResamplingAlgorithm".
%
% * 15-08-2017: Added the field "SMCNumMHSteps".
%
% * 08-01-2018: Updated the documentation.
%
% * 30-07-2018: Added the fields "ModelSolverFile" and "BaseDirModelSolverFile".
%
% * 29-08-2018: Updated the documentation.
%
% * 30-11-2018: Added the fields "ISMaxMixCompValue", "ISInitialDF", "ISWeightShareValue",
%               "ISAddedMixWeightValue", and "ISAddedDF".
%
% * 13-12-2018: Added the field "CoVToleranceValue".
%
% * 21-01-2019: Updated the documentation.
%
% * 10-12-2019: Added the field "StateEquationNames".
%
% * 07-01-2020: Updated the documentation.
%
% * 06-03-2020: Added the fields "BeliefSystem", "BeliefSystemFile", "BaseDirBeliefSystemFile",
%               "ForwardVariablePositions" and "ForwardVariableNames".
%
% * 10-03-2020: Added the fields "BeliefPriorFile", "BeliefPriorFileSheet" and "BaseDirBeliefPriorFile".
%
% * 08-05-2020: Added the field "NonCentralGLSMatrix".
%
% * 11-05-2020: Added the field "NoSmoothedStatesForBeliefs".
%
% * 02-07-2020: Removed the field "NonCentralGLSMatrix".
%
% * 03-07-2020: Added the field "FixedBeliefsForProj".
%
% * 25-01-2021: Updated the documentation.
%
% * 28-01-2021: Added the fields "AdaptiveLearningModelSolverFile" and "BaseDirAdaptiveLearningModelSolverFile".
%
% * 23-02-2021: Added the fields "TargetVariablePosition", "TargetShockValue" and "TargetEqPosition".
%
% * 11-03-2021: Added the field "ResponseDenominatorPosition".
%
% * 30-08-2021: Added the fields "DSGEImportIVFile", "ALDSGEImportIVFile", "DSGEVARMargImportIVFile",
%               "DSGEVARImportIVFile" and the corresponding "BaseDir" fields.
%
% * 04-01-2022: Updated the documentation.
%
% * 13-01-2022: Added the field "ShowEstimationLog".
%
% * 10-02-2022: Changed the default value of RunInitializeFirst to 1.
%
% * 17-02-2022: Made sure that DSGEModel.NumPredPathsValue cannot exceed 185 so that 1 prediction path is
%               no longer supported.
%
% * 23-11-2022: Added the fields "DynarePath", "BaseDirDynareModelFile" and "DynareModelFile".
%
% * 30-11-2022: Removed the field "DynarePath".
%
% * 03-01-2023: Updated the documentation.
%
% * 23-01-2023: Added the field "DriverFunctions".
%
% * 17-02-2023: Added the field "RunScriptFile" and removed "AdditionalDraws".
%
% * 05-10-2023: Added the field "MonteCarloFilterDrawsAL".
%
% * 23-11-2023: Added the field "ZLBRuleType".
%
% * 08-01-2024: Updated the documentation.
%
% * 09-01-2025: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% initialize some base directories
%
DSGEModel.BaseDirDataConstFile = pwd;
DSGEModel.BaseDirMeasureEqFile = pwd;
DSGEModel.BaseDirPriorFile = pwd;
DSGEModel.BaseDirSystemPriorFile = pwd;
DSGEModel.BaseDirUpdateParamFile = pwd;
DSGEModel.BaseDirInitParamFile = pwd;
DSGEModel.BaseDirAIMFile = pwd;
DSGEModel.BaseDirAIMDataFile = pwd;
DSGEModel.BaseDirBVARFile = pwd;
DSGEModel.BaseDirParamCovMatFile = pwd;
DSGEModel.BaseDirOutputDir = pwd;
DSGEModel.BaseDirModelSolverFile = pwd;
DSGEModel.BaseDirAdaptiveLearningModelSolverFile = pwd;
DSGEModel.BaseDirBeliefSystemFile = pwd;
DSGEModel.BaseDirBeliefPriorFile = pwd;
DSGEModel.BaseDirDSGEImportIVFile = pwd;
DSGEModel.BaseDirALDSGEImportIVFile = pwd;
DSGEModel.BaseDirDSGEVARMargImportIVFile = pwd;
DSGEModel.BaseDirDSGEVARImportIVFile = pwd;
DSGEModel.BaseDirDynareModelFile = pwd;
%
% read the DSGE-model file
%
ModTxt = ReadText(ModelFile);
ModTxt = char(ModTxt);
%
% locate all the necessary entries
%
pos = LocateStr(ModTxt,'DataConstructionFile = ');
if pos>0;
   DSGEModel.DataConstructionFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'DataConstructionFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.DataConstructionFile)==1)|(strcmp(DSGEModel.DataConstructionFile(1,1),'\')==1));
      %
      % check if data construction file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.DataConstructionFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.DataConstructionFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.DataConstructionFile])==1;
         DSGEModel.BaseDirDataConstFile = BaseDir;
         DSGEModel.DataConstructionFile = [BaseDir DSGEModel.DataConstructionFile];
      else;
         DSGEModel.DataConstructionFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.DataConstructionFile)==1)|(FileExist(DSGEModel.DataConstructionFile)==0));
      %
      % check if data construction file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.DataConstructionFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.DataConstructionFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.DataConstructionFile])==1;
         DSGEModel.BaseDirDataConstFile = BaseDir;
         DSGEModel.DataConstructionFile = [BaseDir DSGEModel.DataConstructionFile];
      else;
         DSGEModel.DataConstructionFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.DataConstructionFile)==0;
         DSGEModel.DataConstructionFile = pwd;
      end;
   end;
else;
   DSGEModel.DataConstructionFile = pwd;
end;
%
pos = LocateStr(ModTxt,'MeasurementEquationFile = ');
if pos>0;
   DSGEModel.MeasurementEquationFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'MeasurementEquationFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.MeasurementEquationFile)==1)|(strcmp(DSGEModel.MeasurementEquationFile(1,1),'\')==1));
      %
      % check if measurement equation relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.MeasurementEquationFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.MeasurementEquationFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.MeasurementEquationFile])==1;
         DSGEModel.BaseDirMeasureEqFile = BaseDir;
         DSGEModel.MeasurementEquationFile = [BaseDir DSGEModel.MeasurementEquationFile];
      else;
         DSGEModel.MeasurementEquationFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.MeasurementEquationFile)==1)|(FileExist(DSGEModel.MeasurementEquationFile)==0));
      %
      % check if measurement equation relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.MeasurementEquationFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.MeasurementEquationFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.MeasurementEquationFile])==1;
         DSGEModel.BaseDirMeasureEqFile = BaseDir;
         DSGEModel.MeasurementEquationFile = [BaseDir DSGEModel.MeasurementEquationFile];
      else;
         DSGEModel.MeasurementEquationFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.MeasurementEquationFile)==0;
         DSGEModel.MeasurementEquationFile = pwd;
      end;
   end;
else;
   DSGEModel.MeasurementEquationFile = pwd;
end;
%
pos = LocateStr(ModTxt,'PriorFile = ');
if pos>0;
   DSGEModel.PriorFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'PriorFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.PriorFile)==1)|(strcmp(DSGEModel.PriorFile(1,1),'\')==1));
      %
      % check if prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.PriorFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.PriorFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.PriorFile])==1;
         DSGEModel.BaseDirPriorFile = BaseDir;
         DSGEModel.PriorFile = [BaseDir DSGEModel.PriorFile];
      else;
         DSGEModel.PriorFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.PriorFile)==1)|(FileExist(DSGEModel.PriorFile)==0));
      %
      % check if prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.PriorFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.PriorFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.PriorFile])==1;
         DSGEModel.BaseDirPriorFile = BaseDir;
         DSGEModel.PriorFile = [BaseDir DSGEModel.PriorFile];
      else;
         DSGEModel.PriorFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.PriorFile)==0;
         DSGEModel.PriorFile = pwd;
      end;
   end;
else;
   DSGEModel.PriorFile = pwd;
end;
%
pos = LocateStr(ModTxt,'PriorFileSheet = ');
if pos>0;
   DSGEModel.PriorFileSheet = StringTrim(strrep(ModTxt(pos,:),'PriorFileSheet = ',''));
else;
   DSGEModel.PriorFileSheet = 'None';
end;
%
pos = LocateStr(ModTxt,'SystemPriorFile = ');
if pos>0;
   DSGEModel.SystemPriorFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'SystemPriorFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.SystemPriorFile)==1)|(strcmp(DSGEModel.SystemPriorFile(1,1),'\')==1));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.SystemPriorFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.SystemPriorFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.SystemPriorFile])==1;
         DSGEModel.BaseDirSystemPriorFile = BaseDir;
         DSGEModel.SystemPriorFile = [BaseDir DSGEModel.SystemPriorFile];
      else;
         DSGEModel.SystemPriorFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.SystemPriorFile)==1)|(FileExist(DSGEModel.SystemPriorFile)==0));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.SystemPriorFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.SystemPriorFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.SystemPriorFile])==1;
         DSGEModel.BaseDirSystemPriorFile = BaseDir;
         DSGEModel.SystemPriorFile = [BaseDir DSGEModel.SystemPriorFile];
      else;
         DSGEModel.SystemPriorFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.SystemPriorFile)==0;
         DSGEModel.SystemPriorFile = pwd;
      end;
   end;
else;
   DSGEModel.SystemPriorFile = pwd;
end;
%
pos = LocateStr(ModTxt,'UpdateParameterFile = ');
if pos>0;
   DSGEModel.UpdateParameterFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'UpdateParameterFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.UpdateParameterFile)==1)|(strcmp(DSGEModel.UpdateParameterFile(1,1),'\')==1));
      %
      % check if update parameter file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.UpdateParameterFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.UpdateParameterFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.UpdateParameterFile])==1;
         DSGEModel.BaseDirUpdateParamFile = BaseDir;
         DSGEModel.UpdateParameterFile = [BaseDir DSGEModel.UpdateParameterFile];
      else;
         DSGEModel.UpdateParameterFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.UpdateParameterFile)==1)|(FileExist(DSGEModel.UpdateParameterFile)==0));
      %
      % check if update parameter file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.UpdateParameterFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.UpdateParameterFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.UpdateParameterFile])==1;
         DSGEModel.BaseDirUpdateParamFile = BaseDir;
         DSGEModel.UpdateParameterFile = [BaseDir DSGEModel.UpdateParameterFile];
      else;
         DSGEModel.UpdateParameterFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.UpdateParameterFile)==0;
         DSGEModel.UpdateParameterFile = pwd;
      end;
   end;
else;
   DSGEModel.UpdateParameterFile = pwd;
end;
%
pos = LocateStr(ModTxt,'InitializeParameterFile = ');
if pos>0;
   DSGEModel.InitializeParameterFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'InitializeParameterFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.InitializeParameterFile)==1)|(strcmp(DSGEModel.InitializeParameterFile(1,1),'\')==1));
      %
      % check if initialize parameter file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.InitializeParameterFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.InitializeParameterFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.InitializeParameterFile])==1;
         DSGEModel.BaseDirInitParamFile = BaseDir;
         DSGEModel.InitializeParameterFile = [BaseDir DSGEModel.InitializeParameterFile];
      else;
         DSGEModel.InitializeParameterFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.InitializeParameterFile)==1)|(FileExist(DSGEModel.InitializeParameterFile)==0));
      %
      % check if initialize parameter file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.InitializeParameterFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.InitializeParameterFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.InitializeParameterFile])==1;
         DSGEModel.BaseDirInitParamFile = BaseDir;
         DSGEModel.InitializeParameterFile = [BaseDir DSGEModel.InitializeParameterFile];
      else;
         DSGEModel.InitializeParameterFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.InitializeParameterFile)==0;
         DSGEModel.InitializeParameterFile = pwd;
      end;
   end;
else;
   DSGEModel.InitializeParameterFile = pwd;
end;
%
pos = LocateStr(ModTxt,'AIMFile = ');
if pos>0;
   DSGEModel.AIMFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'AIMFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.AIMFile)==1)|(strcmp(DSGEModel.AIMFile(1,1),'\')==1));
      %
      % check if AIM file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.AIMFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.AIMFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.AIMFile])==1;
         DSGEModel.BaseDirAIMFile = BaseDir;
         DSGEModel.AIMFile = [BaseDir DSGEModel.AIMFile];
      else;
         DSGEModel.AIMFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.AIMFile)==1)|(FileExist(DSGEModel.AIMFile)==0));
      %
      % check if AIM file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.AIMFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.AIMFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.AIMFile])==1;
         DSGEModel.BaseDirAIMFile = BaseDir;
         DSGEModel.AIMFile = [BaseDir DSGEModel.AIMFile];
      else;
         DSGEModel.AIMFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.AIMFile)==0;
         DSGEModel.AIMFile = pwd;
      end;
   end;
else;
   DSGEModel.AIMFile = pwd;
end;
pos = LocateStr(ModTxt,'AIMDataFile = ');
if pos>0;
   DSGEModel.AIMDataFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'AIMDataFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.AIMDataFile)==1)|(strcmp(DSGEModel.AIMDataFile(1,1),'\')==1));
      %
      % check if AIMData file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.AIMDataFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.AIMDataFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.AIMDataFile])==1;
         DSGEModel.BaseDirAIMDataFile = BaseDir;
         DSGEModel.AIMDataFile = [BaseDir DSGEModel.AIMDataFile];
      else;
         DSGEModel.AIMDataFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.AIMDataFile)==1)|(FileExist(DSGEModel.AIMDataFile)==0));
      %
      % check if AIMData file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.AIMDataFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.AIMDataFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.AIMDataFile])==1;
         DSGEModel.BaseDirAIMDataFile = BaseDir;
         DSGEModel.AIMDataFile = [BaseDir DSGEModel.AIMDataFile];
      else;
         DSGEModel.AIMDataFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.AIMDataFile)==0;
         DSGEModel.AIMDataFile = pwd;
      end;
   end;
else;
   DSGEModel.AIMDataFile = pwd;
end;
%
pos = LocateStr(ModTxt,'BeliefSystemFile = ');
if pos>0;
   DSGEModel.BeliefSystemFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'BeliefSystemFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.BeliefSystemFile)==1)|(strcmp(DSGEModel.BeliefSystemFile(1,1),'\')==1));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.BeliefSystemFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.BeliefSystemFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.BeliefSystemFile])==1;
         DSGEModel.BaseDirBeliefSystemFile = BaseDir;
         DSGEModel.BeliefSystemFile = [BaseDir DSGEModel.BeliefSystemFile];
      else;
         DSGEModel.BeliefSystemFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.BeliefSystemFile)==1)|(FileExist(DSGEModel.BeliefSystemFile)==0));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.BeliefSystemFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.BeliefSystemFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.BeliefSystemFile])==1;
         DSGEModel.BaseDirBeliefSystemFile = BaseDir;
         DSGEModel.BeliefSystemFile = [BaseDir DSGEModel.BeliefSystemFile];
      else;
         DSGEModel.BeliefSystemFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.BeliefSystemFile)==0;
         DSGEModel.BeliefSystemFile = pwd;
      end;
   end;
else;
   DSGEModel.BeliefSystemFile = pwd;
end;
%
pos = LocateStr(ModTxt,'BeliefPriorFile = ');
if pos>0;
   DSGEModel.BeliefPriorFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'BeliefPriorFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.BeliefPriorFile)==1)|(strcmp(DSGEModel.BeliefPriorFile(1,1),'\')==1));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.BeliefPriorFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.BeliefPriorFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.BeliefPriorFile])==1;
         DSGEModel.BaseDirBeliefPriorFile = BaseDir;
         DSGEModel.BeliefPriorFile = [BaseDir DSGEModel.BeliefPriorFile];
      else;
         DSGEModel.BeliefPriorFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.BeliefPriorFile)==1)|(FileExist(DSGEModel.BeliefPriorFile)==0));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.BeliefPriorFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.BeliefPriorFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.BeliefPriorFile])==1;
         DSGEModel.BaseDirBeliefPriorFile = BaseDir;
         DSGEModel.BeliefPriorFile = [BaseDir DSGEModel.BeliefPriorFile];
      else;
         DSGEModel.BeliefPriorFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.BeliefPriorFile)==0;
         DSGEModel.BeliefPriorFile = pwd;
      end;
   end;
else;
   DSGEModel.BeliefPriorFile = pwd;
end;
%
pos = LocateStr(ModTxt,'BeliefPriorFileSheet = ');
if pos>0;
   DSGEModel.BeliefPriorFileSheet = StringTrim(strrep(ModTxt(pos,:),'BeliefPriorFileSheet = ',''));
else;
   DSGEModel.BeliefPriorFileSheet = 'None';
end;
%
pos = LocateStr(ModTxt,'DSGEImportIVFile = ');
if pos>0;
   DSGEModel.DSGEImportIVFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'DSGEImportIVFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.DSGEImportIVFile)==1)|(strcmp(DSGEModel.DSGEImportIVFile(1,1),'\')==1));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.DSGEImportIVFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.DSGEImportIVFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.DSGEImportIVFile])==1;
         DSGEModel.BaseDirDSGEImportIVFile = BaseDir;
         DSGEModel.DSGEImportIVFile = [BaseDir DSGEModel.DSGEImportIVFile];
      else;
         DSGEModel.DSGEImportIVFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.DSGEImportIVFile)==1)|(FileExist(DSGEModel.DSGEImportIVFile)==0));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.DSGEImportIVFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.DSGEImportIVFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.DSGEImportIVFile])==1;
         DSGEModel.BaseDirDSGEImportIVFile = BaseDir;
         DSGEModel.DSGEImportIVFile = [BaseDir DSGEModel.DSGEImportIVFile];
      else;
         DSGEModel.DSGEImportIVFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.DSGEImportIVFile)==0;
         DSGEModel.DSGEImportIVFile = pwd;
      end;
   end;
else;
   DSGEModel.DSGEImportIVFile = pwd;
end;
%
pos = LocateStr(ModTxt,'ALDSGEImportIVFile = ');
if pos>0;
   DSGEModel.ALDSGEImportIVFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'ALDSGEImportIVFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.ALDSGEImportIVFile)==1)|(strcmp(DSGEModel.ALDSGEImportIVFile(1,1),'\')==1));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.ALDSGEImportIVFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.ALDSGEImportIVFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.ALDSGEImportIVFile])==1;
         DSGEModel.BaseDirALDSGEImportIVFile = BaseDir;
         DSGEModel.ALDSGEImportIVFile = [BaseDir DSGEModel.ALDSGEImportIVFile];
      else;
         DSGEModel.ALDSGEImportIVFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.ALDSGEImportIVFile)==1)|(FileExist(DSGEModel.ALDSGEImportIVFile)==0));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.ALDSGEImportIVFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.ALDSGEImportIVFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.ALDSGEImportIVFile])==1;
         DSGEModel.BaseDirALDSGEImportIVFile = BaseDir;
         DSGEModel.ALDSGEImportIVFile = [BaseDir DSGEModel.ALDSGEImportIVFile];
      else;
         DSGEModel.ALDSGEImportIVFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.ALDSGEImportIVFile)==0;
         DSGEModel.ALDSGEImportIVFile = pwd;
      end;
   end;
else;
   DSGEModel.ALDSGEImportIVFile = pwd;
end;
%
pos = LocateStr(ModTxt,'DSGEVARMargImportIVFile = ');
if pos>0;
   DSGEModel.DSGEVARMargImportIVFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'DSGEVARMargImportIVFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.DSGEVARMargImportIVFile)==1)|(strcmp(DSGEModel.DSGEVARMargImportIVFile(1,1),'\')==1));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.DSGEVARMargImportIVFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.DSGEVARMargImportIVFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.DSGEVARMargImportIVFile])==1;
         DSGEModel.BaseDirDSGEVARMargImportIVFile = BaseDir;
         DSGEModel.DSGEVARMargImportIVFile = [BaseDir DSGEModel.DSGEVARMargImportIVFile];
      else;
         DSGEModel.DSGEVARMargImportIVFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.DSGEVARMargImportIVFile)==1)|(FileExist(DSGEModel.DSGEVARMargImportIVFile)==0));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.DSGEVARMargImportIVFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.DSGEVARMargImportIVFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.DSGEVARMargImportIVFile])==1;
         DSGEModel.BaseDirDSGEVARMargImportIVFile = BaseDir;
         DSGEModel.DSGEVARMargImportIVFile = [BaseDir DSGEModel.DSGEVARMargImportIVFile];
      else;
         DSGEModel.DSGEVARMargImportIVFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.DSGEVARMargImportIVFile)==0;
         DSGEModel.DSGEVARMargImportIVFile = pwd;
      end;
   end;
else;
   DSGEModel.DSGEImportIVFile = pwd;
end;
%
pos = LocateStr(ModTxt,'DSGEVARImportIVFile = ');
if pos>0;
   DSGEModel.DSGEVARImportIVFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'DSGEVARImportIVFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.DSGEVARImportIVFile)==1)|(strcmp(DSGEModel.DSGEVARImportIVFile(1,1),'\')==1));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.DSGEVARImportIVFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.DSGEVARImportIVFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.DSGEVARImportIVFile])==1;
         DSGEModel.BaseDirDSGEVARImportIVFile = BaseDir;
         DSGEModel.DSGEVARImportIVFile = [BaseDir DSGEModel.DSGEVARImportIVFile];
      else;
         DSGEModel.DSGEVARImportIVFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.DSGEVARImportIVFile)==1)|(FileExist(DSGEModel.DSGEVARImportIVFile)==0));
      %
      % check if system prior file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.DSGEVARImportIVFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.DSGEVARImportIVFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.DSGEVARImportIVFile])==1;
         DSGEModel.BaseDirDSGEVARImportIVFile = BaseDir;
         DSGEModel.DSGEVARImportIVFile = [BaseDir DSGEModel.DSGEVARImportIVFile];
      else;
         DSGEModel.DSGEVARImportIVFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.DSGEVARImportIVFile)==0;
         DSGEModel.DSGEVARImportIVFile = pwd;
      end;
   end;
else;
   DSGEModel.DSGEVARImportIVFile = pwd;
end;
%
pos = LocateStr(ModTxt,'DynareModelFile = ');
if pos>0;
   DSGEModel.DynareModelFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'DynareModelFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.DynareModelFile)==1)|(strcmp(DSGEModel.DynareModelFile(1,1),'\')==1));
      %
      % check if AIM file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.DynareModelFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.DynareModelFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.DynareModelFile])==1;
         DSGEModel.BaseDirDynareModelFile = BaseDir;
         DSGEModel.DynareModelFile = [BaseDir DSGEModel.DynareModelFile];
      else;
         DSGEModel.DynareModelFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.DynareModelFile)==1)|(FileExist(DSGEModel.DynareModelFile)==0));
      %
      % check if AIM file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.DynareModelFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.DynareModelFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.DynareModelFile])==1;
         DSGEModel.BaseDirDynareModelFile = BaseDir;
         DSGEModel.DynareModelFile = [BaseDir DSGEModel.DynareModelFile];
      else;
         DSGEModel.DynareModelFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.DynareModelFile)==0;
         DSGEModel.DynareModelFile = pwd;
      end;
   end;
else;
   DSGEModel.DynareModelFile = pwd;
end;
%
pos = LocateStr(ModTxt,'NameOfModel = ');
if pos>0;
   DSGEModel.NameOfModel = StringTrim(strrep(ModTxt(pos,:),'NameOfModel = ',''));
else;
   DSGEModel.NameOfModel = '';
end;
%
pos = LocateStr(ModTxt,'OutputDirectory = ');
if pos>0;
   DSGEModel.OutputDirectory = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'OutputDirectory = ','')));
   if (ispc==1)&((isempty(DSGEModel.OutputDirectory)==1)|(strcmp(DSGEModel.OutputDirectory(1,1),'\')==1));
      %
      % check if OutputDirectory file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.OutputDirectory,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if DirExist(FixFilePath([BaseDir DSGEModel.OutputDirectory]))==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if DirExist(FixFilePath([BaseDir DSGEModel.OutputDirectory]))==1;
         DSGEModel.BaseDirOutputDir = BaseDir;
         DSGEModel.OutputDirectory = FixFilePath([BaseDir DSGEModel.OutputDirectory]);
      else;
         DSGEModel.OutputDirectory = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.OutputDirectory)==1)|(DirExist(DSGEModel.OutputDirectory)==0));
      %
      % check if OutputDirectory relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.OutputDirectory,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if DirExist(FixFilePath([BaseDir DSGEModel.OutputDirectory]))==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if DirExist(FixFilePath([BaseDir DSGEModel.OutputDirectory]))==1;
         DSGEModel.BaseDirOutputDir = BaseDir;
         DSGEModel.OutputDirectory = FixFilePath([BaseDir DSGEModel.OutputDirectory]);
      else;
         DSGEModel.OutputDirectory = pwd;
      end;
   else;
      if DirExist(DSGEModel.OutputDirectory)==0;
         DSGEModel.OutputDirectory = pwd;
      end;
   end;
else;
   DSGEModel.OutputDirectory = pwd;
end;
%
pos = LocateStr(ModTxt,'StateShockNames = ');
if pos>0;
   StateShockNames = StringTrim(strrep(ModTxt(pos,:),'StateShockNames = ',''));
   DSGEModel.StateShockNames = Str2Matrix(StateShockNames,'$');
else;
   DSGEModel.StateShockNames = '';
end;
%
pos = LocateStr(ModTxt,'StateShockPositions = ');
if pos>0;
   DSGEModel.StateShockPositions = str2num(StringTrim(strrep(ModTxt(pos,:),'StateShockPositions = ','')));
else;
   DSGEModel.StateShockPositions = [];
end;
%
pos = LocateStr(ModTxt,'DSGEVARShocks = ');
if pos>0;
   DSGEModel.DSGEVARShocks = str2num(StringTrim(strrep(ModTxt(pos,:),'DSGEVARShocks = ','')));
else;
   DSGEModel.DSGEVARShocks = [];
end;
%
pos = LocateStr(ModTxt,'MarginalLambda = ');
if pos>0;
   DSGEModel.MarginalLambda = str2num(StringTrim(strrep(ModTxt(pos,:),'MarginalLambda = ','')));
else;
   DSGEModel.MarginalLambda = [];
end;
%
pos = LocateStr(ModTxt,'JointLambda = ');
if pos>0;
   DSGEModel.JointLambda = str2num(StringTrim(strrep(ModTxt(pos,:),'JointLambda = ','')));
else;
   DSGEModel.JointLambda = [];
end;
%
pos = LocateStr(ModTxt,'StateVariableNames = ');
if pos>0;
   StateVariableNames = StringTrim(strrep(ModTxt(pos,:),'StateVariableNames = ',''));
   DSGEModel.StateVariableNames = Str2Matrix(StateVariableNames,'$');
else;
   DSGEModel.StateVariableNames = '';
end;
%
pos = LocateStr(ModTxt,'StateVariablePositions = ');
if pos>0;
   DSGEModel.StateVariablePositions = str2num(StringTrim(strrep(ModTxt(pos,:),'StateVariablePositions = ','')));
else;
   DSGEModel.StateVariablePositions = [];
end;
%
pos = LocateStr(ModTxt,'StateEquationNames = ');
if pos>0;
   StateEquationNames = StringTrim(strrep(ModTxt(pos,:),'StateEquationNames = ',''));
   DSGEModel.StateEquationNames = Str2Matrix(StateEquationNames,'$');
else;
   DSGEModel.StateEquationNames = '';
end;
%
pos = LocateStr(ModTxt,'StateEquationPositions = ');
if pos>0;
   DSGEModel.StateEquationPositions = str2num(StringTrim(strrep(ModTxt(pos,:),'StateEquationPositions = ','')));
else;
   DSGEModel.StateEquationPositions = DSGEModel.StateVariablePositions;
end;
%
pos = LocateStr(ModTxt,'ForwardVariablePositions = ');
if pos>0;
   DSGEModel.ForwardVariablePositions = str2num(StringTrim(strrep(ModTxt(pos,:),'ForwardVariablePositions = ','')));
else;
   DSGEModel.ForwardVariablePositions = [];
end;
%
pos = LocateStr(ModTxt,'ForwardVariableNames = ');
if pos>0;
   ForwardVariableNames = StringTrim(strrep(ModTxt(pos,:),'ForwardVariableNames = ',''));
   DSGEModel.ForwardVariableNames = Str2Matrix(ForwardVariableNames,'$');
else;
   DSGEModel.ForwardVariableNames = '';
end;
%
pos = LocateStr(ModTxt,'DataFrequency = ');
if pos>0;
   DSGEModel.DataFrequency = StringTrim(strrep(ModTxt(pos,:),'DataFrequency = ',''));
else;
   DSGEModel.DataFrequency = '';
end;
%
pos = LocateStr(ModTxt,'BeginYear = ');
if pos>0;
   DSGEModel.BeginYear = StringTrim(strrep(ModTxt(pos,:),'BeginYear = ',''));
else;
   DSGEModel.BeginYear = '';
end;
%
pos = LocateStr(ModTxt,'BeginPeriod = ');
if pos>0;
   DSGEModel.BeginPeriod = StringTrim(strrep(ModTxt(pos,:),'BeginPeriod = ',''));
else;
   DSGEModel.BeginPeriod = '';
end;
%
pos = LocateStr(ModTxt,'EndYear = ');
if pos>0;
   DSGEModel.EndYear = StringTrim(strrep(ModTxt(pos,:),'EndYear = ',''));
else;
   DSGEModel.EndYear = '';
end;
%
pos = LocateStr(ModTxt,'EndPeriod = ');
if pos>0;
   DSGEModel.EndPeriod = StringTrim(strrep(ModTxt(pos,:),'EndPeriod = ',''));
else;
   DSGEModel.EndPeriod = '';
end;
%
pos = LocateStr(ModTxt,'SubBeginYear = ');
if pos>0;
   DSGEModel.SubBeginYear = StringTrim(strrep(ModTxt(pos,:),'SubBeginYear = ',''));
   if isempty(StringTrim(DSGEModel.SubBeginYear))==1;
      DSGEModel.SubBeginYear = DSGEModel.BeginYear;
   end;
else;
   DSGEModel.SubBeginYear = DSGEModel.BeginYear;
end;
%
pos = LocateStr(ModTxt,'SubBeginPeriod = ');
if pos>0;
   DSGEModel.SubBeginPeriod = StringTrim(strrep(ModTxt(pos,:),'SubBeginPeriod = ',''));
   if isempty(StringTrim(DSGEModel.SubBeginPeriod))==1;
      DSGEModel.SubBeginPeriod = DSGEModel.BeginPeriod;
   end;
else;
   DSGEModel.SubBeginPeriod = DSGEModel.BeginPeriod;
end;
%
pos = LocateStr(ModTxt,'SubEndYear = ');
if pos>0;
   DSGEModel.SubEndYear = StringTrim(strrep(ModTxt(pos,:),'SubEndYear = ',''));
   if isempty(StringTrim(DSGEModel.SubEndYear))==1;
      DSGEModel.SubEndYear = DSGEModel.EndYear;
   end;
else;
   DSGEModel.SubEndYear = DSGEModel.EndYear;
end;
%
pos = LocateStr(ModTxt,'SubEndPeriod = ');
if pos>0;
   DSGEModel.SubEndPeriod = StringTrim(strrep(ModTxt(pos,:),'SubEndPeriod = ',''));
   if isempty(StringTrim(DSGEModel.SubEndPeriod))==1;
      DSGEModel.SubEndPeriod = DSGEModel.EndPeriod;
   end;
else;
   DSGEModel.SubEndPeriod = DSGEModel.EndPeriod;
end;
%
pos = LocateStr(ModTxt,'RunInitializeFirst = ');
if pos>0;
   DSGEModel.RunInitializeFirst = str2num(StringTrim(strrep(ModTxt(pos,:),'RunInitializeFirst = ','')));
else;
   DSGEModel.RunInitializeFirst = 1;
end;
% ModelSolver
pos = LocateStr(ModTxt,'ModelSolver = ');
if pos>0;
   DSGEModel.ModelSolver = str2num(StringTrim(strrep(ModTxt(pos,:),'ModelSolver = ','')));
else;
   DSGEModel.ModelSolver = 3;
end;
% ModelSolverFile
pos = LocateStr(ModTxt,'ModelSolverFile = ');
if pos>0;
   DSGEModel.ModelSolverFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'ModelSolverFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.ModelSolverFile)==1)|(strcmp(DSGEModel.ModelSolverFile(1,1),'\')==1));
      %
      % check if the model solver file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.ModelSolverFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.ModelSolverFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.ModelSolverFile])==1;
         DSGEModel.BaseDirModelSolverFile = BaseDir;
         DSGEModel.ModelSolverFile = [BaseDir DSGEModel.ModelSolverFile];
      else;
         DSGEModel.ModelSolverFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.ModelSolverFile)==1)|(FileExist(DSGEModel.ModelSolverFile)==0));
      %
      % check if model solver file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.ModelSolverFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.ModelSolverFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.ModelSolverFile])==1;
         DSGEModel.BaseDirModelSolverFile = BaseDir;
         DSGEModel.ModelSolverFile = [BaseDir DSGEModel.ModelSolverFile];
      else;
         DSGEModel.ModelSolverFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.ModelSolverFile)==0;
         DSGEModel.ModelSolverFile = pwd;
      end;
   end;
else;
   DSGEModel.ModelSolverFile = pwd;
end;
% AdaptiveLearningModelSolverFile
pos = LocateStr(ModTxt,'AdaptiveLearningModelSolverFile = ');
if pos>0;
   DSGEModel.AdaptiveLearningModelSolverFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'AdaptiveLearningModelSolverFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.AdaptiveLearningModelSolverFile)==1)|(strcmp(DSGEModel.AdaptiveLearningModelSolverFile(1,1),'\')==1));
      %
      % check if the model solver file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.AdaptiveLearningModelSolverFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.AdaptiveLearningModelSolverFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.AdaptiveLearningModelSolverFile])==1;
         DSGEModel.BaseDirAdaptiveLearningModelSolverFile = BaseDir;
         DSGEModel.AdaptiveLearningModelSolverFile = [BaseDir DSGEModel.AdaptiveLearningModelSolverFile];
      else;
         DSGEModel.AdaptiveLearningModelSolverFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.AdaptiveLearningModelSolverFile)==1)|(FileExist(DSGEModel.AdaptiveLearningModelSolverFile)==0));
      %
      % check if model solver file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.AdaptiveLearningModelSolverFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.AdaptiveLearningModelSolverFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.AdaptiveLearningModelSolverFile])==1;
         DSGEModel.BaseDirAdaptiveLearningModelSolverFile = BaseDir;
         DSGEModel.AdaptiveLearningModelSolverFile = [BaseDir DSGEModel.AdaptiveLearningModelSolverFile];
      else;
         DSGEModel.AdaptiveLearningModelSolverFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.AdaptiveLearningModelSolverFile)==0;
         DSGEModel.AdaptiveLearningModelSolverFile = pwd;
      end;
   end;
else;
   DSGEModel.AdaptiveLearningModelSolverFile = pwd;
end;
% KalmanAlgorithm
pos = LocateStr(ModTxt,'KalmanAlgorithm = ');
if pos>0;
   DSGEModel.KalmanAlgorithm = str2num(StringTrim(strrep(ModTxt(pos,:),'KalmanAlgorithm = ','')));
else;
   DSGEModel.KalmanAlgorithm = 1;
end;
% CsminwelExtraRuns
pos = LocateStr(ModTxt,'CsminwelExtraRuns = ');
if pos>0;
   DSGEModel.CsminwelExtraRuns = str2num(StringTrim(strrep(ModTxt(pos,:),'CsminwelExtraRuns = ','')));
else;
   DSGEModel.CsminwelExtraRuns = 1;
end;
% UseDoublingAlgorithm
pos = LocateStr(ModTxt,'UseDoublingAlgorithm = ');
if pos>0;
   DSGEModel.UseDoublingAlgorithm = str2num(StringTrim(strrep(ModTxt(pos,:),'UseDoublingAlgorithm = ','')));
else;
   DSGEModel.UseDoublingAlgorithm = 2;
end;
% DAMaximumIterationsValue
pos = LocateStr(ModTxt,'DAMaximumIterationsValue = ');
if pos>0;
   DSGEModel.DAMaximumIterationsValue = str2num(StringTrim(strrep(ModTxt(pos,:),'DAMaximumIterationsValue = ','')));
else;
   DSGEModel.DAMaximumIterationsValue = 1;
end;
% ShowProgress
pos = LocateStr(ModTxt,'ShowProgress = ');
if pos>0;
   DSGEModel.ShowProgress = str2num(StringTrim(strrep(ModTxt(pos,:),'ShowProgress = ','')));
else;
   DSGEModel.ShowProgress = 1;
end;
% ShowProgressClock
pos = LocateStr(ModTxt,'ShowProgressClock = ');
if pos>0;
   DSGEModel.ShowProgressClock = str2num(StringTrim(strrep(ModTxt(pos,:),'ShowProgressClock = ','')));
else;
   DSGEModel.ShowProgressClock = 0;
end;
% InitializeKalman
pos = LocateStr(ModTxt,'InitializeKalman = ');
if pos>0;
   DSGEModel.InitializeKalman = str2num(StringTrim(strrep(ModTxt(pos,:),'InitializeKalman = ','')));
else;
   DSGEModel.InitializeKalman = 1;
end;
% KalmanFirstObservation
pos = LocateStr(ModTxt,'KalmanFirstObservation = ');
if pos>0;
   DSGEModel.KalmanFirstObservation = str2num(StringTrim(strrep(ModTxt(pos,:),'KalmanFirstObservation = ','')));
else;
   DSGEModel.KalmanFirstObservation = 1;
end;
% OverwriteDraws
pos = LocateStr(ModTxt,'OverwriteDraws = ');
if pos>0;
   DSGEModel.OverwriteDraws = str2num(StringTrim(strrep(ModTxt(pos,:),'OverwriteDraws = ','')));
else;
   DSGEModel.OverwriteDraws = 0;
end;
% MarginalLikelihoodValue
pos = LocateStr(ModTxt,'MarginalLikelihoodValue = ');
if pos>0;
   DSGEModel.MarginalLikelihoodValue = str2num(StringTrim(strrep(ModTxt(pos,:),'MarginalLikelihoodValue = ','')));
else;
   DSGEModel.MarginalLikelihoodValue = 2;
end;
% SequentialStartIteration
pos = LocateStr(ModTxt,'SequentialStartIteration = ');
if pos>0;
   DSGEModel.SequentialStartIteration = str2num(StringTrim(strrep(ModTxt(pos,:),'SequentialStartIteration = ','')));
else;
   DSGEModel.SequentialStartIteration = 4;
end;
% SequentialStepLength
pos = LocateStr(ModTxt,'SequentialStepLength = ');
if pos>0;
   DSGEModel.SequentialStepLength = str2num(StringTrim(strrep(ModTxt(pos,:),'SequentialStepLength = ','')));
else;
   DSGEModel.SequentialStepLength = 4;
end;
% SequentialML
pos = LocateStr(ModTxt,'SequentialML = ');
if pos>0;
   DSGEModel.SequentialML = str2num(StringTrim(strrep(ModTxt(pos,:),'SequentialML = ','')));
else;
   DSGEModel.SequentialML = 0;
end;
% CoverageStart
pos = LocateStr(ModTxt,'CoverageStart = ');
if pos>0;
   DSGEModel.CoverageStart = str2num(StringTrim(strrep(ModTxt(pos,:),'CoverageStart = ','')));
else;
   DSGEModel.CoverageStart = 2;
end;
% CoverageIncrement
pos = LocateStr(ModTxt,'CoverageIncrement = ');
if pos>0;
   DSGEModel.CoverageIncrement = str2num(StringTrim(strrep(ModTxt(pos,:),'CoverageIncrement = ','')));
else;
   DSGEModel.CoverageIncrement = 2;
end;
% CoverageEnd
pos = LocateStr(ModTxt,'CoverageEnd = ');
if pos>0;
   DSGEModel.CoverageEnd = str2num(StringTrim(strrep(ModTxt(pos,:),'CoverageEnd = ','')));
else;
   DSGEModel.CoverageEnd = 9;
end;
% DAToleranceValue
pos = LocateStr(ModTxt,'DAToleranceValue = ');
if pos>0;
   DSGEModel.DAToleranceValue = str2num(StringTrim(strrep(ModTxt(pos,:),'DAToleranceValue = ','')));
else;
   DSGEModel.DAToleranceValue = 7;
end;
% RiccatiMaxIterations
pos = LocateStr(ModTxt,'RiccatiMaxIterations = ');
if pos>0;
   DSGEModel.RiccatiMaxIterations = str2num(StringTrim(strrep(ModTxt(pos,:),'RiccatiMaxIterations = ','')));
else;
   DSGEModel.RiccatiMaxIterations = 10;
end;
% RiccatiToleranceValue
pos = LocateStr(ModTxt,'RiccatiToleranceValue = ');
if pos>0;
   DSGEModel.RiccatiToleranceValue = str2num(StringTrim(strrep(ModTxt(pos,:),'RiccatiToleranceValue = ','')));
else;
   DSGEModel.RiccatiToleranceValue = 7;
end;
% StateCovConst
pos = LocateStr(ModTxt,'StateCovConst = ');
if pos>0;
   DSGEModel.StateCovConst = str2num(StringTrim(strrep(ModTxt(pos,:),'StateCovConst = ','')));
else;
   DSGEModel.StateCovConst = 19;
end;
% UseOwnInitialState
pos = LocateStr(ModTxt,'UseOwnInitialState = ');
if pos>0;
   DSGEModel.UseOwnInitialState = str2num(StringTrim(strrep(ModTxt(pos,:),'UseOwnInitialState = ','')));
else;
   DSGEModel.UseOwnInitialState = 0;
end;
% InitialStateValues
pos = LocateStr(ModTxt,'InitialStateValues = ');
if pos>0;
   DSGEModel.InitialStateValues = str2num(StringTrim(strrep(ModTxt(pos,:),'InitialStateValues = ','')))';
else;
   DSGEModel.InitialStateValues = [];
end;
% PosteriorSampler
pos = LocateStr(ModTxt,'PosteriorSampler = ');
if pos>0;
   DSGEModel.PosteriorSampler = str2num(StringTrim(strrep(ModTxt(pos,:),'PosteriorSampler = ','')));
else;
   DSGEModel.PosteriorSampler = 1;
end;
% StudenttDegFree
pos = LocateStr(ModTxt,'StudenttDegFree = ');
if pos>0;
   DSGEModel.StudenttDegFree = str2num(StringTrim(strrep(ModTxt(pos,:),'StudenttDegFree = ','')));
else;
   DSGEModel.StudenttDegFree = [];
end;
% FixedNumParamBlocks
pos = LocateStr(ModTxt,'FixedNumParamBlocks = ');
if pos>0;
   DSGEModel.FixedNumParamBlocks = str2num(StringTrim(strrep(ModTxt(pos,:),'FixedNumParamBlocks = ','')));
else;
   DSGEModel.FixedNumParamBlocks = [];
end;
% BlockSize
pos = LocateStr(ModTxt,'BlockSize = ');
if pos>0;
   DSGEModel.BlockSize = str2num(StringTrim(strrep(ModTxt(pos,:),'BlockSize = ','')));
else;
   DSGEModel.BlockSize = [];
end;
% PosteriorDrawsValue
pos = LocateStr(ModTxt,'PosteriorDrawsValue = ');
if pos>0;
   DSGEModel.PosteriorDrawsValue = str2num(StringTrim(strrep(ModTxt(pos,:),'PosteriorDrawsValue = ','')));
else;
   DSGEModel.PosteriorDrawsValue = 1;
end;
% PosteriorDraws
pos = LocateStr(ModTxt,'PosteriorDraws = ');
if pos>0;
   DSGEModel.PosteriorDraws = str2num(StringTrim(strrep(ModTxt(pos,:),'PosteriorDraws = ','')));
else;
   DSGEModel.PosteriorDraws = [];
end;
% SampleBatchValue
pos = LocateStr(ModTxt,'SampleBatchValue = ');
if pos>0;
   DSGEModel.SampleBatchValue = str2num(StringTrim(strrep(ModTxt(pos,:),'SampleBatchValue = ','')));
else;
   DSGEModel.SampleBatchValue = 1;
end;
% ParallelChainsValue
pos = LocateStr(ModTxt,'ParallelChainsValue = ');
if pos>0;
   DSGEModel.ParallelChainsValue = str2num(StringTrim(strrep(ModTxt(pos,:),'ParallelChainsValue = ','')));
else;
   DSGEModel.ParallelChainsValue = 1;
end;
% BurnInValue
pos = LocateStr(ModTxt,'BurnInValue = ');
if pos>0;
   DSGEModel.BurnInValue = str2num(StringTrim(strrep(ModTxt(pos,:),'BurnInValue = ','')));
else;
   DSGEModel.BurnInValue = 1;
end;
% BurnIn
pos = LocateStr(ModTxt,'BurnIn = ');
if pos>0;
   DSGEModel.BurnIn = str2num(StringTrim(strrep(ModTxt(pos,:),'BurnIn = ','')));
else;
   DSGEModel.BurnIn = [];
end;
% MHInitialScaleFactor
pos = LocateStr(ModTxt,'MHInitialScaleFactor = ');
if pos>0;
   DSGEModel.MHInitialScaleFactor = str2num(StringTrim(strrep(ModTxt(pos,:),'MHInitialScaleFactor = ','')));
else;
   DSGEModel.MHInitialScaleFactor = 1;
end;
% MHScaleFactor
pos = LocateStr(ModTxt,'MHScaleFactor = ');
if pos>0;
   DSGEModel.MHScaleFactor = str2num(StringTrim(strrep(ModTxt(pos,:),'MHScaleFactor = ','')));
else;
   DSGEModel.MHScaleFactor = 26;
end;
% RandomWeightValue
pos = LocateStr(ModTxt,'RandomWeightValue = ');
if pos>0;
   DSGEModel.RandomWeightValue = str2num(StringTrim(strrep(ModTxt(pos,:),'RandomWeightValue = ','')));
else;
   DSGEModel.RandomWeightValue = 6;
end;
% ShockGroupNames
pos = LocateStr(ModTxt,'ShockGroupNames = ');
if pos>0;
   ShockGroupNames = StringTrim(strrep(ModTxt(pos,:),'ShockGroupNames = ',''));
   DSGEModel.ShockGroupNames = Str2Matrix(ShockGroupNames,'$');
else;
   DSGEModel.ShockGroupNames = '';
   if isempty(DSGEModel.StateShockNames)==0;
      DSGEModel.ShockGroupNames = DSGEModel.StateShockNames;
   end;
end;
% ShockGroups
pos = LocateStr(ModTxt,'ShockGroups = ');
if pos>0;
   DSGEModel.ShockGroups = str2num(StringTrim(strrep(ModTxt(pos,:),'ShockGroups = ','')));
else;
   DSGEModel.ShockGroups = [];
   if isempty(DSGEModel.StateShockPositions)==0;
      DSGEModel.ShockGroups = (1:length(DSGEModel.StateShockPositions));
   end;
end;
% OptMaxIterationsValue
pos = LocateStr(ModTxt,'OptMaxIterationsValue = ');
if pos>0;
   DSGEModel.OptMaxIterationsValue = str2num(StringTrim(strrep(ModTxt(pos,:),'OptMaxIterationsValue = ','')));
else;
   DSGEModel.OptMaxIterationsValue = 1;
end;
% OptToleranceValue
pos = LocateStr(ModTxt,'OptToleranceValue = ');
if pos>0;
   DSGEModel.OptToleranceValue = str2num(StringTrim(strrep(ModTxt(pos,:),'OptToleranceValue = ','')));
else;
   DSGEModel.OptToleranceValue = 4;
end;
% MaximizeAlgorithmValue
pos = LocateStr(ModTxt,'MaximizeAlgorithmValue = ');
if pos>0;
   DSGEModel.MaximizeAlgorithmValue = str2num(StringTrim(strrep(ModTxt(pos,:),'MaximizeAlgorithmValue = ','')));
   if (DSGEModel.MaximizeAlgorithmValue>6)&(FileExist(FixFilePath([pwd '\optim\fmin\matlab7\YADAfminunc7.m']))==0)&(FileExist(FixFilePath([pwd '\optim\fmin\matlab5\YADAfminunc5.m']))==0)&(FileExist(FixFilePath([pwd '\optim\fmin\matlab75\YADAfminunc7.m']))==0);
      DSGEModel.MaximizeAlgorithmValue = 1;
   end;
else;
   DSGEModel.MaximizeAlgorithmValue = 1;
end;
% StepLengthHessian
pos = LocateStr(ModTxt,'StepLengthHessian = ');
if pos>0;
   DSGEModel.StepLengthHessian = str2num(StringTrim(strrep(ModTxt(pos,:),'StepLengthHessian = ','')));
else;
   DSGEModel.StepLengthHessian = 12;
end;
% NumberOfGridPoints
pos = LocateStr(ModTxt,'NumberOfGridPoints = ');
if pos>0;
   DSGEModel.NumberOfGridPoints = str2num(StringTrim(strrep(ModTxt(pos,:),'NumberOfGridPoints = ','')));
else;
   DSGEModel.NumberOfGridPoints = 3;
end;
% FiniteDifferenceHessian
pos = LocateStr(ModTxt,'FiniteDifferenceHessian = ');
if pos>0;
   DSGEModel.FiniteDifferenceHessian = str2num(StringTrim(strrep(ModTxt(pos,:),'FiniteDifferenceHessian = ','')));
else;
   DSGEModel.FiniteDifferenceHessian = 0;
end;
% CheckOptimum
pos = LocateStr(ModTxt,'CheckOptimum = ');
if pos>0;
   DSGEModel.CheckOptimum = str2num(StringTrim(strrep(ModTxt(pos,:),'CheckOptimum = ','')));
else;
   DSGEModel.CheckOptimum = 1;
end;
% CheckTransformedOptimum
pos = LocateStr(ModTxt,'CheckTransformedOptimum = ');
if pos>0;
   DSGEModel.CheckTransformedOptimum = str2num(StringTrim(strrep(ModTxt(pos,:),'CheckTransformedOptimum = ','')));
else;
   DSGEModel.CheckTransformedOptimum = 1;
end;
% GridWidth
pos = LocateStr(ModTxt,'GridWidth = ');
if pos>0;
   DSGEModel.GridWidth = str2num(StringTrim(strrep(ModTxt(pos,:),'GridWidth = ','')));
else;
   DSGEModel.GridWidth = 4;
end;
% IRHorizon
pos = LocateStr(ModTxt,'IRHorizon = ');
if pos>0;
   DSGEModel.IRHorizon = str2num(StringTrim(strrep(ModTxt(pos,:),'IRHorizon = ','')));
else;
   DSGEModel.IRHorizon = 10;
end;
% ConfidenceRegionMethod
pos = LocateStr(ModTxt,'ConfidenceRegionMethod = ');
if pos>0;
   DSGEModel.ConfidenceRegionMethod = str2num(StringTrim(strrep(ModTxt(pos,:),'ConfidenceRegionMethod = ','')));
else;
   DSGEModel.ConfidenceRegionMethod = 1;
end;
% PriorKernel
pos = LocateStr(ModTxt,'PriorKernel = ');
if pos>0;
   DSGEModel.PriorKernel = str2num(StringTrim(strrep(ModTxt(pos,:),'PriorKernel = ','')));
else;
   DSGEModel.PriorKernel = 0;
end;
% KernelDensityValue
pos = LocateStr(ModTxt,'KernelDensityValue = ');
if pos>0;
   DSGEModel.KernelDensityValue = str2num(StringTrim(strrep(ModTxt(pos,:),'KernelDensityValue = ','')));
else;
   DSGEModel.KernelDensityValue = 2;
end;
% KernelDensityEstimator
pos = LocateStr(ModTxt,'KernelDensityEstimator = ');
if pos>0;
   DSGEModel.KernelDensityEstimator = StringTrim(strrep(ModTxt(pos,:),'KernelDensityEstimator = ',''));
else;
   DSGEModel.KernelDensityEstimator = 'kepan';
end;
% PosteriorDensityValue
pos = LocateStr(ModTxt,'PosteriorDensityValue = ');
if pos>0;
   DSGEModel.PosteriorDensityValue = str2num(StringTrim(strrep(ModTxt(pos,:),'PosteriorDensityValue = ','')));
else;
   DSGEModel.PosteriorDensityValue = 1;
end;
% RandomNumberValue
pos = LocateStr(ModTxt,'RandomNumberValue = ');
if pos>0;
   DSGEModel.RandomNumberValue = str2num(StringTrim(strrep(ModTxt(pos,:),'RandomNumberValue = ','')));
else;
   DSGEModel.RandomNumberValue = 0;
end;
% MaxForecastHorizon
pos = LocateStr(ModTxt,'MaxForecastHorizon = ');
if pos>0;
   DSGEModel.MaxForecastHorizon = str2num(StringTrim(strrep(ModTxt(pos,:),'MaxForecastHorizon = ','')));
else;
   DSGEModel.MaxForecastHorizon = 1;
end;
% ShockGroupColors
pos = LocateStr(ModTxt,'ShockGroupColors = ');
if pos>0;
   DSGEModel.ShockGroupColors = str2num(StringTrim(strrep(ModTxt(pos,:),'ShockGroupColors = ','')));
   %
   % transform this into a matrix if it is not empty
   %
   if isempty(DSGEModel.ShockGroupColors)==0;
      DSGEModel.ShockGroupColors = reshape(DSGEModel.ShockGroupColors,length(DSGEModel.ShockGroupColors)/3,3);
   end;
else;
   DSGEModel.ShockGroupColors = [];
end;
% ShockColors
pos = LocateStr(ModTxt,'ShockColors = ');
if pos>0;
   DSGEModel.ShockColors = str2num(StringTrim(strrep(ModTxt(pos,:),'ShockColors = ','')));
   %
   % transform this into a matrix if it is not empty
   %
   if isempty(DSGEModel.ShockColors)==0;
      DSGEModel.ShockColors = reshape(DSGEModel.ShockColors,length(DSGEModel.ShockColors)/3,3);
   end;
else;
   DSGEModel.ShockColors = [];
end;
% ShockAliases
pos = LocateStr(ModTxt,'ShockAliases = ');
if pos>0;
   ShockAliases = StringTrim(strrep(ModTxt(pos,:),'ShockAliases = ',''));
   DSGEModel.ShockAliases = Str2Matrix(ShockAliases,'$');
else;
   DSGEModel.ShockAliases = '';
   if isempty(DSGEModel.StateShockNames)==0;
      DSGEModel.ShockAliases = DSGEModel.StateShockNames;
   end;
end;
if size(DSGEModel.ShockAliases,1)~=size(DSGEModel.StateShockNames);
   DSGEModel.ShockAliases = DSGEModel.StateShockNames;
end;
% BVARLags
pos = LocateStr(ModTxt,'BVARLags = ');
if pos>0;
   DSGEModel.BVARLags = str2num(StringTrim(strrep(ModTxt(pos,:),'BVARLags = ','')));
else;
   DSGEModel.BVARLags = 4;
end;
% HarmonicLagDecayValue
pos = LocateStr(ModTxt,'HarmonicLagDecayValue = ');
if pos>0;
   DSGEModel.HarmonicLagDecayValue = str2num(StringTrim(strrep(ModTxt(pos,:),'HarmonicLagDecayValue = ','')));
else;
   DSGEModel.HarmonicLagDecayValue = 2;
end;
% CrossEqTightnessValue
pos = LocateStr(ModTxt,'CrossEqTightnessValue = ');
if pos>0;
   DSGEModel.CrossEqTightnessValue = str2num(StringTrim(strrep(ModTxt(pos,:),'CrossEqTightnessValue = ','')));
else;
   DSGEModel.CrossEqTightnessValue = 10;
end;
% OverallTightnessValue
pos = LocateStr(ModTxt,'OverallTightnessValue = ');
if pos>0;
   DSGEModel.OverallTightnessValue = str2num(StringTrim(strrep(ModTxt(pos,:),'OverallTightnessValue = ','')));
else;
   DSGEModel.OverallTightnessValue = 4;
end;
% PriorType
pos = LocateStr(ModTxt,'PriorType = ');
if pos>0;
   DSGEModel.PriorType = str2num(StringTrim(strrep(ModTxt(pos,:),'PriorType = ','')));
else;
   DSGEModel.PriorType = 1;
end;
% PriorLevelMeanValue
pos = LocateStr(ModTxt,'PriorLevelMeanValue = ');
if pos>0;
   DSGEModel.PriorLevelMeanValue = str2num(StringTrim(strrep(ModTxt(pos,:),'PriorLevelMeanValue = ','')));
else;
   DSGEModel.PriorLevelMeanValue = 1;
end;
% PriorDiffMeanValue
pos = LocateStr(ModTxt,'PriorDiffMeanValue = ');
if pos>0;
   DSGEModel.PriorDiffMeanValue = str2num(StringTrim(strrep(ModTxt(pos,:),'PriorDiffMeanValue = ','')));
else;
   DSGEModel.PriorDiffMeanValue = 1;
end;
% OmegaPriorType
pos = LocateStr(ModTxt,'OmegaPriorType = ');
if pos>0;
   DSGEModel.OmegaPriorType = str2num(StringTrim(strrep(ModTxt(pos,:),'OmegaPriorType = ','')));
else;
   DSGEModel.OmegaPriorType = 1;
end;
% WishartType
pos = LocateStr(ModTxt,'WishartType = ');
if pos>0;
   DSGEModel.WishartType = str2num(StringTrim(strrep(ModTxt(pos,:),'WishartType = ','')));
else;
   DSGEModel.WishartType = 1;
end;
% VarianceTightnessValue
pos = LocateStr(ModTxt,'VarianceTightnessValue = ');
if pos>0;
   DSGEModel.VarianceTightnessValue = str2num(StringTrim(strrep(ModTxt(pos,:),'VarianceTightnessValue = ','')));
else;
   DSGEModel.VarianceTightnessValue = 20;
end;
% WishartDFValue
pos = LocateStr(ModTxt,'WishartDFValue = ');
if pos>0;
   DSGEModel.WishartDFValue = str2num(StringTrim(strrep(ModTxt(pos,:),'WishartDFValue = ','')));
else;
   DSGEModel.WishartDFValue = 1;
end;
% SteadyStatePriorFile
pos = LocateStr(ModTxt,'SteadyStatePriorFile = ');
if pos>0;
   DSGEModel.SteadyStatePriorFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'SteadyStatePriorFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.SteadyStatePriorFile)==1)|(strcmp(DSGEModel.SteadyStatePriorFile(1,1),'\')==1));
      %
      % check if steady state file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.SteadyStatePriorFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.SteadyStatePriorFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.SteadyStatePriorFile])==1;
         DSGEModel.BaseDirBVARFile = BaseDir;
         DSGEModel.SteadyStatePriorFile = [BaseDir DSGEModel.SteadyStatePriorFile];
      else;
         DSGEModel.SteadyStatePriorFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.SteadyStatePriorFile)==1)|(FileExist(DSGEModel.SteadyStatePriorFile)==0));
      %
      % check if steady state file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.SteadyStatePriorFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.SteadyStatePriorFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.SteadyStatePriorFile])==1;
         DSGEModel.BaseDirBVARFile = BaseDir;
         DSGEModel.SteadyStatePriorFile = [BaseDir DSGEModel.SteadyStatePriorFile];
      else;
         DSGEModel.SteadyStatePriorFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.SteadyStatePriorFile)==0;
         DSGEModel.SteadyStatePriorFile = pwd;
      end;
   end;
else;
   DSGEModel.SteadyStatePriorFile = pwd;
end;
% BVARY
pos = LocateStr(ModTxt,'BVARY = ');
if pos>0;
   DSGEModel.BVARY = str2num(StringTrim(strrep(ModTxt(pos,:),'BVARY = ','')))';
else;
   DSGEModel.BVARY = [];
end;
% BVARX
pos = LocateStr(ModTxt,'BVARX = ');
if pos>0;
   DSGEModel.BVARX = str2num(StringTrim(strrep(ModTxt(pos,:),'BVARX = ','')))';
else;
   DSGEModel.BVARX = [];
end;
% NumPredPathsValue
pos = LocateStr(ModTxt,'NumPredPathsValue = ');
if pos>0;
   DSGEModel.NumPredPathsValue = str2num(StringTrim(strrep(ModTxt(pos,:),'NumPredPathsValue = ','')));
   if DSGEModel.NumPredPathsValue>185;
      DSGEModel.NumPredPathsValue = 1;
   end;
else;
   DSGEModel.NumPredPathsValue = 1;
end;
% PostDrawsUsageValue
pos = LocateStr(ModTxt,'PostDrawsUsageValue = ');
if pos>0;
   DSGEModel.PostDrawsUsageValue = str2num(StringTrim(strrep(ModTxt(pos,:),'PostDrawsUsageValue = ','')));
else;
   DSGEModel.PostDrawsUsageValue = 1;
end;
% RandomizeDraws
pos = LocateStr(ModTxt,'RandomizeDraws = ');
if pos>0;
   DSGEModel.RandomizeDraws = str2num(StringTrim(strrep(ModTxt(pos,:),'RandomizeDraws = ','')));
else;
   DSGEModel.RandomizeDraws = 0;
end;
% ConfidenceBandBaseColor
pos = LocateStr(ModTxt,'ConfidenceBandBaseColor = ');
if pos>0;
   DSGEModel.ConfidenceBandBaseColor = str2num(StringTrim(strrep(ModTxt(pos,:),'ConfidenceBandBaseColor = ','')))';
   if isempty(DSGEModel.ConfidenceBandBaseColor)==0;
      DSGEModel.ConfidenceBandBaseColor = reshape(DSGEModel.ConfidenceBandBaseColor,1,3);
   end;
else;
   DSGEModel.ConfidenceBandBaseColor = [1 1 1];
end;
% ConditionalShocks
pos = LocateStr(ModTxt,'ConditionalShocks = ');
if pos>0;
   DSGEModel.ConditionalShocks = str2num(StringTrim(strrep(ModTxt(pos,:),'ConditionalShocks = ','')));
else;
   DSGEModel.ConditionalShocks = [];
end;
% MixedConditionalShocks
pos = LocateStr(ModTxt,'MixedConditionalShocks = ');
if pos>0;
   DSGEModel.MixedConditionalShocks = str2num(StringTrim(strrep(ModTxt(pos,:),'MixedConditionalShocks = ','')));
else;
   DSGEModel.MixedConditionalShocks = [];
end;
% ConditionalVariables
pos = LocateStr(ModTxt,'ConditionalVariables = ');
if pos>0;
   DSGEModel.ConditionalVariables = str2num(StringTrim(strrep(ModTxt(pos,:),'ConditionalVariables = ','')));
else;
   DSGEModel.ConditionalVariables = [];
end;
% ZetaConditionalShocks
pos = LocateStr(ModTxt,'ZetaConditionalShocks = ');
if pos>0;
   DSGEModel.ZetaConditionalShocks = str2num(StringTrim(strrep(ModTxt(pos,:),'ZetaConditionalShocks = ','')));
else;
   DSGEModel.ZetaConditionalShocks = [];
end;
% ZetaMixedConditionalShocks
pos = LocateStr(ModTxt,'ZetaMixedConditionalShocks = ');
if pos>0;
   DSGEModel.ZetaMixedConditionalShocks = str2num(StringTrim(strrep(ModTxt(pos,:),'ZetaMixedConditionalShocks = ','')));
else;
   DSGEModel.ZetaMixedConditionalShocks = [];
end;
% ZetaConditionalVariables
pos = LocateStr(ModTxt,'ZetaConditionalVariables = ');
if pos>0;
   DSGEModel.ZetaConditionalVariables = str2num(StringTrim(strrep(ModTxt(pos,:),'ZetaConditionalVariables = ','')));
else;
   DSGEModel.ZetaConditionalVariables = [];
end;
% PostDrawsPercentValue
pos = LocateStr(ModTxt,'PostDrawsPercentValue = ');
if pos>0;
   DSGEModel.PostDrawsPercentValue = str2num(StringTrim(strrep(ModTxt(pos,:),'PostDrawsPercentValue = ','')));
else;
   DSGEModel.PostDrawsPercentValue = 109;
end;
% InverseHessianEstimator
pos = LocateStr(ModTxt,'InverseHessianEstimator = ');
if pos>0;
   DSGEModel.InverseHessianEstimator = str2num(StringTrim(strrep(ModTxt(pos,:),'InverseHessianEstimator = ','')));
else;
   DSGEModel.InverseHessianEstimator = 1;
end;
% MaxCorrelationValue
pos = LocateStr(ModTxt,'MaxCorrelationValue = ');
if pos>0;
   DSGEModel.MaxCorrelationValue = str2num(StringTrim(strrep(ModTxt(pos,:),'MaxCorrelationValue = ','')));
else;
   DSGEModel.MaxCorrelationValue = 1;
end;
% ScenarioShocks
pos = LocateStr(ModTxt,'ScenarioShocks = ');
if pos>0;
   DSGEModel.ScenarioShocks = str2num(StringTrim(strrep(ModTxt(pos,:),'ScenarioShocks = ','')));
else;
   DSGEModel.ScenarioShocks = [];
end;
% ScenarioVariables
pos = LocateStr(ModTxt,'ScenarioVariables = ');
if pos>0;
   DSGEModel.ScenarioVariables = str2num(StringTrim(strrep(ModTxt(pos,:),'ScenarioVariables = ','')));
else;
   DSGEModel.ScenarioVariables = [];
end;
%
% intializing "OrigScenarioVariables" and "OrigScenarioShocks"
%
DSGEModel.OrigScenarioVariables = DSGEModel.ScenarioVariables;
DSGEModel.OrigScenarioShocks = DSGEModel.ScenarioShocks;
% AnnScenarioValue
pos = LocateStr(ModTxt,'AnnScenarioValue = ');
if pos>0;
   DSGEModel.AnnScenarioValue = str2num(StringTrim(strrep(ModTxt(pos,:),'AnnScenarioValue = ','')));
else;
   DSGEModel.AnnScenarioValue = 1;
end;
% ScenarioValue
pos = LocateStr(ModTxt,'ScenarioValue = ');
if pos>0;
   DSGEModel.ScenarioValue = str2num(StringTrim(strrep(ModTxt(pos,:),'ScenarioValue = ','')));
else;
   DSGEModel.ScenarioValue = 1;
end;
% AnnScenarioStateValue
pos = LocateStr(ModTxt,'AnnScenarioStateValue = ');
if pos>0;
   DSGEModel.AnnScenarioStateValue = str2num(StringTrim(strrep(ModTxt(pos,:),'AnnScenarioStateValue = ','')));
else;
   DSGEModel.AnnScenarioStateValue = 1;
end;
% ConstrainedStateValue
pos = LocateStr(ModTxt,'ConstrainedStateValue = ');
if pos>0;
   DSGEModel.ConstrainedStateValue = str2num(StringTrim(strrep(ModTxt(pos,:),'ConstrainedStateValue = ','')));
else;
   DSGEModel.ConstrainedStateValue = 1;
end;
% ScenarioStateValue
pos = LocateStr(ModTxt,'ScenarioStateValue = ');
if pos>0;
   DSGEModel.ScenarioStateValue = str2num(StringTrim(strrep(ModTxt(pos,:),'ScenarioStateValue = ','')));
else;
   DSGEModel.ScenarioStateValue = 1;
end;
% StateScenarioShocks
pos = LocateStr(ModTxt,'StateScenarioShocks = ');
if pos>0;
   DSGEModel.StateScenarioShocks = str2num(StringTrim(strrep(ModTxt(pos,:),'StateScenarioShocks = ','')));
else;
   DSGEModel.StateScenarioShocks = [];
end;
% StateScenarioVariables
pos = LocateStr(ModTxt,'StateScenarioVariables = ');
if pos>0;
   DSGEModel.StateScenarioVariables = str2num(StringTrim(strrep(ModTxt(pos,:),'StateScenarioVariables = ','')));
else;
   DSGEModel.StateScenarioVariables = [];
end;
% ConstrainedStateVariables
pos = LocateStr(ModTxt,'ConstrainedStateVariables = ');
if pos>0;
   DSGEModel.ConstrainedStateVariables = str2num(StringTrim(strrep(ModTxt(pos,:),'ConstrainedStateVariables = ','')));
else;
   DSGEModel.ConstrainedStateVariables = [];
end;
% ScenarioParameters
pos = LocateStr(ModTxt,'ScenarioParameters = ');
if pos>0;
   DSGEModel.ScenarioParameters = str2num(StringTrim(strrep(ModTxt(pos,:),'ScenarioParameters = ','')));
else;
   DSGEModel.ScenarioParameters = [];
end;
% PredictionEvent
pos = LocateStr(ModTxt,'PredictionEvent = ');
if pos>0;
   DSGEModel.PredictionEvent = str2num(StringTrim(strrep(ModTxt(pos,:),'PredictionEvent = ','')));
   %
   % transform this into a matrix if it is not empty
   %
   if (isempty(DSGEModel.PredictionEvent)==0)&(IsInteger(length(DSGEModel.PredictionEvent)/3)==1);
      DSGEModel.PredictionEvent = reshape(DSGEModel.PredictionEvent,floor(length(DSGEModel.PredictionEvent)/3),3);
   else;
      DSGEModel.PredictionEvent = [];
   end;
else;
   DSGEModel.PredictionEvent = [];
end;
% AdjustPredictionPaths
pos = LocateStr(ModTxt,'AdjustPredictionPaths = ');
if pos>0;
   DSGEModel.AdjustPredictionPaths = str2num(StringTrim(strrep(ModTxt(pos,:),'AdjustPredictionPaths = ','')));
else;
   DSGEModel.AdjustPredictionPaths = 1;
end;
% KsiUseCondData
pos = LocateStr(ModTxt,'KsiUseCondData = ');
if pos>0;
   DSGEModel.KsiUseCondData = str2num(StringTrim(strrep(ModTxt(pos,:),'KsiUseCondData = ','')));
else;
   DSGEModel.KsiUseCondData = 0;
end;
% ObsVariableScenarioFile
pos = LocateStr(ModTxt,'ObsVariableScenarioFile = ');
if pos>0;
   DSGEModel.ObsVariableScenarioFile = StringTrim(strrep(ModTxt(pos,:),'ObsVariableScenarioFile = ',''));
else;
   DSGEModel.ObsVariableScenarioFile = '';
end;
% ParameterScenario
pos = LocateStr(ModTxt,'ParameterScenario = ');
if pos>0;
   DSGEModel.ParameterScenario = str2num(StringTrim(strrep(ModTxt(pos,:),'ParameterScenario = ','')));
else;
   DSGEModel.ParameterScenario = [];
end;
% ShockControlMethod
pos = LocateStr(ModTxt,'ShockControlMethod = ');
if pos>0;
   DSGEModel.ShockControlMethod = str2num(StringTrim(strrep(ModTxt(pos,:),'ShockControlMethod = ','')));
else;
   DSGEModel.ShockControlMethod = 1;
end;
% UnitRootStates
pos = LocateStr(ModTxt,'UnitRootStates = ');
if pos>0;
   DSGEModel.UnitRootStates = str2num(StringTrim(strrep(ModTxt(pos,:),'UnitRootStates = ','')));
else;
   DSGEModel.UnitRootStates = [];
end;
% ModifiedHessian
pos = LocateStr(ModTxt,'ModifiedHessian = ');
if pos>0;
   DSGEModel.ModifiedHessian = str2num(StringTrim(strrep(ModTxt(pos,:),'ModifiedHessian = ','')));
else;
   DSGEModel.ModifiedHessian = 0;
end;
% AIMTolerance
pos = LocateStr(ModTxt,'AIMTolerance = ');
if pos>0;
   DSGEModel.AIMTolerance = str2num(StringTrim(strrep(ModTxt(pos,:),'AIMTolerance = ','')));
else;
   DSGEModel.AIMTolerance = 6;
end;
% AllowUnitRoot
pos = LocateStr(ModTxt,'AllowUnitRoot = ');
if pos>0;
   DSGEModel.AllowUnitRoot = str2num(StringTrim(strrep(ModTxt(pos,:),'AllowUnitRoot = ','')));
else;
   DSGEModel.AllowUnitRoot = 0;
end;
% ParameterScenarioValue
pos = LocateStr(ModTxt,'ParameterScenarioValue = ');
if pos>0;
   DSGEModel.ParameterScenarioValue = str2num(StringTrim(strrep(ModTxt(pos,:),'ParameterScenarioValue = ','')));
else;
   DSGEModel.ParameterScenarioValue = 1;
end;
% InitializeHessian
pos = LocateStr(ModTxt,'InitializeHessian = ');
if pos>0;
   DSGEModel.InitializeHessian = str2num(StringTrim(strrep(ModTxt(pos,:),'InitializeHessian = ','')));
else;
   DSGEModel.InitializeHessian = 5;
end;
% ParameterCovMatrix
pos = LocateStr(ModTxt,'ParameterCovMatrix = ');
if pos>0;
   DSGEModel.ParameterCovMatrix = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'ParameterCovMatrix = ','')));
   if (ispc==1)&(strcmp(DSGEModel.ParameterCovMatrix(1,1),'\')==1);
      %
      % check if parameter cov matrix file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.ParameterCovMatrix,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.ParameterCovMatrix])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.ParameterCovMatrix])==1;
         DSGEModel.BaseDirParamCovMatFile = BaseDir;
         DSGEModel.ParameterCovMatrix = [BaseDir DSGEModel.ParameterCovMatrix];
      else;
         DSGEModel.ParameterCovMatrix = 'none';
      end;
   elseif (isunix==1)&(FileExist(DSGEModel.ParameterCovMatrix)==0);
      %
      % check if parameter cov matrix file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.ParameterCovMatrix,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.ParameterCovMatrix])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.ParameterCovMatrix])==1;
         DSGEModel.BaseDirParamCovMatFile = BaseDir;
         DSGEModel.ParameterCovMatrix = [BaseDir DSGEModel.ParameterCovMatrix];
      else;
         DSGEModel.ParameterCovMatrix = 'none';
      end;
   else;
      if FileExist(DSGEModel.ParameterCovMatrix)==0;
         DSGEModel.ParameterCovMatrix = 'none';
      end;
   end;
else;
   DSGEModel.ParameterCovMatrix = 'none';
end;
% ObsVarGroupNames
pos = LocateStr(ModTxt,'ObsVarGroupNames = ');
if pos>0;
   ObsVarGroupNames = StringTrim(strrep(ModTxt(pos,:),'ObsVarGroupNames = ',''));
   DSGEModel.ObsVarGroupNames = Str2Matrix(ObsVarGroupNames,'$');
else;
   DSGEModel.ObsVarGroupNames = '';
end;
% ObsVarGroups
pos = LocateStr(ModTxt,'ObsVarGroups = ');
if pos>0;
   DSGEModel.ObsVarGroups = str2num(StringTrim(strrep(ModTxt(pos,:),'ObsVarGroups = ','')));
else;
   DSGEModel.ObsVarGroups = [];
end;
% ObsVarGroupColors
pos = LocateStr(ModTxt,'ObsVarGroupColors = ');
if pos>0;
   DSGEModel.ObsVarGroupColors = str2num(StringTrim(strrep(ModTxt(pos,:),'ObsVarGroupColors = ','')));
   %
   % transform this into a matrix if it is not empty
   %
   if isempty(DSGEModel.ObsVarGroupColors)==0;
      DSGEModel.ObsVarGroupColors = reshape(DSGEModel.ObsVarGroupColors,length(DSGEModel.ObsVarGroupColors)/3,3);
   end;
else;
   DSGEModel.ObsVarGroupColors = [];
end;
% MonteCarloFilterDraws
pos = LocateStr(ModTxt,'MonteCarloFilterDraws = ');
if pos>0;
   DSGEModel.MonteCarloFilterDraws = str2num(StringTrim(strrep(ModTxt(pos,:),'MonteCarloFilterDraws = ','')));
else;
   DSGEModel.MonteCarloFilterDraws = 9;
end;
% MonteCarloFilterDrawsAL
pos = LocateStr(ModTxt,'MonteCarloFilterDrawsAL = ');
if pos>0;
   DSGEModel.MonteCarloFilterDrawsAL = str2num(StringTrim(strrep(ModTxt(pos,:),'MonteCarloFilterDrawsAL = ','')));
else;
   DSGEModel.MonteCarloFilterDrawsAL = 9;
end;
% StationaryVAR
pos = LocateStr(ModTxt,'StationaryVAR = ');
if pos>0;
   DSGEModel.StationaryVAR = str2num(StringTrim(strrep(ModTxt(pos,:),'StationaryVAR = ','')));
else;
   DSGEModel.StationaryVAR = 1;
end;
% PredictionVariables
pos = LocateStr(ModTxt,'PredictionVariables = ');
if pos>0;
   DSGEModel.PredictionVariables = str2num(StringTrim(strrep(ModTxt(pos,:),'PredictionVariables = ','')));
else;
   DSGEModel.PredictionVariables = [];
end;
% RhatPosition
pos = LocateStr(ModTxt,'RtildePosition = ');
if pos>0;
   DSGEModel.RtildePosition = str2num(StringTrim(strrep(ModTxt(pos,:),'RtildePosition = ','')));
else;
   DSGEModel.RtildePosition = [];
end;
% REqPosition
pos = LocateStr(ModTxt,'REqPosition = ');
if pos>0;
   DSGEModel.REqPosition = str2num(StringTrim(strrep(ModTxt(pos,:),'REqPosition = ','')));
else;
   DSGEModel.REqPosition = [];
end;
% ZLBSampleT
pos = LocateStr(ModTxt,'ZLBSampleT = ');
if pos>0;
   DSGEModel.ZLBSampleT = str2num(StringTrim(strrep(ModTxt(pos,:),'ZLBSampleT = ','')));
else;
   DSGEModel.ZLBSampleT = 100;
end;
% ZLBRuleType
pos = LocateStr(ModTxt,'ZLBRuleType = ');
if pos>0;
   DSGEModel.ZLBRuleType = str2num(StringTrim(strrep(ModTxt(pos,:),'ZLBRuleType = ','')));
else;
   DSGEModel.ZLBRuleType = 1;
end;
% TargetVariablePosition
pos = LocateStr(ModTxt,'TargetVariablePosition = ');
if pos>0;
   DSGEModel.TargetVariablePosition = str2num(StringTrim(strrep(ModTxt(pos,:),'TargetVariablePosition = ','')));
else;
   DSGEModel.TargetVariablePosition = [];
end;
% TargetEqPosition
pos = LocateStr(ModTxt,'TargetEqPosition = ');
if pos>0;
   DSGEModel.TargetEqPosition = str2num(StringTrim(strrep(ModTxt(pos,:),'TargetEqPosition = ','')));
else;
   DSGEModel.TargetEqPosition = [];
end;
% TargetShockValue
pos = LocateStr(ModTxt,'TargetShockValue = ');
if pos>0;
   DSGEModel.TargetShockValue = str2num(StringTrim(strrep(ModTxt(pos,:),'TargetShockValue = ','')));
else;
   DSGEModel.TargetShockValue = 0;
end;
% ResponseDenominatorPosition
pos = LocateStr(ModTxt,'ResponseDenominatorPosition = ');
if pos>0;
   DSGEModel.ResponseDenominatorPosition = str2num(StringTrim(strrep(ModTxt(pos,:),'ResponseDenominatorPosition = ','')));
else;
   DSGEModel.ResponseDenominatorPosition = [];
end;
% TemperingStagesValue
pos = LocateStr(ModTxt,'TemperingStagesValue = ');
if pos>0;
   DSGEModel.TemperingStagesValue = str2num(StringTrim(strrep(ModTxt(pos,:),'TemperingStagesValue = ','')));
else;
   DSGEModel.TemperingStagesValue = 1;
end;
% TemperingLambda
pos = LocateStr(ModTxt,'TemperingLambdaValue = ');
if pos>0;
   DSGEModel.TemperingLambdaValue = str2num(StringTrim(strrep(ModTxt(pos,:),'TemperingLambdaValue = ','')));
else;
   DSGEModel.TemperingLambdaValue = 11;
end;
% NumParamBlocks
pos = LocateStr(ModTxt,'NumParamBlocks = ');
if pos>0;
   DSGEModel.NumParamBlocks = str2num(StringTrim(strrep(ModTxt(pos,:),'NumParamBlocks = ','')));
else;
   DSGEModel.NumParamBlocks = 1;
end;
% MixedDistWeightValue
pos = LocateStr(ModTxt,'MixedDistWeightValue = ');
if pos>0;
   DSGEModel.MixedDistWeightValue = str2num(StringTrim(strrep(ModTxt(pos,:),'MixedDistWeightValue = ','')));
else;
   DSGEModel.MixedDistWeightValue = 9;
end;
% SMCInitialScaleFactor
pos = LocateStr(ModTxt,'SMCInitialScaleFactor = ');
if pos>0;
   DSGEModel.SMCInitialScaleFactor = str2num(StringTrim(strrep(ModTxt(pos,:),'SMCInitialScaleFactor = ','')));
else;
   DSGEModel.SMCInitialScaleFactor = 26;
end;
% TargetAcceptanceRateValue
pos = LocateStr(ModTxt,'TargetAcceptanceRateValue = ');
if pos>0;
   DSGEModel.TargetAcceptanceRateValue = str2num(StringTrim(strrep(ModTxt(pos,:),'TargetAcceptanceRateValue = ','')));
else;
   DSGEModel.TargetAcceptanceRateValue = 2;
end;
% ResamplingAlgorithm
pos = LocateStr(ModTxt,'ResamplingAlgorithm = ');
if pos>0;
   DSGEModel.ResamplingAlgorithm = str2num(StringTrim(strrep(ModTxt(pos,:),'ResamplingAlgorithm = ','')));
else;
   DSGEModel.ResamplingAlgorithm = 1;
end;
% SMCNumMHSteps
pos = LocateStr(ModTxt,'SMCNumMHSteps = ');
if pos>0;
   DSGEModel.SMCNumMHSteps = str2num(StringTrim(strrep(ModTxt(pos,:),'SMCNumMHSteps = ','')));
else;
   DSGEModel.SMCNumMHSteps = 1;
end;
% ISMaxMixCompValue
pos = LocateStr(ModTxt,'ISMaxMixCompValue = ');
if pos>0;
   DSGEModel.ISMaxMixCompValue = str2num(StringTrim(strrep(ModTxt(pos,:),'ISMaxMixCompValue = ','')));
else;
   DSGEModel.ISMaxMixCompValue = 4;
end;
% ISInitialDF
pos = LocateStr(ModTxt,'ISInitialDF = ');
if pos>0;
   DSGEModel.ISInitialDF = str2num(StringTrim(strrep(ModTxt(pos,:),'ISInitialDF = ','')));
else;
   DSGEModel.ISInitialDF = 1;
end;
% ISWeightShareValue
pos = LocateStr(ModTxt,'ISWeightShareValue = ');
if pos>0;
   DSGEModel.ISWeightShareValue = str2num(StringTrim(strrep(ModTxt(pos,:),'ISWeightShareValue = ','')));
else;
   DSGEModel.ISWeightShareValue = 10;
end;
% ISAddedMixWeightValue
pos = LocateStr(ModTxt,'ISAddedMixWeightValue = ');
if pos>0;
   DSGEModel.ISAddedMixWeightValue = str2num(StringTrim(strrep(ModTxt(pos,:),'ISAddedMixWeightValue = ','')));
else;
   DSGEModel.ISAddedMixWeightValue = 10;
end;
% ISAddedDF
pos = LocateStr(ModTxt,'ISAddedDF = ');
if pos>0;
   DSGEModel.ISAddedDF = str2num(StringTrim(strrep(ModTxt(pos,:),'ISAddedDF = ','')));
else;
   DSGEModel.ISAddedDF = 1;
end;
% CoVToleranceValue
pos = LocateStr(ModTxt,'CoVToleranceValue = ');
if pos>0;
   DSGEModel.CoVToleranceValue = str2num(StringTrim(strrep(ModTxt(pos,:),'CoVToleranceValue = ','')));
else;
   DSGEModel.CoVToleranceValue = 19;
end;
% BeliefSystem
pos = LocateStr(ModTxt,'BeliefSystem = ');
if pos>0;
   DSGEModel.BeliefSystem = str2num(StringTrim(strrep(ModTxt(pos,:),'BeliefSystem = ','')));
else;
   DSGEModel.BeliefSystem = 1;
end;
% NoSmoothedStatesForBeliefs
pos = LocateStr(ModTxt,'NoSmoothedStatesForBeliefs = ');
if pos>0;
   DSGEModel.NoSmoothedStatesForBeliefs = str2num(StringTrim(strrep(ModTxt(pos,:),'NoSmoothedStatesForBeliefs = ','')));
else;
   DSGEModel.NoSmoothedStatesForBeliefs = 0;
end;
% FixedBeliefsForProj
pos = LocateStr(ModTxt,'FixedBeliefsForProj = ');
if pos>0;
   DSGEModel.FixedBeliefsForProj = str2num(StringTrim(strrep(ModTxt(pos,:),'FixedBeliefsForProj = ','')));
else;
   DSGEModel.FixedBeliefsForProj = 1;
end;
% ShowEstimationLog
pos = LocateStr(ModTxt,'ShowEstimationLog = ');
if pos>0;
   DSGEModel.ShowEstimationLog = str2num(StringTrim(strrep(ModTxt(pos,:),'ShowEstimationLog = ','')));
else;
   DSGEModel.ShowEstimationLog = 1;
end;
% DriverFunctions
pos = LocateStr(ModTxt,'DriverFunctions = ');
if pos>0;
   DriverFunctions = StringTrim(strrep(ModTxt(pos,:),'DriverFunctions = ',''));
   DSGEModel.DriverFunctions = Str2Matrix(DriverFunctions,'*');
else;
   DSGEModel.DriverFunctions = '';
end;
% RunScriptFile
pos = LocateStr(ModTxt,'RunScriptFile = ');
if pos>0;
   DSGEModel.RunScriptFile = FixFilePath(StringTrim(strrep(ModTxt(pos,:),'RunScriptFile = ','')));
   if (ispc==1)&((isempty(DSGEModel.RunScriptFile)==1)|(strcmp(DSGEModel.RunScriptFile(1,1),'\')==1));
      %
      % check if RunScriptFile file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.RunScriptFile,'\');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>4)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.RunScriptFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.RunScriptFile])==1;
         DSGEModel.RunScriptFile = [BaseDir DSGEModel.RunScriptFile];
      else;
         DSGEModel.RunScriptFile = pwd;
      end;
   elseif (isunix==1)&((isempty(DSGEModel.RunScriptFile)==1)|(FileExist(DSGEModel.RunScriptFile)==0));
      %
      % check if AIM file relative path is part of the path for the model-file
      %
      RelativeDirs = Str2Matrix(DSGEModel.RunScriptFile,'/');
      if size(RelativeDirs,1)>=1;
         StrPos = findstr(ModelFile,StringTrim(RelativeDirs(1,:)));
      else;
         StrPos = 0;
      end;
      if (isempty(StrPos)==0)&(StrPos>2)&(StrPos<length(ModelFile));
         BaseDir = ModelFile(1:StrPos-2);
         if FileExist([BaseDir DSGEModel.RunScriptFile])==0;
            BaseDir = pwd;
         end;
      else;
         BaseDir = pwd;
      end;
      if FileExist([BaseDir DSGEModel.RunScriptFile])==1;
         DSGEModel.RunScriptFile = [BaseDir DSGEModel.RunScriptFile];
      else;
         DSGEModel.RunScriptFile = pwd;
      end;
   else;
      if FileExist(DSGEModel.RunScriptFile)==0;
         DSGEModel.RunScriptFile = pwd;
      end;
   end;
else;
   DSGEModel.RunScriptFile = pwd;
end;
%
% check if we should try to read the aim data file
%
if (isempty(DSGEModel.StateEquationNames)==1)&(isempty(DSGEModel.StateEquationPositions)==0);
   if FileExist(DSGEModel.AIMDataFile)==1;
      try;
         AIMData = load(DSGEModel.AIMDataFile);
      catch;
         AIMData = [];
      end;
      if isempty(AIMData)==0;
         DSGEModel.StateEquationNames = AIMData.eqname(DSGEModel.StateEquationPositions,:);
      end;
   end;
end;

%
% end of ReadDSGEModel.m
%
            