function controls = LearningMenuControls(maingui,controls)
% LearningMenuControls: Sets up the Learning menu.
%
% USAGE:
%
%       controls = LearningMenuControls(maingui,controls)
%
% REQUIRED INPUT:  maingui (handle) to YADA's main dialog.
%
%                  controls (structure) with handles to the controls on the YADA main dialog.
%
% REQUIRED OUTPUT: controls (structure) with handles to the controls on the YADA main dialog.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2025 European Central Bank.
%
%                       First version: March 5, 2020.
%                        This version: January 13, 2025.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 06-03-2020: Added control for selecting the forward looking variables.
%
% * 09-03-2020: Added control for selecting the prior for the belief system.
%
% * 11-03-2020: Added controls for Tools & View items, log-likelihood item, and the
%               DSGE Posterior Mode case.
%
% * 30-03-2020: Added control for the log-likelihood at initial values as well as for
%               estimating the posterior mode.
%
% * 02-04-2020: Added control for the log-likelihood at the posterior mode values, for
%               for displaying the posterior mode results and summary, and for estimating
%               the system prior mode.
%
% * 03-04-2020: Added a separator between the posterior mode and system prior mode estimation
%               controls. Added controls for plotting state variable and state shock estimates.
%
% * 06-04-2020: Added controls for plotting estimated belief coefficients.
%
% * 16-04-2020: Added controls for viewing the prior and the log Jacobian. Added controls for
%               plotting the belief coefficients at initial values and at DSGE posterior
%               mode values.
%
% * 17-04-2020: Added controls for displaying the state shocks at initial values and at the
%               DSGE posterior mode values. Added controls for observed variable decompositions
%               at posterior mode.
%
% * 21-04-2020: Fixed a typo of annualized. Added controls for observed variable decompositions
%               at the initial parameter values and at the DSGE posterior mode values.
%
% * 22-04-2020: Added controls for state variable decompositions at initial values, DSGE posterior
%               mode and posterior mode values.
%
% * 06-05-2020: Added controls for impulse responses for original data at initial values, DSGE
%               posterior mode values and posterior mode values.
%
% * 08-05-2020: Added the Options item with the subitem NonCentralGLSMatrix.
%
% * 11-05-2020: Added the Options subitem NoSmoothedStatesForBeliefs.
%
% * 14-05-2020: Added controls for laws of motion.
%
% * 15-05-2020: Added controls for measurement errors.
%
% * 18-05-2020: Added control for posterior sampling.
%
% * 27-05-2020: Added control for prior sampling, for viewing the posterior sampling summary
%               and for viewing raw plot of the posterior draws.
%
% * 28-05-2020: Added controls for viewing posterior densities, scatter plots of posterior
%               draws, and sequential marginal likelihood estimates.
%
% * 29-06-2020: Began adding controls for the unconditional predictive distributions.
%
% * 02-07-2020: Removed the field "NonCentralGLSMatrix" from DSGEModel. Continued adding
%               controls for the unconditional predictive distributions.
%
% * 03-07-2020: Finished adding fixed parameter based controls for the unconditional
%               predictive distribution.
%
% * 26-01-2021: Updated the documentation.
%
% * 28-01-2021: Added control for selecting a user-written model solver.
%
% * 08-02-2021: Added controls for checking the posterior mode, viewing the iterated parameter
%               estimates, and the prior distribution information.
%
% * 09-02-2021: Added controls for viewing the Laplace posterior densities and the posterior
%               mode surface.
%
% * 03-05-2021: Added control for computing the log predictive likelihood using posterior draws.
%
% * 14-05-2021: Added menu controls for computing the predictive moments and PIT functions.
%
% * 19-05-2021: Added controls for computing the unconditional predictive distribution using
%               the posterior draws.
%
% * 26-05-2021: Added controls for computing the CRPS using annualized data.
%
% * 04-08-2021: Added the import prior data function.
%
% * 06-01-2022: Updated the documentation.
%
% * 19-01-2022: Updated the documentation.
%
% * 05-01-2023: Updated the documentation.
%
% * 11-01-2023: Added controls for graphing persistence (largest eigenvalue of Ftilde).
%
% * 17-01-2023: Added variable scenario controls.
%
% * 13-02-2023: Added controls for viewing parameter values and the time domain
%               information matrix.
%
% * 14-02-2023: Added controls for the frequency domain information matrix.
%
% * 29-03-2023: Added the save inverse Hessian control.
%
% * 05-10-2023: Added controls for Monte Carlo Filtering.
%
% * 25-10-2023: Added controls for displaying the DSGE model eigenvalues.
%
% * 18-01-2024: Updated the documentation.
%
% * 22-02-2024: Added controls for computing the unconditional predictive distribution subject
%               to the ZLB using the posterior draws.
%
% * 06-03-2024: Added controls for computing the predictive likelihood and the CRPS/ES using the
%               unconditional predictive distribution subject to the ZLB with the posterior draws.
%
% * 08-03-2024: Added controls for computing the predictive likelihood and the CRPS/ES using the
%               unconditional predictive distribution subject to the ZLB with the prior draws.
%
% * 11-03-2024: Added controls for computing the unconditional predictive distribution using the
%               prior draws.
%
% * 13-03-2024: Added controls for the predictive likelihood for annualized data using the prior
%               and the posterior draws.
%
% * 14-03-2024: Added controls for the CRPS and ES using the prior draws.
%
% * 19-03-2024: Added control for the marginal predictive moments and pits using the prior draws.
%
% * 11-04-2024: Added controls for the conditional predictive distribution using the posterior mode.
%
% * 19-04-2024: Added controls for the modesty statistics using the posterior mode values.
%
% * 23-04-2024: Added controls for the conditional predictive distribution using the initial values
%               and the DSGE posterior mode values.
%
% * 24-04-2024: Added controls for the conditional predictive distribution and modesty statistics
%               using the posterior draws.
%
% * 31-05-2024: Added controls for the conditional predictive distribution and modesty statistics
%               using the prior draws.
%
% * 04-06-2024: Added controls for the predictive likelihood based on the conditional predictive
%               distribution.
%
% * 26-06-2024: Added controls for the steady-state belief coefficients.
%
% * 04-07-2024: Added controls for displaying the steady-state-space form.
%
% * 17-07-2024: Added controls for displaying the steady-state structural form.
%
% * 05-08-2024: Added controls for the marginal predictive moments using conditional forecasts.
%
% * 09-08-2024: Added controls for the PITs using conditional forecasts.
%
% * 28-08-2024: Added controls for the steady-state correlations for the time domain.
%
% * 24-10-2024: Added controls for writing RE-based PLM into m-file.
%
% * 26-11-2024: Added controls for unconditional forecasts subject to the ZLB for fixed parameters.
%
% * 29-11-2024: Added controls for conditional forecasts subject to the ZLB for fixed parameters.
%
% * 06-12-2024: Added controls for conditional forecasts subject to the ZLB for prior and posterior draws.
%
% * 09-01-2025: Updated the documentation.
%
% * 13-01-2025: Added controls for predictive likelihood and CRPS calculations for the conditional forecasts
%               subject to the ZLB for prior and posterior draws.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% Learning menu
%
controls.learningmenu = uimenu('Parent',maingui, ...
   'Label','&Learning', ...
   'Tag','LearningMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                      Set the forward looking variables                      %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.setforwardvariables = uimenu('Parent',controls.learningmenu, ...
   'Label','Set &Forward Variables...', ...
   'Callback','LearningMenuFunctions SetForwardLookingVariables', ...
   'Enable','off', ...
   'Tag','LearningForwardVariablesMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                       Write RE functional form to PLM                       %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.retoplm = uimenu('Parent',controls.learningmenu, ...
   'Label','&RE Solution -> Belief System...', ...
   'Callback','LearningMenuFunctions REtoPLM', ...
   'Enable','off', ...
   'Tag','LearningREtoPLMMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                           Belief system selection                           %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.belief.parent = uimenu('Parent',controls.learningmenu, ...
   'Label','&Select Belief System', ...
   'Enable','off', ...
   'Tag','LearningBeliefSystemParentMenu');
%
controls.learning.belief.default = uimenu('Parent',controls.learning.belief.parent, ...
   'Label','&Naive Belief System', ...
   'Callback','LearningMenuFunctions SetBeliefSystem', ...
   'Tag','LearningBeliefSystemDefaultMenu');
%
controls.learning.belief.userdefined = uimenu('Parent',controls.learning.belief.parent, ...
   'Label','&Select Belief System File ...', ...
   'Callback','LearningMenuFunctions SetBeliefSystem', ...
   'Tag','LearningBeliefSystemUserDefinedMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%             Prior distribution for the belief system parameters             %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.setbeliefpriorfile = uimenu('Parent',controls.learningmenu, ...
   'Label','&Belief Parameters Prior File...', ...
   'Callback','LearningMenuFunctions SetBeliefParametersPriorFile', ...
   'Enable','off', ...
   'Tag','LearningBeliefParametersPriorMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                                   Options                                   %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.options.parent = uimenu('Parent',controls.learningmenu, ...
   'Label','&Options', ...
   'Enable','off', ...
   'Tag','LearningOptionsParentMenu');
%
% change the boolean DSGEModel.NoSmoothedStatesForBeliefs
%
controls.learning.options.nosmoothedstatesforbeliefs = uimenu('Parent',controls.learning.options.parent, ...
   'Label','&No Smoothed States For Belief Kalman Filter', ...
   'Callback','LearningMenuFunctions NoSmoothedStatesForBeliefs', ...
   'Tag','LearningOptionsNoSmoothedStatesForBeliefsMenu');
%
% change the boolean DSGEModel.FixedBeliefsForProj
%
controls.learning.options.fixedbeliefsforproj = uimenu('Parent',controls.learning.options.parent, ...
   'Label','&Use Fixed Beliefs For Projections', ...
   'Callback','LearningMenuFunctions FixedBeliefsForProjections', ...
   'Tag','LearningOptionsFixedBeliefsForprojectionsMenu');
%
% import prior for adaptive learning posterior mode
%
controls.learning.options.importpriordata = uimenu('Parent',controls.learning.options.parent, ...
   'Label','&Import Prior Data...', ...
   'Separator','on', ...
   'Enable','off', ...
   'Callback','LearningMenuFunctions ImportPriorData', ...
   'Tag','LearningOptionsImportPriorDataMenu');
%
% Enable if DSGEModel.ModelSolver==4 and then set DSGEModel.AdaptiveLearningModelSolverFile
%
controls.learning.options.modelsolver = uimenu('Parent',controls.learning.options.parent, ...
   'Label','&Select Model Solver...', ...
   'Separator','on', ...
   'Enable','off', ...
   'Callback','LearningMenuFunctions ModelSolver', ...
   'Tag','LearningOptionsModelSolverMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                            Save inverse Hessian                             %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.saveinversehessian = uimenu('Parent',controls.learningmenu, ...
   'Label','Save Inverse &Hessian...', ...
   'Callback','LearningMenuFunctions SaveInverseHessian', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningSaveInverseHessianMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                          Posterior mode estimation                          %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.postmodemenu = uimenu('Parent',controls.learningmenu, ...
   'Label','&Estimate Posterior Mode...', ...
   'Callback','LearningMenuFunctions PosteriorModeEstimation', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningEstimatePosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                             Posterior sampling                              %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.posteriorsamplingmenu = uimenu('Parent',controls.learningmenu, ...
   'Label','&Posterior Sampling...', ...
   'Callback','LearningMenuFunctions PosteriorSampling', ...
   'Enable','off', ...
   'Tag','LearningPosteriorSamplingMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                               Prior sampling                                %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.priorsamplingmenu = uimenu('Parent',controls.learningmenu, ...
   'Label','Prior Sa&mpling...', ...
   'Callback','LearningMenuFunctions PriorSampling', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningPriorSamplingMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                        System prior mode estimation                         %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.systempriormodemenu = uimenu('Parent',controls.learningmenu, ...
   'Label','Estimate S&ystem Prior Mode...', ...
   'Callback','LearningMenuFunctions SystemPriorModeEstimation', ...
   'Enable','off', ...
   'Tag','LearningEstimateSystemPriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                                  View menu                                  %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.parent = uimenu('Parent',controls.learningmenu, ...
   'Label','&View', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningViewMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                           View prior information                            %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.priorinformation = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','Prior Distrib&ution Information...', ...
   'Callback','LearningMenuFunctions PriorInformation', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningViewPriorInformationMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
% Steady-state-space form menu %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.steadystatespaceform.parent = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','Steady-State-Space &Form', ...
   'Enable','on', ...
   'Separator','on', ...
   'Tag','AdaptiveLearningViewSteadyStateSpaceFormMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                              Parameter values                               %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.parametervalues.parent = uimenu('Parent',controls.learning.viewmenu.steadystatespaceform.parent, ...
   'Label','P&arameter Values', ...
   'Enable','on', ...
   'Tag','ParameterValuesParentMenu');
%
controls.learning.viewmenu.parametervalues.initialvalues = uimenu('Parent',controls.learning.viewmenu.parametervalues.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions ParameterValuesInitialValues', ...
   'Enable','off', ...
   'Tag','ParameterValuesInitialValuesMenu');
%
controls.learning.viewmenu.parametervalues.dsgemode = uimenu('Parent',controls.learning.viewmenu.parametervalues.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions ParameterValuesDSGEMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ParameterValuesDSGEPosteriorModeMenu');
%
controls.learning.viewmenu.parametervalues.postmode = uimenu('Parent',controls.learning.viewmenu.parametervalues.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions ParameterValuesPostMode', ...
   'Enable','off', ...
   'Tag','ParameterValuesPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                        Steady-state structural form                         %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.structuralform.parent = uimenu('Parent',controls.learning.viewmenu.steadystatespaceform.parent, ...
   'Label','Structural &Form', ...
   'Enable','on', ...
   'Tag','StructuralFormParentMenu');
%
controls.learning.viewmenu.structuralform.initialvalues = uimenu('Parent',controls.learning.viewmenu.structuralform.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions StructuralFormInitialValues', ...
   'Enable','off', ...
   'Tag','StructuralFormInitialValuesMenu');
%
controls.learning.viewmenu.structuralform.dsgemode = uimenu('Parent',controls.learning.viewmenu.structuralform.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions StructuralFormDSGEMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','StructuralFormDSGEPosteriorModeMenu');
%
controls.learning.viewmenu.structuralform.postmode = uimenu('Parent',controls.learning.viewmenu.structuralform.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions StructuralFormPostMode', ...
   'Enable','off', ...
   'Tag','StructuralFormPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                      Steady-state belief coefficients                       %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.beliefcoefficients.parent = uimenu('Parent',controls.learning.viewmenu.steadystatespaceform.parent, ...
   'Label','Steady-State &Belief Coefficients', ...
   'Enable','on', ...
   'Tag','SteadyStateBeliefCoefficientsParentMenu');
%
controls.learning.viewmenu.beliefcoefficients.initialvalues = uimenu('Parent',controls.learning.viewmenu.beliefcoefficients.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions SteadyStateBeliefCoefficientsInitialValues', ...
   'Enable','off', ...
   'Tag','SteadyStateBeliefCoefficientsInitialValuesMenu');
%
controls.learning.viewmenu.beliefcoefficients.dsgemode = uimenu('Parent',controls.learning.viewmenu.beliefcoefficients.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions SteadyStateBeliefCoefficientsDSGEMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','SteadyStateBeliefCoefficientsDSGEPosteriorModeMenu');
%
controls.learning.viewmenu.beliefcoefficients.postmode = uimenu('Parent',controls.learning.viewmenu.beliefcoefficients.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions SteadyStateBeliefCoefficientsPostMode', ...
   'Enable','off', ...
   'Tag','SteadyStateBeliefCoefficientsPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% initial values
%
controls.learning.viewmenu.steadystatespaceform.initialvalues = uimenu('Parent',controls.learning.viewmenu.steadystatespaceform.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions SteadyStateSpaceInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','SteadyStateSpaceInitialValuesMenu');
%
% DSGE posterior mode
%
controls.learning.viewmenu.steadystatespaceform.dsgemode = uimenu('Parent',controls.learning.viewmenu.steadystatespaceform.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions SteadyStateSpaceDSGEMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','SteadyStateSpaceDSGEPosteriorModeMenu');
%
% posterior mode
%
controls.learning.viewmenu.steadystatespaceform.postmode = uimenu('Parent',controls.learning.viewmenu.steadystatespaceform.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions SteadyStateSpacePostMode', ...
   'Enable','off', ...
   'Tag','SteadyStateSpacePosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                     Posterior mode summary and results                      %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.postmode.results = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','&Posterior Mode Results...', ...
   'Callback','LearningMenuFunctions PosteriorModeResults', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningPosteriorModeResultsMenu');
%
controls.learning.viewmenu.postmode.summary = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','Posterior &Mode Summary...', ...
   'Callback','LearningMenuFunctions PosteriorModeResults', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningPosteriorModeSummaryMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                         posterior sampling summary                          %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.postsamplesummary.parent = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','Posterior &Sampling Summary', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','AdaptiveLearningPostSampleSummaryMenu');
%
%
for i=1:10;
   ModHandle = uimenu('Parent',controls.learning.viewmenu.postsamplesummary.parent, ...
      'Label',['Chain ' int2str(i) '...'], ...
      'Callback','LearningMenuFunctions PostSampleSummary', ...
      'Enable','off', ...
      'UserData','', ...
      'Tag',['AdaptiveLearningPostSampleSummaryChain' int2str(i) 'Menu']);
   controls.learning.viewmenu.postsamplesummary = setfield(controls.learning.viewmenu.postsamplesummary,['chain' int2str(i)],ModHandle);
end;
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                         posterior plots - raw draws                         %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.postsample.rawplots.parent = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','Ra&w Posterior Draws', ...
   'Enable','on', ...
   'Tag','AdaptiveLearningPostSampleRawPlotsMenu');
%
controls.learning.viewmenu.postsample.rawplots.original = uimenu('Parent',controls.learning.viewmenu.postsample.rawplots.parent, ...
   'Label','&Original Parameters...', ...
   'Callback','LearningMenuFunctions RawPlots', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningPostSampleOriginalRawPlotsMenu');
%
controls.learning.viewmenu.postsample.rawplots.transformed = uimenu('Parent',controls.learning.viewmenu.postsample.rawplots.parent, ...
   'Label','&Transformed Parameters...', ...
   'Callback','LearningMenuFunctions RawPlots', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningPostSampleTransformedRawPlotsMenu');
%
controls.learning.viewmenu.postsample.rawplots.logpost = uimenu('Parent',controls.learning.viewmenu.postsample.rawplots.parent, ...
   'Label','&Log Posterior Kernel...', ...
   'Callback','LearningMenuFunctions RawPlots', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningLogPosteriorRawPlotsMenu');
%
controls.learning.viewmenu.postsample.rawplots.weights = uimenu('Parent',controls.learning.viewmenu.postsample.rawplots.parent, ...
   'Label','&Particle Weights...', ...
   'Callback','LearningMenuFunctions RawPlots', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningWeightsRawPlotsMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                        scatter plot posterior draws                         %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.postsample.scatterplots.parent = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','Scatt&er-Plot Posterior Draws', ...
   'Enable','on', ...
   'Tag','AdaptiveLearningPostSampleScatterPlotsMenu');
%
controls.learning.viewmenu.postsample.scatterplots.original = uimenu('Parent',controls.learning.viewmenu.postsample.scatterplots.parent, ...
   'Label','&Original Parameters...', ...
   'Callback','LearningMenuFunctions ScatterPlots', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningPostSampleOriginalScatterPlotsMenu');
%
controls.learning.viewmenu.postsample.scatterplots.transformed = uimenu('Parent',controls.learning.viewmenu.postsample.scatterplots.parent, ...
   'Label','&Transformed Parameters...', ...
   'Callback','LearningMenuFunctions ScatterPlots', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningPostSampleTransformedScatterPlotsMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                       marginal likelihood estimation                        %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.postsample.marglike = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','Se&quential Marginal Likelihood', ...
   'Enable','on', ...
   'Tag','AdaptiveLearningMargLikeMenu');
%
% Laplace approximation
%
controls.learning.viewmenu.postsample.laplace.parent = uimenu('Parent',controls.learning.viewmenu.postsample.marglike, ...
   'Label','&Laplace Approximation', ...
   'Enable','on', ...
   'Tag','AdaptiveLearningLaplaceMargLikeMenu');
%
% initial values
%
controls.learning.viewmenu.postsample.laplace.initialvalues = uimenu('Parent',controls.learning.viewmenu.postsample.laplace.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions LaplaceInitialValues', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningLaplaceMargLikeInitialValuesMenu');
%
% DSGE posterior mode
%
controls.learning.viewmenu.postsample.laplace.dsgemode = uimenu('Parent',controls.learning.viewmenu.postsample.laplace.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions LaplaceDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningLaplaceMargLikePosteriorModeMenu');
%
% posterior mode
%
controls.learning.viewmenu.postsample.laplace.postmode = uimenu('Parent',controls.learning.viewmenu.postsample.laplace.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions LaplacePostMode', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningLaplaceMargLikePosteriorModeMenu');
%
% Chib and Jeliazkov
%
controls.learning.viewmenu.postsample.chibjeliazkov = uimenu('Parent',controls.learning.viewmenu.postsample.marglike, ...
   'Label','&Chib and Jeliazkov...', ...
   'Callback','LearningMenuFunctions ChibJeliazkov', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningPostSampleCJMenu');
%
% Geweke's modified harmonic mean
%
controls.learning.viewmenu.postsample.mhm = uimenu('Parent',controls.learning.viewmenu.postsample.marglike, ...
   'Label','&Modified Harmonic Mean...', ...
   'Callback','LearningMenuFunctions ModifiedHarmonicMean', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningPostSampleMHMMenu');
%
% Sims, Waggoner and Zha
%
controls.learning.viewmenu.postsample.swz = uimenu('Parent',controls.learning.viewmenu.postsample.marglike, ...
   'Label','&Sims, Waggoner and Zha...', ...
   'Callback','LearningMenuFunctions TruncatedElliptical', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningPostSampleSWZMenu');
%




%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                             modesty statistics                              %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.modesty.parent = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','Modest&y Statistics', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','AdaptiveLearningModestyMenu');
%
% initial values
%
controls.learning.viewmenu.modesty.initialvalues = uimenu('Parent',controls.learning.viewmenu.modesty.parent, ...
      'Label','&Initial Values...', ...
      'Callback','LearningMenuFunctions ViewModestyStat', ...
      'Enable','off', ...
      'UserData','', ...
      'Tag','AdaptiveLearningModestyInitialValuesMenu');
%
% prior distribution
%
controls.learning.viewmenu.modesty.prior = uimenu('Parent',controls.learning.viewmenu.modesty.parent, ...
      'Label','P&rior Distribution...', ...
      'Callback','LearningMenuFunctions ViewModestyStat', ...
      'Enable','off', ...
      'UserData','', ...
      'Tag','AdaptiveLearningModestyPriorDistributionMenu');
%
% DSGE posterior mode
%
controls.learning.viewmenu.modesty.dsgemode = uimenu('Parent',controls.learning.viewmenu.modesty.parent, ...
      'Label','DSGE &Posterior Mode...', ...
      'Callback','LearningMenuFunctions ViewModestyStat', ...
      'Separator','on', ...
      'Enable','off', ...
      'UserData','', ...
      'Tag','AdaptiveLearningModestyDSGEPosteriorModeMenu');
%
% posterior mode
%
controls.learning.viewmenu.modesty.postmode = uimenu('Parent',controls.learning.viewmenu.modesty.parent, ...
      'Label','Posterior &Mode...', ...
      'Callback','LearningMenuFunctions ViewModestyStat', ...
      'Enable','off', ...
      'UserData','', ...
      'Tag','AdaptiveLearningModestyPosteriorModeMenu');
%
% posterior distribution
%
for i=1:10;
   ModHandle = uimenu('Parent',controls.learning.viewmenu.modesty.parent, ...
      'Label',['Chain &' int2str(i) '...'], ...
      'Callback','LearningMenuFunctions ViewModestyStat', ...
      'Enable','off', ...
      'UserData','', ...
      'Tag',['AdaptiveLearningChain' num2str(i,'%0.0f') 'Menu']);
   if i==1;
      set(ModHandle,'Separator','on');
   end;
   if i==10;
      set(ModHandle,'Label','Chain 1&0...');
   end;
   controls.learning.viewmenu.modesty = setfield(controls.learning.viewmenu.modesty,['chain' int2str(i)],ModHandle);
end;
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                        Iterated parameter estimates                         %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.iteratedparameters = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','&Iterated Parameter Estimates...', ...
   'Separator','on', ...
   'Callback','LearningMenuFunctions IteratedParameters', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningViewIteratedParameterEstimatesMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                          Check the posterior mode                           %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.checkposterior = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','Chec&k Posterior Mode...', ...
   'Callback','LearningMenuFunctions CheckPosteriorMode', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningViewCheckPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                         3D plots of posterior mode                          %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.threedeepostmode.parent = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','Posterior Mode Surfa&ce', ...
   'Enable','on', ...
   'Tag','AdaptiveLearningPosteriorModeSurfaceMenu');
%
controls.learning.viewmenu.threedeepostmode.original = uimenu('Parent',controls.learning.viewmenu.threedeepostmode.parent, ...
   'Label','&Original Parameters...', ...
   'Callback','LearningMenuFunctions ThreeDeePostMode', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningOriginalPosteriorModeSurfaceMenu');
%
controls.learning.viewmenu.threedeepostmode.transformed = uimenu('Parent',controls.learning.viewmenu.threedeepostmode.parent, ...
   'Label','&Transformed Parameters...', ...
   'Callback','LearningMenuFunctions ThreeDeePostMode', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningTransformedPosteriorModeSurfaceMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                   Laplace approximation of the posterior                    %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.viewlaplaceposterior = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','&Laplace Posterior Densities...', ...
   'Separator','on', ...
   'Callback','LearningMenuFunctions ViewLaplacePosterior', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningViewLaplacePosteriorMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                             Graph the posterior                             %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.viewposterior.parent = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','Pos&terior Densities', ...
   'Enable','on', ...
   'Tag','AdaptiveLearningViewPosteriorMenu');
%
controls.learning.viewmenu.viewposterior.marginal = uimenu('Parent',controls.learning.viewmenu.viewposterior.parent, ...
   'Label','&Marginal Posterior Densities...', ...
   'Callback','LearningMenuFunctions ViewPosterior', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningViewMarginalPosteriorMenu');
%
controls.learning.viewmenu.viewposterior.bivariate = uimenu('Parent',controls.learning.viewmenu.viewposterior.parent, ...
   'Label','&Bivariate Posterior Densities...', ...
   'Callback','LearningMenuFunctions ViewBivariatePosterior', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningViewBivariatePosteriorMenu');
%
controls.learning.viewmenu.viewposterior.correlations = uimenu('Parent',controls.learning.viewmenu.viewposterior.parent, ...
   'Label','&Posterior Correlations...', ...
   'Callback','LearningMenuFunctions PosteriorCorrelations', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','AdaptiveLearningViewPosteriorCorrelationsMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                        View Prior and log Jacobian                          %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.viewmenu.viewprior.parent = uimenu('Parent',controls.learning.viewmenu.parent, ...
   'Label','Prior and Log &Jacobian Value', ...
   'Enable','on', ...
   'Tag','ViewPriorValueMenu');
%
% initial values
%
controls.learning.viewmenu.viewprior.initialvalues = uimenu('Parent',controls.learning.viewmenu.viewprior.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions ViewPriorInitialValues', ...
   'Enable','off', ...
   'Tag','LearningViewPriorInitialValuesMenu');
%
% DSGE posterior mode values
%
controls.learning.viewmenu.viewprior.dsgemode = uimenu('Parent',controls.learning.viewmenu.viewprior.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions ViewPriorDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningViewPriorDSGEPosteriorModeMenu');
%
% posterior mode values
%
controls.learning.viewmenu.viewprior.postmode = uimenu('Parent',controls.learning.viewmenu.viewprior.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions ViewPriorPostMode', ...
   'Enable','off', ...
   'Tag','LearningViewPriorPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                                 Tools menu                                  %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learning.toolsmenu.parent = uimenu('Parent',controls.learningmenu, ...
   'Label','&Tools', ...
   'Enable','off', ...
   'Tag','LearningToolsMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                           DSGE Model Eigenvalues                            %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.dsgeeigenvalues.parent = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','DS&GE Model Solution Eigenvalues', ...
   'Enable','on', ...
   'Tag','LearningDSGEEigenvaluesMenu');
%
% initial values
%
controls.learningtools.dsgeeigenvalues.initialvalues = uimenu('Parent',controls.learningtools.dsgeeigenvalues.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions DSGEEigenvaluesInitialValues', ...
   'Enable','off', ...
   'Tag','LearningDSGEEigenvaluesInitialValuesMenu');
%
% DSGE posterior mode
%
controls.learningtools.dsgeeigenvalues.dsgemode = uimenu('Parent',controls.learningtools.dsgeeigenvalues.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions DSGEEigenvaluesDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningDSGEEigenvaluesDSGEPosteriorModeMenu');
%
% posterior mode
%
controls.learningtools.dsgeeigenvalues.postmode = uimenu('Parent',controls.learningtools.dsgeeigenvalues.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions DSGEEigenvaluesPostMode', ...
   'Enable','off', ...
   'Tag','LearningDSGEEigenvaluesPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                            Monte Carlo Filtering                            %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.montecarlofiltering = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','Monte Carlo &Filtering...', ...
   'Callback','LearningMenuFunctions MonteCarloFiltering', ...
   'Enable','off', ...
   'Tag','LearningMonteCarloFilteringMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                             Information matrix                              %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.informationmatrix.parent = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','Information Matri&x', ...
   'Enable','on', ...
   'Tag','LearningInformationMatrixMenu');
%
% frequency domain
%
controls.learningtools.informationmatrix.frequencydomain.parent = uimenu('Parent',controls.learningtools.informationmatrix.parent, ...
   'Label','&Frequency Domain', ...
   'Enable','on', ...
   'Tag','LearningInformationMatrixFrequencyDomainMenu');
%
% initial values
%
controls.learningtools.informationmatrix.frequencydomain.initialvalues = uimenu('Parent',controls.learningtools.informationmatrix.frequencydomain.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions InfMatFreqDomainInitialValues', ...
   'Enable','off', ...
   'Tag','LearningInformationMatrixFrequencyDomainInitialValuesMenu');
%
% DSGE posterior mode
%
controls.learningtools.informationmatrix.frequencydomain.dsgemode = uimenu('Parent',controls.learningtools.informationmatrix.frequencydomain.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions InfMatFreqDomainDSGEMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningInformationMatrixFrequencyDomainDSGEPosteriorModeMenu');
%
% posterior mode
%
controls.learningtools.informationmatrix.frequencydomain.postmode = uimenu('Parent',controls.learningtools.informationmatrix.frequencydomain.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions InfMatFreqDomainPostMode', ...
   'Enable','off', ...
   'Tag','LearningInformationMatrixFrequencyDomainPosteriorModeMenu');
%
% time domain
%
controls.learningtools.informationmatrix.timedomain.parent = uimenu('Parent',controls.learningtools.informationmatrix.parent, ...
   'Label','&Time Domain', ...
   'Enable','on', ...
   'Tag','LearningInformationMatrixTimeDomainMenu');
%
% initial values
%
controls.learningtools.informationmatrix.timedomain.initialvalues = uimenu('Parent',controls.learningtools.informationmatrix.timedomain.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions InfMatTimeDomainInitialValues', ...
   'Enable','off', ...
   'Tag','LearningInformationMatrixTimeDomainInitialValuesMenu');
%
% DSGE posterior mode
%
controls.learningtools.informationmatrix.timedomain.dsgemode = uimenu('Parent',controls.learningtools.informationmatrix.timedomain.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions InfMatTimeDomainDSGEMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningInformationMatrixTimeDomainDSGEPosteriorModeMenu');
%
% posterior mode
%
controls.learningtools.informationmatrix.timedomain.postmode = uimenu('Parent',controls.learningtools.informationmatrix.timedomain.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions InfMatTimeDomainPostMode', ...
   'Enable','off', ...
   'Tag','LearningInformationMatrixTimeDomainPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                          Steady-state correlations                          %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.steadystatecorrelations.parent = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','Stead&y-State Correlation', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','LearningSteadyStateCorrelationsMenu');
%
controls.learningtools.steadystatecorrelations.obsvar.parent = uimenu('Parent',controls.learningtools.steadystatecorrelations.parent, ...
   'Label','&Observed Variables', ...
   'Enable','on', ...
   'Tag','LearningObservedVariableCorrelationsMenu');
%
controls.learningtools.steadystatecorrelations.statevar.parent = uimenu('Parent',controls.learningtools.steadystatecorrelations.parent, ...
   'Label','&State Variables', ...
   'Enable','on', ...
   'Tag','LearningStateVariableCorrelationsMenu');
%
% time domain
%
controls.learningtools.steadystatecorrelations.obsvar.timedomain.parent = uimenu('Parent',controls.learningtools.steadystatecorrelations.obsvar.parent, ...
   'Label','&Time Domain', ...
   'Enable','on', ...
   'Tag','LearningObservedVariableCorrelationsTimeDomainMenu');
%
controls.learningtools.steadystatecorrelations.statevar.timedomain.parent = uimenu('Parent',controls.learningtools.steadystatecorrelations.statevar.parent, ...
   'Label','&Time Domain', ...
   'Enable','on', ...
   'Tag','LearningStateVariableCorrelationsTimeDomainMenu');
%
% observed variables: time domain
%
controls.learningtools.steadystatecorrelations.obsvar.timedomain.initialvalues = uimenu('Parent',controls.learningtools.steadystatecorrelations.obsvar.timedomain.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions ObsVarCorrInitialValues', ...
   'Enable','off', ...
   'Tag','LearningObservedVariableCorrelationsTimeDomainInitialValuesMenu');
%
controls.learningtools.steadystatecorrelations.obsvar.timedomain.dsgemode = uimenu('Parent',controls.learningtools.steadystatecorrelations.obsvar.timedomain.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions ObsVarCorrDSGEMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningObservedVariableCorrelationsTimeDomainDSGEModeMenu');
%
controls.learningtools.steadystatecorrelations.obsvar.timedomain.postmode = uimenu('Parent',controls.learningtools.steadystatecorrelations.obsvar.timedomain.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions ObsVarCorrPostMode', ...
   'Enable','off', ...
   'Tag','LearningObservedVariableCorrelationsTimeDomainDSGEPosteriorModeMenu');
%
% state variables: time domain
%
controls.learningtools.steadystatecorrelations.statevar.timedomain.initialvalues = uimenu('Parent',controls.learningtools.steadystatecorrelations.statevar.timedomain.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions ObsVarCorrInitialValues', ...
   'Enable','off', ...
   'Tag','LearningStateVariableCorrelationsTimeDomainInitialValuesMenu');
%
controls.learningtools.steadystatecorrelations.statevar.timedomain.dsgemode = uimenu('Parent',controls.learningtools.steadystatecorrelations.statevar.timedomain.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions ObsVarCorrDSGEMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningStateVariableCorrelationsTimeDomainDSGEModeMenu');
%
controls.learningtools.steadystatecorrelations.statevar.timedomain.postmode = uimenu('Parent',controls.learningtools.steadystatecorrelations.statevar.timedomain.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions ObsVarCorrPostMode', ...
   'Enable','off', ...
   'Tag','LearningStateVariableCorrelationsTimeDomainDSGEPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                               State Variables                               %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.statevariables.parent = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','&State Variables', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','LearningStateVariablesMenu');
%
% initial values
%
controls.learningtools.statevariables.initialvalues = uimenu('Parent',controls.learningtools.statevariables.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions StateVariablesInitialValues', ...
   'Enable','off', ...
   'Tag','LearningStateVariablesInitialValuesMenu');
%
% DSGE posterior mode values
%
controls.learningtools.statevariables.dsgemode = uimenu('Parent',controls.learningtools.statevariables.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions StateVariablesDSGEMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningStateVariablesDSGEPosteriorModeMenu');
%
% posterior mode values from adaptive learning version
%
controls.learningtools.statevariables.postmode = uimenu('Parent',controls.learningtools.statevariables.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions StateVariablesPostMode', ...
   'Enable','off', ...
   'Tag','LearningStateVariablesPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                                State shocks                                 %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.stateshocks.parent = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','State Shoc&ks', ...
   'Enable','on', ...
   'Tag','LearningStateShockMenu');
%
% initial values
%
controls.learningtools.stateshocks.initialvalues = uimenu('Parent',controls.learningtools.stateshocks.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions StateShocksInitialValues', ...
   'Enable','off', ...
   'Tag','LearningStateShocksInitialValuesMenu');
%
% DSGE posterior mode values
%
controls.learningtools.stateshocks.dsgemode = uimenu('Parent',controls.learningtools.stateshocks.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions StateShocksDSGEMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningStateShocksDSGEPosteriorModeMenu');
%
% posterior mode values from adaptive learning version
%
controls.learningtools.stateshocks.postmode = uimenu('Parent',controls.learningtools.stateshocks.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions StateShocksPostMode', ...
   'Enable','off', ...
   'Tag','LearningStateShocksPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                             Measurement errors                              %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.measurementerrors.parent = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','&Measurement Errors', ...
   'Enable','on', ...
   'Tag','LearningMeasurementErrorsMenu');
%
% initial values
%
controls.learningtools.measurementerrors.initialvalues = uimenu('Parent',controls.learningtools.measurementerrors.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions MeasurementErrorsInitialValues', ...
   'Enable','off', ...
   'Tag','LearningMeasurementErrorsInitialValuesMenu');
%
% DSGE posterior mode
%
controls.learningtools.measurementerrors.dsgemode = uimenu('Parent',controls.learningtools.measurementerrors.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions MeasurementErrorsDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningMeasurementErrorsDSGEPosteriorModeMenu');
%
% posterior mode
%
controls.learningtools.measurementerrors.postmode = uimenu('Parent',controls.learningtools.measurementerrors.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions MeasurementErrorsPostMode', ...
   'Enable','off', ...
   'Tag','LearningMeasurementErrorsPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                             Belief coefficients                             %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.beliefcoefficients.parent = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','&Belief Coefficients', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','LearningBeliefCoefficientsMenu');
%
% initial valies
%
controls.learningtools.beliefcoefficients.initialvalues = uimenu('Parent',controls.learningtools.beliefcoefficients.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions BeliefCoefficientsInitialValues', ...
   'Enable','off', ...
   'Tag','LearningBeliefCoefficientsInitialValuesMenu');
%
% DSGE posterior mode values
%
controls.learningtools.beliefcoefficients.dsgemode = uimenu('Parent',controls.learningtools.beliefcoefficients.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions BeliefCoefficientsDSGEMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningBeliefCoefficientsDSGEPosteriorModeMenu');
%
% posterior mode values from adaptive learning version
%
controls.learningtools.beliefcoefficients.postmode = uimenu('Parent',controls.learningtools.beliefcoefficients.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions BeliefCoefficientsPostMode', ...
   'Enable','off', ...
   'Tag','LearningBeliefCoefficientsPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                               Laws of motion                                %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.lawsofmotion.parent = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','La&ws Of Motion', ...
   'Enable','on', ...
   'Tag','LearningLawsOfMotionMenu');
%
% initial values
%
controls.learningtools.lawsofmotion.initialvalues = uimenu('Parent',controls.learningtools.lawsofmotion.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions LawsOfMotionInitialValues', ...
   'Enable','off', ...
   'Tag','LearningLawsOfMotionInitialValuesMenu');
%
% DSGE posterior mode
%
controls.learningtools.lawsofmotion.dsgemode = uimenu('Parent',controls.learningtools.lawsofmotion.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions LawsOfMotionDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningLawsOfMotionDSGEPosteriorModeMenu');
%
% posterior mode
%
controls.learningtools.lawsofmotion.postmode = uimenu('Parent',controls.learningtools.lawsofmotion.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions LawsOfMotionPostMode', ...
   'Enable','off', ...
   'Tag','LearningLawsOfMotionPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                                 Persistence                                 %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.persistence.parent = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','Persisten&ce', ...
   'Enable','on', ...
   'Tag','LearningPersistenceMenu');
%
% initial values
%
controls.learningtools.persistence.initialvalues = uimenu('Parent',controls.learningtools.persistence.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions PersistenceInitialValues', ...
   'Enable','off', ...
   'Tag','LearningPersistenceInitialValuesMenu');
%
% DSGE posterior mode
%
controls.learningtools.persistence.dsgemode = uimenu('Parent',controls.learningtools.persistence.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions PersistenceDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningPersistenceDSGEPosteriorModeMenu');
%
% posterior mode
%
controls.learningtools.persistence.postmode = uimenu('Parent',controls.learningtools.persistence.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions PersistencePostMode', ...
   'Enable','off', ...
   'Tag','LearningPersistencePosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                      Graph the log-likelihood function                      %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% NOTE: We should add a separator to this control
%
controls.learningtools.loglikelihood.parent = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','&Log-likelihood Function', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','LearningLogLikelihoodMenu');
%
% initial values for all parameters
%
controls.learningtools.loglikelihood.initialvalues = uimenu('Parent',controls.learningtools.loglikelihood.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions LogLikelihoodInitialValues', ...
   'Enable','off', ...
   'Tag','LearningLogLikelihoodInitialValuesMenu');
%
% posterior mode values from DSGE model and initial values from adaptive learning
%
controls.learningtools.loglikelihood.dsgemode = uimenu('Parent',controls.learningtools.loglikelihood.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions LogLikelihoodDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningLogLikelihoodDSGEPosteriorModeMenu');
%
% posterior mode values from adaptive learning version
%
controls.learningtools.loglikelihood.postmode = uimenu('Parent',controls.learningtools.loglikelihood.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions LogLikelihoodPostMode', ...
   'Enable','off', ...
   'Tag','LearningLogLikelihoodPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                             Variable scenarios                              %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
if FileExist(FixFilePath([pwd '\addons\ovs\OVSControls.m']))==1;
   controls = OVSControls(controls,'learningmenu');
end;
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                          Predictive distributions                           %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% parent control
%
controls.learningtools.predictivedist.parent = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','&Predictive Distributions', ...
   'Enable','on', ...
   'Tag','LearningPredictiveDistMenu');
%
% unconditional
%
controls.learningtools.predictivedist.unconditional.parent = uimenu('Parent',controls.learningtools.predictivedist.parent, ...
   'Label','&Unconditional', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalPredictiveDistMenu');
%
% conditional
%
controls.learningtools.predictivedist.conditional.parent = uimenu('Parent',controls.learningtools.predictivedist.parent, ...
   'Label','&Conditional', ...
   'Enable','on', ...
   'Tag','LearningConditionalPredictiveDistMenu');
%
% state conditional
%
controls.learningtools.predictivedist.stateconditional.parent = uimenu('Parent',controls.learningtools.predictivedist.parent, ...
   'Label','&State Conditional', ...
   'Enable','on', ...
   'Tag','LearningStateConditionalPredictiveDistMenu');
%
% 1. Unconditional predictive distributions
%
% original data
%
controls.learningtools.predictivedist.unconditional.original.parent = uimenu('Parent',controls.learningtools.predictivedist.unconditional.parent, ...
   'Label','&Original Data', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalPredictiveDistOriginalMenu');
%
% annualized data
%
controls.learningtools.predictivedist.unconditional.annual.parent = uimenu('Parent',controls.learningtools.predictivedist.unconditional.parent, ...
   'Label','&Annualized Data', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalPredictiveDistAnnualizedMenu');
%
% transformed data
%
controls.learningtools.predictivedist.unconditional.transformed.parent = uimenu('Parent',controls.learningtools.predictivedist.unconditional.parent, ...
   'Label','&Transformed Data', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalPredictiveDistTransformedMenu');
%
%
% 2. Conditional predictive distributions
%
% original data
%
controls.learningtools.predictivedist.conditional.original.parent = uimenu('Parent',controls.learningtools.predictivedist.conditional.parent, ...
   'Label','&Original Data', ...
   'Enable','on', ...
   'Tag','LearningConditionalPredictiveDistOriginalMenu');
%
% annualized data
%
controls.learningtools.predictivedist.conditional.annual.parent = uimenu('Parent',controls.learningtools.predictivedist.conditional.parent, ...
   'Label','&Annualized Data', ...
   'Enable','on', ...
   'Tag','LearningConditionalPredictiveDistAnnualizedMenu');
%
% transformed data
%
controls.learningtools.predictivedist.conditional.transformed.parent = uimenu('Parent',controls.learningtools.predictivedist.conditional.parent, ...
   'Label','&Transformed Data', ...
   'Enable','on', ...
   'Tag','LearningConditionalPredictiveDistTransformedMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% predictive likelihood unconditional forecasts
%
controls.learningtools.predictivedist.unconditional.original.height.parent = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.parent, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalPredictiveDensityHeightOriginalMenu');
%
% annualized observables
%
controls.learningtools.predictivedist.unconditional.annual.height.parent = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.parent, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalPredictiveDensityHeightAnnualMenu');
%
% prior distribution: predictive likelihood
%
controls.learningtools.predictivedist.unconditional.original.height.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.height.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions UnconPredLikePriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDensityHeightOriginalPriorDistMenu');
%
controls.learningtools.predictivedist.unconditional.annual.height.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.height.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions UnconPredLikePriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDensityHeightAnnualPriorDistMenu');
%
% posterior distribution: predictive likelihood
%
controls.learningtools.predictivedist.unconditional.original.height.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.height.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions UnconPredLikePosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDensityHeightOriginalPosteriorDistMenu');
%
controls.learningtools.predictivedist.unconditional.annual.height.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.height.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions UnconPredLikePosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDensityHeightAnnualPosteriorDistMenu');
%
% predictive likelihood conditional forecasts
%
controls.learningtools.predictivedist.conditional.original.height.parent = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.parent, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','LearningConditionalPredictiveDensityHeightOriginalMenu');
%
% annualized observables
%
controls.learningtools.predictivedist.conditional.annual.height.parent = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.parent, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','LearningConditionalPredictiveDensityHeightAnnualMenu');
%
% prior distribution: predictive likelihood
%
controls.learningtools.predictivedist.conditional.original.height.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.height.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions ConPredLikePriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDensityHeightOriginalPriorDistMenu');
%
controls.learningtools.predictivedist.conditional.annual.height.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.height.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions ConPredLikePriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDensityHeightAnnualPriorDistMenu');
%
% posterior distribution: predictive likelihood
%
controls.learningtools.predictivedist.conditional.original.height.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.height.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions ConPredLikePosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDensityHeightOriginalPosteriorDistMenu');
%
controls.learningtools.predictivedist.conditional.annual.height.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.height.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions ConPredLikePosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDensityHeightAnnualPosteriorDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% continuous ranked probability score: unconditional forecasts
%
controls.learningtools.predictivedist.unconditional.original.crps.parent = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.parent, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalCRPSOriginalMenu');
%
% annualized observables
%
controls.learningtools.predictivedist.unconditional.annual.crps.parent = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.parent, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalCRPSAnnualizedMenu');
%
% prior distribution
%
controls.learningtools.predictivedist.unconditional.original.crps.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.crps.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions UnconCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalCRPSOriginalPriorDistMenu');
%
controls.learningtools.predictivedist.unconditional.annual.crps.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.crps.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions UnconCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalCRPSAnnualizedPriorDistMenu');
%
% posterior distribution
%
controls.learningtools.predictivedist.unconditional.original.crps.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.crps.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions UnconCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalCRPSOriginalPosteriorDistMenu');
%
controls.learningtools.predictivedist.unconditional.annual.crps.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.crps.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions UnconCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalCRPSAnnualizedPosteriorDistMenu');
%
% CRPS: conditional forecasts
%
controls.learningtools.predictivedist.conditional.original.crps.parent = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.parent, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','LearningConditionalCRPSOriginalMenu');
%
% annualized observables
%
controls.learningtools.predictivedist.conditional.annual.crps.parent = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.parent, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','LearningConditionalCRPSAnnualizedMenu');
%
% prior distribution: CRPS & ES
%
controls.learningtools.predictivedist.conditional.original.crps.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.crps.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions ConCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalCRPSOriginalPriorDistMenu');
%
controls.learningtools.predictivedist.conditional.annual.crps.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.crps.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions ConCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalCRPSAnnualizedPriorDistMenu');
%
% posterior distribution: CRPS & ES
%
controls.learningtools.predictivedist.conditional.original.crps.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.crps.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions ConCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalCRPSOriginalPosteriorDistMenu');
%
controls.learningtools.predictivedist.conditional.annual.crps.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.crps.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions ConCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalCRPSAnnualizedPosteriorDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% predictive moments
%
controls.learningtools.predictivedist.unconditional.original.moments.parent = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.parent, ...
   'Label','&Marginal Predictive Moments', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalPredictiveDensityMomentsOriginalMenu');
%
% prior distribution
%
controls.learningtools.predictivedist.unconditional.original.moments.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.moments.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions UnconMargPredMomentsPriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDensityMomentsOriginalPriorDistMenu');
%
% posterior distribution
%
controls.learningtools.predictivedist.unconditional.original.moments.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.moments.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions UnconMargPredMomentsPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDensityMomentsOriginalPosteriorDistMenu');
%
% predictive moments: conditional forecasts
%
controls.learningtools.predictivedist.conditional.original.moments.parent = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.parent, ...
   'Label','&Marginal Predictive Moments', ...
   'Enable','on', ...
   'Tag','LearningConditionalPredictiveDensityMomentsOriginalMenu');
%
% prior distribution
%
controls.learningtools.predictivedist.conditional.original.moments.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.moments.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions ConMargPredMomentsPriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDensityMomentsOriginalPriorDistMenu');
%
% posterior distribution
%
controls.learningtools.predictivedist.conditional.original.moments.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.moments.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions ConMargPredMomentsPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDensityMomentsOriginalPosteriorDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% probability integral transform
%
controls.learningtools.predictivedist.unconditional.original.pit.parent = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.parent, ...
   'Label','Pro&bability Integral Transform', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalPITOriginalMenu');
%
% prior distribution
%
controls.learningtools.predictivedist.unconditional.original.pit.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.pit.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions UnconPITPriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPITOriginalPriorDistMenu');
%
% posterior distribution
%
controls.learningtools.predictivedist.unconditional.original.pit.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.pit.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions UnconPITPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPITOriginalPosteriorDistMenu');
%
% PITs: conditional forecasts
%
controls.learningtools.predictivedist.conditional.original.pit.parent = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.parent, ...
   'Label','Pro&bability Integral Transform', ...
   'Enable','on', ...
   'Tag','LearningConditionalPITOriginalMenu');
%
% prior distribution
%
controls.learningtools.predictivedist.conditional.original.pit.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.pit.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions ConPITPriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalPITOriginalPriorDistMenu');
%
% posterior distribution
%
controls.learningtools.predictivedist.conditional.original.pit.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.pit.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions ConPITPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalPITOriginalPosteriorDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% zero lower bound menu controls for unconditional predictions
%
controls.learningtools.predictivedist.unconditional.original.zlbmenu = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.parent, ...
   'Label','&Zero Lower Bound', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalOriginalZLBPredictiveDistMenu');
%
controls.learningtools.predictivedist.unconditional.annual.zlbmenu = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.parent, ...
   'Label','&Zero Lower Bound', ...
   'Enable','off', ...
   'Tag','LeaningUnconditionalAnnualZLBPredictiveDistMenu');
%
controls.learningtools.predictivedist.unconditional.transformed.zlbmenu = uimenu('Parent',controls.learningtools.predictivedist.unconditional.transformed.parent, ...
   'Label','&Zero Lower Bound', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalTransformedZLBPredictiveDistMenu');
%
% zero lower bound controls for conditional predictions
%
controls.learningtools.predictivedist.conditional.original.zlbmenu = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.parent, ...
   'Label','&Zero Lower Bound', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalOriginalZLBPredictiveDistMenu');
%
controls.learningtools.predictivedist.conditional.annual.zlbmenu = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.parent, ...
   'Label','&Zero Lower Bound', ...
   'Enable','off', ...
   'Tag','LeaningUnconditionalAnnualZLBPredictiveDistMenu');
%
controls.learningtools.predictivedist.conditional.transformed.zlbmenu = uimenu('Parent',controls.learningtools.predictivedist.conditional.transformed.parent, ...
   'Label','&Zero Lower Bound', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalTransformedZLBPredictiveDistMenu');
%
% predictive likelihood controls
%
controls.learningtools.predictivedist.unconditional.original.zlb.heightmenu = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.zlbmenu, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalPredictiveDensityHeightOriginalZLBMenu');
%
controls.learningtools.predictivedist.unconditional.annual.zlb.heightmenu = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.zlbmenu, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalPredictiveDensityHeightAnnualizedZLBMenu');
%
% prior distributions
%
controls.learningtools.predictivedist.unconditional.original.zlb.height.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.zlb.heightmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredHeightLikeDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBOriginalPredHeightPriorMenu');
%
controls.learningtools.predictivedist.unconditional.annual.zlb.height.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.zlb.heightmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredLikePriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBAnnualPredHeightPriorMenu');
%
% posterior distribution
%
controls.learningtools.predictivedist.unconditional.original.zlb.height.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.zlb.heightmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredLikePosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBOriginalPredHeightPosteriorMenu');
%
controls.learningtools.predictivedist.unconditional.annual.zlb.height.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.zlb.heightmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredLikePosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBAnnualPredHeightPosteriorMenu');
%
% crps controls for unconditional predictions subject to ZLB
%
controls.learningtools.predictivedist.unconditional.original.zlb.crpsmenu = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.zlbmenu, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalCRPSOriginalZLBMenu');
%
controls.learningtools.predictivedist.unconditional.annual.zlb.crpsmenu = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.zlbmenu, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','LearningUnconditionalCRPSAnnualZLBMenu');
%
% prior distribution
%
controls.learningtools.predictivedist.unconditional.original.zlb.crps.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.zlb.crpsmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBOriginalCRPSPriorMenu');
%
controls.learningtools.predictivedist.unconditional.annual.zlb.crps.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.zlb.crpsmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBAnnualCRPSPriorMenu');
%
% posterior distribution
%
controls.learningtools.predictivedist.unconditional.original.zlb.crps.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.zlb.crpsmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBOriginalCRPSPosteriorMenu');
%
controls.learningtools.predictivedist.unconditional.annual.zlb.crps.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.zlb.crpsmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBAnnualCRPSPosteriorMenu');
%
% predictive distribution controls
%
% initial values
%
controls.learningtools.predictivedist.unconditional.original.zlb.initialvalues = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.zlbmenu, ...
   'Label','&Initial Values...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistOriginalInitialValuesMenu');
%
controls.learningtools.predictivedist.unconditional.annual.zlb.initialvalues = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.zlbmenu, ...
   'Label','&Initial Values...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistAnnualInitialValuesMenu');
%
controls.learningtools.predictivedist.unconditional.transformed.zlb.initialvalues = uimenu('Parent',controls.learningtools.predictivedist.unconditional.transformed.zlbmenu, ...
   'Label','&Initial Values...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredInitialValues', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistTransformedInitialValuesMenu');
%
% prior distribution
%
controls.learningtools.predictivedist.unconditional.original.zlb.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.zlbmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredPriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistOriginalPriorMenu');
%
controls.learningtools.predictivedist.unconditional.annual.zlb.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.zlbmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredPriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistOriginalPriorMenu');
%
controls.learningtools.predictivedist.unconditional.transformed.zlb.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.transformed.zlbmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredPriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistOriginalPriorMenu');
%
% DSGE posterior mode
%
controls.learningtools.predictivedist.unconditional.original.zlb.dsgemode = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.zlbmenu, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistOriginalDSGEPosteriorModeMenu');
%
controls.learningtools.predictivedist.unconditional.annual.zlb.dsgemode = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.zlbmenu, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistAnnualDSGEPosteriorModeMenu');
%
controls.learningtools.predictivedist.unconditional.transformed.zlb.dsgemode = uimenu('Parent',controls.learningtools.predictivedist.unconditional.transformed.zlbmenu, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistTransformedDSGEPosteriorModeMenu');
%
% posterior mode
%
controls.learningtools.predictivedist.unconditional.original.zlb.postmode = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.zlbmenu, ...
   'Label','Posterior &Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredPostMode', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistOriginalPosteriorModeMenu');
%
controls.learningtools.predictivedist.unconditional.annual.zlb.postmode = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.zlbmenu, ...
   'Label','Posterior &Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredPostMode', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistAnnualPosteriorModeMenu');
%
controls.learningtools.predictivedist.unconditional.transformed.zlb.postmode = uimenu('Parent',controls.learningtools.predictivedist.unconditional.transformed.zlbmenu, ...
   'Label','Posterior &Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredPostMode', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistTransformedPosteriorModeMenu');
%
% posterior distribution
%
controls.learningtools.predictivedist.unconditional.original.zlb.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.zlbmenu, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistOriginalPosteriorMenu');
%
controls.learningtools.predictivedist.unconditional.annual.zlb.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.zlbmenu, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistAnnualPosteriorMenu');
%
controls.learningtools.predictivedist.unconditional.transformed.zlb.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.transformed.zlbmenu, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBUnconPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalZLBPredictiveDistTransformedPosteriorMenu');
%
% predictive likelihood controls for conditional forecasts subject to the ZLB
%
controls.learningtools.predictivedist.conditional.original.zlb.heightmenu = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.zlbmenu, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','LearningConditionalPredictiveDensityHeightOriginalZLBMenu');
%
controls.learningtools.predictivedist.conditional.annual.zlb.heightmenu = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.zlbmenu, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','LearningConditionalPredictiveDensityHeightAnnualizedZLBMenu');
%
% prior distributions
%
controls.learningtools.predictivedist.conditional.original.zlb.height.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.zlb.heightmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredLikePriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBOriginalPredHeightPriorMenu');
%
controls.learningtools.predictivedist.conditional.annual.zlb.height.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.zlb.heightmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredLikePriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBAnnualPredHeightPriorMenu');
%
% posterior distribution
%
controls.learningtools.predictivedist.conditional.original.zlb.height.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.zlb.heightmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredLikePosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBOriginalPredHeightPosteriorMenu');
%
controls.learningtools.predictivedist.conditional.annual.zlb.height.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.zlb.heightmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredLikePosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBAnnualPredHeightPosteriorMenu');
%
% crps controls for conditional predictions subject to ZLB
%
controls.learningtools.predictivedist.conditional.original.zlb.crpsmenu = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.zlbmenu, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','LearningConditionalCRPSOriginalZLBMenu');
%
controls.learningtools.predictivedist.conditional.annual.zlb.crpsmenu = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.zlbmenu, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','LearningConditionalCRPSAnnualZLBMenu');
%
% prior distribution
%
controls.learningtools.predictivedist.conditional.original.zlb.crps.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.zlb.crpsmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBOriginalCRPSPriorMenu');
%
controls.learningtools.predictivedist.conditional.annual.zlb.crps.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.zlb.crpsmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBAnnualCRPSPriorMenu');
%
% posterior distribution
%
controls.learningtools.predictivedist.conditional.original.zlb.crps.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.zlb.crpsmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBOriginalCRPSPosteriorMenu');
%
controls.learningtools.predictivedist.conditional.annual.zlb.crps.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.zlb.crpsmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBAnnualCRPSPosteriorMenu');
%
% conditional forecasts:
%
%    initial values
%
controls.learningtools.predictivedist.conditional.original.zlb.initialvalues = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.zlbmenu, ...
   'Label','&Initial Values...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistOriginalInitialValuesMenu');
%
controls.learningtools.predictivedist.conditional.annual.zlb.initialvalues = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.zlbmenu, ...
   'Label','&Initial Values...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistAnnualInitialValuesMenu');
%
controls.learningtools.predictivedist.conditional.transformed.zlb.initialvalues = uimenu('Parent',controls.learningtools.predictivedist.conditional.transformed.zlbmenu, ...
   'Label','&Initial Values...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredInitialValues', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistTransformedInitialValuesMenu');
%
% prior distribution
%
controls.learningtools.predictivedist.conditional.original.zlb.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.zlbmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredPriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistOriginalPriorMenu');
%
controls.learningtools.predictivedist.conditional.annual.zlb.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.zlbmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredPriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistAnnualPriorMenu');
%
controls.learningtools.predictivedist.conditional.transformed.zlb.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.transformed.zlbmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredPriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistTransformedPriorMenu');
%
%     DSGE posterior mode
%
controls.learningtools.predictivedist.conditional.original.zlb.dsgemode = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.zlbmenu, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistOriginalDSGEPosteriorModeMenu');
%
controls.learningtools.predictivedist.conditional.annual.zlb.dsgemode = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.zlbmenu, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistAnnualDSGEPosteriorModeMenu');
%
controls.learningtools.predictivedist.conditional.transformed.zlb.dsgemode = uimenu('Parent',controls.learningtools.predictivedist.conditional.transformed.zlbmenu, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistTransformedDSGEPosteriorModeMenu');
%
%     posterior mode
%
controls.learningtools.predictivedist.conditional.original.zlb.postmode = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.zlbmenu, ...
   'Label','Posterior &Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredPostMode', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistOriginalPosteriorModeMenu');
%
controls.learningtools.predictivedist.conditional.annual.zlb.postmode = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.zlbmenu, ...
   'Label','Posterior &Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredPostMode', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistAnnualPosteriorModeMenu');
%
controls.learningtools.predictivedist.conditional.transformed.zlb.postmode = uimenu('Parent',controls.learningtools.predictivedist.conditional.transformed.zlbmenu, ...
   'Label','Posterior &Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredPostMode', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistTransformedPosteriorModeMenu');
%
% posterior distribution
%
controls.learningtools.predictivedist.conditional.original.zlb.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.zlbmenu, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistOriginalPosteriorMenu');
%
controls.learningtools.predictivedist.conditional.annual.zlb.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.zlbmenu, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistAnnualPosteriorMenu');
%
controls.learningtools.predictivedist.conditional.transformed.zlb.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.transformed.zlbmenu, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ZLBConPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalZLBPredictiveDistTransformedPosteriorMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% initial values: predictive distribution
%
controls.learningtools.predictivedist.unconditional.original.initialvalues = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions UnconPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistOriginalInitialValuesMenu');
%
controls.learningtools.predictivedist.unconditional.annual.initialvalues = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions UnconPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistAnnualInitialValuesMenu');
%
controls.learningtools.predictivedist.unconditional.transformed.initialvalues = uimenu('Parent',controls.learningtools.predictivedist.unconditional.transformed.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions UnconPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistTransformedInitialValuesMenu');
%
% initial values conditional
%
controls.learningtools.predictivedist.conditional.original.initialvalues = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions ConPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistOriginalInitialValuesMenu');
%
controls.learningtools.predictivedist.conditional.annual.initialvalues = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions ConPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistAnnualInitialValuesMenu');
%
controls.learningtools.predictivedist.conditional.transformed.initialvalues = uimenu('Parent',controls.learningtools.predictivedist.conditional.transformed.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions ConPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistTransformedInitialValuesMenu');
%
% prior distribution
%
controls.learningtools.predictivedist.unconditional.original.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions UnconPredPriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistOriginalPriorMenu');
%
controls.learningtools.predictivedist.unconditional.annual.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions UnconPredPriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistAnnualPriorMenu');
%
controls.learningtools.predictivedist.unconditional.transformed.prior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.transformed.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions UnconPredPriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistTransformedPriorMenu');
%
% prior distribution conditional
%
controls.learningtools.predictivedist.conditional.original.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions ConPredPriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistOriginalPriorMenu');
%
controls.learningtools.predictivedist.conditional.annual.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions ConPredPriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistAnnualPriorMenu');
%
controls.learningtools.predictivedist.conditional.transformed.prior = uimenu('Parent',controls.learningtools.predictivedist.conditional.transformed.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','LearningMenuFunctions ConPredPriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistTransformedPriorMenu');
%
% DSGE posterior mode unconditional
%
controls.learningtools.predictivedist.unconditional.original.dsgemode = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions UnconPredDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistOriginalDSGEPosteriorModeMenu');
%
controls.learningtools.predictivedist.unconditional.annual.dsgemode = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions UnconPredDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistAnnualDSGEPosteriorModeMenu');
%
controls.learningtools.predictivedist.unconditional.transformed.dsgemode = uimenu('Parent',controls.learningtools.predictivedist.unconditional.transformed.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions UnconPredDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistTransformedDSGEPosteriorModeMenu');
%
% DSGE posterior mode conditional
%
controls.learningtools.predictivedist.conditional.original.dsgemode = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions ConPredDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistOriginalDSGEPosteriorModeMenu');
%
controls.learningtools.predictivedist.conditional.annual.dsgemode = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions ConPredDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistAnnualDSGEPosteriorModeMenu');
%
controls.learningtools.predictivedist.conditional.transformed.dsgemode = uimenu('Parent',controls.learningtools.predictivedist.conditional.transformed.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions ConPredDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistTransformedDSGEPosteriorModeMenu');
%
% posterior mode unconditional
%
controls.learningtools.predictivedist.unconditional.original.postmode = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions UnconPredPostMode', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistOriginalPosteriorModeMenu');
%
controls.learningtools.predictivedist.unconditional.annual.postmode = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions UnconPredPostMode', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistAnnualPosteriorModeMenu');
%
controls.learningtools.predictivedist.unconditional.transformed.postmode = uimenu('Parent',controls.learningtools.predictivedist.unconditional.transformed.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions UnconPredPostMode', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistTransformedPosteriorModeMenu');
%
% posterior mode conditional
%
controls.learningtools.predictivedist.conditional.original.postmode = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions ConPredPostMode', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistOriginalPosteriorModeMenu');
%
controls.learningtools.predictivedist.conditional.annual.postmode = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions ConPredPostMode', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistAnnualPosteriorModeMenu');
%
controls.learningtools.predictivedist.conditional.transformed.postmode = uimenu('Parent',controls.learningtools.predictivedist.conditional.transformed.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions ConPredPostMode', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistTransformedPosteriorModeMenu');
%
% posterior distribution uncondtional
%
controls.learningtools.predictivedist.unconditional.original.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.original.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions UnconPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistOriginalPosteriorMenu');
%
controls.learningtools.predictivedist.unconditional.annual.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.annual.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions UnconPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistAnnualPosteriorMenu');
%
controls.learningtools.predictivedist.unconditional.transformed.posterior = uimenu('Parent',controls.learningtools.predictivedist.unconditional.transformed.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions UnconPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','LearningUnconditionalPredictiveDistTransformedPosteriorMenu');
%
% conditional
%
controls.learningtools.predictivedist.conditional.original.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.original.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions ConPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistOriginalPosteriorMenu');
%
controls.learningtools.predictivedist.conditional.annual.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.annual.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions ConPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistAnnualPosteriorMenu');
%
controls.learningtools.predictivedist.conditional.transformed.posterior = uimenu('Parent',controls.learningtools.predictivedist.conditional.transformed.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','LearningMenuFunctions ConPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','LearningConditionalPredictiveDistTransformedPosteriorMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                               Decompositions                                %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.decompositions.parent = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','&Decompositions', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','LearningDecompositionsMenu');
%



%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                      Observed variable decompositions                       %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.decompositions.obsvar.parent = uimenu('Parent',controls.learningtools.decompositions.parent, ...
   'Label','&Observed Variables', ...
   'Enable','on', ...
   'Tag','LearningObsVarDecompositionsMenu');
%
% decompositions
%
controls.learningtools.decompositions.obsvar.decomp.parent = uimenu('Parent',controls.learningtools.decompositions.obsvar.parent, ...
   'Label','&Decompositions', ...
   'Enable','on', ...
   'Tag','LearningObsVarDecDecompositionsMenu');
%
% paths
%


%
% original data
%
controls.learningtools.decompositions.obsvar.decomp.original.parent = uimenu('Parent',controls.learningtools.decompositions.obsvar.decomp.parent, ...
   'Label','&Original Data', ...
   'Enable','on', ...
   'Tag','LearningObsVarDecDecompositionsOrigMenu');
%
% annualized data
%
controls.learningtools.decompositions.obsvar.decomp.annual.parent = uimenu('Parent',controls.learningtools.decompositions.obsvar.decomp.parent, ...
   'Label','&Annualized Data', ...
   'Enable','on', ...
   'Tag','LearningObsVarDecDecompositionsAnnMenu');
%
% initial values
%
controls.learningtools.decompositions.obsvar.decomp.original.initialvalues = uimenu('Parent',controls.learningtools.decompositions.obsvar.decomp.original.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions ObsVarDecompInitialValues', ...
   'Enable','off', ...
   'Tag','LearningObsVarDecompOrigInitialValuesMenu');
%
controls.learningtools.decompositions.obsvar.decomp.annual.initialvalues = uimenu('Parent',controls.learningtools.decompositions.obsvar.decomp.annual.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions ObsVarDecompInitialValues', ...
   'Enable','off', ...
   'Tag','LearningObsVarDecompAnnInitialValuesMenu');
%
% DSGE posterior mode values
%
controls.learningtools.decompositions.obsvar.decomp.original.dsgemode = uimenu('Parent',controls.learningtools.decompositions.obsvar.decomp.original.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions ObsVarDecompDSGEMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningObsVarDecompOrigDSGEPosteriorModeMenu');
%
controls.learningtools.decompositions.obsvar.decomp.annual.dsgemode = uimenu('Parent',controls.learningtools.decompositions.obsvar.decomp.annual.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions ObsVarDecompDSGEMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningObsVarDecompAnnDSGEPosteriorModeMenu');
%
% posterior mode values
%
controls.learningtools.decompositions.obsvar.decomp.original.postmode = uimenu('Parent',controls.learningtools.decompositions.obsvar.decomp.original.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions ObsVarDecompPostMode', ...
   'Enable','off', ...
   'Tag','LearningObsVarDecompOrigPosteriorModeMenu');
%
controls.learningtools.decompositions.obsvar.decomp.annual.postmode = uimenu('Parent',controls.learningtools.decompositions.obsvar.decomp.annual.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions ObsVarDecompPostMode', ...
   'Enable','off', ...
   'Tag','LearningObsVarDecompAnnPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                        State variable decompositions                        %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.decompositions.statevar.parent = uimenu('Parent',controls.learningtools.decompositions.parent, ...
   'Label','S&tate Variables', ...
   'Enable','on', ...
   'Tag','LearningStateVarDecompositionsMenu');
%
% initial values
%
controls.learningtools.decompositions.statevar.initialvalues = uimenu('Parent',controls.learningtools.decompositions.statevar.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions StateVarDecompInitialValues', ...
   'Enable','off', ...
   'Tag','LearningStateVarDecompInitialValuesMenu');
%
% DSGE posterior mode
%
controls.learningtools.decompositions.statevar.dsgemode = uimenu('Parent',controls.learningtools.decompositions.statevar.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions StateVarDecompDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningStateVarDecompDSGEPosteriorModeMenu');
%
% posterior mode
%
controls.learningtools.decompositions.statevar.postmode = uimenu('Parent',controls.learningtools.decompositions.statevar.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions StateVarDecompPostMode', ...
   'Enable','off', ...
   'Tag','LearningStateVarDecompPosteriorModeMenu');
%








%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                              Impulse responses                              %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.learningtools.irfs.parent = uimenu('Parent',controls.learning.toolsmenu.parent, ...
   'Label','&Impulse Responses', ...
   'Enable','on', ...
   'Tag','LearningImpulseResponseMenu');
%
% Original data
%
controls.learningtools.irfs.original.parent = uimenu('Parent',controls.learningtools.irfs.parent, ...
   'Label','&Original Data', ...
   'Enable','on', ...
   'Tag','LearningImpulseResponseOrigMenu');
%
% annualized data
%
controls.learningtools.irfs.annual.parent = uimenu('Parent',controls.learningtools.irfs.parent, ...
   'Label','&Annualized Data', ...
   'Enable','on', ...
   'Tag','LearningImpulseResponseAnnMenu');
%
% levels data
%
controls.learningtools.irfs.levels.parent = uimenu('Parent',controls.learningtools.irfs.parent, ...
   'Label','&Levels Data', ...
   'Enable','on', ...
   'Tag','IRLevelsMenu');
%
% initial values
%
controls.learningtools.irfs.original.initialvalues = uimenu('Parent',controls.learningtools.irfs.original.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions IRFSInitialValues', ...
   'Enable','off', ...
   'Tag','LearningImpulseResponseOrigInitialValuesMenu');
%
controls.learningtools.irfs.annual.initialvalues = uimenu('Parent',controls.learningtools.irfs.annual.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions IRFSInitialValues', ...
   'Enable','off', ...
   'Tag','LearningImpulseResponseAnnInitialValuesMenu');
%
controls.learningtools.irfs.levels.initialvalues = uimenu('Parent',controls.learningtools.irfs.levels.parent, ...
   'Label','&Initial Values...', ...
   'Callback','LearningMenuFunctions IRFSInitialValues', ...
   'Enable','off', ...
   'Tag','LearningImpulseResponseLevelsInitialValuesMenu');
%
% DSGE posterior mode
%
controls.learningtools.irfs.original.dsgemode = uimenu('Parent',controls.learningtools.irfs.original.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions IRFSDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningImpulseResponseOrigDSGEPosteriorModeMenu');
%
controls.learningtools.irfs.annual.dsgemode = uimenu('Parent',controls.learningtools.irfs.annual.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions IRFSDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningImpulseResponseAnnDSGEPosteriorModeMenu');
%
controls.learningtools.irfs.levels.dsgemode = uimenu('Parent',controls.learningtools.irfs.levels.parent, ...
   'Label','DSGE &Posterior Mode...', ...
   'Callback','LearningMenuFunctions IRFSDSGEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','LearningImpulseResponseLevelsDSGEPosteriorModeMenu');
%
% posterior mode
%
controls.learningtools.irfs.original.postmode = uimenu('Parent',controls.learningtools.irfs.original.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions IRFSPostMode', ...
   'Enable','off', ...
   'Tag','LearningImpulseResponseOrigPosteriorModeMenu');
%
controls.learningtools.irfs.annual.postmode = uimenu('Parent',controls.learningtools.irfs.annual.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions IRFSPostMode', ...
   'Enable','off', ...
   'Tag','LearningImpulseResponseAnnPosteriorModeMenu');
%
controls.learningtools.irfs.levels.postmode = uimenu('Parent',controls.learningtools.irfs.levels.parent, ...
   'Label','Posterior &Mode...', ...
   'Callback','LearningMenuFunctions IRFSPostMode', ...
   'Enable','off', ...
   'Tag','LearningImpulseResponseAnnPosteriorModeMenu');
%


%
% end of LearningMenuControls.m
%
