function PrintPITs(ResFile,ModelStr,PredictionVariables,PredictionSampleStrMat,HistSampleStrMat,YDataStr,PITMatrix,BNPITMatrix,PathPITMatrix,IsPosterior,IsConditional,IsAdaptiveLearning,NumDraws,NumBurnin,TotalDraws,lambda,CompTimeStepOne,CompTimeStepTwo,DSGEModel,CurrINI)
% PrintPITs: Prints the results from estimating probability integral transforms of a model.
%
% USAGE:
%
%       PrintPITs(ResFile,ModelStr,PredictionVariables,PredictionSampleStrMat,HistSampleStrMat,YDataStr,PITMatrix,...
%                 BNPITMatrix,PathPITMatrix,IsPosterior,IsConditional,IsAdaptiveLearning,NumDraws,NumBurnin,...
%                 TotalDraws,lambda,CompTimeStepOne,CompTimeStepTwo,DSGEModel,CurrINI)
%
% REQUIRED INPUT: ResFile (string) with the full path and name of the text file to write to.
%
%                 ModelStr (string) which takes the value "DSGE", "DSGE with learning" or "DSGE-VAR".
%
%                 PredictionVariables (vector) with integer values between 1 and n with the variables used
%                                     for the joint PIT calculations.
%
%                 PredictionSampleStrMat (string matrix) with the prediction sample dates.
%
%                 HistSampleStrMat (string matrix) with the sample dates for the back- and nowcasts.
%
%                 YDataStr (string vector) with a description of the actuals data used for the computation.
%
%                 PITMatrix (matrix) of dimension (n+1) x h with the PIT values for the n observed variables
%                                     and the joint PIT for the specified combination in PredictionVariables
%                                     over the forecast horizon.
%
%                 BNPITMatrix (matrix) of dimension (n+1) x 2 with the PIT values for the n observed variables
%                                     and the joint PIT for the specified combination in PredictionVariables
%                                     for the one-period backcast and the nowcast. May be empty.
%
%                 PathPITMatrix (matrix) of dimension n x h with the estimated probabilities that the predicted
%                                     variables are less than the true values.
%
%                 IsPosterior (boolean) that takes the value 1 if the parameter draws are taken from the posterior
%                                     distribution and 0 otherwise.
%
%                 IsConditional (boolean) that takes the value 1 if conditional forecasts have been used and 0
%                                     otherwise.
%
%                 IsAdaptiveLearning (boolean) that takes the value 1 if the adaptive learning mechanism is used for the
%                                     expectations formation, and 0 otherwise.
%
%                 NumDraws (integer) with the total number of parameters draws used to compute the PITs.
%
%                 NumBurnin (integer) with the number of burn-in draws.
%
%                 TotalDraws (integer) with the total number of parameter draws that could have been used.
%
%                 lambda (scalar) hyperparameter value that is used to measure degree of misspecification
%                                     for DSGE-VAR models.
%
%                 CompTimeStepOne (time) with the computational time for the first step with the results in
%                                     the PITMatrix (and the BNPITMatrix if computed).
%
%                 CompTimeStepTwo (time) with the computational time for the possibly second step with the
%                                     results in the PathPITMatrix.
%
%                 DSGEModel (structure) with fields containing all the information about a DSGE Model for YADA.
%
%                 CurrINI (structure), with initialization information.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2025 European Central Bank.
%
%                       First version: August 26, 2020.
%                        This version: January 9, 2025.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 27-08-2020: Finished the function from "BNPITMatrix".
%
% * 31-08-2020: Updated the documentation.
%
% * 26-01-2021: Updated the documentation.
%
% * 19-05-2021: Added the input variable "IsAdaptiveLearning".
%
% * 25-05-2021: Updated the documentation.
%
% * 06-01-2022: Updated the documentation.
%
% * 06-01-2023: Updated the documentation.
%
% * 19-01-2024: Updated the documentation.
%
% * 01-08-2024: Added the input variable "IsConditional".
%
% * 09-01-2025: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

[n1,h] = size(PITMatrix);
n = n1-1;
fid = fopen(ResFile,'wt');
%
% the header information
%
fprintf(fid,'*********************************************************************************************************\n');
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*                      P R O B A B I L I T Y   I N T E G R A L   T R A N S F O R M                      *\n');
if IsAdaptiveLearning==1;
   fprintf(fid,'*                                   A D A P T I V E   L E A R N I N G                                   *\n');
end;
fprintf(fid,'*                                                                                                       *\n');
fprintf(fid,'*********************************************************************************************************\n\n');
%
if IsPosterior==1;
   DistStr = 'Posterior';
else;
   DistStr = 'Prior';
end;
%
fprintf(fid,'Model used:                                        %s \n',ModelStr);
fprintf(fid,'Parameter draws:                                   %s distribution \n',DistStr);
if IsPosterior==1;
   fprintf(fid,'Number of available posterior draws:               %0.0f\n',TotalDraws);
   fprintf(fid,'Number of used draws:                              %0.0f\n',NumDraws);
   fprintf(fid,'Number of burn-in draws:                           %0.0f\n',NumBurnin);
else;
   fprintf(fid,'Number of available prior draws:                   %0.0f\n',TotalDraws);
end;
if isempty(lambda)==0;
   fprintf(fid,'Number of lags in DSGE-VAR:                        %0.0f \n',DSGEModel.BVARLags);
   fprintf(fid,'Lambda:                                            %0.4f \n',lambda);
end;
if IsAdaptiveLearning==1;
   fprintf(fid,'Number of forward variables:                       %0.0f\n\n',length(DSGEModel.ForwardVariablePositions));
   fprintf(fid,'Name of belief system:                             %s\n',DSGEModel.BeliefSys.Name);
   if DSGEModel.BeliefSystem==1;
      fprintf(fid,'Belief system file:                                YADA''s default (two own lags)\n');
   else;
      fprintf(fid,'Belief system file:                                %s\n',GetFilename(DSGEModel.BeliefSystemFile));
      fprintf(fid,'Maximum lag order:                                 %0.0f\n', DSGEModel.BeliefSys.m);
   end;
end;
fprintf(fid,'Set of actual data for the observed variables:     %s \n',YDataStr);
if IsConditional==1;
   VarNames = StrWrap(vecstr(DSGEModel.ZVariableNames(DSGEModel.ConditionalVariables,:),' '),40);
   fprintf(fid,'Names of conditional variables:                    %s\n',VarNames(1,:));
   for i=2:size(VarNames,1);
      if strcmp(StringTrim(VarNames(i,:)),'')==0;
         fprintf(fid,'                                                   %s\n',VarNames(i,:));
      end;
   end;
   if DSGEModel.ShockControlMethod==1;
      ShockMethod = 'Values for shocks';
   elseif DSGEModel.ShockControlMethod==2;
      ShockMethod = 'Distribution of shocks (Waggoner-Zha)';
   else;
      ShockMethod = 'Distribution of subset of shocks';
   end;
   fprintf(fid,'Conditioning method:                               %s\n',ShockMethod);
end;
if isempty(PathPITMatrix)==1;
   fprintf(fid,'Computation time:                                  %s (hrs:min:sec)\n\n',SecondsToHoursStr(CompTimeStepOne));
else;
   fprintf(fid,'Computation time (moment based PITs):              %s (hrs:min:sec)\n',SecondsToHoursStr(CompTimeStepOne));
   fprintf(fid,'Computation time (path based PITS):                %s (hrs:min:sec)\n',SecondsToHoursStr(CompTimeStepTwo));
   fprintf(fid,'Total computation time:                            %s (hrs:min:sec)\n\n',SecondsToHoursStr(CompTimeStepOne+CompTimeStepTwo));
end;
%
PrtVal = ['%' num2str(3+CurrINI.decimals,'%0.0f') '.' num2str(CurrINI.decimals,'%0.0f') 'f'];
%
FirstStr = MultiCharStr('=',70);
DivStr = MultiCharStr('-',70);
PrtStr1 = ['%s%s     %2.0f     %s      ' PrtVal '      ' PrtVal ' \n'];
PrtStr2 = ['                         %2.0f     %s      ' PrtVal '      ' PrtVal ' \n'];
%
nv = size(DSGEModel.VariableNames,2);
if nv<20;
   AddStr = SpaceStr(20-nv);
else;
   AddStr = '';
end;
VarStr = vecstr(DSGEModel.VariableNames(PredictionVariables,:),', ');
VarStr = VarStr(1:length(VarStr)-1);
%
fprintf(fid,'%s\n',FirstStr);
fprintf(fid,'                                           Moment based PIT estimates \n');
fprintf(fid,'    Variable          Horizon   Period       uniform        normal \n');
fprintf(fid,'%s\n',DivStr);
for i=1:n;
   fprintf(fid,PrtStr1,DSGEModel.VariableNames(i,:),AddStr,1,PredictionSampleStrMat(1,:),PITMatrix(i,1),norminv(PITMatrix(i,1)));
   for j=2:h;
      fprintf(fid,PrtStr2,j,PredictionSampleStrMat(j,:),PITMatrix(i,j),norminv(PITMatrix(i,j)));
   end;
   if i<n;
      fprintf(fid,'%s\n',DivStr);
   else;
      fprintf(fid,'%s\n',FirstStr);
      fprintf(fid,'Selected prediction variables: %s \n',VarStr);
      fprintf(fid,'%s\n',DivStr);
      for j=1:h;
         fprintf(fid,PrtStr2,j,PredictionSampleStrMat(j,:),PITMatrix(n+1,j),norminv(PITMatrix(n+1,j)));
      end;
      fprintf(fid,'%s\n\n',FirstStr);
   end;
end;
%
% now check if we should print backcast and nowcast based PITs to file
%
if isempty(BNPITMatrix)==0;
   fprintf(fid,'%s\n',FirstStr);
   fprintf(fid,'                                           Moment based PIT estimates \n');
   fprintf(fid,'    Variable          Horizon   Period       uniform        normal \n');
   fprintf(fid,'%s\n',DivStr);
   for i=1:n;
      fprintf(fid,PrtStr1,DSGEModel.VariableNames(i,:),AddStr,-1,HistSampleStrMat(1,:),BNPITMatrix(i,1),norminv(BNPITMatrix(i,1)));
      fprintf(fid,PrtStr2,0,HistSampleStrMat(2,:),BNPITMatrix(i,2),norminv(BNPITMatrix(i,2)));
      if i<n;
         fprintf(fid,'%s\n',DivStr);
      else;
         fprintf(fid,'%s\n',FirstStr);
         fprintf(fid,'Selected prediction variables: %s \n',VarStr);
         fprintf(fid,'%s\n',DivStr);
         for j=1:2;
            fprintf(fid,PrtStr2,j-2,HistSampleStrMat(j,:),BNPITMatrix(n+1,j),norminv(BNPITMatrix(n+1,j)));
         end;
         fprintf(fid,'%s\n\n',FirstStr);
      end;
   end;
end;
%
% check if we should print tha path-based PITs to file
%
if isempty(PathPITMatrix)==0;
   fprintf(fid,'%s\n',FirstStr);
   fprintf(fid,'                                            Path based PIT estimates \n');
   fprintf(fid,'    Variable          Horizon   Period       uniform        normal \n');
   fprintf(fid,'%s\n',DivStr);
   for i=1:n;
      fprintf(fid,PrtStr1,DSGEModel.VariableNames(i,:),AddStr,1,PredictionSampleStrMat(1,:),PathPITMatrix(i,1),norminv(PathPITMatrix(i,1)));
      for j=2:h;
         fprintf(fid,PrtStr2,j,PredictionSampleStrMat(j,:),PathPITMatrix(i,j),norminv(PathPITMatrix(i,j)));
      end;
      if i<n;
         fprintf(fid,'%s\n',DivStr);
      else;
         fprintf(fid,'%s\n\n',FirstStr);
      end;
   end;
end;
%
% bottom file data
%
fprintf(fid,'********************************************************************************\n\n');
fprintf(fid,'Directory for file: %s\n',GetPath(ResFile));
fprintf(fid,'Name of file:       %s\n',GetFilename(ResFile));
fprintf(fid,'Output created on:  %s\n\n',datestr(now,0));
fclose(fid);

%
% end of PrintPITs.m
%
