function PrintPredictiveMoments(ResFile,PredY,CovPred,PredictionSampleStrMat,BNPredictY,BNCov,BNSampleStrMat,lambda,NumDraws,TotalDraws,NumBurnin,IsPosterior,IsConditional,IsAdaptiveLearning,CompTime,DSGEModel,CurrINI)
% PrintPredictiveMoments: Prints marginal predictive means and standard deviations to a text file.
%
% USAGE:
%
%       PrintPredictiveMoments(ResFile,PredY,CovPred,PredictionSampleStrMat,BNPredictY,BNCov,BNSampleStrMat,lambda,...
%                              NumDraws,TotalDraws,NumBurnin,IsPosterior,IsConditional,IsAdaptiveLearning,...
%                              CompTime,DSGEModel,CurrINI)
%
% REQUIRED INPUT: ResFile (string) with the full path and name of the text-file where the results
%                         are written.
%
%                 PredY (matrix) of dimension nxh with the h-step-ahead forecast of the n observed variables.
%
%                 CovPred (matrix) of dimension nxnxh with h-step-ahead forecast error covariance matrix.
%
%                 PredictionSampleStrMat (string matrix) with the prediction sample dates.
%
%                 BNPredictY (matrix) of dimension nx2 with the back- and the nowcast of the n observed
%                         variables. Can be an empty matrix.
%
%                 BNCov (matrix) of dimension nxnx2 with the covariance matrix of the observables for the
%                         back- and the nowcast.
%
%                 BNSampleStrMat (string matrix) with the date of the back- and the nowcast.
%
%                 lambda (scalar) with the lambda hyperparameter of the DSGE-VAR.
%
%                 NumDraws (integer) with the number of used parameter draws.
%
%                 TotalDraws (integer) with the total number of available parameter draws.
%
%                 NumBurnin (integer) with the number of burn-in draws.
%
%                 IsPosterior (boolean) with is 1 if posterior draws have been used and 0 if the predictive
%                         moments have been computed using prior draws.
%
%                 IsConditional (boolean) that takes the value 1 if conditional forecasts have been used and 0
%                         otherwise.
%
%                 IsAdaptiveLearning (boolean) that takes the value 1 if the adaptive learning mechanism is used for the
%                         expectations formation, and 0 otherwise.
%
%                 CompTime (time) with the computational time.
%
%                 DSGEModel (structure) whose fields contain all required information
%                         about the model, such as input files, variable and sample data.
%
%                 CurrINI (structure) with initialization information.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2025 European Central Bank.
%
%                       First version: February 6, 2014.
%                        This version: January 9, 2025.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 09-02-2015: Updated the documentation.
%
% * 22-02-2016: Updated the documentation.
%
% * 22-03-2017: Updated the documentation.
%
% * 24-10-2017: Added the input variables "BNPredictY", "BNCov", and "BNSampleStrMat".
%
% * 14-05-2018: Updated the documentation.
%
% * 24-01-2019: Updated the documentation.
%
% * 10-01-2020: Updated the documentation.
%
% * 26-01-2021: Updated the documentation.
%
% * 18-05-2021: Added the input variable "IsAdaptiveLearning".
%
% * 06-01-2022: Updated the documentation.
%
% * 06-01-2023: Updated the documentation.
%
% * 19-01-2024: Updated the documentation.
%
% * 30-07-2024: Added the input variable "IsConditional".
%
% * 09-01-2025: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

fid = fopen(ResFile,'wt');
fprintf(fid,'********************************************************************************\n');
fprintf(fid,'*                                                                              *\n');
fprintf(fid,'*            P O P U L A T I O N - B A S E D   P R E D I C T I V E             *\n');
fprintf(fid,'*            M E A N S   &   S T A N D A R D   D E V I A T I O N S             *\n');
if IsAdaptiveLearning==1;
   fprintf(fid,'*                      A D A P T I V E   L E A R N I N G                       *\n');
end;
fprintf(fid,'*                                                                              *\n');
fprintf(fid,'********************************************************************************\n\n');
%
if IsPosterior==1;
   DistStr = 'Posterior';
else;
   DistStr = 'Prior';
end;
%
PrtVal = ['%' int2str(6+CurrINI.decimals) '.' int2str(CurrINI.decimals) 'f'];
%
fprintf(fid,'Parameter draws:                                   %s distribution \n',DistStr);
if IsPosterior==1;
   fprintf(fid,'Number of available posterior draws:               %0.0f\n',TotalDraws);
   fprintf(fid,'Number of used draws:                              %0.0f\n',NumDraws);
   fprintf(fid,'Number of burn-in draws:                           %0.0f\n',NumBurnin);
else;
   fprintf(fid,'Number of available prior draws:                   %0.0f\n',TotalDraws);
end;
if isempty(lambda)==0;
   fprintf(fid,'Number of lags in DSGE-VAR:                        %0.0f \n',DSGEModel.BVARLags);
   fprintf(fid,'Lambda:                                            %0.4f \n',lambda);
end;
if IsAdaptiveLearning==1;
   fprintf(fid,'Number of forward variables:                       %0.0f\n\n',length(DSGEModel.ForwardVariablePositions));
   fprintf(fid,'Name of belief system:                             %s\n',DSGEModel.BeliefSys.Name);
   if DSGEModel.BeliefSystem==1;
      fprintf(fid,'Belief system file:                                YADA''s default (two own lags)\n');
   else;
      fprintf(fid,'Belief system file:                                %s\n',GetFilename(DSGEModel.BeliefSystemFile));
      fprintf(fid,'Maximum lag order:                                 %0.0f\n', DSGEModel.BeliefSys.m);
   end;
end;
if IsConditional==1;
   VarNames = StrWrap(vecstr(DSGEModel.ZVariableNames(DSGEModel.ConditionalVariables,:),' '),40);
   fprintf(fid,'Names of conditional variables:                    %s\n',VarNames(1,:));
   for i=2:size(VarNames,1);
      if strcmp(StringTrim(VarNames(i,:)),'')==0;
         fprintf(fid,'                                                   %s\n',VarNames(i,:));
      end;
   end;
   if DSGEModel.ShockControlMethod==1;
      ShockMethod = 'Values for shocks';
   elseif DSGEModel.ShockControlMethod==2;
      ShockMethod = 'Distribution of shocks (Waggoner-Zha)';
   else;
      ShockMethod = 'Distribution of subset of shocks';
   end;
   fprintf(fid,'Conditioning method:                               %s\n',ShockMethod);
end;
fprintf(fid,'Computation time:                                  %s (hrs:min:sec)\n\n',SecondsToHoursStr(CompTime));
%
[n,nv] = size(DSGEModel.VariableNames);
h = size(PredY,2);
if nv<15;
   AddStr = SpaceStr(15-nv);
else;
   AddStr = '';
end;
FirstStr = MultiCharStr('=',53);
DivStr = MultiCharStr('-',53);
PrtStr = ['%s%s     ' PrtVal '     ' PrtVal '\n'];
%
for i=1:h;
   fprintf(fid,'%s\n',FirstStr);
   fprintf(fid,'Forecast period %1.0f: %s\n',i,PredictionSampleStrMat(i,:));
   fprintf(fid,'  Variable              Mean      Standard deviation\n');
   fprintf(fid,'%s\n',FirstStr);
   for j=1:n;
      fprintf(fid,PrtStr,DSGEModel.VariableNames(j,:),AddStr,PredY(j,i),sqrt(CovPred(j,j,i)));
      if j<n;
         fprintf(fid,'%s\n',DivStr);
      else;
         fprintf(fid,'%s\n\n',FirstStr);
      end;
   end;
end;
%
% check if we have back and nowcast data
%
if isempty(BNPredictY)==0;
   for i=1:2;
      fprintf(fid,'%s\n',FirstStr);
      if i==1;
         fprintf(fid,'Backcast period: %s\n',BNSampleStrMat(1,:));
      else;
         fprintf(fid,'Nowcast period:  %s\n',BNSampleStrMat(2,:));
      end;
      fprintf(fid,'  Variable              Mean      Standard deviation\n');
      fprintf(fid,'%s\n',FirstStr);
      for j=1:n;
         fprintf(fid,PrtStr,DSGEModel.VariableNames(j,:),AddStr,BNPredictY(j,i),sqrt(BNCov(j,j,i)));
         if j<n;
            fprintf(fid,'%s\n',DivStr);
         else;
            fprintf(fid,'%s\n\n',FirstStr);
         end;
      end;
   end;
end;
%
% bottom file data
%
fprintf(fid,'********************************************************************************\n\n');
fprintf(fid,'Directory for file: %s\n',GetPath(ResFile));
fprintf(fid,'Name of file:       %s\n',GetFilename(ResFile));
fprintf(fid,'Output created on:  %s\n\n',datestr(now,0));
fclose(fid);

%
% end of PrintPredictiveMoments.m
%
