function [PITMatrix,BNPITMatrix] = ComputePITs(YTrueValues,YHist,BackYData,PredictionVariables,MatFile,Weights,IsPosterior,mvncdfExist,CurrINI)
% ComputePITs: Computes the PITs as in Amisano and Geweke (2017, RESTAT) for the individual
%              variables and for the specified combination of individual variables.
%
% USAGE:
%
%       [PITMatrix,BNPITMatrix] = ComputePITs(YTrueValues,YHist,BackYData,PredictionVariables,MatFile, ...
%                                             Weights,IsPosterior,mvncdfExist,CurrINI)
%
% REQUIRED INPUT:  YTrueValues (matrix) of dimension n x h with the true values of the
%                              observed variables over the forecast horizon.
%
%                  YHist (matrix) of dimension n x 2 with the historical data on the observed
%                              variables in the last two historical time periods.
%
%                  BackYData (matrix) of dimension n x 2 with the true values of the observed
%                              variables in the last two historical time periods. Used for
%                              back and nowcasts.
%
%                  PredictionVariables (vector) with the integer values of the observed
%                              variables for which joint PITs should be computed.
%
%                  MatFile (string) with the full path and names of the mat-file which
%                              includes the mean and covariance matrix over the forecast
%                              horizon, as well as possibly also the one-period backcast
%                              and the nowcast.
%
%                  Weights (vector) of dimension NumDraws x 1 with the importance weights
%                              from the SMC with likelihood tempering posterior sampler.
%
%                  IsPosterior (boolean) which takes the value 1 if posterior draws are
%                              used and 0 otherwise.
%
%                  mvncdfExist (boolean) that takes the value 1 if the matlab function
%                              mvncdf exists, and 0 otherwise.
%
%                  CurrINI (structure) with initialization information.
%
% REQUIRED OUTPUT: PITMatrix (matrix) of dimension (n+1) x h with the PIT values for the n
%                              observed variables and the joint PIT for the specified
%                              combination in PredictionVariables over the forecast horizon.
%
%                  BNPITMatrix (matrix) of dimension (n+1) x 2 with the PIT values for the n
%                              observed variables and the joint PIT for the specified
%                              combination in PredictionVariables for the one-period backcast
%                              and the nowcast.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2025 European Central Bank.
%
%                       First version: August 25, 2020.
%                        This version: January 10, 2025.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 26-08-2020: Updated the documentation.
%
% * 23-10-2020: Fixed a bug when initializing BNPITMatrix, where all values were NaN
%               before and now only those that won't be computed are NaN.
%
% * 26-10-2020: Added to check if the covariance matrix is symmetric.
%
% * 27-01-2021: Remember Shoah.
%
% * 06-01-2022: Updated the documentation.
%
% * 06-01-2023: Updated the documentation.
%
% * 25-01-2024: Updated the documentation.
%
% * 01-08-2024: Changed zero-values of PITMatrix and BNPITMatrix to NaN.
%
% * 10-01-2025: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

BNPITMatrix = [];
ForecastData = load(MatFile);
NumDraws = length(ForecastData.PITMoments);
[n,h] = size(ForecastData.MeanPredictY);
if isempty(Weights)==1;
   Weights = ones(NumDraws,1);
end;
PITMatrix = zeros(n+1,h);
%
% setup a wait dialog
%
PriorHeader = '';
if IsPosterior==0;
   PriorHeader = ' For Prior';
end;
%
% check if we should setup a wait handle
%
txt = ['Please wait while YADA computes probability integral transform (PIT) values based on the predictive means and covariance matrices conditional on the parameters. Computations started at: ' StringTrim(datestr(now,14))];
WaitHandle = WaitDLG(txt,'information',['Probability Integral Transform ' PriorHeader ' - ' int2str(h) ' Periods Ahead'],600,200,CurrINI,0);
WaitControls = get(WaitHandle,'UserData');
%
% begin the loop with the forecasted values
%
for ParamIndex=1:NumDraws;
   MeanVar = ForecastData.PITMoments(ParamIndex).PredictY;
   CovVar = ForecastData.PITMoments(ParamIndex).PredictYCov;
   for j=1:h;
      for i=1:n;
         %
         % compute the PIT for variable j and horizon i using
         % parameter draw number ParamIndex
         %
         PITvalue = normcdf(YTrueValues(i,j),MeanVar(i,j),sqrt(CovVar(i,i,j)));
         PITMatrix(i,j) = PITMatrix(i,j)+((Weights(ParamIndex)/NumDraws)*PITvalue);
      end;
      if IsSymmetric(CovVar(PredictionVariables,PredictionVariables,j))==1;
         Sigma = CovVar(PredictionVariables,PredictionVariables,j);
      else;
         [V,D] = eig(CovVar(PredictionVariables,PredictionVariables,j));
         Sigma = real(V*D*V');
      end;
      if mvncdfExist==1;
         PITvalue = mvncdf(YTrueValues(PredictionVariables,j),MeanVar(PredictionVariables,j),Sigma);
      else;
         PITvalue = YADAmvncdf(YTrueValues(PredictionVariables,j),MeanVar(PredictionVariables,j),Sigma,0.0001,99.5,1000);
      end;
      PITMatrix(n+1,j) = PITMatrix(n+1,j)+((Weights(ParamIndex)/NumDraws)*PITvalue);
   end;
   drawnow;
end;
ZeroPos = (PITMatrix==0);
if max(max(ZeroPos))==1;
   PITMatrix(ZeroPos) = NaN;
end;
%
% check if we should compute back and nowcast
%
NaNHist = isnan(YHist);
if (max(max(NaNHist))==1)&(isfield(ForecastData.PITMoments(1),'BNPredictY'));
   BNPITMatrix = NaN*ones(n+1,2);
   %
   % check if prediction variables are both missing
   %
   NaNhelp = sum(NaNHist(PredictionVariables,:),1);
   NaNhelp = (NaNhelp==length(PredictionVariables)*ones(1,2));
   NaNhelp = [NaNHist;NaNhelp];
   BNPITMatrix(NaNhelp) = 0;
   %
   for ParamIndex=1:NumDraws;
      MeanVar = ForecastData.PITMoments(ParamIndex).BNPredictY;
      CovVar = ForecastData.PITMoments(ParamIndex).BNPredictYCov;
      for j=1:2;
         for i=1:n;
            if NaNHist(i,j)==1;
               PITvalue = normcdf(BackYData(i,j),MeanVar(i,j),sqrt(CovVar(i,i,j)));
               BNPITMatrix(i,j) = BNPITMatrix(i,j)+((Weights(ParamIndex)/NumDraws)*PITvalue);
            end;
         end;
         if IsSymmetric(CovVar(PredictionVariables,PredictionVariables,j))==1;
            Sigma = CovVar(PredictionVariables,PredictionVariables,j);
         else;
            [V,D] = eig(CovVar(PredictionVariables,PredictionVariables,j));
            Sigma = real(V*D*V');
         end;
         if sum(NaNHist(PredictionVariables,j))==length(PredictionVariables);
            if mvncdfExist==1;
               PITvalue = mvncdf(BackYData(PredictionVariables,j),MeanVar(PredictionVariables,j),Sigma);
            else;
               PITvalue = YADAmvncdf(BackYData(PredictionVariables,j),MeanVar(PredictionVariables,j),Sigma,0.0001,99.5,1000);
            end;
            BNPITMatrix(n+1,j) = BNPITMatrix(n+1,j)+((Weights(ParamIndex)/NumDraws)*PITvalue);
         end;
      end;
      drawnow;
   end;
   ZeroPos = (BNPITMatrix==0);
   if max(max(ZeroPos))==1;
      BNPITMatrix(ZeroPos) = NaN;
   end;
end;
%
% delete the wait dialog
%
set(WaitControls.text,'UserData','done');
delete(WaitHandle);
drawnow;
pause(0.02);

%
% end of ComputePITs.m
%
