function YADAHandle = YADAGUI(selector,optcmd)
% YADAGUI: Creates the Graphical User Interface for YADA.
%
% USAGE:
%
%       YADAHandle = YADAGUI(selector,optcmd)
%
% REQUIRED INPUT:  selector (string vector) for a case switch function.
%
% OPTIONAL INPUT:  optcmd (string) which supports the values empty (default),
%                         "--driver" and "--seq-driver".
%
% OPTIONAL OUTPUT: YADAHandle (integer) with the handle to the GUI.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2025 European Central Bank.
%
%                       First version: July 21, 2006.
%                        This version: January 28, 2025.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <https://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <https://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 24-7-2006 -
%   05-01-2009: Added major GUI functionality.
%
% * 12-01-2009: Added conditional correlations for posterior mode
%               and initial values.
%
% * 13-01-2009: Started working on conditional correlations for
%               the posterior draws.
%
% * 15-01-2009: Additional data can now be stored when running the conditional
%               and unconditional predictions for fixed parameter values.
%
% * 29-01-2009: Added the control controls.optimize.initcsminwel for choosing
%               the initial value for the inverse Hessian when running the
%               csminwel optimization routine.
%
% * 30-01-2009: Made sure that error messages from running the "SolveDSGEModel" function are
%               always caught.
%
% * 12-02-2009: Added the function to estimate the parameter covariance matrix from draws
%               from the posterior distribution. The option to use a user specified parameter
%               covariance matrix for the proposal density in the random-walk Metropolis
%               algorithm was also added.
%
% * 14-02-2009: Moved the function "Parameter Covariance Matrix" from the Actions menu
%               to the View menu.
%
% * 19-02-2009: Added code on the conditional correlations function for the posterior
%               draws. Fixed a bug where deselecting certain state shocks could make the
%               used length of shocks and variables for conditional forecasts and/or observed
%               variable scenarios different.
%
% * 24-02-2009: Added code for computing impulse responses based on shocks groups.
%
% * 25-02-2009: Added code for preparing graphs of the posterior densities for the
%               parameters that are function of the estimated parameters.
%
% * 26-02-2009: Took into account that the function "GetUpdatePosteriorDraws" takes
%               an additional variable as input. View conditioning data code was also
%               added.
%
% * 27-02-2009: Added code for estimating the prior densities of the parameters
%               that are a function of the estimated parameters.
%
% * 02-03-2009: Added code for displaying the prior densities of the parameters
%               that are a function of the estimated parameters. The functions for
%               saving the state-space matrices to disk were also added.
%
% * 03-03-2009: Added code for saving and viewing marginal predictive densties based
%               on kernel density estimation for each prediction period.
%
% * 09-03-2009: Added quotation marks around paths for the dos del and copy commands.
%
% * 12-03-2009: Updated the documentation.
%
% * 13-03-2009: Removed check if "YADAbetarnd" and "betarnd" exist. The "YADARndBeta" now allow all
%               systems to get random draws from the beta distribution.
%
% * 18-03-2009: Added missing semi-colons when defining "UnSelectedGroups". Improved the
%               suggested selected of shock belonging to a shock groups when changes has been
%               made relative to what was previously suggested.
%
% * 20-03-2009: Changed the label of posterior distribution based functions on the menus
%               from "Distribution" to "Posterior Distribution". This will open up for
%               having "Prior Distribution" functions from impulse responses, etc., that
%               use random draws from the prior.
%
% * 22-03-2009: Added the function "Prior Sampling".
%
% * 23-03-2009: Added "Prior Distribution" code for observed variable correlations and
%               conditional correlations.
%
% * 24-03-2009: Added "Prior Distribution" code for state variable correlations, state shock
%               correlations, measurement error correlations, 1-step ahead forecasts, state
%               variables, state shocks, and measurement errors.
%
% * 25-03-2009: Began work on "Prior Distribution" code for unconditional predictions.
%
% * 26-03-2009: Finished "Prior Distribution" code for unconditional predictions. Began coding
%               the same functionality for the conditional predictions.
%
% * 27-03-2009: Finished "Prior Distribution" code for the conditional predictions. Added such
%               code for forecast error decompositions, impulse responses, and conditional
%               forecast error variances.
%
% * 29-03-2009: Added "Prior Distribution" code for variance decompositions.
%
% * 30-03-2009: Added the plot-a-prior function.
%
% * 07-04-2009: Changed the maximum height of the "YADA - Error Message" message boxes.
%
% * 08-04-2009: Fixed a bug where a controls could have the "Enable" property set to "of". Added
%               the "Import YADA Settings" function to the file menu.
%
% * 09-04-2009: Made sure that more than 1 lag of the state equation is treated as an error and that
%               the proper message is displayed for it.
%
% * 15-04-2009: Added calls to "VerifyStateScenarioInformation".
%
% * 16-04-2009: Added enabling and disabling code for various state variable scenarios controls.
%
% * 22-04-2009: Added code for running observed variable decomposition paths at initial values and
%               at posterior mode.
%
% * 23-04-2009: Began work on observed variable decomposition paths for draws from the posterior
%               distribution.
%
% * 24-04-2009: Finished the observed variable decomposition paths for posterior draws, and added all
%               code for the same type of decompositions for the prior draws.
%
% * 30-04-2009: Took into account that the status output from the Kalman filter can now also be -1, i.e.,
%               that the state covariance matrix is not positive definite for some dates.
%
% * 04-05-2009: Made sure that Query primarily uses the 'question' image instead of the 'information'
%               image.
%
% * 18-05-2009: Added the values of the input variablea "RecEst" and "HeaderStr" for "CalculateDSGEStateVariables".
%
% * 12-06-2009: Added the "Extending YADA" item to the Help menu.
%
% * 24-06-2009: The sequential estimation of the modified harmonic mean estimator of the marginal likelihood can
%               now optionally be computed for the full sample of posterior draws only. The results are then
%               displayed in a TextGUI dialog.
%
% * 25-06-2009: The sequential estimation of the Chib-Jeliazkov estimator of the marginal likelihood can now
%               optionally be computed for the full sample of the posterior draws only. The results are then
%               displayed in a TextGUI dialog. Added the computation of the eigenvalues for the Bayesian
%               VAR at posterior mode.
%
% * 14-07-2009: Added code for running forecasts conditional on state variable assumptions.
%
% * 20-07-2009: The Eagle has landed.
%
% * 21-07-2009: 3 year anniversary!
%
% * 22-07-2009: Added the value for "CondTypeStr" to the "DSGEModestyStatistics" function.
%
% * 31-07-2009: Took the support for "CovPrediction" from "DSGEPredictionDistribution" into account.
%
% * 03-08-2009: Took the support for "CovPrediction" from "BVARPredictionDistribution" into account.
%
% * 11-08-2009: The outputdir controls are now also enabled when the data construction file exists.
%
% * 14-08-2009: Changed a dialog header from "State Variables - Posterior Mode" to "State Variables - Initial Values"
%               since the latter parameter values were used.
%
% * 18-08-2009: Made sure that OutputDirectory is only changed when the model name changes if it was equal to
%               the YADA base directory.
%
% * 19-08-2009: Made sure that the control "viewstateconditionalvars" is only enabled and disabled when it
%               exists.
%
% * 26-08-2009: Added try-catch code when attempting to load data from the posterior mode
%               results file. This prevents YADA from crashing if the mat-file was created
%               with a more recent matlab version than the version currently running the code.
%
% * 16-09-2009: Added the "Decompositions" menu item to the Tools menu, under which forecast error
%               decompositions, observed variable and state variable decompositions, variance and
%               conditional variable decompositions reside as well as the new observation weights
%               item.
%
% * 17-09-2009: Began work on the observation weight code for the posterior mode.
%
% * 18-09-2009: Made sure that "lasterr" is reset to an empty string.
%
% * 24-09-2009: The DSGEModel fields "ObsVarGroups", "ObsVarGroupNames", and "ObsVarGroupColors" are
%               now properly initialized.
%
% * 25-09-2009: Added controls and callback for performing observation weight decompositions of state
%               variables and shocks at initial parameter values.
%
% * 28-09-2009: The function "GraphPriorDensity" now requires the input variables "thetaPositions"
%               and "ModelParameters".
%
% * 29-09-2009: Added controls for the observation weights for the posterior mode values as well as
%               the callback function.
%
% * 30-09-2009: Added controls and callback code for the observation weights at the initial values.
%
% * 05-10-2009: Started working on spectral decompositions code for the posterior mode of the DSGE model.
%
% * 06-10-2009: Finished the code on spectral decompositions for the DSGE model at posterior mode.
%
% * 08-10-2009: Added spectral decompositions code for the initial values.
%
% * 09-10-2009: The "DSGEObservationWeightsTheta" function is now executed with try-catch code.
%
% * 12-10-2009: Moreover, the catch statement tries to capture the handle of the wait dialog so that
%               it can be properly closed.
%
% * 15-10-2009: Fixed "fopen" issues when writing to a script-file and the path contains characters that
%               YADA had removed from the path-string.
%
% * 09-11-2009: Added support for the "DSGEModel" field "MCMCSampler".
%
% * 27-11-2009: Changed the name of the posterior sampling function to "posterior_sampling", which can now
%               either call the random walk Metropolis function or the slice sampling function.
%
% * 02-12-2009: Updated the documentation.
%
% * 04-12-2009: Fixed a bug for DSGEModel.U where a longer conditioning horizon than the number of
%               historical time periods would lead to taking negative columns of the initial conditions
%               for the conditioning assumptions. This issue is fixed by setting the required additional
%               conditioning assumptions for periods 0, -1, -2, etc. equal to the value for period 1.
%
% * 23-12-2009: The call to "GetUpdatePriorDensity" now has a temporary CurrINI structure with the field
%               name "UpdateNames" included. This makes it possible to get information about problematic
%               prior densities for the updated parameters. The information matrix functions now also
%               call functions for determining identification patterns a la Michal Andrle.
%
% * 05-01-2010: The information matrix functions now examine the eigenvalues and eigenvectors of the matrix
%               and write the text-file its findings when the smallest eigenvalue is below 0.01.
%
% * 14-01-2010: The Chib & Jeliazkov estimator of the marginal likelihood is now disabled when the user has
%               selected the slice sampler for DSGE model sampling.
%
% * 18-01-2010: Began adding DSGE-VAR features to the GUI.
%
% * 19-01-2010: The code for estimating the marginal posterior mode of the DSGE model parameters from the
%               DSGE-VAR model was added.
%
% * 28-01-2010: Added code for selecting the shocks of the DSGE model that can be used by the DSGE-VAR. The
%               code for estimating the joint posterior mode of the DSGE model and DSGE-VAR parameters
%               was also added.
%
% * 12-02-2010: Moved callbacks from the BVAR, DSGE-VAR, Edit, and Help menus in "YADAGUI" to the
%               "BVARMenuFunctions", "DSGEVARMenuFunctions", "EditMenuFunctions", and the
%               "HelpMenuFunctions" files.
%
% * 13-02-2010: Moved callbacks from the Actions and File menus in "YADAGUI" to the "ActionsMenuFunctions"
%               and "FileMenuFunctions" files.
%
% * 14-02-2010: Moved callbacks from the view menu in "YADAGUI" to the "ViewMenuFunctions" file.
%
% * 15-02-2010: Moved callback from the tools menu in "YADAGUI" to the "ToolsMenuFunctions" file.
%
% * 16-02-2010: Finished deleting callbacks in "YADAGUI" that concern the tools menu.
%
% * 18-02-2010: Added the DSGE-VAR prior sampling control.
%
% * 19-02-2010: Added controls for viewing DSGE-VAR model using initial and posterior mode values.
%
% * 20-02-2010: Added controls for viewing posterior mode results for DSGE-VARs.
%
% * 22-02-2010: Added controls for checking the optimum for DSGE-VARs.
%
% * 23-02-2010: Added controls for DSGE-VAR impulse responses for single parameters.
%
% * 24-02-2010: Added controls for DSGE-VAR optimization error summary.
%
% * 25-02-2010: Added controls for DSGE-VAR shock estimation for single parameters.
%
% * 02-03-2010: Added controls for DSGE-VAR posterior sampling summary and view raw posterior draws.
%
% * 03-03-2010: Moved all menu controls to separate menu functions.
%
% * 19-05-2010: Added fast redraw commands at the top of the function to ensure that the GUI
%               is refreshed as soon as possible.
%
% * 23-11-2010: Made sure that the "ShowStatus" function is only executed when IsWinXP is unity.
%
% * 14-12-2010: Enhanced the GUI to allow for DSGE model solver selection, Kalman filter algorithm
%               selection, and to select the maximum number of extra csminwel runs after the original
%               optimization run. The height of the GUI was therefore increased by 30 pixels.
%
% * 25-12-2010: Changed "inverse Wishart" to "inverted Wishart".
%
% * 09-01-2011: The function now supports unix and mac paths.
%
% * 11-01-2011: Added more code for dealing with system consistent paths.
%
% * 12-01-2011: Added additional support for unix and mac paths.
%
% * 13-01-2011: Made sure that the paths from uigetfile ends with '/' on unix and mac.
%
% * 25-01-2011: The function now supports the "YTransMatrix" field of the "DSGEModel" structure.
%
% * 27-01-2011: 66 years ago since the liberation of Auschwitz and Birkenau. Changed behavior of IsWinXP
%               to handle unix and mac status.
%
% * 31-01-2011: Excel spreadsheets with file extension ".xls*" are now supported. Added try-catch code around
%               the "xlsfinfo" and "wk1finfo" functions.
%
% * 09-02-2011: YADA can now shut down in some situations where it has frozen in some other function.
%
% * 10-03-2011: Took into account that "YNaNs" is now a field of the "DSGEModel" structure.
%
% * 17-03-2011: And it's St Patrick's Day! YADA has gone green.
%
% * 21-03-2011: Added the option to used mixed distribution of shocks for the conditional forecasts.
%
% * 22-03-2011: Added tests before resetting the "DSGEModel.ShockControlMethod" value on the control
%               "controls.forecast.shockcontrols".
%
% * 06-04-2011: Added the toolbar item "Configure Shocks".
%
% * 19-05-2011: Made sure that "YADAEnableControls" is run after "DSGEModel" and "CurrINI" are stored
%               as userdata in "controls.open" and "controls.filemenu", respectively. This ensures that
%               "Save Model" uses the latest values for the fields of these structures.
%
% * 04-07-2011: Happy 4th of July, folks!
%
% * 05-07-2011: The DSGEModel field "MaximizeAlgorithmValue" has been altered to allow the user to optimize
%               with respect to the original parameters as well as to the transformed parameters.
%
% * 07-07-2011: Added the newrat options to the posterior mode estimation selection.
%
% * 12-07-2011: Added gmhmaxlik options to the posterior mode estimation selection.
%
% * 21-07-2011: The 5 year anniversary!
%
% * 04-10-2011: Added the "univariate filter" option to the Kalman filter selection control.
%
% * 17-10-2011: Allowed "DSGEModel.UseDoublingAlgorithm" to take the value 4 when the diffuse Kalman filter
%               should be used.
%
% * 18-10-2011: Fixed issues to ensure that diffuse initialization can function with square-root filtering.
%               The latter then uses the univariate approach during the initialization phase.
%
% * 13-12-2011: DSGEModel.YNaNs variable is now reset depending on the selected sample when DSGEModel.Y has
%               missing observations.
%
% * 09-02-2012: Added code for requiring posterior draws of VAR models to enforce stationarity.
%
% * 28-02-2012: Added the possibility of selecting 1 path per parameters value when forecasting.
%
% * 01-03-2012: More posterior draws can now be used for prediction and simulation.
%
% * 13-03-2012: The prior mean for the BVAR can now be unity for the first lag.
%
% * 03-04-2012: Dave C is 55 today.
%
% * 05-06-2012: Took the controls "controls.stateeqmenu" and "controls.stateeq" for selecting state equations
%               into account.
%
% * 20-08-2012: Added the "confidence region estimation method" controls.
%
% * 25-09-2012: Fixed a bug when a single sheet for the prior file is available and xlsfinfo provides
%               a cell array with that sheet-name rather than a string with the sheet-name.
%
% * 15-11-2012: Added support for selecting the Chandrasekhar recursions when using the Kalman filter.
%
% * 30-11-2012: Added the possibility of computing the marginal likelihood with Sims, Waggoner and Zha's
%               truncated elliptical distribution for the harmonic mean.
%
% * 26-04-2013: Fixed a bug determining DSGEModel.k when DataStructure.X.names is a 1x1 cell array
%               with an empty element.
%
% * 17-07-2013: Opened the Waggoner-Zha and mixed approaches to conditional forecasting for all YADA releases.
%
% * 28-08-2013: I have a dream... and YADA now supports a user selected number of posterior draws and burnin
%               draws in addition to the selection of prespecified selection numbers of such draws.
%
% * 11-09-2013: Changed the size of the GUI to match small screen sizes (such as 768 pixels in height) better.
%
% * 16-09-2013: Adjusted the window height of the GUI to 655 when the screen size is less than or equal to 768.
%
% * 18-09-2013: Changed the GUI height to 655 pixels for all screen sizes.
%
% * 29-01-2014: YADA now assumes that the oldest used OS under Windows is XP.
%
% * 14-08-2014: Added try-catch code when attempting to read a DSGE model file.
%
% * 15-08-2014: Took into account that the DSGEModel structure now has the fields "ZLBData" and "ZLBPosition"
%               which are determined from the data construction file.
%
% * 20-08-2014: Fixed a bug where the DSGEModel fields "ShockControlMethod" and "KsiUseCondData" were incorrectly
%               reset to their default values when initializing YADA.
%
% * 24-10-2014: Added the field "YADApath" to the CurrINI structure. This makes it possible for certain models to change
%               the path and to reset it to the desired YADApath once the model is closed.
%
% * 27-10-2014: Made sure that the user is informed when a change in the selected sample has an affect on the length of
%               the Kalman filter training sample.
%
% * 28-11-2014: Removed 10 pixels from the GUI height.
%
% * 27-01-2015: 70 years ago since the liberation of Auschwitz and Birkenau.
%
% * 17-03-2015: Happy St. Patrick's Day! Switched to the new IsHandle function.
%
% * 31-03-2015: Updated the documentation.
%
% * 30-04-2015: A new version is being built.
%
% * 07-05-2015: Charlie's birthday (It was actually the 5th of July)!
%
% * 08-06-2015: The code takes the field CurrINI.GraphicsRoot into account.
%
% * 09-06-2015: It's Pat's birthday. Updated the documentation.
%
% * 12-06-2015: The function calls "VerifyActualsData" to ensure that the actuals for
%               forecasting are valid.
%
% * 24-08-2015: The function now makes it possible to select a Student-t proposal density for the random walk
%               Metropolis algorithm.
%
% * 08-09-2015: Another day of rememberance for Tomas.
%
% * 27-11-2015: Updated the documentation.
%
% * 27-01-2016: Remember Shoah.
%
% * 31-10-2016: Updated the documentation and released version 4.00.
%
% * 07-12-2016: Updated the documentation.
%
% * 27-01-2017: Remember Shoah.
%
% * 17-03-2017: Updated the documentation. And it's St Patrick's Day!
%
% * 01-04-2017: Added code for selecting the fixed blocking RWM posterior sampler with a normal proposal
%               density.
%
% * 07-04-2017: Updated the documentation.
%
% * 10-04-2017: Added code for selecting the fixed blocking RWM posterior sampler with a Student-t
%               proposal density.
%
% * 13-04-2017: Added code for selecting random blocking RWM posterior sampler with a normal
%               proposal density.
%
% * 19-04-2017: Added code for selecting the random blocking RWM posterior sampler with a Student-t
%               proposal density.
%
% * 25-04-2017: Released version 4.10.
%
% * 05-05-2017: Updated the documentation.
%
% * 12-05-2017: Redesigned the DSGE Data tab to allow for 37 pixels additional height for the prior
%               distribution data axesbox. Added controls for the system prior file.
%
% * 21-07-2017: YADA is now 11 years old. Happy birthday, Yodlhead.
%
% * 10-08-2017: Began work on adding the sequential Monte Carlo posterior sampler.
%
% * 11-08-2017: Continued work on adding the SMC with likelihood tempering posterior sampler.
%
% * 28-08-2017: Added controls for the number of Metropolis-Hastings steps.
%
% * 14-09-2017: Added controls for the threshold of the effective sample size when resampling occurs
%               under SMC with likelihood tempering.
%
% * 21-09-2017: Released version 4.30.
%
% * 09-11-2017: Remember Kristallnacht.
%
% * 12-12-2017: Happy Chanukah!
%
% * 10-04-2018: Updated the documentation.
%
% * 20-04-2018: Yesterday was the 75th rememberance day of the ghetto uprising in Warsaw.
%
% * 26-06-2018: Updated the documentation.
%
% * 30-07-2018: Added code to support user written model solver.
%
% * 01-08-2018: Warsaw uprising August 1, 1944.
%
% * 02-08-2018: Treblinka uprising August 2, 1943. Only 75 years ago.
%
% * 13-08-2018: Took into account the new error handling via the function YADALastError.
%
% * 30-08-2018: Released version 4.40.
%
% * 15-10-2018: Updated the documentation.
%
% * 16-10-2018: Added the necessary machinery for selecting posterior sampling using SMC with
%               data tempering.
%
% * 26-10-2018: Released version 4.50.
%
% * 29-11-2018: Updated the documentation.
%
% * 30-11-2018: Added the tools for selecting importance sampling based on MitISEM algorithm.
%
% * 13-12-2018: Added an extra option for setting the tolerance of the CoV criterion under the
%               MitISEM algorithm.
%
% * 14-12-2018: Took into account that posterior sample batch controls should be disabled when
%               using IS based on MitISEM.
%
% * 02-01-2019: Happy new year!
%
% * 01-02-2019: Released version 4.60.
%
% * 04-03-2019: My mother turns 85 today.
%
% * 29-03-2019: Updated the documentation.
%
% * 05-04-2019: Released version 4.70.
%
% * 21-01-2020: Updated the documentation.
%
% * 27-01-2020: Remember Shoah.
%
% * 05-03-2020: Added the LearningMenuControls function.
%
% * 27-01-2021: Remember Shoah.
%
% * 29-04-2021: Released version 4.80.
%
% * 17-07-2021: YADA is 15 years old!
%
% * 21-07-2021: The YADA GUI is now 15 years old!
%
% * 21-01-2022: Released version 4.90.
%
% * 24-01-2022: Updated the documentation.
%
% * 27-01-2022: Remember Shoah.
%
% * 21-02-2022: Changed eval calls to feval calls.
%
% * 22-02-2022: A palindrome date.
%
% * 09-12-2022: Released version 5.00.
%
% * 06-01-2023: Updated the documentation.
%
% * 25-01-2023: Added driver select and run driver functions to the toolbar.
%
% * 26-01-2023: Updated the documentation.
%
% * 27-01-2023: Remember Shoah.
%
% * 21-02-2023: Added the optional input "optcmd".
%
% * 22-02-2023: Added the optional value of optcmd "--seq-driver".
%
% * 15-03-2023: Changed the button image for the rename model UI control.
%
% * 04-04-2023: Added run dynare to toolbar.
%
% * 04-03-2024: My mother is 90 today.
%
% * 15-03-2024: Updated the documentation.
%
% * 18-03-2024: Took into account that "CompareDSGEModel" provides the optional output variable "DiffField".
%
% * 03-04-2024: Version 5.50 was released.
%
% * 23-07-2024: YADA turned 18 years two days ago.
%
% * 15-01-2025: Updated the documentation.
%
% * 27-01-2025: Remember Shoah.
%
% * 28-01-2025: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

if nargin==1;
   optcmd = '';
end;
%
% Initialize the GUI
%
if strcmp(selector,'init')==1;
   %
   % create the initialization structure
   %
   CurrINI = InitializeINIFile;
   CurrINI.YADApath = path;
   %
   % Read CDATA information for creating images on toolbar button and pushbuttons
   %
   ButtonImages = ReadImages;
   %
   % add some things to this structure that are never stored on disk
   %
   GraphicsRoot = CurrINI.GraphicsRoot;
   CurrINI.scrsz = get(GraphicsRoot,'ScreenSize');
   CurrINI.images = ButtonImages;
   %
   % The GUI is painted in the lower right corner of the screen!
   %
   [VersionOfYADA,VersionDateStr] = YADAVersion;
   StatusStr = ['Welcome to YADA! Version ' num2str(VersionOfYADA,'%3.2f') ', dated ' VersionDateStr '. Your matlab version is: ' MatlabVersion];
   %
   % Setting up a structure with model information
   %
   DSGEModel = InitializeDSGEModel;
   [DSGEModel.SubBeginYearValue,DSGEModel.SubBeginPeriodValue,DSGEModel.SubEndYearValue,DSGEModel.SubEndPeriodValue,DSGEModel.YearStrMatrix,DSGEModel.PeriodStrMatrix] = CreateEstimationSampleValues(DSGEModel);
   CurrINI.CurrentModelFile = '';
   CurrINI.ModelFiles = '';
   %
   % Now we should try to read any model-file that was recorded in the INI-file
   %
   CurrINI = ReadINIFile(CurrINI);
   %
   % if CurrINI.CurrentModelFile exists we load all information from this file given
   % that it can be verified
   %
   if FileExist(CurrINI.CurrentModelFile)==1;
      ValidFile = 1;
      try;
         NewDSGEModel = ReadDSGEModel(CurrINI.CurrentModelFile);
      catch;
         ValidFile = 0;
      end;
      if ValidFile==1;
         [NewDSGEModel.SubBeginYearValue,NewDSGEModel.SubBeginPeriodValue,NewDSGEModel.SubEndYearValue,NewDSGEModel.SubEndPeriodValue,NewDSGEModel.YearStrMatrix,NewDSGEModel.PeriodStrMatrix] = CreateEstimationSampleValues(NewDSGEModel);
         [ModelStatus,NewDSGEModel] = VerifyDSGEModel(NewDSGEModel,CurrINI.CurrentModelFile,DSGEModel.DataConstructionFile,CurrINI);
         if ModelStatus==1;
            [NewDSGEModel.SubBeginYearValue,NewDSGEModel.SubBeginPeriodValue,NewDSGEModel.SubEndYearValue,NewDSGEModel.SubEndPeriodValue,NewDSGEModel.YearStrMatrix,NewDSGEModel.PeriodStrMatrix] = CreateEstimationSampleValues(NewDSGEModel);
            if (isempty(NewDSGEModel.StateShockPositions)==0)&(isempty(NewDSGEModel.DSGEVARShocks)==1);
               NewDSGEModel.DSGEVARShocks = (1:min(length(NewDSGEModel.StateShockPositions),NewDSGEModel.n));
            end;
            DSGEModel = NewDSGEModel;
            [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
            DSGEModel.YNaNs = max(max(isnan(DSGEModel.Y(:,FirstPeriod:LastPeriod))));
         else;
            %
            % make sure that CurrINI.CurrentModelFile is removed from CurrINI.ModelFiles
            %
            CurrINI.ModelFiles = RemoveFromModelFiles(CurrINI.ModelFiles,CurrINI.CurrentModelFile);
            CurrINI.CurrentModelFile = '';
         end;
      end;
   end;
   %
   if FileExist(DSGEModel.AIMDataFile)==1;
      StateEnable = 'on';
   else;
      StateEnable = 'off';
   end;
   %
   %
   YADAName = 'YADA';
   if strcmp(DSGEModel.NameOfModel,'')==0;
      YADAName = ['YADA - ' DSGEModel.NameOfModel ' - [' GetFilename(CurrINI.CurrentModelFile) ']'];
   end;
   if FileExist(DSGEModel.AIMFile)==1;
      AiMEnable = 'on';
   else;
      AiMEnable = 'off';
   end;
   if DSGEModel.T>0;
      DataEnable = 'on';
   else;
      DataEnable = 'off';
   end;
   [FirstPeriod,LastPeriod,EstSample] = CreateSubSample(DSGEModel);
   if (DSGEModel.InitializeKalman>1)&(DSGEModel.KalmanFirstObservation==1);
      DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
   end;
   OrigDSGEModel = DSGEModel;
else;
   drawnow;
   pause(0.02);
   maingui = findobj('Type','figure','Tag','YADA');
   controls = get(maingui,'UserData');
   if isfield(controls,'filemenu')==1;
      CurrINI = get(controls.filemenu,'UserData');
      DSGEModel = get(controls.open,'UserData');
      OrigDSGEModel = get(controls.openmenu,'UserData');
   end;
end;
if MatlabNumber<7;
   lasterr = '';
end;
%
switch selector
   case 'init'
      GUIHeight = 645;
      Height = 32;
      if ispc==1;
         WinVersion = GetWindowsVersion;
         if WinVersion>=10;
            Height = 50;
         end;
      end;
      %
      % create main dialog
      %
      maingui = figure('Color',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
                       'FileName','YADAGUI.m', ...
                       'MenuBar','none', ...
                       'PaperUnits','points', ...
                       'Units','pixels', ...
                       'Position',[max(CurrINI.scrsz(3)-702,3) Height 700 GUIHeight], ...
                       'Tag','YADA', ...
                       'Resize','off', ...
                       'Visible','off', ...
                       'Name',YADAName, ...
                       'NumberTitle','off', ...
                       'CloseRequestFcn','YADAGUI Quit', ...
                       'DeleteFcn','YADAGUI done', ...
                       'Toolbar','none');
      %
      % make sure the GUI dialog cannot be docked under matlab 7 and later
      %
      if MatlabNumber>=7.0;
         set(maingui,'DockControl','off');
         controls = [];
      else;
         controls.Xline = XLine([1 GUIHeight-1 700],[0.5 1],CurrINI,maingui);
      end;
      %
      % Now we create a new Toolbar for the GUI
      %
      flds = cellstr(strvcat('toolbar','open','save','reload','close','runaim','postmode','postsampling','priorsampling','rundynareparser','viewgraphics','statevar','stateeq','stateshock','configureshocks','shockgroup','selectdrivers','rundrivers','helpfile','license','about','leave'));
      buttons.type = cellstr(strvcat('push','push','push','push','push','push','push','push','push','push','push','push','push','push','push','push','push','push','push','push','push'));
      buttons.tooltipstr = cellstr(strvcat('Open Model','Save Model','Reload Model','Close Model','Run AiM Parser','Estimate Posterior Mode','Posterior Sampling','Prior Sampling','Run Dynare Parser','Open Graphics','Set State Variables','Set State Equations','Set State Shocks','Configure Shocks','Set Shock Groups','Select Driver Functions','Run Driver Functions','Help','License','About','Quit'));
      buttons.callbackstr = cellstr(strvcat('FileMenuFunctions Open','FileMenuFunctions SaveModel','FileMenuFunctions ReloadModel','FileMenuFunctions CloseModel','ActionsMenuFunctions RunAiM','ActionsMenuFunctions PosteriorModeEstimation','ActionsMenuFunctions PosteriorSampling','ActionsMenuFunctions PriorSampling','ActionsMenuFunctions RunDynareParser','ViewMenuFunctions ViewGraphics','ActionsMenuFunctions SetStateVariables','ActionsMenuFunctions SetStateEquations','ActionsMenuFunctions SetStateShocks','ActionsMenuFunctions ConfigureShocks','ActionsMenuFunctions SetShockGroups','FileMenuFunctions DriverSelection','FileMenuFunctions RunDriverFunctions','HelpMenuFunctions HelpFile','HelpMenuFunctions License','HelpMenuFunctions About','YADAGUI Quit'));
      buttons.enablestr = cellstr(strvcat('on','on','on','on',AiMEnable,'off','off','off','off','on',StateEnable,StateEnable,StateEnable,'off','off','on','on','on','on','on','on'));
      buttons.separatorstr = cellstr(strvcat('off','off','on','on','on','off','off','on','on','on','on','off','off','on','off','on','off','on','on','off','on'));
      buttons.statestr = cellstr(strvcat(' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' '));
      buttons.tagstr = cellstr(strvcat('OpenButton','SaveButton','ReloadButton','CloseButton','RunAIMButton','EstimatePostModeButton','PosteriorSamplingButton','PriorSamplingButton','RunDynareParserButton','ViewGraphicsButton','StateVariableButton','StateEquationButton','StateShockButton','ConfigureShocksButton','ShockGroupButton','SelectDriversButton','RunDriversButton','HelpFileButton','LicenseButton','AboutButton','QuitButton'));
      %
      btndata(1).cdata = ButtonImages.open;
      btndata(1).userdata = DSGEModel;
      btndata(2).cdata = ButtonImages.save;
      btndata(2).userdata = [];
      btndata(3).cdata = ButtonImages.reload;
      btndata(3).userdata = [];
      btndata(4).cdata = ButtonImages.clear;
      btndata(4).userdata = [];
      btndata(5).cdata = ButtonImages.runaim;
      btndata(5).userdata = [];
      btndata(6).cdata = ButtonImages.postmode;
      btndata(6).userdata = [];
      btndata(7).cdata = ButtonImages.simulate;
      btndata(7).userdata = [];
      btndata(8).cdata = ButtonImages.priorsampling;
      btndata(8).userdata = [];
      btndata(9).cdata = ButtonImages.dynare;
      btndata(9).userdata = [];
      btndata(10).cdata = ButtonImages.viewgraphics;
      btndata(10).userdata = [];
      btndata(11).cdata = ButtonImages.statevar;
      btndata(11).userdata = [];
      btndata(12).cdata = ButtonImages.stateeq;
      btndata(12).userdata = [];
      btndata(13).cdata = ButtonImages.stateshock;
      btndata(13).userdata = [];
      btndata(14).cdata = ButtonImages.configureshocks;
      btndata(14).userdata = [];
      btndata(15).cdata = ButtonImages.shockgroups;
      btndata(15).userdata = [];
      btndata(16).cdata = ButtonImages.renametoolbar;
      btndata(16).userdata = [];
      btndata(17).cdata = ButtonImages.runscenario;
      btndata(17).userdata = [];
      btndata(18).cdata = ButtonImages.help;
      btndata(18).userdata = [];
      btndata(19).cdata = ButtonImages.YADAlicense;
      btndata(19).userdata = 0;
      btndata(20).cdata = ButtonImages.about;
      btndata(20).userdata = 0;
      btndata(21).cdata = ButtonImages.close;
      btndata(21).userdata = 'waiting';
      %
      % Now we create the toolbar
      %
      controls = MakeToolbar(controls,maingui,flds,btndata,buttons);
      %
      % Create menus
      %
      %
      % 1. File menu
      %
      controls = FileMenuControls(maingui,controls,OrigDSGEModel,CurrINI);
      %
      % 2. Edit menu
      %
      if MatlabNumber<6;
         controls = EditMenuControls(maingui,controls);
      end;
      %
      % 3. View menu
      %
      controls = ViewMenuControls(maingui,controls,AiMEnable,DataEnable);
      %
      % 4. Tools menu
      %
      controls = ToolsMenuControls(maingui,controls);
      %
      % 5. Actions menu
      %
      controls = ActionsMenuControls(maingui,controls,AiMEnable,StateEnable);
%      controls.reorderconditionalshocks = uimenu('Parent',controls.actionsmenu, ...
%         'Label','Reorder Co&nditioning Shocks...', ...
%         'Callback','YADAGUI reorderconditionalshocks', ...
%         'Enable','off', ...
%         'Tag','ReorderConditionalShocksMenu');
      %
      if FileExist(FixFilePath([pwd '\addons\ovs\EditDataControls.m']))==1;
         controls = EditDataControls(controls);
      end;
      if FileExist(FixFilePath([pwd '\addons\ovs\OVSControls.m']))==1;
         controls = OVSControls(controls,'actionsmenu');
      end;
      %
      % 6. DSGE-VAR menu
      %
      controls = DSGEVARMenuControls(maingui,controls);
      %
      % 7. Learning menu
      %
      controls = LearningMenuControls(maingui,controls);
      %
      % 8. BVAR menu
      %
      controls = BVARMenuControls(maingui,controls);
      %
      % 9. Help Menu
      %
      controls = HelpMenuControls(maingui,controls);
      %
      % Outer axis
      %
      AxesBox([2 21 698 618],'YADA Specifications',96,[0.5 1],'on',CurrINI);
      %
      % Setting up the tabbed dialog
      %
      TabInput.fldnames = {'tab1' 'tab2' 'tab3' 'tab4' 'tab5' 'tab6'};
      TabInput.tags = {'tab1' 'tab2' 'tab3' 'tab4' 'tab5' 'tab6'};
      TabInput.strings = {'DSGE Data' 'Settings' 'Options' 'Miscellaneous' 'Bayesian VAR' 'Output'};
      TabInput.visible = {'on' 'on' 'on' 'on' 'on' 'on'};
      TabInput.callbackstr = {'YADAGUI tab' 'YADAGUI tab' 'YADAGUI tab' 'YADAGUI tab' 'YADAGUI tab' 'YADAGUI tab'};
      controls = TabDialog(controls,CurrINI,[14 34 672 570],6,TabInput,[104 102]);
      %
      % Controls on the DSGE data tab
      %
      %
      % Frame for Observation data
      %
      controls.dsge.obsfilesbox = AxesBox([28 464 644 126],'Observation Data',90,[0.5 1],'on',CurrINI);
      %
      % The DSGE data file
      %
      controls.dsge.datafiletext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 555 522 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'String','Data construction file:', ...
         'Tag','DataFileText');
      %
      controls.dsge.datafile = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[44 531 522 25], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','edit', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI checkdatafile', ...
         'String',DSGEModel.DataConstructionFile, ...
         'Enable','on', ...
         'Tag','dataFileEditBox');
      %
      % browse for the data file
      %
      controls.dsge.datafilebutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[576 531 80 25], ...
         'TooltipString','Browse', ...
         'Visible','on', ...
         'CData',ButtonImages.browse, ...
         'Callback','YADAGUI browsedatafile', ...
         'Enable','on', ...
         'Tag','DataFileButton');
      %
      % The DSGE measurement equation file
      %
      controls.dsge.measurefiletext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 505 522 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'String','Measurement equation file:', ...
         'Tag','MeasurementFileText');
      %
      controls.dsge.measurefile = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[44 481 522 25], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','edit', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI checkmeasurefile', ...
         'String',DSGEModel.MeasurementEquationFile, ...
         'Enable','on', ...
         'Tag','MeasurementFileEditBox');
      %
      % browse for the measurement file
      %
      controls.dsge.measurefilebutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[576 481 80 25], ...
         'TooltipString','Browse', ...
         'Visible','on', ...
         'CData',ButtonImages.browse, ...
         'Callback','YADAGUI browsemeasurefile', ...
         'Enable','on', ...
         'Tag','MeasurementFileButton');
      %
      % Frame for Prior distribution data
      %
      controls.dsge.priorfilesbox = AxesBox([28 322 644 126],'Prior Distribution Data',90,[0.5 1],'on',CurrINI);
      %
      % The DSGE marginal prior information file
      %
      controls.dsge.priorfiletext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 413 522 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'String','Marginal prior distribution specification file:', ...
         'Tag','PriorFileText');
      %
      controls.dsge.priorfile = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[44 389 522 25], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','edit', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI checkpriorfile', ...
         'String',DSGEModel.PriorFile, ...
         'Enable','on', ...
         'Tag','PriorFileEditBox');
      %
      % browse for the prior distribution specification file
      %
      controls.dsge.priorfilebutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[576 389 80 25], ...
         'TooltipString','Browse', ...
         'Visible','on', ...
         'CData',ButtonImages.browse, ...
         'Callback','YADAGUI browsepriorfile', ...
         'Enable','on', ...
         'Tag','PriorFileButton');
      %
      % The selected data sheet for the file if any
      %
      controls.dsge.priorfilesheet = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[180 366 386 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','on', ...
         'HorizontalAlignment','right', ...
         'String',['Sheet: ' DSGEModel.PriorFileSheet], ...
         'Tag','PriorFileSheetText');
      %
      % system prior distribution file
      %
      controls.dsge.systempriorfiletext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 363 136 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'String','System prior density file:', ...
         'Tag','SystemPriorFileText');
      %
      controls.dsge.systempriorfile = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[44 339 522 25], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','edit', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI checksystempriorfile', ...
         'String',DSGEModel.SystemPriorFile, ...
         'Enable','on', ...
         'Tag','SystemPriorFileEditBox');
      %
      %
      % browse for the prior distribution specification file
      %
      controls.dsge.systempriorfilebutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[576 339 80 25], ...
         'TooltipString','Browse', ...
         'Visible','on', ...
         'CData',ButtonImages.browse, ...
         'Callback','YADAGUI browsesystempriorfile', ...
         'Enable','on', ...
         'Tag','SystemPriorFileButton');
      %
      % Frame for additional parameters data
      %
      controls.dsge.parameterfilesbox = AxesBox([28 161 644 147],'Parameter Data',90,[0.5 1],'on',CurrINI);
      %
      % File with additional parameters to update
      %
      controls.dsge.updateparameterfiletext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 274 522 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'String','File with parameters to update:', ...
         'Tag','UpdateParemeterFileText');
      %
      controls.dsge.updateparameterfile = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[44 250 522 25], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','edit', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI checkparameterfile', ...
         'String',DSGEModel.UpdateParameterFile, ...
         'Enable','on', ...
         'Tag','UpdateParameterFileEditBox');
      %
      % browse for the update parameter file
      %
      controls.dsge.updateparameterfilebutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[576 250 80 25], ...
         'TooltipString','Browse', ...
         'Visible','on', ...
         'CData',ButtonImages.browse, ...
         'Callback','YADAGUI browseparameterfile', ...
         'Enable','on', ...
         'Tag','UpdateParameterFileButton');
      %
      %
      % File with additional parameters to initialize
      %
      controls.dsge.initialparameterfiletext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 224 522 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'String','File with parameters to initialize:', ...
         'Tag','InitializeParemeterFileText');
      %
      controls.dsge.initialparameterfile = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[44 200 522 25], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','edit', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI checkparameterfile', ...
         'String',DSGEModel.InitializeParameterFile, ...
         'Enable','on', ...
         'Tag','InitializeParameterFileEditBox');
      %
      % browse for the initialzie parameter file
      %
      controls.dsge.initialparameterfilebutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[576 200 80 25], ...
         'TooltipString','Browse', ...
         'Visible','on', ...
         'CData',ButtonImages.browse, ...
         'Callback','YADAGUI browseparameterfile', ...
         'Enable','on', ...
         'Tag','InitializeParameterFileButton');
      %
      % Check box with option to run file with parameters that need to be initialized
      % only before running the file with the parameters that will be updated
      %
      controls.dsge.runinitialfirst = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 172 522 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','checkbox', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI initializefirst', ...
         'String','Run file with parameters to initialize before file with parameters to update', ...
         'Value',DSGEModel.RunInitializeFirst, ...
         'Enable','off', ...
         'Tag','RunInitializeFirstCheckBox');
      %
      if FileExist(DSGEModel.InitializeParameterFile)==1;
         set(controls.dsge.runinitialfirst,'Enable','on');
      end;
      %
      % Frame for AiM Data
      %
      controls.dsge.aimfilesbox = AxesBox([28 48 644 99],'DSGE Model Data',90,[0.5 1],'on',CurrINI);
      %
      % The DSGE AiM model file
      %
      controls.dsge.aimfiletext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 116 522 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'String','AiM model file:', ...
         'Tag','AIMModelFileText');
      %
      % the edit box for the output file
      %
      controls.dsge.aimfile = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[44 92 522 25], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','edit', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI checkaimfile', ...
         'String',DSGEModel.AIMFile, ...
         'Enable','on', ...
         'Tag','AIMModelFileEditBox');
      %
      % browse for the AiM model file
      %
      controls.dsge.aimfilebutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[576 92 80 25], ...
         'TooltipString','Browse', ...
         'Visible','on', ...
         'CData',ButtonImages.browse, ...
         'Callback','YADAGUI browseaim', ...
         'Enable','on', ...
         'Tag','AIMModelFileButton');
      %
      % The DSGE model solver routine
      %
      controls.dsge.modelsolvertext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 55 100 25], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'String','DSGE model solver:', ...
         'Tag','DSGEModelSolverText');
      %
      % DSGE model solver settings
      %
      ModelSolverStr = 'Other';
      if (DSGEModel.ModelSolver>3)|(FileExist(DSGEModel.ModelSolverFile)==1);
         ModelSolverStr = ['Other (' GetName(DSGEModel.ModelSolverFile) ')'];
      end;
      %
      controls.dsge.modelsolver = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[150 60 210 25], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI modelsolver', ...
         'String',['Anderson & Moore''s algorithm (AiM)|Paul Klein''s algorithm (solab)|Christopher Sims'' algorithm (gensys)|' ModelSolverStr], ...
         'Value',DSGEModel.ModelSolver, ...
         'Tag','DSGEModelSolverPopup');
      %
      % Set the name of the model
      %
      controls.dsge.modelnametext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[375 55 70 25], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'String','Model name:', ...
         'Tag','ModelNameText');
      %
      % Axes for text controls
      %
      controls.dsge.modelnameaxes = axes('Units','pixels', ...
         'Box','on', ...
         'TickLength',[0 0], ...
         'CameraUpVector',[0 1 0], ...
         'Color',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[445 55 130 35], ...
         'XTickLabelMode','manual', ...
         'YTickLabelMode','manual', ...
         'Tag','ModelNameAxes', ...
         'XColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'ZColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'));
      %
      % The text controls for holding the model name
      %
      controls.dsge.modelname = text('Parent',controls.dsge.modelnameaxes, ...
         'Position',[0 0.5], ...
         'String',DSGEModel.NameOfModel, ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'HorizontalAlignment','left', ...
         'Interpreter','none', ...
         'Color',CurrINI.gui_foreground_color, ...
         'ButtonDownFcn','YADAGUI editmodelname', ...
         'Tag','ModelNameText');
      %
      % Button for editing model name
      %
      controls.dsge.modelnamebutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[576 62 80 25], ...
         'TooltipString','Edit Model Name', ...
         'Visible','on', ...
         'Callback','YADAGUI editmodelname', ...
         'CData',ButtonImages.editmodelname, ...
         'Enable','on', ...
         'Tag','ModelNameButton');
      %
      % Controls on the Settings tab
      %
      controls.dsge.posteriorsamplingbox = AxesBox([28 453 644 137],'DSGE Posterior Sampling',50,[0.5 1],'off',CurrINI);
      %
      % Selection of marginal likelihood algorithm
      %
      controls.dsge.marginallikelihoodtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 550 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Marginal likelihood algorithm:', ...
         'Tag','MarginalLikelihoodText');
      %
      controls.dsge.marginallikelihood = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 555 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI marginallikelihood', ...
         'String','All|Geweke''s modified harmonic mean|Sims-Waggoner-Zha''s mod. harmonic mean|Chib and Jeliazkov''s estimator|None', ...
         'Value',DSGEModel.MarginalLikelihoodValue, ...
         'Tag','MarginalLikelihoodPopup');
      %
      % StartIteration value and StepLength value for sequential marginal likelihood
      % estimation.
      %
      controls.dsge.sequantialmltext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 522 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Sequential estimation [StartIteration StepLength]:', ...
         'Tag','SequentialMarginalLikelihoodText');
      %
      controls.dsge.sequentialstart = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 527 120.5 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI sequentialstartiteration', ...
         'String','10|50|100|200|300|400|500|600|700|800|900|1,000|5,000|10,000|15,000|20,000|25,000|30,000|35,000|40,000|45,000|50,000|55,000|60,000|65,000|70,000|75,000|80,000|85,000|90,000|95,000|100,000', ...
         'Value',DSGEModel.SequentialStartIteration, ...
         'Tag','SequentialStartIterationPopup');
      %
      controls.dsge.sequentialstep = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[535.5 527 120.5 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI sequentialsteplength', ...
         'String','1|10|50|100|200|300|400|500|600|700|800|900|1,000|5,000|10,000|15,000|20,000|25,000|30,000|35,000|40,000|45,000|50,000|55,000|60,000|65,000|70,000|75,000|80,000|85,000|90,000|95,000|100,000', ...
         'Value',DSGEModel.SequentialStepLength, ...
         'Tag','SequentialStepLengthPopup');
      %
      % Coverage probability (used by the Modified Harmonic Mean estimator)
      %
      controls.dsge.coverageprobtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 494 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Coverage probability (Start:Increment:End):', ...
         'Tag','CoverageProbabilityText');
      %
      controls.dsge.coveragestart = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 499 77.333 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI coverageprobability', ...
         'String','0.05|0.10|0.15|0.20|0.25|0.30|0.35|0.40|0.45|0.50', ...
         'Value',DSGEModel.CoverageStart, ...
         'Tag','CoverageStartPopup');
      %
      controls.dsge.coverageincrement = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[492.333 499 77.333 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI coverageprobability', ...
         'String','0.05|0.10|0.15|0.20|0.25', ...
         'Value',DSGEModel.CoverageIncrement, ...
         'Tag','CoverageIncrementPopup');
      %
      controls.dsge.coverageend = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[578.667 499 77.333 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI coverageprobability', ...
         'String','0.50|0.55|0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95', ...
         'Value',DSGEModel.CoverageEnd, ...
         'Tag','CoverageEndPopup');
      %
      % Determine if the marginal likelihood should be computed sequentially,
      % directly after having computed all posterior draws
      %
      controls.dsge.sequentialml = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[44 465 362 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI sequentialml', ...
            'String','Compute the marginal likelihood sequentially', ...
            'Value',DSGEModel.SequentialML, ...
            'Enable','on', ...
            'Tag','SequentialMLCheckBox');
      %
      % Overwrite previous draws. If checked, then yes, if unchecked then previous draws are used.
      %
      controls.dsge.overwritedraws = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[406 465 160 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI overwritedraws', ...
            'String','Overwrite old draws', ...
            'Value',DSGEModel.OverwriteDraws, ...
            'Enable','on', ...
            'Tag','OverwriteCheckBox');
      %
      % settings for progress dialogs
      %
      controls.dsge.progressbox = AxesBox([28 389 644 50],'Progress Dialog Selections',90,[0.5 1],'off',CurrINI);
      %
      % Show progress dialog
      %
      controls.dsge.progress = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[44 403 362 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI showprogress', ...
            'String','Show dialog during optimization and posterior sampling', ...
            'Value',DSGEModel.ShowProgress, ...
            'Enable','on', ...
            'Tag','ShowProgressCheckBox');
      %
      % Show clock on progress dialog
      %
      controls.dsge.progressclock = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[406 403 160 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI showprogressclock', ...
            'String','Show clock on dialog', ...
            'Value',DSGEModel.ShowProgressClock, ...
            'Enable','on', ...
            'Tag','ShowProgressClockCheckBox');
      %
      if DSGEModel.ShowProgress==0;
         set(controls.dsge.progressclock,'Enable','off');
      end;
      %
      % settings for the Kalman filter
      %
      controls.dsge.kalmanbox = AxesBox([28 118 644 257],'Kalman Filter Selections',90,[0.5 1],'off',CurrINI);
      %
      % Kalman filter algorithm for optimzation
      %
      controls.dsge.kalmanalgorithmtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 332 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'Enable','on', ...
         'HorizontalAlignment','left', ...
         'String','Kalman filter algorithm:', ...
         'Tag','KalmanAlgorithmText');
      %
      if DSGEModel.KalmanAlgorithm==4;
         if (isempty(DSGEModel.UnitRootStates)==0)|(DSGEModel.AllowUnitRoot==1)|(DSGEModel.UseDoublingAlgorithm>=3)|(DSGEModel.YNaNs==1)|(CheckHMatrix(DSGEModel,CurrINI)==0);
            DSGEModel.KalmanAlgorithm = 1;
            OrigDSGEModel.KalmanAlgorithm = 1;
         end;
      end;
      %
      controls.dsge.kalmanalgorithm = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 337 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI kalmanalgorithm', ...
         'String','Standard filter (fast)|Square-root filter (slower but robust)|Univariate filter (fast and robust)|Chandrasekhar recursions (very fast)', ...
         'Value',DSGEModel.KalmanAlgorithm, ...
         'Tag','KalmanAlgorithmPopup');
      %
      % Select algorithm for computing the covariance matrix of the initial state forecast
      %
      if DSGEModel.UseDoublingAlgorithm==0;
         DSGEModel.UseDoublingAlgorithm = 1;
         OrigDSGEModel.UseDoublingAlgorithm = 1;
      end;
      %
      controls.dsge.usedoublingalgorithmtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 303 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'Enable','on', ...
         'HorizontalAlignment','left', ...
         'String','Select method for initializing the state covariance matrix:', ...
         'Tag','UseDoublingAlgorithmText');
      %
      controls.dsge.usedoublingalgorithm = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[406 308 250 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','popup', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI usedoublingalgorithm', ...
            'String','Analytically through vectorization (slow)|Engage the doubling algorithm|Use constant times identity|Diffuse initialization', ...
            'Value',DSGEModel.UseDoublingAlgorithm, ...
            'Enable','on', ...
            'Tag','UseDoublingAlgorithmCheckBox');
      %
      % number of maximum iterations for the doubling algorithm
      %
      controls.dsge.doublingalgorithmtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 274 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'Enable','on', ...
         'HorizontalAlignment','left', ...
         'String','Maximum number of iterations for the doubling algorithm:', ...
         'Tag','DoublingAlgorithmText');
      %
      controls.dsge.doublingalgorithm = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 279 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI doublingalgorithm', ...
         'String','100|200|300|400|500|600|700|800|900|1,000|1,100|1,200|1,300|1,400|1,500|1,600|1,700|1,800|1,900|2,000', ...
         'Value',DSGEModel.DAMaximumIterationsValue, ...
         'Tag','DoublingAlgorithmMaxIterationsPopup');
      %
      % Tolerance level for doubling algorithm
      %
      controls.dsge.doublingtolerancetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 245 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'Enable','on', ...
         'HorizontalAlignment','left', ...
         'String','Tolerance level for the doubling algorithm:', ...
         'Tag','DoublingToleranceText');
      %
      controls.dsge.doublingtolerance = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 250 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI da_tolerance', ...
         'String','0.01|0.001|0.0001|0.00001|0.000001|0.0000001|0.00000001|0.000000001|0.0000000001|0.00000000001', ...
         'Value',DSGEModel.DAToleranceValue, ...
         'Tag','DAToleranceValuePopup');
      %
      % Constant for initial state covariance matrix
      %
      controls.dsge.statecovariancetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 216 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'Enable','on', ...
         'HorizontalAlignment','left', ...
         'String','Constant for initial state covariance matrix:', ...
         'Tag','StateCovarianceConstantText');
      %
      controls.dsge.statecovariance = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 221 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI statecov', ...
         'String','1|2|3|4|5|6|7|8|9|10|20|30|40|50|60|70|80|90|100|150|200|250|300|350|400|450|500|550|600|650|700|750|800|850|900|950|1,000|1,100|1,200|1,300|1,400|1,500|1,600|1,700|1,800|1,900|2,000|3,000|4,000|5,000|6,000|7,000|8,000|9,000|10,000', ...
         'Value',DSGEModel.StateCovConst, ...
         'Tag','StateCovarianceConstantPopup');
      %
      StateCStr = get(controls.dsge.statecovariance,'String');
      DSGEModel.StateCovConstValue = str2num(strrep(StringTrim(StateCStr(DSGEModel.StateCovConst,:)),',',''));
      OrigDSGEModel.StateCovConstValue = DSGEModel.StateCovConstValue;
      set(controls.open,'UserData',DSGEModel);
      %
      % Enable and disable controls depending on the value of UseDoublingAlgorithm
      %
      if DSGEModel.UseDoublingAlgorithm==2;
         set(controls.dsge.doublingalgorithmtext,'Enable','on');
         set(controls.dsge.doublingalgorithm,'Enable','on');
         set(controls.dsge.doublingtolerancetext,'Enable','on');
         set(controls.dsge.doublingtolerance,'Enable','on');
         set(controls.dsge.statecovariancetext,'Enable','off');
         set(controls.dsge.statecovariance,'Enable','off');
      elseif DSGEModel.UseDoublingAlgorithm==3;
         set(controls.dsge.doublingalgorithmtext,'Enable','off');
         set(controls.dsge.doublingalgorithm,'Enable','off');
         set(controls.dsge.doublingtolerancetext,'Enable','off');
         set(controls.dsge.doublingtolerance,'Enable','off');
         set(controls.dsge.statecovariancetext,'Enable','on');
         set(controls.dsge.statecovariance,'Enable','on');
      else;
         set(controls.dsge.doublingalgorithmtext,'Enable','off');
         set(controls.dsge.doublingalgorithm,'Enable','off');
         set(controls.dsge.doublingtolerancetext,'Enable','off');
         set(controls.dsge.doublingtolerance,'Enable','off');
         set(controls.dsge.statecovariancetext,'Enable','off');
         set(controls.dsge.statecovariance,'Enable','off');
      end;
      %
      % Initialization period for Kalman filter
      %
      controls.dsge.initializekalmantext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 187 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'Enable','on', ...
         'HorizontalAlignment','left', ...
         'String','First observation after Kalman filter training sample:', ...
         'Tag','InitializeKalmanText');
      %
      controls.dsge.initializekalman = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 192 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI initializekalman', ...
         'String',EstSample, ...
         'Value',DSGEModel.KalmanFirstObservation, ...
         'Tag','InitializeKalmanPopup');
      %
      % Numerical tolerance for AiM
      %
      controls.dsge.aimtolerancetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 158 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'Enable','on', ...
         'HorizontalAlignment','left', ...
         'String','Numerical tolerance for DSGE model solver:', ...
         'Tag','AiMToleranceText');
      %
      controls.dsge.aimtolerance = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 163 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI aimtolerance', ...
         'String','0.01|0.001|0.0001|0.00001|0.000001|0.0000001|0.00000001|0.000000001|0.0000000001|0.00000000001', ...
         'Value',DSGEModel.AIMTolerance-1, ...
         'Tag','AiMTolerancePopup');
      %
      % Select to use own initial values for the state vector
      % 
      controls.dsge.useowninitialstate = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[44 132 362 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI useowninitialstate', ...
            'String','Use own initial values for the state variables', ...
            'Value',DSGEModel.UseOwnInitialState, ...
            'Enable','on', ...
            'Tag','UseOwnInitialStateCheckBox');
      %
      controls.dsge.allowunitroot = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[406 132 250 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI allowunitroot', ...
            'String','Allow for undefined unit roots', ...
            'Value',DSGEModel.AllowUnitRoot, ...
            'Enable','on', ...
            'Tag','AllowUnitRootCheckBox');
      %
      % the DSGE sample selection axes box
      %
      controls.dsge.sampleselect = AxesBox([28 48 644 56],'Sample Selection',90,[0.5 1],'off',CurrINI);
      %
      % Control for selecting estimation sample
      %
      controls.dsge.subsample = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 61 150 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Selected sample:', ...
         'Tag','SubSampleText1');
      %
      controls.dsge.subbeginyear = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[226 66 110 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'HorizontalAlignment','left', ...
         'String',DSGEModel.YearStrMatrix, ...
         'Value',DSGEModel.SubBeginYearValue, ...
         'Callback','YADAGUI checksample', ...
         'Enable','on', ...
         'Visible','off', ...
         'Tag','SubPopupYear1');
      %
      controls.dsge.subbeginperiod = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[341 66 95 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'HorizontalAlignment','left', ...
         'String',DSGEModel.PeriodStrMatrix, ...
         'Value',DSGEModel.SubBeginPeriodValue, ...
         'Callback','YADAGUI checksample', ...
         'Visible','off', ...
         'Enable','on', ...
         'Tag','SubPopupPeriod1');
      %
      controls.dsge.subsampleseparator = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[436 66 10 20], ...
         'FontSize',10, ...
         'Style','text', ...
         'HorizontalAlignment','center', ...
         'String','-', ...
         'Visible','off', ...
         'Tag','SubSampleText2');
      %
      controls.dsge.subendyear = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[446 66 110 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'HorizontalAlignment','left', ...
         'String',DSGEModel.YearStrMatrix, ...
         'Value',DSGEModel.SubEndYearValue, ...
         'Callback','YADAGUI checksample', ...
         'Enable','on', ...
         'Visible','off', ...
         'Tag','SubEditYear2');
      %
      controls.dsge.subendperiod = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[561 66 95 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'HorizontalAlignment','left', ...
         'String',DSGEModel.PeriodStrMatrix, ...
         'Value',DSGEModel.SubEndPeriodValue, ...
         'Callback','YADAGUI checksample', ...
         'Enable','on', ...
         'Visible','off', ...
         'Tag','SubEditPeriod2');
      %
      % Controls on the Options tab
      %
      controls.posteriorsamplingbox = AxesBox([28 248 644 342],'Posterior Sampling',50,[0.5 1],'off',CurrINI);
      %
      % posterior draws sampler
      %
      controls.posterior.posteriorsamplertext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 550 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Posterior sampler:', ...
         'Tag','PosteriorSamplerText');
      %
      % Student-t proposal density
      %
      if (isempty(DSGEModel.StudenttDegFree)==0)&(DSGEModel.PosteriorSampler==3);
         StudenttString = ['Random Walk Metropolis, t proposal, ' int2str(DSGEModel.StudenttDegFree) ' df'];
      else;
         StudenttString = 'Random Walk Metropolis, t proposal';
      end;
      %
      % fixed blocking normal proposal
      %
      if (isempty(DSGEModel.FixedNumParamBlocks)==0)&(DSGEModel.PosteriorSampler==4);
         FixedBlockNormalString = [int2str(DSGEModel.FixedNumParamBlocks) ' block RWM, normal proposal'];
      else;
         FixedBlockNormalString = 'Fixed block RWM, normal proposal';
      end;
      %
      % fixed blocking t proposal density
      %
      if (isempty(DSGEModel.FixedNumParamBlocks)==0)&(isempty(DSGEModel.StudenttDegFree)==0)&(DSGEModel.PosteriorSampler==5);
         FixedBlockStudentString = [int2str(DSGEModel.FixedNumParamBlocks) ' block RWM, t proposal, ' int2str(DSGEModel.StudenttDegFree) ' df'];
      else;
         FixedBlockStudentString = 'Fixed block RWM, t proposal';
      end;
      %
      % random blocking normal proposal
      %
      if (length(DSGEModel.BlockSize)==2)&(DSGEModel.PosteriorSampler==6);
         RandomBlockNormalString = ['Random block (' int2str(DSGEModel.BlockSize(1)) ' to ' int2str(DSGEModel.BlockSize(2)) ') RWM, normal proposal'];
      else;
         RandomBlockNormalString = 'Random block RWM, normal proposal';
      end;
      %
      % random blocking t proposal
      %
      if (length(DSGEModel.BlockSize)==2)&(isempty(DSGEModel.StudenttDegFree)==0)&(DSGEModel.PosteriorSampler==7);
         RandomBlockStudentString = ['Random block (' int2str(DSGEModel.BlockSize(1)) ' to ' int2str(DSGEModel.BlockSize(2)) ') RWM, t proposal, ' int2str(DSGEModel.StudenttDegFree) ' df'];
      else;
         RandomBlockStudentString = 'Random block RWM, t proposal';
      end;
      %
      controls.posterior.posteriorsampler = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 555 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI posteriorsampler', ...
         'String',['Random Walk Metropolis, normal proposal|Slice sampler|' StudenttString '|' FixedBlockNormalString '|' FixedBlockStudentString '|' RandomBlockNormalString '|' RandomBlockStudentString '|Sequential Monte Carlo, likelihood tempering|Sequential Monte Carlo, data tempering|Importance Sampling based on MitISEM'], ...
         'Value',DSGEModel.PosteriorSampler, ...
         'Tag','PosteriorSamplerPopup');
      %
      % Number of posterior draws
      %
      controls.posterior.drawstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 523 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Number of posterior draws per chain:', ...
         'Tag','NumberPosteriorDrawsText');
      %
      % alternative text for SMC
      %
      controls.posterior.smcdrawstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 523 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Number of posterior draws (particles) per chain:', ...
         'Tag','NumberPosteriorDrawsText');
      %
      if DSGEModel.PosteriorDrawsValue>174;
         DSGEModel.PosteriorDrawsValue = 1;
         OrigDSGEModel.PosteriorDrawsValue = 1;
         DSGEModel.PosteriorDraws = [];
         OrigDSGEModel.PosteriorDraws = [];
      end;
      %
      controls.posterior.draws = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 528 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI posteriordraws', ...
         'String','1,000|5,000|10,000|15,000|20,000|25,000|30,000|35,000|40,000|45,000|50,000|75,000|100,000|105,000|110,000|115,000|120,000|125,000|130,000|135,000|140,000|145,000|150,000|155,000|160,000|165,000|170,000|175,000|180,000|185,000|190,000|195,000|200,000|205,000|210,000|215,000|220,000|225,000|230,000|235,000|240,000|245,000|250,000|255,000|260,000|265,000|270,000|275,000|280,000|285,000|290,000|295,000|300,000|305,000|310,000|315,000|320,000|325,000|330,000|335,000|340,000|345,000|350,000|355,000|360,000|365,000|370,000|375,000|380,000|385,000|390,000|395,000|400,000|405,000|410,000|415,000|420,000|425,000|430,000|435,000|440,000|445,000|450,000|455,000|460,000|465,000|470,000|475,000|480,000|485,000|490,000|495,000|500,000|510,000|520,000|525,000|530,000|540,000|550,000|560,000|570,000|575,000|580,000|590,000|600,000|610,000|620,000|625,000|630,000|640,000|650,000|660,000|670,000|675,000|680,000|690,000|700,000|710,000|720,000|725,000|730,000|740,000|750,000|760,000|770,000|775,000|780,000|790,000|800,000|810,000|820,000|825,000|830,000|840,000|850,000|860,000|870,000|875,000|880,000|890,000|900,000|910,000|920,000|925,000|930,000|940,000|950,000|960,000|970,000|975,000|980,000|990,000|1,000,000|1,050,000|1,100,000|1,150,000|1,200,000|1,250,000|1,300,000|1,350,000|1,400,000|1,450,000|1,500,000|1,550,000|1,600,000|1,650,000|1,700,000|1,750,000|1,800,000|1,850,000|1,900,000|1,950,000|2,000,000|Other', ...
         'Value',DSGEModel.PosteriorDrawsValue, ...
         'Tag','NumberPosteriorDrawsPopup');
      %
      if DSGEModel.PosteriorDrawsValue==174;
         DrawsStr = cellstr(get(controls.posterior.draws,'String'));
         if isempty(DSGEModel.PosteriorDraws)==0;
            DrawsStr{174} = num2str(DSGEModel.PosteriorDraws);
            set(controls.posterior.draws,'String',char(DrawsStr));
         else;
            DSGEModel.PosteriorDrawsValue = 1;
            OrigDSGEModel.PosteriorDrawsValue = 1;
            set(controls.posterior.draws,'Value',1);
            DSGEModel.PosteriorDraws = [];
            OrigDSGEModel.PosteriorDraws = [];
         end;
      end;
      %
      % Number of sample batches with draws to save to disk
      %
      controls.posterior.batchtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 496 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Number of posterior sample batches to save per chain:', ...
         'Tag','NumberSampleBatchesText');
      %
      controls.posterior.batch = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 501 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI samplebatches', ...
         'String','1|10|50|100|500|1,000|5,000|10,000', ...
         'Value',DSGEModel.SampleBatchValue, ...
         'Tag','NumberSampleBatchesPopup');
      %
      % Number of tempering stages for SMC with likelihood tempering
      %
      EnableTxt = 'on';
      %
      if DSGEModel.PosteriorSampler==9;
         EnableTxt = 'off';
      end;
      controls.posterior.temperingstagestext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 496 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable',EnableTxt, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Number of tempering stages per chain:', ...
         'Tag','NumberTemperingStagesText');
      %
      controls.posterior.temperingstages = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 501 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable',EnableTxt, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI temperingstages', ...
         'String','100|150|200|250|300|350|400|450|500|550|600|650|700|750|800|850|900|950|1,000|1,100|1,200|1,300|1,400|1,500|1,600|1,700|1,800|1,900|2,000|2,500|3,000|3,500|4,000|4,500|5,000|5,500|6,000|6,500|7,000|7,500|8,000|8,500|9,000|9,500|10,000', ...
         'Value',DSGEModel.TemperingStagesValue, ...
         'Tag','NumberTemperingStagesPopup');
      %
      % Number of posterior chains
      %
      controls.posterior.chainstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 470 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Number of parallel chains:', ...
         'Tag','NumberParallelChainsText');
      %
      NumChainsStr = '1';
      for i=2:50;
         NumChainsStr = [NumChainsStr '|' num2str(i,'%0.0f')];
      end;
      %
      controls.posterior.chains = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 475 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI parallelchains', ...
         'String',NumChainsStr, ...
         'Value',DSGEModel.ParallelChainsValue, ...
         'Tag','NumberParallelChainsPopup');
      %
      % Number of burn-in draws for the posterior sampler
      %
      controls.posterior.burnintext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 444 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Number of posterior draws discarded as burn-in period:', ...
         'Tag','NumberBurnInText');
      %
      % this fix is needed since the change of using percentage into absolute numbers
      % for the length of the burn-in period
      %
      if DSGEModel.BurnInValue>150;
         DSGEModel.BurnInValue = 1;
         OrigDSGEModel.BurnInValue = 1;
         DSGEModel.BurnIn = [];
         OrigDSGEModel.BurnIn = [];
      end;
      %
      controls.posterior.burnin = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 448 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI burnin', ...
         'String','0|100|200|300|400|500|1,000|1,500|2,000|2,500|3,000|3,500|4,000|4,500|5,000|7,500|10,000|12,500|15,000|17,500|20,000|22,500|25,000|27,500|30,000|32,500|35,000|37,500|40,000|42,500|45,000|47,500|50,000|55,000|60,000|65,000|70,000|75,000|80,000|85,000|90,000|95,000|100,000|110,000|120,000|125,000|130,000|140,000|150,000|160,000|170,000|175,000|180,000|190,000|200,000|210,000|220,000|225,000|230,000|240,000|250,000|260,000|270,000|275,000|280,000|290,000|300,000|310,000|320,000|325,000|330,000|340,000|350,000|360,000|370,000|375,000|380,000|390,000|400,000|410,000|420,000|425,000|430,000|440,000|450,000|460,000|470,000|475,000|480,000|490,000|500,000|510,000|520,000|530,000|540,000|550,000|560,000|570,000|580,000|590,000|600,000|610,000|620,000|630,000|640,000|650,000|660,000|670,000|680,000|690,000|700,000|710,000|720,000|730,000|740,000|750,000|760,000|770,000|780,000|790,000|800,000|810,000|820,000|830,000|840,000|850,000|860,000|870,000|880,000|890,000|900,000|910,000|920,000|930,000|940,000|950,000|960,000|970,000|980,000|990,000|1,000,000|Other', ...
         'Value',DSGEModel.BurnInValue, ...
         'Tag','NumberBurnInPopup');
      %
      if DSGEModel.BurnInValue==142;
         DrawsStr = cellstr(get(controls.posterior.burnin,'String'));
         if isempty(DSGEModel.BurnIn)==0;
            DrawsStr{142} = num2str(DSGEModel.BurnIn);
            set(controls.posterior.burnin,'String',char(DrawsStr));
         else;
            DSGEModel.BurnInValue = 1;
            OrigDSGEModel.BurnInValue = 1;
            set(controls.posterior.burnin,'Value',1);
            DSGEModel.BurnIn = [];
            OrigDSGEModel.BurnIn = [];
         end;
      end;
      %
      % tempering schedule parameter
      %
      controls.posterior.temperinglambdatext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 444 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable',EnableTxt, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Value of the tempering schedule (bending) parameter (lambda):', ...
         'Tag','TemperingLambdaText');
      %
      controls.posterior.temperinglambda = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 448 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable',EnableTxt, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI temperinglambda', ...
         'String','1.0|1.1|1.2|1.3|1.4|1.5|1.6|1.7|1.8|1.9|2.0|2.1|2.2|2.3|2.4|2.5|2.6|2.7|2.8|2.9|3.0|3.1|3.2|3.3|3.4|3.5|3.6|3.7|3.8|3.9|4.0', ...
         'Value',DSGEModel.TemperingLambdaValue, ...
         'Tag','TemperingLambdaPopup');
      %
      % tolerance level of the MitISEM algorithm
      %
      controls.posterior.covtolerancetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 444 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Tolerance level for coefficient of variation criterion of MitISEM algorithm:', ...
         'Tag','CoVToleranceText');
      %
      controls.posterior.covtolerance = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 448 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI covtolerance', ...
         'String','0.001|0.002|0.003|0.004|0.005|0.006|0.007|0.008|0.009|0.01|0.02|0.03|0.04|0.05|0.06|0.07|0.08|0.09|0.10|0.11|0.12|0.13|0.14|0.15|0.16|0.17|0.18|0.19|0.20', ...
         'Value',DSGEModel.CoVToleranceValue, ...
         'Tag','CoVTolerancePopup');
      %
      % inverse Hessian estimator
      %
      controls.posterior.invhessiantext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 417 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Method for estimating the inverse Hessian:', ...
         'Tag','InverseHessianEstimatorText');
      %
      controls.posterior.invhessian = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 422 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI invhessian', ...
         'String',['Output from optimization routine|Fit quadratic to evaluated log posterior|Finite difference|My estimate ("' GetName(DSGEModel.ParameterCovMatrix) '")'], ...
         'Value',DSGEModel.InverseHessianEstimator, ...
         'Tag','InverseHessianEstimatorPopup');
      %
      % number of parameter blocks (for SMC)
      %
      controls.posterior.numparamblockstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 417 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Number of parameter blocks (mutation step):', ...
         'Tag','NumParamBlocksText');
      %
      NPBStr = '1';
      for j=2:100;
         NPBStr = [NPBStr '|' int2str(j)];
      end;
      %
      controls.posterior.numparamblocks = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 422 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI numparamblocks', ...
         'String',NPBStr, ...
         'Value',DSGEModel.NumParamBlocks, ...
         'Tag','NumParamBlocksPopup');
      %
      % number of Metropolis-Hastings steps
      %
      controls.posterior.smcmhstepstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 390 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Number of Metropolis-Hastings steps (mutation step):', ...
         'Tag','SMCNumMHStepsText');
      %
      SelectionOptions = '1';
      for i=2:100;
         SelectionOptions = [SelectionOptions '|' int2str(i)];
      end;
      %
      controls.posterior.smcmhsteps = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 395 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI smcmhsteps', ...
         'String',SelectionOptions, ...
         'Value',DSGEModel.SMCNumMHSteps, ...
         'Tag','SMCNumMHStepsPopup');
      %
      % maximum correlation for the inverse Hessian estimator
      %
      controls.posterior.maxcorrelationtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 390 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Maximum absolute correlation for inverse Hessian estimator:', ...
         'Tag','MaximumCorrelationText');
      %
      controls.posterior.maxcorrelation = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 395 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI maxhesscorrelation', ...
         'String','No restriction|0.95|0.90|0.85|0.80|0.75|0.70|0.65|0.60|0.55|0.50|0.45|0.40|0.35|0.30|0.25|0.20|0.15|0.10|0.05|0.00', ...
         'Value',DSGEModel.MaxCorrelationValue, ...
         'Tag','MaximumCorrelationPopup');
      %
      % mixture distribution weight (alpha) for proposal density of SMC
      %
      controls.posterior.mixeddistweighttext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 364 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Mixing weight (alpha) for proposal density (mutation step):', ...
         'Tag','MixedDistributionWeightText');
      %
      controls.posterior.mixeddistweight = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 369 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI mixeddistweight', ...
         'String','0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95|1.00', ...
         'Value',DSGEModel.MixedDistWeightValue, ...
         'Tag','MixedDistributionWeightPopup');
      %
      % Scale factor for initialization of random walk Metropolis
      %
      controls.posterior.initialscaletext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 364 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Scale factor for initializing the posterior sampler:', ...
         'Tag','InitialScaleFactorText');
      %
      controls.posterior.initialscale = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 369 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI initialscalefactor', ...
         'String','0.00|0.01|0.02|0.03|0.04|0.05|0.06|0.07|0.08|0.09|0.10|0.11|0.12|0.13|0.14|0.15|0.16|0.17|0.18|0.19|0.20|0.21|0.22|0.23|0.24|0.25|0.26|0.27|0.28|0.29|0.30|0.31|0.32|0.33|0.34|0.35|0.36|0.37|0.38|0.39|0.40|0.41|0.42|0.43|0.44|0.45|0.46|0.47|0.48|0.49|0.50|0.51|0.52|0.53|0.54|0.55|0.56|0.57|0.58|0.59|0.60|0.61|0.62|0.63|0.64|0.65|0.66|0.67|0.68|0.69|0.70|0.71|0.72|0.73|0.74|0.75|0.76|0.77|0.78|0.79|0.80|0.81|0.82|0.83|0.84|0.85|0.86|0.87|0.88|0.89|0.90|0.91|0.92|0.93|0.94|0.95|0.96|0.97|0.98|0.99|1.00|1.05|1.10|1.15|1.20|1.25|1.30|1.35|1.40|1.45|1.50|1.55|1.60|1.65|1.70|1.75|1.80|1.85|1.90|1.95|2.00|2.05|2.10|2.15|2.20|2.25|2.30|2.35|2.40|2.45|2.50|2.55|2.60|2.65|2.70|2.75|2.80|2.85|2.90|2.95|3.00|3.05|3.10|3.15|3.20|3.25|3.30|3.35|3.40|3.45|3.50|3.55|3.60|3.65|3.70|3.75|3.80|3.85|3.90|3.95|4.00|4.05|4.10|4.15|4.20|4.25|4.30|4.35|4.40|4.45|4.50|4.55|4.60|4.65|4.70|4.75|4.80|4.85|4.90|4.95|5.00|5.05|5.10|5.15|5.20|5.25|5.30|5.35|5.40|5.45|5.50|5.55|5.60|5.65|5.70|5.75|5.80|5.85|5.90|5.95|6.00|6.10|6.20|6.30|6.40|6.50|6.60|6.70|6.80|6.90|7.00|7.10|7.20|7.30|7.40|7.50|7.60|7.70|7.80|7.90|8.00|8.10|8.20|8.30|8.40|8.50|8.60|8.70|8.80|8.90|9.00|9.10|9.20|9.30|9.40|9.50|9.60|9.70|9.80|9.90|10.00', ...
         'Value',DSGEModel.MHInitialScaleFactor, ...
         'Tag','InitialScaleFactorPopup');
      %
      % number of mixture components for MitISEM
      %
      controls.posterior.ismaxmixcomptext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 364 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Maximum number of Student-t mixture components:', ...
         'Tag','ISMaxMixCompText');
      %
      controls.posterior.ismaxmixcomp = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 369 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI ismaxmixcomp', ...
         'String','2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|18|19|20', ...
         'Value',DSGEModel.ISMaxMixCompValue, ...
         'Tag','ISMaxMixCompPopup');
      %
      % Initial scale factor for the SMC proposal density
      %
      controls.posterior.smcinitialscaletext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 337 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Initial value of scale factor for proposal density (mutation step):', ...
         'Tag','SMCInitialScaleFactorText');
      %
      controls.posterior.smcinitialscale = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 342 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI smcinitialscalefactor', ...
         'String','0.05|0.06|0.07|0.08|0.09|0.10|0.11|0.12|0.13|0.14|0.15|0.16|0.17|0.18|0.19|0.20|0.21|0.22|0.23|0.24|0.25|0.26|0.27|0.28|0.29|0.30|0.31|0.32|0.33|0.34|0.35|0.36|0.37|0.38|0.39|0.40|0.41|0.42|0.43|0.44|0.45|0.46|0.47|0.48|0.49|0.50|0.51|0.52|0.53|0.54|0.55|0.56|0.57|0.58|0.59|0.60|0.61|0.62|0.63|0.64|0.65|0.66|0.67|0.68|0.69|0.70|0.71|0.72|0.73|0.74|0.75|0.76|0.77|0.78|0.79|0.80|0.81|0.82|0.83|0.84|0.85|0.86|0.87|0.88|0.89|0.90|0.91|0.92|0.93|0.94|0.95|0.96|0.97|0.98|0.99|1.00|1.05|1.10|1.15|1.20|1.25|1.30|1.35|1.40|1.45|1.50|1.55|1.60|1.65|1.70|1.75|1.80|1.85|1.90|1.95|2.00|2.05|2.10|2.15|2.20|2.25|2.30|2.35|2.40|2.45|2.50|2.55|2.60|2.65|2.70|2.75|2.80|2.85|2.90|2.95|3.00|3.05|3.10|3.15|3.20|3.25|3.30|3.35|3.40|3.45|3.50|3.55|3.60|3.65|3.70|3.75|3.80|3.85|3.90|3.95|4.00|4.05|4.10|4.15|4.20|4.25|4.30|4.35|4.40|4.45|4.50|4.55|4.60|4.65|4.70|4.75|4.80|4.85|4.90|4.95|5.00|5.05|5.10|5.15|5.20|5.25|5.30|5.35|5.40|5.45|5.50|5.55|5.60|5.65|5.70|5.75|5.80|5.85|5.90|5.95|6.00|6.10|6.20|6.30|6.40|6.50|6.60|6.70|6.80|6.90|7.00|7.10|7.20|7.30|7.40|7.50|7.60|7.70|7.80|7.90|8.00|8.10|8.20|8.30|8.40|8.50|8.60|8.70|8.80|8.90|9.00|9.10|9.20|9.30|9.40|9.50|9.60|9.70|9.80|9.90|10.00', ...
         'Value',DSGEModel.SMCInitialScaleFactor, ...
         'Tag','SMCInitialScaleFactorPopup');
      %
      % Scale factor for the random walk Metropolis algorithm
      %
      controls.posterior.scalefactortext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 337 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Scale factor for the posterior sampler:', ...
         'Tag','ScaleFactorText');
      %
      controls.posterior.scalefactor = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 342 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI scalefactor', ...
         'String','0.05|0.06|0.07|0.08|0.09|0.10|0.11|0.12|0.13|0.14|0.15|0.16|0.17|0.18|0.19|0.20|0.21|0.22|0.23|0.24|0.25|0.26|0.27|0.28|0.29|0.30|0.31|0.32|0.33|0.34|0.35|0.36|0.37|0.38|0.39|0.40|0.41|0.42|0.43|0.44|0.45|0.46|0.47|0.48|0.49|0.50|0.51|0.52|0.53|0.54|0.55|0.56|0.57|0.58|0.59|0.60|0.61|0.62|0.63|0.64|0.65|0.66|0.67|0.68|0.69|0.70|0.71|0.72|0.73|0.74|0.75|0.76|0.77|0.78|0.79|0.80|0.81|0.82|0.83|0.84|0.85|0.86|0.87|0.88|0.89|0.90|0.91|0.92|0.93|0.94|0.95|0.96|0.97|0.98|0.99|1.00|1.05|1.10|1.15|1.20|1.25|1.30|1.35|1.40|1.45|1.50|1.55|1.60|1.65|1.70|1.75|1.80|1.85|1.90|1.95|2.00|2.05|2.10|2.15|2.20|2.25|2.30|2.35|2.40|2.45|2.50|2.55|2.60|2.65|2.70|2.75|2.80|2.85|2.90|2.95|3.00|3.05|3.10|3.15|3.20|3.25|3.30|3.35|3.40|3.45|3.50|3.55|3.60|3.65|3.70|3.75|3.80|3.85|3.90|3.95|4.00|4.05|4.10|4.15|4.20|4.25|4.30|4.35|4.40|4.45|4.50|4.55|4.60|4.65|4.70|4.75|4.80|4.85|4.90|4.95|5.00|5.05|5.10|5.15|5.20|5.25|5.30|5.35|5.40|5.45|5.50|5.55|5.60|5.65|5.70|5.75|5.80|5.85|5.90|5.95|6.00|6.10|6.20|6.30|6.40|6.50|6.60|6.70|6.80|6.90|7.00|7.10|7.20|7.30|7.40|7.50|7.60|7.70|7.80|7.90|8.00|8.10|8.20|8.30|8.40|8.50|8.60|8.70|8.80|8.90|9.00|9.10|9.20|9.30|9.40|9.50|9.60|9.70|9.80|9.90|10.00', ...
         'Value',DSGEModel.MHScaleFactor, ...
         'Tag','ScaleFactorPopup');
      %
      % Degrees of freedom initialization for MitISEM
      %
      controls.posterior.isinitialdftext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 337 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Initial number of degrees of freedom for Student-t density:', ...
         'Tag','ISInitialDFText');
      %
      controls.posterior.isinitialdf = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 342 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI isinitialdf', ...
         'String','1|2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|18|19|20', ...
         'Value',DSGEModel.ISInitialDF, ...
         'Tag','ISInitialDFPopup');
      %
      % target acceptance rate for mutation step of SMC
      %
      controls.posterior.targetacceptanceratetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 311 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Target acceptance rate (mutation step):', ...
         'Tag','TargetAcceptanceRateText');
      %
      controls.posterior.targetacceptancerate = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 316 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI targetacceptancerate', ...
         'String','0.20|0.25|0.30|0.35|0.40|0.45|0.50', ...
         'Value',DSGEModel.TargetAcceptanceRateValue, ...
         'Tag','TargetAcceptanceRatePopup');
      %
      % Weight on randomization when initial values are generated under several chains. A zero value means that the
      % posterior mode is given full weight. A value of 1, means that initial values are drawn "completely" random.
      %
      controls.posterior.randomweighttext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 311 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Weight on randomization for initial values (multiple chains):', ...
         'Tag','RandomizationWeightText');
      %
      controls.posterior.randomweight = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 316 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI randomweight', ...
         'String','0.00|0.05|0.10|0.15|0.20|0.25|0.30|0.35|0.40|0.45|0.50|0.55|0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95|1.00', ...
         'Value',DSGEModel.RandomWeightValue, ...
         'Tag','ScaleFactorPopup');
      %
      % share of draws and weights for estimating component H+1 with MitISEM
      %
      controls.posterior.isweightsharetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 311 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Share of draws & weights to initialize added Student-t component:', ...
         'Tag','ISWeightShareText');
      %
      controls.posterior.isweightshare = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 316 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI isweightshare', ...
         'String','0.01|0.02|0.03|0.04|0.05|0.06|0.07|0.08|0.09|0.10|0.11|0.12|0.13|0.14|0.15|0.16|0.17|0.18|0.19|0.20|(0.01,0.05)|(0.05,0.10)|(0.05,0.15)|(0.10,0,15)|(0.15,0.20)|(0.01,0.05,0.10)|(0.05,0.10,0.15)|(0.10,0.15,0.20)|(0.01,0.05,0.10,0.15)|(0.05,0.10,0.15,0.20)|(0.01,0.05,0.10,0.15,0.20)', ...
         'Value',DSGEModel.ISWeightShareValue, ...
         'Tag','ISWeightSharePopup');
      %
      % Resampling algorithm for selection step of SMC
      %
      controls.posterior.resamplingalgorithmtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 284 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Resampling algorithm (selection step):', ...
         'Tag','ResamplingAlgorithmText');
      %
      controls.posterior.resamplingalgorithm = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 289 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI resamplingalgorithm', ...
         'String','Multinomial resampling|Stratified resampling|Systematic resampling|Residual resampling', ...
         'Value',DSGEModel.ResamplingAlgorithm, ...
         'Tag','ResamplingAlgorithmPopup');
      %
      % percent draws from posterior to use for prediction, etc.
      %
      controls.posterior.usepostdrawstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 284 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Percentage use of posterior draws for impulse responses, etc.:', ...
         'Tag','UsePostDrawsText');
      %
      controls.posterior.usepostdraws = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 289 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI usepostdraws', ...
         'String','0.1%|0.2%|0.3%|0.4%|0.5%|0.6%|0.7%|0.8%|0.9%|1%|2%|3%|4%|5%|6%|7%|8%|9%|10%|11%|12%|13%|14%|15%|16%|17%|18%|19%|20%|21%|22%|23%|24%|25%|26%|27%|28%|29%|30%|31%|32%|33%|34%|35%|36%|37%|38%|39%|40%|41%|42%|43%|44%|45%|46%|47%|48%|49%|50%|51%|52%|53%|54%|55%|56%|57%|58%|59%|60%|61%|62%|63%|64%|65%|66%|67%|68%|69%|70%|71%|72%|73%|74%|75%|76%|77%|78%|79%|80%|81%|82%|83%|84%|85%|86%|87%|88%|89%|90%|91%|92%|93%|94%|95%|96%|97%|98%|99%|100%', ...
         'Value',DSGEModel.PostDrawsPercentValue, ...
         'Tag','UsePostDrawsPopup');
      %
      % initial weight on added Student-t component
      %
      controls.posterior.isaddedmixweighttext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 284 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Initial weight on added Student-t component:', ...
         'Tag','ISAddedMixWeightText');
      %
      controls.posterior.isaddedmixweight = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 289 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI isaddedmixweight', ...
         'String','0.01|0.02|0.03|0.04|0.05|0.06|0.07|0.08|0.09|0.10|0.11|0.12|0.13|0.14|0.15|0.16|0.17|0.18|0.19|0.20', ...
         'Value',DSGEModel.ISAddedMixWeightValue, ...
         'Tag','ISAddedMixWeightPopup');
      %
      % percent draws from posterior to use for prediction
      %
      controls.posterior.postdrawsusagetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 258 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Maximum number of posterior draws to use for prediction:', ...
         'Tag','PostDrawsUsageText');
      %
      controls.posterior.postdrawsusage = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 263 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI postdrawsusage', ...
         'String','100|200|300|400|500|600|700|800|900|1,000|1,500|2,000|2,500|3,000|3,500|4,000|4,500|5,000|6,000|7,000|8,000|9,000|10,000|11,000|12,000|13,000|14,000|15,000|16,000|17,000|18,000|19,000|20,000|25,000|30,000|35,000|40,000|45,000|50,000|55,000|60,000|65,000|70,000|75,000|80,000|85,000|90,000|95,000|100,000|105,000|110,000|115,000|120,000|125,000|130,000|135,000|140,000|145,000|150,000|155,000|160,000|165,000|170,000|175,000|180,000|185,000|190,000|195,000|200,000|205,000|210,000|215,000|220,000|225,000|230,000|235,000|240,000|245,000|250,000|255,000|260,000|265,000|270,000|275,000|280,000|285,000|290,000|295,000|300,000|305,000|310,000|315,000|320,000|325,000|330,000|335,000|340,000|345,000|350,000|355,000|360,000|365,000|370,000|375,000|380,000|385,000|390,000|395,000|400,000|405,000|410,000|415,000|420,000|425,000|430,000|435,000|440,000|445,000|450,000|455,000|460,000|465,000|470,000|475,000|480,000|485,000|490,000|495,000|500,000|510,000|520,000|525,000|530,000|540,000|550,000|560,000|570,000|575,000|580,000|590,000|600,000|610,000|620,000|625,000|630,000|640,000|650,000|660,000|670,000|675,000|680,000|690,000|700,000|710,000|720,000|725,000|730,000|740,000|750,000|760,000|770,000|775,000|780,000|790,000|800,000|810,000|820,000|825,000|830,000|840,000|850,000|860,000|870,000|875,000|880,000|890,000|900,000|910,000|920,000|925,000|930,000|940,000|950,000|960,000|970,000|975,000|980,000|990,000|1,000,000', ...
         'Value',DSGEModel.PostDrawsUsageValue, ...
         'Tag','PostDrawsUsagePopup');
      %
      % threshold value of effective sample size for resampling
      %
      controls.posterior.resamplingthresholdtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 258 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Resampling threshold of the effective sample size (selection step):', ...
         'Tag','ResamplingThresholdText');
      %
      if DSGEModel.PosteriorSampler==9;
         set(controls.posterior.resamplingthresholdtext,'String','Recursion threshold of the effective sample size (correction step):');
      end;
      %
      controls.posterior.resamplingthreshold = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 263 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI resamplingthreshold', ...
         'String','10 percent|15 percent|20 percent|25 percent|30 percent|35 percent|40 percent|45 percent|50 percent|55 percent|60 percent|65 percent|70 percent|75 percent|80 percent|85 percent|90 percent', ...
         'Value',DSGEModel.ResamplingThresholdValue, ...
         'Tag','ResamplingThresholdPopup');
      %
      % Initial degrees of freedom for added Student-t component
      %
      controls.posterior.isaddeddftext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 258 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Initial degrees of freedom for added Student-t component:', ...
         'Tag','ISAddedDFText');
      %
      controls.posterior.isaddeddf = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 263 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI isaddeddf', ...
         'String','1|2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|18|19|20', ...
         'Value',DSGEModel.ISAddedDF, ...
         'Tag','ISAddedDFPopup');
      %
      % The optimization axes box
      %
      controls.optimizationbox = AxesBox([28 48 644 187],'Optimization',75,[0.5 1],'off',CurrINI);
      %
      % Optimization routine
      %
      controls.optimize.maxroutinetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 195 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Posterior maximization algorithm:', ...
         'Tag','MaximizationAlgorithmText');
      %
      controls.optimize.maxroutine = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 200 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI maxroutine', ...
         'String','Sims'' csminwel (transformed parameters)|Sims'' csminwel (original parameters)|Ratto''s newrat (transformed parameters)|Ratto''s newrat (original parameters)|Dynare''s gmhmaxlik (transformed parameters)|Dynare''s gmhmaxlik (original parameters)|Matlab''s fminunc (transformed parameters)|Matlab''s fminunc (original parameters)', ...
         'Value',DSGEModel.MaximizeAlgorithmValue, ...
         'Tag','MaximizationAlgorithmPopup');
      %
      if (FileExist(FixFilePath([pwd '\optim\fmin\matlab7\YADAfminunc7.m']))==0)&(FileExist(FixFilePath([pwd '\optim\fmin\matlab5\YADAfminunc5.m']))==0)&(FileExist(FixFilePath([pwd '\optim\fmin\matlab75\YADAfminunc7.m']))==0);
         if DSGEModel.MaximizeAlgorithmValue>6;
            DSGEModel.MaximizeAlgorithmValue = 1;
         end;
         set(controls.optimize.maxroutinetext,'Enable','off');
         set(controls.optimize.maxroutine,'String','Sims'' csminwel (transformed parameters)|Sims'' csminwel (original parameters)|Ratto''s newrat (transformed parameters)|Ratto''s newrat (original parameters)|Dynare''s gmhmaxlik (transformed parameters)|Dynare''s gmhmaxlik (original parameters)','Value',DSGEModel.MaximizeAlgorithmValue);
      end;
      %
      % Tolerance level
      %
      controls.optimize.tolerancetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 168 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Tolerance level:', ...
         'Tag','ToleranceText');
      %
      controls.optimize.tolerance = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 173 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI tolerance', ...
         'String','0.01|0.001|0.0001|0.00001|0.000001|0.0000001|0.00000001|0.000000001|0.0000000001|0.00000000001', ...
         'Value',DSGEModel.OptToleranceValue, ...
         'Tag','TolerancePopup');
      %
      % maximum number of iterations
      %
      controls.optimize.maximumiterationstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 141 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Maximum number of iterations:', ...
         'Tag','MaxIterationsText');
      %
      controls.optimize.maximumiterations = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 146 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI maximumiterations', ...
         'String','1,000|5,000|10,000|50,000|100,000|500,000|1,000,000|5,000,000|10,000,000|50,000,000|100,000,000|500,000,000|1,000,000,000', ...
         'Value',DSGEModel.OptMaxIterationsValue, ...
         'Tag','MaxIterationsPopup');
      %
      % Initialization of Hessian for csminwel
      %
      controls.optimize.initcsminweltext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 114 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Method for initializing inverse Hessian (csminwel and newrat only):', ...
         'Tag','InitialHessianCSMinWelText');
      %
      controls.optimize.initcsminwel = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 119 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI initcsminwel', ...
         'String','10 times identity matrix|Identity matrix|0.1 times identity matrix|0.01 times identity matrix|0.001 times identity matrix|0.0001 times identity matrix|0.00001 times identity matrix|Diagonal matrix using draws from prior', ...
         'Value',DSGEModel.InitializeHessian, ...
         'Tag','InitialHessianCSMinWelPopup');
      %
      % select number of extra csminwel runs that can be undertaken
      %
      controls.optimize.csminwelextrarunstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 86 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Maximum number of extra csminwel runs:', ...
         'Tag','CSMinWelExtraRunsText');
      %
      controls.optimize.csminwelextraruns = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 91 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI csminwelextraruns', ...
         'String','0|1|2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|18|19|20', ...
         'Value',DSGEModel.CsminwelExtraRuns, ...
         'Tag','CSMinWelExtraRunsPopup');
      %
      % grid width for checking the optimum
      %
      controls.optimize.widthnumberpointsgridtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 58 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Grid when checking the optimum [width / number of points]:', ...
         'Tag','NumberOfGridPointsText');
      %
      controls.optimize.gridwidth = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 63 120.5 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI gridwidth', ...
         'String','+/-1 st. dev.|+/-2 st. dev.|+/-3 st. dev.|+/-4 st. dev.|+/-5 st. dev.|+/-6 st. dev.|+/-7 st. dev.|+/-8 st. dev.|+/-9 stt. dev.|+/-10 st. dev.', ...
         'Value',DSGEModel.GridWidth, ...
         'Tag','GridWidthPopup');
      %
      controls.optimize.numbergridpoints = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[535.5 63 120.5 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI numbergridpoints', ...
         'String','10|15|20|25|30|35|40|45|50|55|60|65|70|75|80|85|90|95|100|110|120|130|140|150|160|170|180|190|200', ...
         'Value',DSGEModel.NumberOfGridPoints, ...
         'Tag','NumberOfGridPointsPopup');
      %
      % Controls on the Miscellaneous tab
      %
      controls.forecastbox = AxesBox([28 450 644 140],'Forecasting',50,[0.5 1],'off',CurrINI);
      %
      % Max forecast horizon
      %
      controls.forecast.maxhorizontext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 550 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Maximum forecast horizon:', ...
         'Tag','MaximumForecastHorizonText');
      %
      ForecastStr.annual = '1 year|2 years|3 years|4 years|5 years|6 years|7 years|8 years|9 years|10 years|11 years|12 years|13 years|14 years|15 years|16 years|17 years|18 years|19 years|20 years|21 years|22 years|23 years|24 years|25 years|26 years|27 years|28 years|29 years|30 years';
      ForecastStr.month = '1 month';
      for i=2:360;
         ForecastStr.month = [ForecastStr.month '|' int2str(i) ' months'];
      end;
      ForecastStr.quarter = '1 quarter';
      for i=2:120;
         ForecastStr.quarter = [ForecastStr.quarter '|' int2str(i) ' quarters'];
      end;
      %
      controls.forecast.maxhorizon = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 555 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI maxforecasthorizon', ...
         'UserData',ForecastStr, ...
         'String',ForecastStr.annual, ...
         'Value',DSGEModel.MaxForecastHorizon, ...
         'Tag','MaximumForecastHorizonPopup');
      %
      if strcmp(lower(DSGEModel.DataFrequency),'q')==1;
         set(controls.forecast.maxhorizon,'String',ForecastStr.quarter);
      elseif strcmp(lower(DSGEModel.DataFrequency),'m')==1;
         set(controls.forecast.maxhorizon,'String',ForecastStr.month);
      end;
      %
      % number of prediction paths per parameter value
      %
      controls.forecast.predpathstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 522 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Number of observed variables paths per parameter value:', ...
         'Tag','NumberPredictionPathsText');
      %
      controls.forecast.predpaths = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 527 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI predpaths', ...
         'String','100 paths|200 paths|300 paths|400 paths|500 paths|600 paths|700 paths|800 paths|900 paths|1,000 paths|1,500 paths|2,000 paths|2,500 paths|3,000 paths|3,500 paths|4,000 paths|4,500 paths|5,000 paths|6,000 paths|7,000 paths|8,000 paths|9,000 paths|10,000 paths|11,000 paths|12,000 paths|13,000 paths|14,000 paths|15,000 paths|16,000 paths|17,000 paths|18,000 paths|19,000 paths|20,000 paths|22,500 paths|25,000 paths|27,500 paths|30,000 paths|32,500 paths|35,000 paths|37,500 paths|40,000 paths|42,500 paths|45,000 paths|47,500 paths|50,000 paths|55,000 paths|60,000 paths|65,000 paths|70,000 paths|75,000 paths|80,000 paths|85,000 paths|90,000 paths|95,000 paths|100,000 paths|105,000 paths|110,000 paths|115,000 paths|120,000 paths|125,000 paths|130,000 paths|135,000 paths|140,000 paths|145,000 paths|150,000 paths|155,000 paths|160,000 paths|165,000 paths|170,000 paths|175,000 paths|180,000 paths|185,000 paths|190,000 paths|195,000 paths|200,000 paths|205,000 paths|210,000 paths|215,000 paths|220,000 paths|225,000 paths|230,000 paths|235,000 paths|240,000 paths|245,000 paths|250,000 paths|255,000 paths|260,000 paths|265,000 paths|270,000 paths|275,000 paths|280,000 paths|285,000 paths|290,000 paths|295,000 paths|300,000 paths|305,000 paths|310,000 paths|315,000 paths|320,000 paths|325,000 paths|330,000 paths|335,000 paths|340,000 paths|345,000 paths|350,000 paths|355,000 paths|360,000 paths|365,000 paths|370,000 paths|375,000 paths|380,000 paths|385,000 paths|390,000 paths|395,000 paths|400,000 paths|405,000 paths|410,000 paths|415,000 paths|420,000 paths|425,000 paths|430,000 paths|435,000 paths|440,000 paths|445,000 paths|450,000 paths|455,000 paths|460,000 paths|465,000 paths|470,000 paths|475,000 paths|480,000 paths|485,000 paths|490,000 paths|495,000 paths|500,000 paths|510,000 paths|520,000 paths|530,000 paths|540,000 paths|550,000 paths|560,000 paths|570,000 paths|580,000 paths|590,000 paths|600,000 paths|610,000 paths|620,000 paths|630,000 paths|640,000 paths|650,000 paths|660,000 paths|670,000 paths|680,000 paths|690,000 paths|700,000 paths|710,000 paths|720,000 paths|730,000 paths|740,000 paths|750,000 paths|760,000 paths|770,000 paths|780,000 paths|790,000 paths|800,000 paths|810,000 paths|820,000 paths|830,000 paths|840,000 paths|850,000 paths|860,000 paths|870,000 paths|880,000 paths|890,000 paths|900,000 paths|910,000 paths|920,000 paths|930,000 paths|940,000 paths|950,000 paths|960,000 paths|970,000 paths|980,000 paths|990,000 paths|1,000,000 paths', ...
         'Value',DSGEModel.NumPredPathsValue, ...
         'Tag','NumberPredictionPathsPopup');
      %
      % method for controlling shocks in conditional forecasting
      %
      controls.forecast.shockcontroltext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 494 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Method for controlling conditional forecasts:', ...
         'Tag','ShockControlMethodText');
      %
      controls.forecast.shockcontrol = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 499 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI shockcontrol', ...
         'String','Values for shocks|Distribution of shocks (Waggoner-Zha)|Distribution of subset of shocks', ...
         'Value',DSGEModel.ShockControlMethod, ...
         'Tag','ShockControlMethodPopup');
      %
      % How frequently should the parameters be updated when forecasting
      %
%      controls.forecast.freqreesttext = uicontrol('Units','pixels', ...
%         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
%         'Position',[44 487 312 20], ...
%         'FontSize',CurrINI.gui_fontsize, ...
%         'FontName',CurrINI.gui_fontname, ...
%         'FontWeight',CurrINI.gui_fontweight, ...
%         'FontAngle',CurrINI.gui_fontangle, ...
%         'Style','text', ...
%         'Enable','on', ...
%         'Visible','off', ...
%         'HorizontalAlignment','left', ...
%         'String','Frequency of parameter re-estimation:', ...
%         'Tag','FrequencyParameterReestimationText');
      %
%      controls.forecast.freqreest = uicontrol('Units','pixels', ...
%         'BackgroundColor',[1 1 1], ...
%         'Position',[356 492 250 20], ...
%         'FontSize',CurrINI.gui_fontsize, ...
%         'FontName',CurrINI.gui_fontname, ...
%         'FontWeight',CurrINI.gui_fontweight, ...
%         'FontAngle',CurrINI.gui_fontangle, ...
%         'Style','popup', ...
%         'Enable','on', ...
%         'Visible','off', ...
%         'HorizontalAlignment','left', ...
%         'Callback','YADAGUI freqreest', ...
%         'String','1 period|2 periods|3 periods|4 periods|5 periods|6 periods|7 periods|8 periods|9 periods|10 periods|11 periods|12 periods|13 periods|14 periods|15 periods|16 periods|17 periods|18 periods|19 periods|20 periods|21 periods|22 periods|23 periods|24 periods|25 periods|26 periods|27 periods|28 periods|29 periods|30 periods', ...
%         'Value',DSGEModel.FreqParameterReest, ...
%         'Tag','FrequencyParameterReestimationPopup');

      %
      % controls for automatically adjusting sample means for prediction to population means
      %
      controls.forecast.adjustpredictionpaths = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[44 465 362 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI checkadjustpredictionpaths', ...
            'String','Adjust prediction paths (sample mean = population mean)', ...
            'Value',DSGEModel.AdjustPredictionPaths, ...
            'Enable','on', ...
            'Tag','AdjustPredictionPathsCheckBox');
      %
      % use conditioning data for smooth estimation of time T state
      %
      controls.forecast.ksiuseconddata = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[406 465 250 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI checkksiuseconddata', ...
            'String','Use conditioning data for state distribution', ...
            'Value',DSGEModel.KsiUseCondData, ...
            'Enable','on', ...
            'Tag','KsiUseCondDataCheckBox');
      %
      % The tools axes box
      %
      controls.toolsbox = AxesBox([28 173 644 263],'Tools',50,[0.5 1],'off',CurrINI);
      %
      % maximum number of iterations for the Riccati solver when calculating the
      % forecast error variance decompositions.
      %
      controls.tools.riccatiiterationtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 394 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Maximum number of iterations for the Riccati solver:', ...
         'Tag','RiccatiIterationText');
      %
      controls.tools.riccatiiteration = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 399 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI riccati_maximumiterations', ...
         'String','1,000|2,000|3,000|4,000|5,000|6,000|7,000|8,000|9,000|10,000|11,000|12,000|13,000|14,000|15,000|16,000|17,000|18,000|19,000|20,000|21,000|22,000|23,000|24,000|25,000', ...
         'Value',DSGEModel.RiccatiMaxIterations, ...
         'Tag','RiccatiIterationsPopup');
      %
      % Tolerance value for the Riccati solver when calculating the
      % forecast error variance decompositions
      %
      controls.tools.riccatitolerancetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 366 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Tolerance value for the Riccati solver:', ...
         'Tag','RiccatiToleranceValueText');
      %
      controls.tools.riccatitolerance = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 371 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI riccati_tolerance', ...
         'String','0.01|0.001|0.0001|0.00001|0.000001|0.0000001|0.00000001|0.000000001|0.0000000001|0.00000000001', ...
         'Value',DSGEModel.RiccatiToleranceValue, ...
         'Tag','RiccatiToleranceValuePopup');
      %
      % Impulse response horizon
      %
      controls.tools.irhorizontext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 338 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Length of impulse response function horizon:', ...
         'Tag','IRHorizonText');
      %
      ir_str = '1 year';
      for i=2:50;
         ir_str = [ir_str '|' num2str(i,'%0.0f') ' years'];
      end;
      controls.tools.irhorizon = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 343 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI irhorizon', ...
         'String',ir_str, ...
         'Value',DSGEModel.IRHorizon, ...
         'Tag','IRHorizonPopup');
      %
      % step length for inverse hessian
      %
      controls.optimize.steplengthtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 311 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Step length for finite difference approx. of inverse Hessian:', ...
         'Tag','StepLengthHessianText');
      %
      controls.optimize.steplength = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 316 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI hessiansteplength', ...
         'String','0.0001|0.001|0.01|0.02|0.03|0.04|0.05|0.06|0.07|0.08|0.09|0.10|0.15|0.20|0.25|0.30|0.35|0.40|0.45|0.50|0.55|0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95|1.00', ...
         'Value',DSGEModel.StepLengthHessian, ...
         'Tag','StepLengthHessianPopup');
      %
      controls.tools.confidencemethodtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 283 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Confidence region estimation method:', ...
         'Tag','ConfidenceMethodText');
      %
      controls.tools.confidencemethod = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 288 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI confidencemethod', ...
         'String','Equal tails|Highest probability density (unimodal)', ...
         'Value',DSGEModel.ConfidenceRegionMethod, ...
         'Tag','ConfidenceMethodPopup');
      %
      % Option to check the optimum
      %
      controls.optimize.checkoptimum = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[44 258 360 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI checkoptimum', ...
            'String','Check the optimum', ...
            'Value',DSGEModel.CheckOptimum, ...
            'Enable','on', ...
            'Tag','CheckOptimumCheckBox');
      %
      % check optimum for transformed only [44 64 310 20], [356 64 250 20]
      %
      controls.optimize.checktransformed = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[406 258 250 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI checktransformedoptimum', ...
            'String','Check only for transformed parameters', ...
            'Value',DSGEModel.CheckTransformedOptimum, ...
            'Enable','on', ...
            'Tag','CheckTransformedOptimumCheckBox');
      %
      % check box for transforming the conditional modified Hessian estimates
      % to unconditional estimates
      %
      controls.optimize.modifiedhessian = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[44 234 612 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI checkmodifiedhessian', ...
            'String','Transform conditional standard deviations for modified Hessian to marginal using correlations from Hessian', ...
            'Value',DSGEModel.ModifiedHessian, ...
            'Enable','on', ...
            'Tag','FiniteDifferenceHessianCheckBox');
      %
      % check box for dealing with the random number generator
      %
      controls.tools.randomnumber = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[44 210 360 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI randomnumbervalue', ...
            'String','Use fixed state to initialize random number generators', ...
            'Value',DSGEModel.RandomNumberValue, ...
            'Enable','on', ...
            'Tag','RandomNumberCheckBox');
      %
      controls.tools.randomizedraws = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[406 210 250 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI randomizedraws', ...
            'String','Randomize draws from posterior distribution', ...
            'Value',DSGEModel.RandomizeDraws, ...
            'Enable','on', ...
            'Tag','RandomizeDrawsCheckBox');
      %
      % Option to compute posterior standard deviations using finite difference methods
      %
      controls.optimize.finitediffhessian = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[44 186 612 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI finitediffhessian', ...
            'String','Compute posterior standard deviations from inverse Hessian using finite differences', ...
            'Value',DSGEModel.FiniteDifferenceHessian, ...
            'Enable','on', ...
            'Tag','FiniteDifferenceHessianCheckBox');
      %
      % kernel density estimation controls
      %
      controls.kerneldensitybox = AxesBox([28 48 644 111],'Kernel Density Estimation',75,[0.5 1],'off',CurrINI);
      %
      % selection of kernel density estimator for the posterior
      %
      controls.graphics.posteriorkerneltext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 115 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Select kernel density estimator for the posterior density:', ...
         'Tag','PosteriorKernelDensityText');
      %
      controls.graphics.posteriorkernel = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 120 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI posteriorkerneldensity', ...
         'String','Gaussian|Silverman-type and Skld-Roberts correction|Sheather-Jones bandwidth|Bump killing bandwidth', ...
         'Value',DSGEModel.PosteriorDensityValue, ...
         'Tag','PosteriorKernelDensityPopup');
      %
      % Selection of Kernel density estimator for the prior
      %
      controls.graphics.kerneldensitytext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 87 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','off', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Select kernel density estimator for the prior density:', ...
         'Tag','KernelDensityText');
      %
      controls.graphics.kerneldensity = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 92 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','off', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI kerneldensity', ...
         'String','Normal kernel|Epanechnikov kernel|Rectangular kernel|Triangular kernel|Bi-weight kernel|Tri-weight kernel|Laplace kernel|Logistic kernel', ...
         'Value',DSGEModel.KernelDensityValue, ...
         'Tag','KernelDensityPopup');
      %
      % Show Kernel density estimates of the prior distribution instead of grid density PriorKernel
      %
      controls.graphics.priorkernel = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[44 62 522 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI priorkernel', ...
            'String','Compute kernel density estimates of prior densities instead of grid density estimates', ...
            'Value',DSGEModel.PriorKernel, ...
            'Enable','on', ...
            'Tag','PriorKernelCheckBox');
      %
      if DSGEModel.PriorKernel==1;
         set(controls.graphics.kerneldensitytext,'Enable','on');
         set(controls.graphics.kerneldensity,'Enable','on');
      end;
      %
      % Controls on the Bayesian VAR tab
      %
      controls.steadystatebox = AxesBox([28 510 644 80],'Prior - Steady State Parameters',75,[0.5 1],'off',CurrINI);
      %
      % the text control for selecting the file with the steady state prior
      %
      controls.bvar.steadystatefiletext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 555 522 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Steady state parameter prior file:', ...
         'Tag','SteadyStateFileText');
      %
      % the edit box for the steady state prior file
      %
      controls.bvar.steadystatefile = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[44 531 522 25], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','edit', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI checksteadystatefile', ...
            'String',DSGEModel.SteadyStatePriorFile, ...
            'Enable','on', ...
            'Tag','SteadyStateFileEditBox');
      %
      % browse for the steady state prior file
      %
      controls.bvar.steadystatefilebutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[576 531 80 25], ...
         'TooltipString','Browse', ...
         'Visible','off', ...
         'CData',ButtonImages.browse, ...
         'Callback','YADAGUI browsesteadystatefile', ...
         'Enable','on', ...
         'Tag','SteadyStateFileButton');
      %
      % Box for prior for parameters on lagged variables
      %
      controls.bvarpriorbox = AxesBox([28 297 644 199],'Prior - Parameters on Lags',75,[0.5 1],'off',CurrINI);
      %
      % Prior type
      %
      controls.bvar.priortypetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 451 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Prior type:', ...
         'Tag','PriorTypeText');
      %
      controls.bvar.priortype = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 456 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI priortype', ...
         'String','Minnesota-style|Normal conditional on covariance matrix|Diffuse', ...
         'Value',DSGEModel.PriorType, ...
         'Tag','PriorTypePopup');
      %
      % Prior mean for parameters on own first lag for levels variables
      %
      controls.bvar.priorlevelmeantext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 423 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Prior mean for own first lag parameter on levels variables:', ...
         'Tag','PriorLevelMeanText');
      %
      controls.bvar.priorlevelmean = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 428 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI priorlevelmean', ...
         'String','0.00|0.05|0.10|0.15|0.20|0.30|0.35|0.40|0.45|0.50|0.55|0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95|1.00', ...
         'Value',DSGEModel.PriorLevelMeanValue, ...
         'Tag','PriorLevelMeanPopup');
      %
      % Prior mean for parameters on own first lag for first difference
      %
      controls.bvar.priordiffmeantext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 395 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Prior mean for own first lag parameter on first diff variables:', ...
         'Tag','PriorDiffMeanText');
      %
      controls.bvar.priordiffmean = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 400 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI priordiffmean', ...
         'String','0.00|0.05|0.10|0.15|0.20|0.30|0.35|0.40|0.45|0.50|0.55|0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95|1.00', ...
         'Value',DSGEModel.PriorDiffMeanValue, ...
         'Tag','PriorDiffMeanPopup');
      %
      % Overall tightness
      %
      controls.bvar.overalltightnesstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 367 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Overall tightness hyperparameter:', ...
         'Tag','OverallTightnessText');
      %
      controls.bvar.overalltightness = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 372 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI overalltightness', ...
         'String','0.05|0.10|0.15|0.20|0.25|0.30|0.35|0.40|0.45|0.50|0.55|0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95|1.00|1.10|1.20|1.30|1.40|1.50|1.60|1.70|1.80|1.90|2.00|2.-10|2.20|2.30|2.40|2.50|2.70|2.80|2.90|3.00|3.10|3.20|3.30|3.40|3.50|3.60|3.70|3.80|3.90|4.00|4.10|4.20|4.30|4.40|4.50|4.60|4.70|4.80|4.90|5.00', ...
         'Value',DSGEModel.OverallTightnessValue, ...
         'Tag','OverallTightnessPopup');
      %
      % Cross-equation tightness
      %
      controls.bvar.crosseqtightnesstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 339 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Cross-equation tightness hyperparameter:', ...
         'Tag','CrossEquationTightnessText');
      %
      controls.bvar.crosseqtightness = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 344 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI crossequationtightness', ...
         'String','0.05|0.10|0.15|0.20|0.25|0.30|0.35|0.40|0.45|0.50|0.55|0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95', ...
         'Value',DSGEModel.CrossEqTightnessValue, ...
         'Tag','CrossEquationTightnessPopup');
      %
      % Harmonic lag decay parameter
      %
      controls.bvar.harmoniclagdecaytext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 311 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Harmonic lag decay hyperparameter:', ...
         'Tag','HarmonicLagDecayText');
      %
      controls.bvar.harmoniclagdecay = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 316 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI harmoniclagdecay', ...
         'String','0.5|1.0|1.5|2.0|2.5|3.0|3.5|4.0|4.5|5.0|5.5|6.0', ...
         'Value',DSGEModel.HarmonicLagDecayValue, ...
         'Tag','HarmonicLagDecayPopup');
      %
      if DSGEModel.PriorType==3;
         set(controls.bvar.priorlevelmeantext,'Enable','off');
         set(controls.bvar.priorlevelmean,'Enable','off');
         set(controls.bvar.priordiffmeantext,'Enable','off');
         set(controls.bvar.priordiffmean,'Enable','off');
         set(controls.bvar.overalltightnesstext,'Enable','off');
         set(controls.bvar.overalltightness,'Enable','off');
         set(controls.bvar.crosseqtightnesstext,'Enable','off');
         set(controls.bvar.crosseqtightness,'Enable','off');
         set(controls.bvar.harmoniclagdecaytext,'Enable','off');
         set(controls.bvar.harmoniclagdecay,'Enable','off');
      end;
      %
      % Box for Omega prior
      %
      controls.omegapriorbox = AxesBox([28 142 644 141],'Prior - Covariance Parameters',75,[0.5 1],'off',CurrINI);
      %
      controls.bvar.omegapriortypetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 240 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Prior type:', ...
         'Tag','OmegaPriorTypeText');
      %
      controls.bvar.omegapriortype = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 245 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI omegapriortype', ...
         'String','Diffuse|Inverted Wishart', ...
         'Value',DSGEModel.OmegaPriorType, ...
         'Tag','OmegaPriorTypePopup');
      %
      % A matrix determination
      %
      controls.bvar.wisharttypetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 212 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','off', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Wishart distribution parameterization format:', ...
         'Tag','WishartTypeText');
      %
      controls.bvar.wisharttype = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 217 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','off', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI wisharttype', ...
         'String','ML estimate of covariance matrix as A|Identity times variance tightness as A', ...
         'Value',DSGEModel.WishartType, ...
         'Tag','WishartTypePopup');
      %
      % Variance tightness hyperparameter
      %
      controls.bvar.variancetightnesstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 184 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','off', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Variance tightness hyperparameter:', ...
         'Tag','VarianceTightnessText');
      %
      controls.bvar.variancetightness = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 189 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','off', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI variancetightness', ...
         'String','0.05|0.10|0.15|0.20|0.25|0.30|0.35|0.40|0.45|0.50|0.55|0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95|1.00|1.10|1.20|1.30|1.40|1.50|1.60|1.70|1.80|1.90|2.00|2.25|2.50|2.75|3.00|3.25|3.50|3.75|4.00|4.25|4.50|4.75|5.00|5.25|5.50|5.75|6.00|6.25|6.50|6.75|7.00|7.25|7.50|7.75|8.00|8.25|8.50|8.75|9.00|9.25|9.50|9.75|10.00|11.50|12.00|12.50|13.00|13.50|14.00|14.50|15.00|15.50|16.00|16.50|17.00|17.50|18.00|18.50|19.00|19.50|20.00|21.00|22.00|23.00|24.00|25.00|26.00|27.00|28.00|29.00|30.00|35.00|40.00|45.00|50.00|55.00|60.00|65.00|70.00|75.00|80.00|85.00|90.00|95.00|100.00', ...
         'Value',DSGEModel.VarianceTightnessValue, ...
         'Tag','VarianceTightnessPopup');
      %
      % Degrees of freedom hyperparameter
      %
      controls.bvar.wishartdftext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 156 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','off', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Degrees of freedom:', ...
         'Tag','WishartDFText');
      %
      controls.bvar.wishartdf = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 161 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','off', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI wishartdf', ...
         'String','Number of endogenous variables + 2|Number of endogenous variables + 3|Number of endogenous variables + 4|Number of endogenous variables + 5|Number of endogenous variables + 6|Number of endogenous variables + 7|Number of endogenous variables + 8|Number of endogenous variables + 9|Number of endogenous variables + 10|Number of endogenous variables + 11|Number of endogenous variables + 12|Number of endogenous variables + 13|Number of endogenous variables + 14|Number of endogenous variables + 15|Number of endogenous variables + 16|Number of endogenous variables + 17|Number of endogenous variables + 18|Number of endogenous variables + 19|Number of endogenous variables + 20', ...
         'Value',DSGEModel.WishartDFValue, ...
         'Tag','WishartDFPopup');
      %
      % Enable entries that should be
      %
      if DSGEModel.OmegaPriorType==2;
         set(controls.bvar.wisharttypetext,'Enable','on');
         set(controls.bvar.wisharttype,'Enable','on');
         set(controls.bvar.wishartdftext,'Enable','on');
         set(controls.bvar.wishartdf,'Enable','on');
         if DSGEModel.WishartType==2;
            set(controls.bvar.variancetightnesstext,'Enable','on');
            set(controls.bvar.variancetightness,'Enable','on');
         end;
      end;
      %
      % Box for lag order selection
      %
      controls.bvarlagbox = AxesBox([28 48 644 80],'Lag Order Selection',75,[0.5 1],'off',CurrINI);
      %
      % Lag order selection
      %
      controls.bvar.lagtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 85 362 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Lag order of VAR and DSGE-VAR models:', ...
         'Tag','BVARLagsText');
      %
      controls.bvar.lag = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[406 90 250 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','popup', ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI bvarlags', ...
         'String','1|2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|18|19|20', ...
         'Value',DSGEModel.BVARLags, ...
         'Tag','BVARLagsPopup');
      %
      % stationarity setting
      %
      controls.bvar.stationaryvar = uicontrol('Units','pixels', ...
            'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
            'Position',[44 61 362 20], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','checkbox', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI stationaryvar', ...
            'String','Accept only stationary VARs for posterior sampling', ...
            'Value',DSGEModel.StationaryVAR, ...
            'Enable','on', ...
            'Tag','StationaryVARCheckBox');
      %
      % Controls on the Output tab
      %
      % the output selection axes box
      %
      controls.outputselect = AxesBox([28 513 644 77],'Output Selection',84,[0.5 1],'off',CurrINI);
      %
      controls.outputdirtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 555 522 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','text', ...
         'Enable','off', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Base output directory:', ...
         'Tag','OutputFileText');
      %
      % the edit box for the output file
      %
      controls.outputdir = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[44 531 522 25], ...
            'FontSize',CurrINI.gui_fontsize, ...
            'FontName',CurrINI.gui_fontname, ...
            'FontWeight',CurrINI.gui_fontweight, ...
            'FontAngle',CurrINI.gui_fontangle, ...
            'Style','edit', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'Callback','YADAGUI checkoutput', ...
            'String',DSGEModel.OutputDirectory, ...
            'Enable','off', ...
            'Tag','OutputFileEditBox');
      %
      % browse for the output file
      %
      controls.outputbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[576 531 80 25], ...
         'TooltipString','Browse', ...
         'Visible','off', ...
         'CData',ButtonImages.browsedisable, ...
         'Callback','YADAGUI browseoutput', ...
         'Enable','off', ...
         'Tag','BrowseOutputButton');
      %
      % If AiM file or data construction file exists we enable these controls
      %
      if (FileExist(DSGEModel.AIMFile)==1)|(FileExist(DSGEModel.DataConstructionFile)==1);
         set(controls.outputdirtext,'Enable','on');
         set(controls.outputdir,'Enable','on');
         set(controls.outputbutton,'Enable','on','CData',ButtonImages.browse);
      end;
      %
      % the estimation axes box
      %
      controls.estimationlog = AxesBox([28 48 644 451],'Estimation Log',75,[0.5 1],'off',CurrINI);
      %
      % checkbox for showing output in the estimation log
      %
      controls.showestimationlog = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 458 522 20], ...
         'FontSize',CurrINI.gui_fontsize, ...
         'FontName',CurrINI.gui_fontname, ...
         'FontWeight',CurrINI.gui_fontweight, ...
         'FontAngle',CurrINI.gui_fontangle, ...
         'Style','checkbox', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','YADAGUI showestimationlog', ...
         'String','Show information in the estimation log', ...
         'TooltipString','', ...
         'Value',DSGEModel.ShowEstimationLog, ...
         'Enable','on', ...
         'Tag','ShowEstimationLogCheckBox');
      %
      % set the tooltip string
      %
      set(controls.showestimationlog,'TooltipString',sprintf('Uncheck this box if YADA appears to be stuck when running estimations.\nThis can happen in large models when the graphics driver is strained.'));
      %
      % button to clear log window
      %
      controls.clearlogwindow = uicontrol('Units','pixels', ...
         'BackgroundColor',get(GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'Position',[576 458 80 25], ...
         'TooltipString','Clear Log', ...
         'CData',ButtonImages.cleanup, ...
         'Visible','off', ...
         'Callback','YADAGUI clearlogwindow', ...
         'Enable','on', ...
         'Tag','ClearLogWindowButton');
      %
      % and the estimation log controls
      %
      controls.estimation_log = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[44 64 612 379], ...
         'FontSize',10, ...
         'FontName','FixedWidth', ...
         'Style','listbox', ...
         'Enable','inactive', ...
         'Visible','off', ...
         'UserData',1, ...
         'Min',0, ...
         'Max',2, ...
         'ListboxTop',1, ...
         'HorizontalAlignment','left', ...
         'String','', ...
         'Tag','EstimationLogListBox', ...
         'Value',[]);
      %
      % And finally we include a status bar
      %
      controls.status = StatusBar(CurrINI,'String',StatusStr,'Position',[2 2 698 16]);
      %
      % store all handles for the controls in the figures user data
      %
      set(maingui,'UserData',controls, ...
                  'HandleVisibility','callback');
      if (ispc==1)&(MatlabNumber<=8.3);
         set(maingui,'WindowButtonMotionFcn','ShowStatus');
      end;
   case 'tab'
%      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % show and hide the various tabs
         %
         oldtab = get(controls.tab1,'UserData');
         newtab = get(gco,'Tag');
         newtab = strrep(newtab,'tab','');
         newtab = str2num(newtab);
         if abs(oldtab-newtab)>0;
            if MatlabNumber>=7;
               FixTabs(controls,oldtab,newtab);
            end;
            set(controls.tab1,'UserData',newtab);
            if newtab==1;
               %
               % DSGE Data tab
               %
               set(controls.frame3tab1,'Visible','off');
               set(controls.frame3tab2,'Visible','on');
               set(controls.frame3tab3,'Visible','on');
               set(controls.frame3tab4,'Visible','on');
               set(controls.frame3tab5,'Visible','on');
               set(controls.frame3tab6,'Visible','on');
               set(controls.frame1tab2,'Position',[118 594 102 11]);
               set(controls.frame1tab3,'Position',[221 594 102 11]);
               set(controls.frame1tab4,'Position',[324 594 102 11]);
               set(controls.frame1tab5,'Position',[427 594 102 11]);
               set(controls.frame1tab6,'Position',[530 594 102 11]);
               set(controls.tab1,'Position',[14 602 104 25]);
               set(controls.tab2,'Position',[118 602 102 23]);
               set(controls.tab3,'Position',[221 602 102 23]);
               set(controls.tab4,'Position',[324 602 102 23]);
               set(controls.tab5,'Position',[427 602 102 23]);
               set(controls.tab6,'Position',[530 602 102 23]);
               %
               set(controls.dsge.posteriorsamplingbox,'Visible','off');
               set(controls.dsge.marginallikelihoodtext,'Visible','off');
               set(controls.dsge.marginallikelihood,'Visible','off');
               set(controls.dsge.sequantialmltext,'Visible','off');
               set(controls.dsge.sequentialstart,'Visible','off');
               set(controls.dsge.sequentialstep,'Visible','off');
               set(controls.dsge.coverageprobtext,'Visible','off');
               set(controls.dsge.coveragestart,'Visible','off');
               set(controls.dsge.coverageincrement,'Visible','off');
               set(controls.dsge.coverageend,'Visible','off');
               set(controls.dsge.sequentialml,'Visible','off');
               set(controls.dsge.overwritedraws,'Visible','off');
               set(controls.dsge.progressbox,'Visible','off');
               set(controls.dsge.progress,'Visible','off');
               set(controls.dsge.progressclock,'Visible','off');
               set(controls.dsge.kalmanbox,'Visible','off');
               set(controls.dsge.doublingalgorithmtext,'Visible','off');
               set(controls.dsge.doublingalgorithm,'Visible','off');
               set(controls.dsge.doublingtolerancetext,'Visible','off');
               set(controls.dsge.doublingtolerance,'Visible','off');
               set(controls.dsge.statecovariancetext,'Visible','off');
               set(controls.dsge.statecovariance,'Visible','off');
               set(controls.dsge.initializekalmantext,'Visible','off');
               set(controls.dsge.initializekalman,'Visible','off');
               set(controls.dsge.kalmanalgorithmtext,'Visible','off');
               set(controls.dsge.kalmanalgorithm,'Visible','off');
               set(controls.dsge.aimtolerancetext,'Visible','off');
               set(controls.dsge.aimtolerance,'Visible','off');
               set(controls.dsge.usedoublingalgorithmtext,'Visible','off');
               set(controls.dsge.usedoublingalgorithm,'Visible','off');
               set(controls.dsge.useowninitialstate,'Visible','off');
               set(controls.dsge.allowunitroot,'Visible','off');
               set(controls.dsge.sampleselect,'Visible','off');
               set(controls.dsge.subsample,'Visible','off');
               set(controls.dsge.subbeginyear,'Visible','off');
               set(controls.dsge.subbeginperiod,'Visible','off');
               set(controls.dsge.subsampleseparator,'Visible','off');
               set(controls.dsge.subendyear,'Visible','off');
               set(controls.dsge.subendperiod,'Visible','off');
               %
               set(controls.posteriorsamplingbox,'Visible','off');
               set(controls.posterior.posteriorsamplertext,'Visible','off');
               set(controls.posterior.posteriorsampler,'Visible','off');
               set(controls.posterior.drawstext,'Visible','off');
               set(controls.posterior.draws,'Visible','off');
               set(controls.posterior.smcdrawstext,'Visible','off');
               set(controls.posterior.batchtext,'Visible','off');
               set(controls.posterior.batch,'Visible','off');
               set(controls.posterior.temperingstagestext,'Visible','off');
               set(controls.posterior.temperingstages,'Visible','off');
               set(controls.posterior.chainstext,'Visible','off');
               set(controls.posterior.chains,'Visible','off');
               set(controls.posterior.burnintext,'Visible','off');
               set(controls.posterior.burnin,'Visible','off');
               set(controls.posterior.temperinglambdatext,'Visible','off');
               set(controls.posterior.temperinglambda,'Visible','off');
               set(controls.posterior.invhessiantext,'Visible','off');
               set(controls.posterior.invhessian,'Visible','off');
               set(controls.posterior.numparamblockstext,'Visible','off');
               set(controls.posterior.numparamblocks,'Visible','off');
               set(controls.posterior.smcmhstepstext,'Visible','off');
               set(controls.posterior.smcmhsteps,'Visible','off');
               set(controls.posterior.maxcorrelationtext,'Visible','off');
               set(controls.posterior.maxcorrelation,'Visible','off');
               set(controls.posterior.mixeddistweighttext,'Visible','off');
               set(controls.posterior.mixeddistweight,'Visible','off');
               set(controls.posterior.initialscaletext,'Visible','off');
               set(controls.posterior.initialscale,'Visible','off');
               set(controls.posterior.smcinitialscaletext,'Visible','off');
               set(controls.posterior.smcinitialscale,'Visible','off');
               set(controls.posterior.scalefactortext,'Visible','off');
               set(controls.posterior.scalefactor,'Visible','off');
               set(controls.posterior.targetacceptanceratetext,'Visible','off');
               set(controls.posterior.targetacceptancerate,'Visible','off');
               set(controls.posterior.randomweighttext,'Visible','off');
               set(controls.posterior.randomweight,'Visible','off');
               set(controls.posterior.resamplingalgorithmtext,'Visible','off');
               set(controls.posterior.resamplingalgorithm,'Visible','off');
               set(controls.posterior.resamplingthresholdtext,'Visible','off');
               set(controls.posterior.resamplingthreshold,'Visible','off');
               set(controls.posterior.postdrawsusagetext,'Visible','off');
               set(controls.posterior.postdrawsusage,'Visible','off');
               set(controls.posterior.usepostdrawstext,'Visible','off');
               set(controls.posterior.usepostdraws,'Visible','off');
               set(controls.posterior.covtolerancetext,'Visible','off');
               set(controls.posterior.covtolerance,'Visible','off');
               set(controls.posterior.ismaxmixcomptext,'Visible','off');
               set(controls.posterior.ismaxmixcomp,'Visible','off');
               set(controls.posterior.isinitialdftext,'Visible','off');
               set(controls.posterior.isinitialdf,'Visible','off');
               set(controls.posterior.isweightsharetext,'Visible','off');
               set(controls.posterior.isweightshare,'Visible','off');
               set(controls.posterior.isaddedmixweighttext,'Visible','off');
               set(controls.posterior.isaddedmixweight,'Visible','off');
               set(controls.posterior.isaddeddftext,'Visible','off');
               set(controls.posterior.isaddeddf,'Visible','off');
               set(controls.forecastbox,'Visible','off');
               set(controls.forecast.maxhorizontext,'Visible','off');
               set(controls.forecast.maxhorizon,'Visible','off');
%               set(controls.forecast.freqreesttext,'Visible','off');
%               set(controls.forecast.freqreest,'Visible','off');
               set(controls.forecast.predpathstext,'Visible','off');
               set(controls.forecast.predpaths,'Visible','off');
               set(controls.forecast.shockcontroltext,'Visible','off');
               set(controls.forecast.shockcontrol,'Visible','off');
               set(controls.forecast.adjustpredictionpaths,'Visible','off');
               set(controls.forecast.ksiuseconddata,'Visible','off');
               set(controls.toolsbox,'Visible','off');
               set(controls.tools.riccatiiterationtext,'Visible','off');
               set(controls.tools.riccatiiteration,'Visible','off');
               set(controls.tools.riccatitolerancetext,'Visible','off');
               set(controls.tools.riccatitolerance,'Visible','off');
               set(controls.tools.irhorizontext,'Visible','off');
               set(controls.tools.irhorizon,'Visible','off');
               set(controls.tools.randomnumber,'Visible','off');
               set(controls.tools.randomizedraws,'Visible','off');
               set(controls.optimizationbox,'Visible','off');
               set(controls.optimize.maxroutinetext,'Visible','off');
               set(controls.optimize.maxroutine,'Visible','off');
               set(controls.optimize.tolerancetext,'Visible','off');
               set(controls.optimize.tolerance,'Visible','off');
               set(controls.optimize.maximumiterationstext,'Visible','off');
               set(controls.optimize.maximumiterations,'Visible','off');
               set(controls.optimize.initcsminweltext,'Visible','off');
               set(controls.optimize.initcsminwel,'Visible','off');
               set(controls.optimize.csminwelextrarunstext,'Visible','off');
               set(controls.optimize.csminwelextraruns,'Visible','off');
               set(controls.optimize.steplengthtext,'Visible','off');
               set(controls.optimize.steplength,'Visible','off');
               set(controls.tools.confidencemethodtext,'Visible','off');
               set(controls.tools.confidencemethod,'Visible','off');
               set(controls.optimize.gridwidth,'Visible','off');
               set(controls.optimize.widthnumberpointsgridtext,'Visible','off');
               set(controls.optimize.numbergridpoints,'Visible','off');
               set(controls.optimize.finitediffhessian,'Visible','off');
               set(controls.optimize.checkoptimum,'Visible','off');
               set(controls.optimize.checktransformed,'Visible','off');
               set(controls.optimize.modifiedhessian,'Visible','off');
               %
               set(controls.kerneldensitybox,'Visible','off');
               set(controls.graphics.posteriorkerneltext,'Visible','off');
               set(controls.graphics.posteriorkernel,'Visible','off');
               set(controls.graphics.kerneldensitytext,'Visible','off');
               set(controls.graphics.kerneldensity,'Visible','off');
               set(controls.graphics.priorkernel,'Visible','off');
               %
               set(controls.steadystatebox,'Visible','off');
               set(controls.bvar.steadystatefiletext,'Visible','off');
               set(controls.bvar.steadystatefile,'Visible','off');
               set(controls.bvar.steadystatefilebutton,'Visible','off');
               set(controls.bvarpriorbox,'Visible','off');
               set(controls.bvar.priorlevelmeantext,'Visible','off');
               set(controls.bvar.priorlevelmean,'Visible','off');
               set(controls.bvar.priordiffmeantext,'Visible','off');
               set(controls.bvar.priordiffmean,'Visible','off');
               set(controls.bvar.priortypetext,'Visible','off');
               set(controls.bvar.priortype,'Visible','off');
               set(controls.bvar.overalltightnesstext,'Visible','off');
               set(controls.bvar.overalltightness,'Visible','off');
               set(controls.bvar.crosseqtightnesstext,'Visible','off');
               set(controls.bvar.crosseqtightness,'Visible','off');
               set(controls.bvar.harmoniclagdecaytext,'Visible','off');
               set(controls.bvar.harmoniclagdecay,'Visible','off');
               set(controls.omegapriorbox,'Visible','off');
               set(controls.bvar.omegapriortypetext,'Visible','off');
               set(controls.bvar.omegapriortype,'Visible','off');
               set(controls.bvar.wisharttypetext,'Visible','off');
               set(controls.bvar.wisharttype,'Visible','off');
               set(controls.bvar.variancetightnesstext,'Visible','off');
               set(controls.bvar.variancetightness,'Visible','off');
               set(controls.bvar.wishartdftext,'Visible','off');
               set(controls.bvar.wishartdf,'Visible','off');
               set(controls.bvarlagbox,'Visible','off');
               set(controls.bvar.lagtext,'Visible','off');
               set(controls.bvar.lag,'Visible','off');
               set(controls.bvar.stationaryvar,'Visible','off');
               %
               set(controls.outputselect,'Visible','off');
               set(controls.outputdirtext,'Visible','off');
               set(controls.outputdir,'Visible','off');
               set(controls.outputbutton,'Visible','off');
               set(controls.showestimationlog,'Visible','off');
               set(controls.estimationlog,'Visible','off');
               set(controls.clearlogwindow,'Visible','off');
               set(controls.estimation_log,'Visible','off');
               %
               set(controls.dsge.obsfilesbox,'Visible','on');
               set(controls.dsge.priorfilesbox,'Visible','on');
               set(controls.dsge.parameterfilesbox,'Visible','on');
               set(controls.dsge.aimfilesbox,'Visible','on');
               set(controls.dsge.datafiletext,'Visible','on');
               set(controls.dsge.datafile,'Visible','on');
               set(controls.dsge.datafilebutton,'Visible','on');
               set(controls.dsge.priorfiletext,'Visible','on');
               set(controls.dsge.priorfile,'Visible','on');
               set(controls.dsge.priorfilebutton,'Visible','on');
               set(controls.dsge.priorfilesheet,'Visible','on');
               set(controls.dsge.systempriorfiletext,'Visible','on');
               set(controls.dsge.systempriorfile,'Visible','on');
               set(controls.dsge.systempriorfilebutton,'Visible','on');
               set(controls.dsge.updateparameterfiletext,'Visible','on');
               set(controls.dsge.updateparameterfile,'Visible','on');
               set(controls.dsge.updateparameterfilebutton,'Visible','on');
               set(controls.dsge.initialparameterfiletext,'Visible','on');
               set(controls.dsge.initialparameterfile,'Visible','on');
               set(controls.dsge.initialparameterfilebutton,'Visible','on');
               set(controls.dsge.runinitialfirst,'Visible','on');
               set(controls.dsge.measurefiletext,'Visible','on');
               set(controls.dsge.measurefile,'Visible','on');
               set(controls.dsge.measurefilebutton,'Visible','on');
               set(controls.dsge.aimfiletext,'Visible','on');
               set(controls.dsge.aimfile,'Visible','on');
               set(controls.dsge.aimfilebutton,'Visible','on');
               set(controls.dsge.modelnametext,'Visible','on');
               set(controls.dsge.modelnameaxes,'Visible','on');
               set(controls.dsge.modelname,'Visible','on');
               set(controls.dsge.modelnamebutton,'Visible','on');
               set(controls.dsge.modelsolvertext,'Visible','on');
               set(controls.dsge.modelsolver,'Visible','on');
            elseif newtab==2;
               %
               % Settings tab
               %
               set(controls.frame3tab1,'Visible','on');
               set(controls.frame3tab2,'Visible','off');
               set(controls.frame3tab3,'Visible','on');
               set(controls.frame3tab4,'Visible','on');
               set(controls.frame3tab5,'Visible','on');
               set(controls.frame3tab6,'Visible','on');
               set(controls.frame1tab2,'Position',[117 594 104 11]);
               set(controls.frame1tab3,'Position',[221 594 102 11]);
               set(controls.frame1tab4,'Position',[324 594 102 11]);
               set(controls.frame1tab5,'Position',[427 594 102 11]);
               set(controls.frame1tab6,'Position',[530 594 102 11]);
               set(controls.tab1,'Position',[15 602 102 23]);
               set(controls.tab2,'Position',[117 602 104 25]);
               set(controls.tab3,'Position',[221 602 102 23]);
               set(controls.tab4,'Position',[324 602 102 23]);
               set(controls.tab5,'Position',[427 602 102 23]);
               set(controls.tab6,'Position',[530 602 102 23]);
               %
               set(controls.dsge.obsfilesbox,'Visible','off');
               set(controls.dsge.priorfilesbox,'Visible','off');
               set(controls.dsge.parameterfilesbox,'Visible','off');
               set(controls.dsge.aimfilesbox,'Visible','off');
               set(controls.dsge.datafiletext,'Visible','off');
               set(controls.dsge.datafile,'Visible','off');
               set(controls.dsge.datafilebutton,'Visible','off');
               set(controls.dsge.priorfiletext,'Visible','off');
               set(controls.dsge.priorfile,'Visible','off');
               set(controls.dsge.priorfilebutton,'Visible','off');
               set(controls.dsge.priorfilesheet,'Visible','off');
               set(controls.dsge.systempriorfiletext,'Visible','off');
               set(controls.dsge.systempriorfile,'Visible','off');
               set(controls.dsge.systempriorfilebutton,'Visible','off');
               set(controls.dsge.updateparameterfiletext,'Visible','off');
               set(controls.dsge.updateparameterfile,'Visible','off');
               set(controls.dsge.updateparameterfilebutton,'Visible','off');
               set(controls.dsge.initialparameterfiletext,'Visible','off');
               set(controls.dsge.initialparameterfile,'Visible','off');
               set(controls.dsge.initialparameterfilebutton,'Visible','off');
               set(controls.dsge.runinitialfirst,'Visible','off');
               set(controls.dsge.measurefiletext,'Visible','off');
               set(controls.dsge.measurefile,'Visible','off');
               set(controls.dsge.measurefilebutton,'Visible','off');
               set(controls.dsge.aimfiletext,'Visible','off');
               set(controls.dsge.aimfile,'Visible','off');
               set(controls.dsge.aimfilebutton,'Visible','off');
               set(controls.dsge.modelnametext,'Visible','off');
               set(controls.dsge.modelnameaxes,'Visible','off');
               set(controls.dsge.modelname,'Visible','off');
               set(controls.dsge.modelnamebutton,'Visible','off');
               set(controls.dsge.modelsolvertext,'Visible','off');
               set(controls.dsge.modelsolver,'Visible','off');
               %
               set(controls.posteriorsamplingbox,'Visible','off');
               set(controls.posterior.posteriorsamplertext,'Visible','off');
               set(controls.posterior.posteriorsampler,'Visible','off');
               set(controls.posterior.drawstext,'Visible','off');
               set(controls.posterior.draws,'Visible','off');
               set(controls.posterior.smcdrawstext,'Visible','off');
               set(controls.posterior.batchtext,'Visible','off');
               set(controls.posterior.batch,'Visible','off');
               set(controls.posterior.temperingstagestext,'Visible','off');
               set(controls.posterior.temperingstages,'Visible','off');
               set(controls.posterior.chainstext,'Visible','off');
               set(controls.posterior.chains,'Visible','off');
               set(controls.posterior.burnintext,'Visible','off');
               set(controls.posterior.burnin,'Visible','off');
               set(controls.posterior.temperinglambdatext,'Visible','off');
               set(controls.posterior.temperinglambda,'Visible','off');
               set(controls.posterior.invhessiantext,'Visible','off');
               set(controls.posterior.invhessian,'Visible','off');
               set(controls.posterior.numparamblockstext,'Visible','off');
               set(controls.posterior.numparamblocks,'Visible','off');
               set(controls.posterior.smcmhstepstext,'Visible','off');
               set(controls.posterior.smcmhsteps,'Visible','off');
               set(controls.posterior.maxcorrelationtext,'Visible','off');
               set(controls.posterior.maxcorrelation,'Visible','off');
               set(controls.posterior.mixeddistweighttext,'Visible','off');
               set(controls.posterior.mixeddistweight,'Visible','off');
               set(controls.posterior.initialscaletext,'Visible','off');
               set(controls.posterior.initialscale,'Visible','off');
               set(controls.posterior.smcinitialscaletext,'Visible','off');
               set(controls.posterior.smcinitialscale,'Visible','off');
               set(controls.posterior.scalefactortext,'Visible','off');
               set(controls.posterior.scalefactor,'Visible','off');
               set(controls.posterior.targetacceptanceratetext,'Visible','off');
               set(controls.posterior.targetacceptancerate,'Visible','off');
               set(controls.posterior.randomweighttext,'Visible','off');
               set(controls.posterior.randomweight,'Visible','off');
               set(controls.posterior.resamplingalgorithmtext,'Visible','off');
               set(controls.posterior.resamplingalgorithm,'Visible','off');
               set(controls.posterior.resamplingthresholdtext,'Visible','off');
               set(controls.posterior.resamplingthreshold,'Visible','off');
               set(controls.posterior.postdrawsusagetext,'Visible','off');
               set(controls.posterior.postdrawsusage,'Visible','off');
               set(controls.posterior.usepostdrawstext,'Visible','off');
               set(controls.posterior.usepostdraws,'Visible','off');
               set(controls.posterior.covtolerancetext,'Visible','off');
               set(controls.posterior.covtolerance,'Visible','off');
               set(controls.posterior.ismaxmixcomptext,'Visible','off');
               set(controls.posterior.ismaxmixcomp,'Visible','off');
               set(controls.posterior.isinitialdftext,'Visible','off');
               set(controls.posterior.isinitialdf,'Visible','off');
               set(controls.posterior.isweightsharetext,'Visible','off');
               set(controls.posterior.isweightshare,'Visible','off');
               set(controls.posterior.isaddedmixweighttext,'Visible','off');
               set(controls.posterior.isaddedmixweight,'Visible','off');
               set(controls.posterior.isaddeddftext,'Visible','off');
               set(controls.posterior.isaddeddf,'Visible','off');
               set(controls.forecastbox,'Visible','off');
               set(controls.forecast.maxhorizontext,'Visible','off');
               set(controls.forecast.maxhorizon,'Visible','off');
%               set(controls.forecast.freqreesttext,'Visible','off');
%               set(controls.forecast.freqreest,'Visible','off');
               set(controls.forecast.predpathstext,'Visible','off');
               set(controls.forecast.predpaths,'Visible','off');
               set(controls.forecast.shockcontroltext,'Visible','off');
               set(controls.forecast.shockcontrol,'Visible','off');
               set(controls.forecast.adjustpredictionpaths,'Visible','off');
               set(controls.forecast.ksiuseconddata,'Visible','off');
               set(controls.toolsbox,'Visible','off');
               set(controls.tools.riccatiiterationtext,'Visible','off');
               set(controls.tools.riccatiiteration,'Visible','off');
               set(controls.tools.riccatitolerancetext,'Visible','off');
               set(controls.tools.riccatitolerance,'Visible','off');
               set(controls.tools.irhorizontext,'Visible','off');
               set(controls.tools.irhorizon,'Visible','off');
               set(controls.tools.randomnumber,'Visible','off');
               set(controls.tools.randomizedraws,'Visible','off');
               set(controls.optimizationbox,'Visible','off');
               set(controls.optimize.maxroutinetext,'Visible','off');
               set(controls.optimize.maxroutine,'Visible','off');
               set(controls.optimize.tolerancetext,'Visible','off');
               set(controls.optimize.tolerance,'Visible','off');
               set(controls.optimize.maximumiterationstext,'Visible','off');
               set(controls.optimize.maximumiterations,'Visible','off');
               set(controls.optimize.initcsminweltext,'Visible','off');
               set(controls.optimize.initcsminwel,'Visible','off');
               set(controls.optimize.csminwelextrarunstext,'Visible','off');
               set(controls.optimize.csminwelextraruns,'Visible','off');
               set(controls.optimize.steplengthtext,'Visible','off');
               set(controls.optimize.steplength,'Visible','off');
               set(controls.tools.confidencemethodtext,'Visible','off');
               set(controls.tools.confidencemethod,'Visible','off');
               set(controls.optimize.gridwidth,'Visible','off');
               set(controls.optimize.widthnumberpointsgridtext,'Visible','off');
               set(controls.optimize.numbergridpoints,'Visible','off');
               set(controls.optimize.finitediffhessian,'Visible','off');
               set(controls.optimize.checkoptimum,'Visible','off');
               set(controls.optimize.checktransformed,'Visible','off');
               set(controls.optimize.modifiedhessian,'Visible','off');
               %
               set(controls.kerneldensitybox,'Visible','off');
               set(controls.graphics.posteriorkerneltext,'Visible','off');
               set(controls.graphics.posteriorkernel,'Visible','off');
               set(controls.graphics.kerneldensitytext,'Visible','off');
               set(controls.graphics.kerneldensity,'Visible','off');
               set(controls.graphics.priorkernel,'Visible','off');
               %
               set(controls.steadystatebox,'Visible','off');
               set(controls.bvar.steadystatefiletext,'Visible','off');
               set(controls.bvar.steadystatefile,'Visible','off');
               set(controls.bvar.steadystatefilebutton,'Visible','off');
               set(controls.bvarpriorbox,'Visible','off');
               set(controls.bvar.priorlevelmeantext,'Visible','off');
               set(controls.bvar.priorlevelmean,'Visible','off');
               set(controls.bvar.priordiffmeantext,'Visible','off');
               set(controls.bvar.priordiffmean,'Visible','off');
               set(controls.bvar.priortypetext,'Visible','off');
               set(controls.bvar.priortype,'Visible','off');
               set(controls.bvar.overalltightnesstext,'Visible','off');
               set(controls.bvar.overalltightness,'Visible','off');
               set(controls.bvar.crosseqtightnesstext,'Visible','off');
               set(controls.bvar.crosseqtightness,'Visible','off');
               set(controls.bvar.harmoniclagdecaytext,'Visible','off');
               set(controls.bvar.harmoniclagdecay,'Visible','off');
               set(controls.omegapriorbox,'Visible','off');
               set(controls.bvar.omegapriortypetext,'Visible','off');
               set(controls.bvar.omegapriortype,'Visible','off');
               set(controls.bvar.wisharttypetext,'Visible','off');
               set(controls.bvar.wisharttype,'Visible','off');
               set(controls.bvar.variancetightnesstext,'Visible','off');
               set(controls.bvar.variancetightness,'Visible','off');
               set(controls.bvar.wishartdftext,'Visible','off');
               set(controls.bvar.wishartdf,'Visible','off');
               set(controls.bvarlagbox,'Visible','off');
               set(controls.bvar.lagtext,'Visible','off');
               set(controls.bvar.lag,'Visible','off');
               set(controls.bvar.stationaryvar,'Visible','off');
               %
               set(controls.outputselect,'Visible','off');
               set(controls.outputdirtext,'Visible','off');
               set(controls.outputdir,'Visible','off');
               set(controls.outputbutton,'Visible','off');
               set(controls.showestimationlog,'Visible','off');
               set(controls.estimationlog,'Visible','off');
               set(controls.clearlogwindow,'Visible','off');
               set(controls.estimation_log,'Visible','off');
               %
               set(controls.dsge.posteriorsamplingbox,'Visible','on');
               set(controls.dsge.marginallikelihoodtext,'Visible','on');
               set(controls.dsge.marginallikelihood,'Visible','on');
               set(controls.dsge.sequantialmltext,'Visible','on');
               set(controls.dsge.sequentialstart,'Visible','on');
               set(controls.dsge.sequentialstep,'Visible','on');
               set(controls.dsge.coverageprobtext,'Visible','on');
               set(controls.dsge.coveragestart,'Visible','on');
               set(controls.dsge.coverageincrement,'Visible','on');
               set(controls.dsge.coverageend,'Visible','on');
               set(controls.dsge.sequentialml,'Visible','on');
               set(controls.dsge.overwritedraws,'Visible','on');
               set(controls.dsge.progressbox,'Visible','on');
               set(controls.dsge.progress,'Visible','on');
               set(controls.dsge.progressclock,'Visible','on');
               set(controls.dsge.kalmanbox,'Visible','on');
               set(controls.dsge.doublingalgorithmtext,'Visible','on');
               set(controls.dsge.doublingalgorithm,'Visible','on');
               set(controls.dsge.doublingtolerancetext,'Visible','on');
               set(controls.dsge.doublingtolerance,'Visible','on');
               set(controls.dsge.statecovariancetext,'Visible','on');
               set(controls.dsge.statecovariance,'Visible','on');
               set(controls.dsge.initializekalmantext,'Visible','on');
               set(controls.dsge.initializekalman,'Visible','on');
               set(controls.dsge.kalmanalgorithmtext,'Visible','on');
               set(controls.dsge.kalmanalgorithm,'Visible','on');
               set(controls.dsge.aimtolerancetext,'Visible','on');
               set(controls.dsge.aimtolerance,'Visible','on');
               set(controls.dsge.usedoublingalgorithmtext,'Visible','on');
               set(controls.dsge.usedoublingalgorithm,'Visible','on');
               set(controls.dsge.useowninitialstate,'Visible','on');
               set(controls.dsge.allowunitroot,'Visible','on');
               set(controls.dsge.sampleselect,'Visible','on');
               set(controls.dsge.subsample,'Visible','on');
               set(controls.dsge.subbeginyear,'Visible','on');
               set(controls.dsge.subbeginperiod,'Visible','on');
               set(controls.dsge.subsampleseparator,'Visible','on');
               set(controls.dsge.subendyear,'Visible','on');
               set(controls.dsge.subendperiod,'Visible','on');
            elseif newtab==3;
               %
               % Options tab
               %
               set(controls.frame3tab1,'Visible','on');
               set(controls.frame3tab2,'Visible','on');
               set(controls.frame3tab3,'Visible','off');
               set(controls.frame3tab4,'Visible','on');
               set(controls.frame3tab5,'Visible','on');
               set(controls.frame3tab6,'Visible','on');
               set(controls.frame1tab2,'Position',[118 594 102 11]);
               set(controls.frame1tab3,'Position',[220 594 104 11]);
               set(controls.frame1tab4,'Position',[324 594 102 11]);
               set(controls.frame1tab5,'Position',[427 594 102 11]);
               set(controls.frame1tab6,'Position',[530 594 102 11]);
               set(controls.tab1,'Position',[15 602 102 23]);
               set(controls.tab2,'Position',[118 602 102 23]);
               set(controls.tab3,'Position',[220 602 104 25]);
               set(controls.tab4,'Position',[324 602 102 23]);
               set(controls.tab5,'Position',[427 602 102 23]);
               set(controls.tab6,'Position',[530 602 102 23]);
               %
               set(controls.dsge.obsfilesbox,'Visible','off');
               set(controls.dsge.priorfilesbox,'Visible','off');
               set(controls.dsge.parameterfilesbox,'Visible','off');
               set(controls.dsge.aimfilesbox,'Visible','off');
               set(controls.dsge.datafiletext,'Visible','off');
               set(controls.dsge.datafile,'Visible','off');
               set(controls.dsge.datafilebutton,'Visible','off');
               set(controls.dsge.priorfiletext,'Visible','off');
               set(controls.dsge.priorfile,'Visible','off');
               set(controls.dsge.priorfilebutton,'Visible','off');
               set(controls.dsge.priorfilesheet,'Visible','off');
               set(controls.dsge.systempriorfiletext,'Visible','off');
               set(controls.dsge.systempriorfile,'Visible','off');
               set(controls.dsge.systempriorfilebutton,'Visible','off');
               set(controls.dsge.updateparameterfiletext,'Visible','off');
               set(controls.dsge.updateparameterfile,'Visible','off');
               set(controls.dsge.updateparameterfilebutton,'Visible','off');
               set(controls.dsge.initialparameterfiletext,'Visible','off');
               set(controls.dsge.initialparameterfile,'Visible','off');
               set(controls.dsge.initialparameterfilebutton,'Visible','off');
               set(controls.dsge.runinitialfirst,'Visible','off');
               set(controls.dsge.measurefiletext,'Visible','off');
               set(controls.dsge.measurefile,'Visible','off');
               set(controls.dsge.measurefilebutton,'Visible','off');
               set(controls.dsge.aimfiletext,'Visible','off');
               set(controls.dsge.aimfile,'Visible','off');
               set(controls.dsge.aimfilebutton,'Visible','off');
               set(controls.dsge.modelnametext,'Visible','off');
               set(controls.dsge.modelnameaxes,'Visible','off');
               set(controls.dsge.modelname,'Visible','off');
               set(controls.dsge.modelnamebutton,'Visible','off');
               set(controls.dsge.modelsolvertext,'Visible','off');
               set(controls.dsge.modelsolver,'Visible','off');
               %
               set(controls.dsge.posteriorsamplingbox,'Visible','off');
               set(controls.dsge.marginallikelihoodtext,'Visible','off');
               set(controls.dsge.marginallikelihood,'Visible','off');
               set(controls.dsge.sequantialmltext,'Visible','off');
               set(controls.dsge.sequentialstart,'Visible','off');
               set(controls.dsge.sequentialstep,'Visible','off');
               set(controls.dsge.coverageprobtext,'Visible','off');
               set(controls.dsge.coveragestart,'Visible','off');
               set(controls.dsge.coverageincrement,'Visible','off');
               set(controls.dsge.coverageend,'Visible','off');
               set(controls.dsge.sequentialml,'Visible','off');
               set(controls.dsge.overwritedraws,'Visible','off');
               set(controls.dsge.progressbox,'Visible','off');
               set(controls.dsge.progress,'Visible','off');
               set(controls.dsge.progressclock,'Visible','off');
               set(controls.dsge.kalmanbox,'Visible','off');
               set(controls.dsge.doublingalgorithmtext,'Visible','off');
               set(controls.dsge.doublingalgorithm,'Visible','off');
               set(controls.dsge.doublingtolerancetext,'Visible','off');
               set(controls.dsge.doublingtolerance,'Visible','off');
               set(controls.dsge.statecovariancetext,'Visible','off');
               set(controls.dsge.statecovariance,'Visible','off');
               set(controls.dsge.initializekalmantext,'Visible','off');
               set(controls.dsge.initializekalman,'Visible','off');
               set(controls.dsge.kalmanalgorithmtext,'Visible','off');
               set(controls.dsge.kalmanalgorithm,'Visible','off');
               set(controls.dsge.aimtolerancetext,'Visible','off');
               set(controls.dsge.aimtolerance,'Visible','off');
               set(controls.dsge.usedoublingalgorithmtext,'Visible','off');
               set(controls.dsge.usedoublingalgorithm,'Visible','off');
               set(controls.dsge.useowninitialstate,'Visible','off');
               set(controls.dsge.allowunitroot,'Visible','off');
               set(controls.dsge.sampleselect,'Visible','off');
               set(controls.dsge.subsample,'Visible','off');
               set(controls.dsge.subbeginyear,'Visible','off');
               set(controls.dsge.subbeginperiod,'Visible','off');
               set(controls.dsge.subsampleseparator,'Visible','off');
               set(controls.dsge.subendyear,'Visible','off');
               set(controls.dsge.subendperiod,'Visible','off');
               %
               set(controls.kerneldensitybox,'Visible','off');
               set(controls.graphics.posteriorkerneltext,'Visible','off');
               set(controls.graphics.posteriorkernel,'Visible','off');
               set(controls.graphics.kerneldensitytext,'Visible','off');
               set(controls.graphics.kerneldensity,'Visible','off');
               set(controls.graphics.priorkernel,'Visible','off');
               %
               set(controls.steadystatebox,'Visible','off');
               set(controls.bvar.steadystatefiletext,'Visible','off');
               set(controls.bvar.steadystatefile,'Visible','off');
               set(controls.bvar.steadystatefilebutton,'Visible','off');
               set(controls.bvarpriorbox,'Visible','off');
               set(controls.bvar.priorlevelmeantext,'Visible','off');
               set(controls.bvar.priorlevelmean,'Visible','off');
               set(controls.bvar.priordiffmeantext,'Visible','off');
               set(controls.bvar.priordiffmean,'Visible','off');
               set(controls.bvar.priortypetext,'Visible','off');
               set(controls.bvar.priortype,'Visible','off');
               set(controls.bvar.overalltightnesstext,'Visible','off');
               set(controls.bvar.overalltightness,'Visible','off');
               set(controls.bvar.crosseqtightnesstext,'Visible','off');
               set(controls.bvar.crosseqtightness,'Visible','off');
               set(controls.bvar.harmoniclagdecaytext,'Visible','off');
               set(controls.bvar.harmoniclagdecay,'Visible','off');
               set(controls.omegapriorbox,'Visible','off');
               set(controls.bvar.omegapriortypetext,'Visible','off');
               set(controls.bvar.omegapriortype,'Visible','off');
               set(controls.bvar.wisharttypetext,'Visible','off');
               set(controls.bvar.wisharttype,'Visible','off');
               set(controls.bvar.variancetightnesstext,'Visible','off');
               set(controls.bvar.variancetightness,'Visible','off');
               set(controls.bvar.wishartdftext,'Visible','off');
               set(controls.bvar.wishartdf,'Visible','off');
               set(controls.bvarlagbox,'Visible','off');
               set(controls.bvar.lagtext,'Visible','off');
               set(controls.bvar.lag,'Visible','off');
               set(controls.bvar.stationaryvar,'Visible','off');
               %
               set(controls.outputselect,'Visible','off');
               set(controls.outputdirtext,'Visible','off');
               set(controls.outputdir,'Visible','off');
               set(controls.outputbutton,'Visible','off');
               set(controls.showestimationlog,'Visible','off');
               set(controls.estimationlog,'Visible','off');
               set(controls.clearlogwindow,'Visible','off');
               set(controls.estimation_log,'Visible','off');
               %
               set(controls.forecastbox,'Visible','off');
               set(controls.forecast.maxhorizontext,'Visible','off');
               set(controls.forecast.maxhorizon,'Visible','off');
%               set(controls.forecast.freqreesttext,'Visible','off');
%               set(controls.forecast.freqreest,'Visible','off');
               set(controls.forecast.predpathstext,'Visible','off');
               set(controls.forecast.predpaths,'Visible','off');
               set(controls.forecast.shockcontroltext,'Visible','off');
               set(controls.forecast.shockcontrol,'Visible','off');
               set(controls.forecast.adjustpredictionpaths,'Visible','off');
               set(controls.forecast.ksiuseconddata,'Visible','off');
               set(controls.toolsbox,'Visible','off');
               set(controls.tools.riccatiiterationtext,'Visible','off');
               set(controls.tools.riccatiiteration,'Visible','off');
               set(controls.tools.riccatitolerancetext,'Visible','off');
               set(controls.tools.riccatitolerance,'Visible','off');
               set(controls.optimize.steplengthtext,'Visible','off');
               set(controls.optimize.steplength,'Visible','off');
               set(controls.tools.confidencemethodtext,'Visible','off');
               set(controls.tools.confidencemethod,'Visible','off');
               set(controls.tools.irhorizontext,'Visible','off');
               set(controls.tools.irhorizon,'Visible','off');
               set(controls.tools.randomnumber,'Visible','off');
               set(controls.tools.randomizedraws,'Visible','off');
               set(controls.optimize.finitediffhessian,'Visible','off');
               set(controls.optimize.checkoptimum,'Visible','off');
               set(controls.optimize.checktransformed,'Visible','off');
               set(controls.optimize.modifiedhessian,'Visible','off');
               %
               set(controls.posteriorsamplingbox,'Visible','on');
               set(controls.posterior.posteriorsamplertext,'Visible','on');
               set(controls.posterior.posteriorsampler,'Visible','on');
               if (DSGEModel.PosteriorSampler<=7)|(DSGEModel.PosteriorSampler==10);
                  set(controls.posterior.drawstext,'Visible','on');
               else;
                  set(controls.posterior.smcdrawstext,'Visible','on');
               end;
               set(controls.posterior.draws,'Visible','on');
               if DSGEModel.PosteriorSampler<=7;
                  set(controls.posterior.batchtext,'Visible','on','Enable','on');
                  set(controls.posterior.batch,'Visible','on','Enable','on');
                  set(controls.posterior.burnintext,'Visible','on');
                  set(controls.posterior.burnin,'Visible','on');
                  set(controls.posterior.invhessiantext,'Visible','on');
                  set(controls.posterior.invhessian,'Visible','on');
                  set(controls.posterior.maxcorrelationtext,'Visible','on');
                  set(controls.posterior.maxcorrelation,'Visible','on');
                  set(controls.posterior.initialscaletext,'Visible','on');
                  set(controls.posterior.initialscale,'Visible','on');
                  set(controls.posterior.scalefactortext,'Visible','on');
                  set(controls.posterior.scalefactor,'Visible','on');
                  set(controls.posterior.randomweighttext,'Visible','on');
                  set(controls.posterior.randomweight,'Visible','on');
                  set(controls.posterior.usepostdrawstext,'Visible','on');
                  set(controls.posterior.usepostdraws,'Visible','on');
                  set(controls.posterior.postdrawsusagetext,'Visible','on');
                  set(controls.posterior.postdrawsusage,'Visible','on');
               elseif (DSGEModel.PosteriorSampler==8)|(DSGEModel.PosteriorSampler==9);
                  set(controls.posterior.temperingstagestext,'Visible','on');
                  set(controls.posterior.temperingstages,'Visible','on');
                  set(controls.posterior.temperinglambdatext,'Visible','on');
                  set(controls.posterior.temperinglambda,'Visible','on');
                  set(controls.posterior.numparamblockstext,'Visible','on');
                  set(controls.posterior.numparamblocks,'Visible','on');
                  set(controls.posterior.smcmhstepstext,'Visible','on');
                  set(controls.posterior.smcmhsteps,'Visible','on');
                  set(controls.posterior.mixeddistweighttext,'Visible','on');
                  set(controls.posterior.mixeddistweight,'Visible','on');
                  set(controls.posterior.smcinitialscaletext,'Visible','on');
                  set(controls.posterior.smcinitialscale,'Visible','on');
                  set(controls.posterior.targetacceptanceratetext,'Visible','on');
                  set(controls.posterior.targetacceptancerate,'Visible','on');
                  set(controls.posterior.resamplingalgorithmtext,'Visible','on');
                  set(controls.posterior.resamplingalgorithm,'Visible','on');
                  set(controls.posterior.resamplingthresholdtext,'Visible','on');
                  set(controls.posterior.resamplingthreshold,'Visible','on');
               elseif DSGEModel.PosteriorSampler==10;
                  set(controls.posterior.batchtext,'Visible','on','Enable','off');
                  set(controls.posterior.batch,'Visible','on','Enable','off');
                  set(controls.posterior.covtolerancetext,'Visible','on');
                  set(controls.posterior.covtolerance,'Visible','on');
                  set(controls.posterior.invhessiantext,'Visible','on');
                  set(controls.posterior.invhessian,'Visible','on');
                  set(controls.posterior.maxcorrelationtext,'Visible','on');
                  set(controls.posterior.maxcorrelation,'Visible','on');
                  set(controls.posterior.ismaxmixcomptext,'Visible','on');
                  set(controls.posterior.ismaxmixcomp,'Visible','on');
                  set(controls.posterior.isinitialdftext,'Visible','on');
                  set(controls.posterior.isinitialdf,'Visible','on');
                  set(controls.posterior.isweightsharetext,'Visible','on');
                  set(controls.posterior.isweightshare,'Visible','on');
                  set(controls.posterior.isaddedmixweighttext,'Visible','on');
                  set(controls.posterior.isaddedmixweight,'Visible','on');
                  set(controls.posterior.isaddeddftext,'Visible','on');
                  set(controls.posterior.isaddeddf,'Visible','on');
                  %
%                  set(controls.posterior.initialscaletext,'Visible','on');
%                  set(controls.posterior.initialscale,'Visible','on');
%                  set(controls.posterior.scalefactortext,'Visible','on');
%                  set(controls.posterior.scalefactor,'Visible','on');
%                  set(controls.posterior.randomweighttext,'Visible','on');
%                  set(controls.posterior.randomweight,'Visible','on');
%                  set(controls.posterior.usepostdrawstext,'Visible','on');
%                  set(controls.posterior.usepostdraws,'Visible','on');
%                  set(controls.posterior.postdrawsusagetext,'Visible','on');
%                  set(controls.posterior.postdrawsusage,'Visible','on');
               end;
               set(controls.posterior.chainstext,'Visible','on');
               set(controls.posterior.chains,'Visible','on');
               set(controls.optimizationbox,'Visible','on');
               set(controls.optimize.maxroutinetext,'Visible','on');
               set(controls.optimize.maxroutine,'Visible','on');
               set(controls.optimize.tolerancetext,'Visible','on');
               set(controls.optimize.tolerance,'Visible','on');
               set(controls.optimize.maximumiterationstext,'Visible','on');
               set(controls.optimize.maximumiterations,'Visible','on');
               set(controls.optimize.initcsminweltext,'Visible','on');
               set(controls.optimize.initcsminwel,'Visible','on');
               set(controls.optimize.csminwelextrarunstext,'Visible','on');
               set(controls.optimize.csminwelextraruns,'Visible','on');
               set(controls.optimize.gridwidth,'Visible','on');
               set(controls.optimize.widthnumberpointsgridtext,'Visible','on');
               set(controls.optimize.numbergridpoints,'Visible','on');
            elseif newtab==4;
               %
               % Miscellaneous tab
               %
               set(controls.frame3tab1,'Visible','on');
               set(controls.frame3tab2,'Visible','on');
               set(controls.frame3tab3,'Visible','on');
               set(controls.frame3tab4,'Visible','off');
               set(controls.frame3tab5,'Visible','on');
               set(controls.frame3tab6,'Visible','on');
               set(controls.frame1tab2,'Position',[118 594 102 11]);
               set(controls.frame1tab3,'Position',[221 594 102 11]);
               set(controls.frame1tab4,'Position',[323 594 104 11]);
               set(controls.frame1tab5,'Position',[427 594 102 11]);
               set(controls.frame1tab6,'Position',[530 594 102 11]);
               set(controls.tab1,'Position',[15 602 102 23]);
               set(controls.tab2,'Position',[118 602 102 23]);
               set(controls.tab3,'Position',[221 602 102 23]);
               set(controls.tab4,'Position',[323 602 104 25]);
               set(controls.tab5,'Position',[427 602 102 23]);
               set(controls.tab6,'Position',[530 602 102 23]);
               %
               set(controls.dsge.obsfilesbox,'Visible','off');
               set(controls.dsge.priorfilesbox,'Visible','off');
               set(controls.dsge.parameterfilesbox,'Visible','off');
               set(controls.dsge.aimfilesbox,'Visible','off');
               set(controls.dsge.datafiletext,'Visible','off');
               set(controls.dsge.datafile,'Visible','off');
               set(controls.dsge.datafilebutton,'Visible','off');
               set(controls.dsge.priorfiletext,'Visible','off');
               set(controls.dsge.priorfile,'Visible','off');
               set(controls.dsge.priorfilebutton,'Visible','off');
               set(controls.dsge.priorfilesheet,'Visible','off');
               set(controls.dsge.systempriorfiletext,'Visible','off');
               set(controls.dsge.systempriorfile,'Visible','off');
               set(controls.dsge.systempriorfilebutton,'Visible','off');
               set(controls.dsge.updateparameterfiletext,'Visible','off');
               set(controls.dsge.updateparameterfile,'Visible','off');
               set(controls.dsge.updateparameterfilebutton,'Visible','off');
               set(controls.dsge.initialparameterfiletext,'Visible','off');
               set(controls.dsge.initialparameterfile,'Visible','off');
               set(controls.dsge.initialparameterfilebutton,'Visible','off');
               set(controls.dsge.runinitialfirst,'Visible','off');
               set(controls.dsge.measurefiletext,'Visible','off');
               set(controls.dsge.measurefile,'Visible','off');
               set(controls.dsge.measurefilebutton,'Visible','off');
               set(controls.dsge.aimfiletext,'Visible','off');
               set(controls.dsge.aimfile,'Visible','off');
               set(controls.dsge.aimfilebutton,'Visible','off');
               set(controls.dsge.modelnametext,'Visible','off');
               set(controls.dsge.modelnameaxes,'Visible','off');
               set(controls.dsge.modelname,'Visible','off');
               set(controls.dsge.modelnamebutton,'Visible','off');
               set(controls.dsge.modelsolvertext,'Visible','off');
               set(controls.dsge.modelsolver,'Visible','off');
               %
               set(controls.dsge.posteriorsamplingbox,'Visible','off');
               set(controls.dsge.marginallikelihoodtext,'Visible','off');
               set(controls.dsge.marginallikelihood,'Visible','off');
               set(controls.dsge.sequantialmltext,'Visible','off');
               set(controls.dsge.sequentialstart,'Visible','off');
               set(controls.dsge.sequentialstep,'Visible','off');
               set(controls.dsge.coverageprobtext,'Visible','off');
               set(controls.dsge.coveragestart,'Visible','off');
               set(controls.dsge.coverageincrement,'Visible','off');
               set(controls.dsge.coverageend,'Visible','off');
               set(controls.dsge.sequentialml,'Visible','off');
               set(controls.dsge.overwritedraws,'Visible','off');
               set(controls.dsge.progressbox,'Visible','off');
               set(controls.dsge.progress,'Visible','off');
               set(controls.dsge.progressclock,'Visible','off');
               set(controls.dsge.kalmanbox,'Visible','off');
               set(controls.dsge.doublingalgorithmtext,'Visible','off');
               set(controls.dsge.doublingalgorithm,'Visible','off');
               set(controls.dsge.doublingtolerancetext,'Visible','off');
               set(controls.dsge.doublingtolerance,'Visible','off');
               set(controls.dsge.statecovariancetext,'Visible','off');
               set(controls.dsge.statecovariance,'Visible','off');
               set(controls.dsge.initializekalmantext,'Visible','off');
               set(controls.dsge.initializekalman,'Visible','off');
               set(controls.dsge.kalmanalgorithmtext,'Visible','off');
               set(controls.dsge.kalmanalgorithm,'Visible','off');
               set(controls.dsge.aimtolerancetext,'Visible','off');
               set(controls.dsge.aimtolerance,'Visible','off');
               set(controls.dsge.usedoublingalgorithmtext,'Visible','off');
               set(controls.dsge.usedoublingalgorithm,'Visible','off');
               set(controls.dsge.useowninitialstate,'Visible','off');
               set(controls.dsge.allowunitroot,'Visible','off');
               set(controls.dsge.sampleselect,'Visible','off');
               set(controls.dsge.subsample,'Visible','off');
               set(controls.dsge.subbeginyear,'Visible','off');
               set(controls.dsge.subbeginperiod,'Visible','off');
               set(controls.dsge.subsampleseparator,'Visible','off');
               set(controls.dsge.subendyear,'Visible','off');
               set(controls.dsge.subendperiod,'Visible','off');
               %
               set(controls.posteriorsamplingbox,'Visible','off');
               set(controls.posterior.posteriorsamplertext,'Visible','off');
               set(controls.posterior.posteriorsampler,'Visible','off');
               set(controls.posterior.drawstext,'Visible','off');
               set(controls.posterior.draws,'Visible','off');
               set(controls.posterior.smcdrawstext,'Visible','off');
               set(controls.posterior.batchtext,'Visible','off');
               set(controls.posterior.batch,'Visible','off');
               set(controls.posterior.temperingstagestext,'Visible','off');
               set(controls.posterior.temperingstages,'Visible','off');
               set(controls.posterior.chainstext,'Visible','off');
               set(controls.posterior.chains,'Visible','off');
               set(controls.posterior.burnintext,'Visible','off');
               set(controls.posterior.burnin,'Visible','off');
               set(controls.posterior.temperinglambdatext,'Visible','off');
               set(controls.posterior.temperinglambda,'Visible','off');
               set(controls.posterior.invhessiantext,'Visible','off');
               set(controls.posterior.invhessian,'Visible','off');
               set(controls.posterior.numparamblockstext,'Visible','off');
               set(controls.posterior.numparamblocks,'Visible','off');
               set(controls.posterior.smcmhstepstext,'Visible','off');
               set(controls.posterior.smcmhsteps,'Visible','off');
               set(controls.posterior.maxcorrelationtext,'Visible','off');
               set(controls.posterior.maxcorrelation,'Visible','off');
               set(controls.posterior.mixeddistweighttext,'Visible','off');
               set(controls.posterior.mixeddistweight,'Visible','off');
               set(controls.posterior.initialscaletext,'Visible','off');
               set(controls.posterior.initialscale,'Visible','off');
               set(controls.posterior.smcinitialscaletext,'Visible','off');
               set(controls.posterior.smcinitialscale,'Visible','off');
               set(controls.posterior.scalefactortext,'Visible','off');
               set(controls.posterior.scalefactor,'Visible','off');
               set(controls.posterior.targetacceptanceratetext,'Visible','off');
               set(controls.posterior.targetacceptancerate,'Visible','off');
               set(controls.posterior.randomweighttext,'Visible','off');
               set(controls.posterior.randomweight,'Visible','off');
               set(controls.posterior.resamplingalgorithmtext,'Visible','off');
               set(controls.posterior.resamplingalgorithm,'Visible','off');
               set(controls.posterior.resamplingthresholdtext,'Visible','off');
               set(controls.posterior.resamplingthreshold,'Visible','off');
               set(controls.posterior.postdrawsusagetext,'Visible','off');
               set(controls.posterior.postdrawsusage,'Visible','off');
               set(controls.posterior.usepostdrawstext,'Visible','off');
               set(controls.posterior.usepostdraws,'Visible','off');
               set(controls.posterior.covtolerancetext,'Visible','off');
               set(controls.posterior.covtolerance,'Visible','off');
               set(controls.posterior.ismaxmixcomptext,'Visible','off');
               set(controls.posterior.ismaxmixcomp,'Visible','off');
               set(controls.posterior.isinitialdftext,'Visible','off');
               set(controls.posterior.isinitialdf,'Visible','off');
               set(controls.posterior.isweightsharetext,'Visible','off');
               set(controls.posterior.isweightshare,'Visible','off');
               set(controls.posterior.isaddedmixweighttext,'Visible','off');
               set(controls.posterior.isaddedmixweight,'Visible','off');
               set(controls.posterior.isaddeddftext,'Visible','off');
               set(controls.posterior.isaddeddf,'Visible','off');
               set(controls.optimizationbox,'Visible','off');
               set(controls.optimize.maxroutinetext,'Visible','off');
               set(controls.optimize.maxroutine,'Visible','off');
               set(controls.optimize.tolerancetext,'Visible','off');
               set(controls.optimize.tolerance,'Visible','off');
               set(controls.optimize.maximumiterationstext,'Visible','off');
               set(controls.optimize.maximumiterations,'Visible','off');
               set(controls.optimize.initcsminweltext,'Visible','off');
               set(controls.optimize.initcsminwel,'Visible','off');
               set(controls.optimize.csminwelextrarunstext,'Visible','off');
               set(controls.optimize.csminwelextraruns,'Visible','off');
               set(controls.optimize.gridwidth,'Visible','off');
               set(controls.optimize.widthnumberpointsgridtext,'Visible','off');
               set(controls.optimize.numbergridpoints,'Visible','off');
               %
               set(controls.steadystatebox,'Visible','off');
               set(controls.bvar.steadystatefiletext,'Visible','off');
               set(controls.bvar.steadystatefile,'Visible','off');
               set(controls.bvar.steadystatefilebutton,'Visible','off');
               set(controls.bvarpriorbox,'Visible','off');
               set(controls.bvar.priorlevelmeantext,'Visible','off');
               set(controls.bvar.priorlevelmean,'Visible','off');
               set(controls.bvar.priordiffmeantext,'Visible','off');
               set(controls.bvar.priordiffmean,'Visible','off');
               set(controls.bvar.priortypetext,'Visible','off');
               set(controls.bvar.priortype,'Visible','off');
               set(controls.bvar.overalltightnesstext,'Visible','off');
               set(controls.bvar.overalltightness,'Visible','off');
               set(controls.bvar.crosseqtightnesstext,'Visible','off');
               set(controls.bvar.crosseqtightness,'Visible','off');
               set(controls.bvar.harmoniclagdecaytext,'Visible','off');
               set(controls.bvar.harmoniclagdecay,'Visible','off');
               set(controls.omegapriorbox,'Visible','off');
               set(controls.bvar.omegapriortypetext,'Visible','off');
               set(controls.bvar.omegapriortype,'Visible','off');
               set(controls.bvar.wisharttypetext,'Visible','off');
               set(controls.bvar.wisharttype,'Visible','off');
               set(controls.bvar.variancetightnesstext,'Visible','off');
               set(controls.bvar.variancetightness,'Visible','off');
               set(controls.bvar.wishartdftext,'Visible','off');
               set(controls.bvar.wishartdf,'Visible','off');
               set(controls.bvarlagbox,'Visible','off');
               set(controls.bvar.lagtext,'Visible','off');
               set(controls.bvar.lag,'Visible','off');
               set(controls.bvar.stationaryvar,'Visible','off');
               %
               set(controls.outputselect,'Visible','off');
               set(controls.outputdirtext,'Visible','off');
               set(controls.outputdir,'Visible','off');
               set(controls.outputbutton,'Visible','off');
               set(controls.showestimationlog,'Visible','off');
               set(controls.estimationlog,'Visible','off');
               set(controls.clearlogwindow,'Visible','off');
               set(controls.estimation_log,'Visible','off');
               %
               set(controls.forecastbox,'Visible','on');
               set(controls.forecast.maxhorizontext,'Visible','on');
               set(controls.forecast.maxhorizon,'Visible','on');
%               set(controls.forecast.freqreesttext,'Visible','on');
%               set(controls.forecast.freqreest,'Visible','on');
               set(controls.forecast.predpathstext,'Visible','on');
               set(controls.forecast.predpaths,'Visible','on');
               set(controls.forecast.shockcontroltext,'Visible','on');
               set(controls.forecast.shockcontrol,'Visible','on');
               set(controls.forecast.adjustpredictionpaths,'Visible','on');
               set(controls.forecast.ksiuseconddata,'Visible','on');
               set(controls.toolsbox,'Visible','on');
               set(controls.tools.riccatiiterationtext,'Visible','on');
               set(controls.tools.riccatiiteration,'Visible','on');
               set(controls.tools.riccatitolerancetext,'Visible','on');
               set(controls.tools.riccatitolerance,'Visible','on');
               set(controls.tools.irhorizontext,'Visible','on');
               set(controls.tools.irhorizon,'Visible','on');
               set(controls.optimize.steplengthtext,'Visible','on');
               set(controls.optimize.steplength,'Visible','on');
               set(controls.tools.confidencemethodtext,'Visible','on');
               set(controls.tools.confidencemethod,'Visible','on');
               set(controls.tools.randomnumber,'Visible','on');
               set(controls.tools.randomizedraws,'Visible','on');
               set(controls.optimize.finitediffhessian,'Visible','on');
               set(controls.optimize.checkoptimum,'Visible','on');
               set(controls.optimize.checktransformed,'Visible','on');
               set(controls.optimize.modifiedhessian,'Visible','on');
               set(controls.kerneldensitybox,'Visible','on');
               set(controls.graphics.posteriorkerneltext,'Visible','on');
               set(controls.graphics.posteriorkernel,'Visible','on');
               set(controls.graphics.kerneldensitytext,'Visible','on');
               set(controls.graphics.kerneldensity,'Visible','on');
               set(controls.graphics.priorkernel,'Visible','on');
            elseif newtab==5;
               %
               % VAR tab
               %
               set(controls.frame3tab1,'Visible','on');
               set(controls.frame3tab2,'Visible','on');
               set(controls.frame3tab3,'Visible','on');
               set(controls.frame3tab4,'Visible','on');
               set(controls.frame3tab5,'Visible','off');
               set(controls.frame3tab6,'Visible','on');
               set(controls.frame1tab2,'Position',[118 594 102 11]);
               set(controls.frame1tab3,'Position',[221 594 102 11]);
               set(controls.frame1tab4,'Position',[324 594 102 11]);
               set(controls.frame1tab5,'Position',[426 594 104 11]);
               set(controls.frame1tab6,'Position',[530 594 102 11]);
               set(controls.tab1,'Position',[15 602 102 23]);
               set(controls.tab2,'Position',[118 602 102 23]);
               set(controls.tab3,'Position',[221 602 102 23]);
               set(controls.tab4,'Position',[324 602 102 23]);
               set(controls.tab5,'Position',[426 602 104 25]);
               set(controls.tab6,'Position',[530 602 102 23]);
               %
               set(controls.dsge.obsfilesbox,'Visible','off');
               set(controls.dsge.priorfilesbox,'Visible','off');
               set(controls.dsge.parameterfilesbox,'Visible','off');
               set(controls.dsge.aimfilesbox,'Visible','off');
               set(controls.dsge.datafiletext,'Visible','off');
               set(controls.dsge.datafile,'Visible','off');
               set(controls.dsge.datafilebutton,'Visible','off');
               set(controls.dsge.priorfiletext,'Visible','off');
               set(controls.dsge.priorfile,'Visible','off');
               set(controls.dsge.priorfilebutton,'Visible','off');
               set(controls.dsge.priorfilesheet,'Visible','off');
               set(controls.dsge.systempriorfiletext,'Visible','off');
               set(controls.dsge.systempriorfile,'Visible','off');
               set(controls.dsge.systempriorfilebutton,'Visible','off');
               set(controls.dsge.updateparameterfiletext,'Visible','off');
               set(controls.dsge.updateparameterfile,'Visible','off');
               set(controls.dsge.updateparameterfilebutton,'Visible','off');
               set(controls.dsge.initialparameterfiletext,'Visible','off');
               set(controls.dsge.initialparameterfile,'Visible','off');
               set(controls.dsge.initialparameterfilebutton,'Visible','off');
               set(controls.dsge.runinitialfirst,'Visible','off');
               set(controls.dsge.measurefiletext,'Visible','off');
               set(controls.dsge.measurefile,'Visible','off');
               set(controls.dsge.measurefilebutton,'Visible','off');
               set(controls.dsge.aimfiletext,'Visible','off');
               set(controls.dsge.aimfile,'Visible','off');
               set(controls.dsge.aimfilebutton,'Visible','off');
               set(controls.dsge.modelnametext,'Visible','off');
               set(controls.dsge.modelnameaxes,'Visible','off');
               set(controls.dsge.modelname,'Visible','off');
               set(controls.dsge.modelnamebutton,'Visible','off');
               set(controls.dsge.modelsolvertext,'Visible','off');
               set(controls.dsge.modelsolver,'Visible','off');
               %
               set(controls.dsge.posteriorsamplingbox,'Visible','off');
               set(controls.dsge.marginallikelihoodtext,'Visible','off');
               set(controls.dsge.marginallikelihood,'Visible','off');
               set(controls.dsge.sequantialmltext,'Visible','off');
               set(controls.dsge.sequentialstart,'Visible','off');
               set(controls.dsge.sequentialstep,'Visible','off');
               set(controls.dsge.coverageprobtext,'Visible','off');
               set(controls.dsge.coveragestart,'Visible','off');
               set(controls.dsge.coverageincrement,'Visible','off');
               set(controls.dsge.coverageend,'Visible','off');
               set(controls.dsge.sequentialml,'Visible','off');
               set(controls.dsge.overwritedraws,'Visible','off');
               set(controls.dsge.progressbox,'Visible','off');
               set(controls.dsge.progress,'Visible','off');
               set(controls.dsge.progressclock,'Visible','off');
               set(controls.dsge.kalmanbox,'Visible','off');
               set(controls.dsge.doublingalgorithmtext,'Visible','off');
               set(controls.dsge.doublingalgorithm,'Visible','off');
               set(controls.dsge.doublingtolerancetext,'Visible','off');
               set(controls.dsge.doublingtolerance,'Visible','off');
               set(controls.dsge.statecovariancetext,'Visible','off');
               set(controls.dsge.statecovariance,'Visible','off');
               set(controls.dsge.initializekalmantext,'Visible','off');
               set(controls.dsge.initializekalman,'Visible','off');
               set(controls.dsge.kalmanalgorithmtext,'Visible','off');
               set(controls.dsge.kalmanalgorithm,'Visible','off');
               set(controls.dsge.aimtolerancetext,'Visible','off');
               set(controls.dsge.aimtolerance,'Visible','off');
               set(controls.dsge.usedoublingalgorithmtext,'Visible','off');
               set(controls.dsge.usedoublingalgorithm,'Visible','off');
               set(controls.dsge.useowninitialstate,'Visible','off');
               set(controls.dsge.allowunitroot,'Visible','off');
               set(controls.dsge.sampleselect,'Visible','off');
               set(controls.dsge.subsample,'Visible','off');
               set(controls.dsge.subbeginyear,'Visible','off');
               set(controls.dsge.subbeginperiod,'Visible','off');
               set(controls.dsge.subsampleseparator,'Visible','off');
               set(controls.dsge.subendyear,'Visible','off');
               set(controls.dsge.subendperiod,'Visible','off');
               %
               set(controls.posteriorsamplingbox,'Visible','off');
               set(controls.posterior.posteriorsamplertext,'Visible','off');
               set(controls.posterior.posteriorsampler,'Visible','off');
               set(controls.posterior.drawstext,'Visible','off');
               set(controls.posterior.draws,'Visible','off');
               set(controls.posterior.smcdrawstext,'Visible','off');
               set(controls.posterior.batchtext,'Visible','off');
               set(controls.posterior.batch,'Visible','off');
               set(controls.posterior.temperingstagestext,'Visible','off');
               set(controls.posterior.temperingstages,'Visible','off');
               set(controls.posterior.chainstext,'Visible','off');
               set(controls.posterior.chains,'Visible','off');
               set(controls.posterior.burnintext,'Visible','off');
               set(controls.posterior.burnin,'Visible','off');
               set(controls.posterior.temperinglambdatext,'Visible','off');
               set(controls.posterior.temperinglambda,'Visible','off');
               set(controls.posterior.invhessiantext,'Visible','off');
               set(controls.posterior.invhessian,'Visible','off');
               set(controls.posterior.numparamblockstext,'Visible','off');
               set(controls.posterior.numparamblocks,'Visible','off');
               set(controls.posterior.smcmhstepstext,'Visible','off');
               set(controls.posterior.smcmhsteps,'Visible','off');
               set(controls.posterior.maxcorrelationtext,'Visible','off');
               set(controls.posterior.maxcorrelation,'Visible','off');
               set(controls.posterior.mixeddistweighttext,'Visible','off');
               set(controls.posterior.mixeddistweight,'Visible','off');
               set(controls.posterior.initialscaletext,'Visible','off');
               set(controls.posterior.initialscale,'Visible','off');
               set(controls.posterior.smcinitialscaletext,'Visible','off');
               set(controls.posterior.smcinitialscale,'Visible','off');
               set(controls.posterior.scalefactortext,'Visible','off');
               set(controls.posterior.scalefactor,'Visible','off');
               set(controls.posterior.targetacceptanceratetext,'Visible','off');
               set(controls.posterior.targetacceptancerate,'Visible','off');
               set(controls.posterior.randomweighttext,'Visible','off');
               set(controls.posterior.randomweight,'Visible','off');
               set(controls.posterior.resamplingalgorithmtext,'Visible','off');
               set(controls.posterior.resamplingalgorithm,'Visible','off');
               set(controls.posterior.resamplingthresholdtext,'Visible','off');
               set(controls.posterior.resamplingthreshold,'Visible','off');
               set(controls.posterior.postdrawsusagetext,'Visible','off');
               set(controls.posterior.postdrawsusage,'Visible','off');
               set(controls.posterior.usepostdrawstext,'Visible','off');
               set(controls.posterior.usepostdraws,'Visible','off');
               set(controls.posterior.covtolerancetext,'Visible','off');
               set(controls.posterior.covtolerance,'Visible','off');
               set(controls.posterior.ismaxmixcomptext,'Visible','off');
               set(controls.posterior.ismaxmixcomp,'Visible','off');
               set(controls.posterior.isinitialdftext,'Visible','off');
               set(controls.posterior.isinitialdf,'Visible','off');
               set(controls.posterior.isweightsharetext,'Visible','off');
               set(controls.posterior.isweightshare,'Visible','off');
               set(controls.posterior.isaddedmixweighttext,'Visible','off');
               set(controls.posterior.isaddedmixweight,'Visible','off');
               set(controls.posterior.isaddeddftext,'Visible','off');
               set(controls.posterior.isaddeddf,'Visible','off');
               set(controls.forecastbox,'Visible','off');
               set(controls.forecast.maxhorizontext,'Visible','off');
               set(controls.forecast.maxhorizon,'Visible','off');
%               set(controls.forecast.freqreesttext,'Visible','off');
%               set(controls.forecast.freqreest,'Visible','off');
               set(controls.forecast.predpathstext,'Visible','off');
               set(controls.forecast.predpaths,'Visible','off');
               set(controls.forecast.shockcontroltext,'Visible','off');
               set(controls.forecast.shockcontrol,'Visible','off');
               set(controls.forecast.adjustpredictionpaths,'Visible','off');
               set(controls.forecast.ksiuseconddata,'Visible','off');
               set(controls.toolsbox,'Visible','off');
               set(controls.tools.riccatiiterationtext,'Visible','off');
               set(controls.tools.riccatiiteration,'Visible','off');
               set(controls.tools.riccatitolerancetext,'Visible','off');
               set(controls.tools.riccatitolerance,'Visible','off');
               set(controls.tools.irhorizontext,'Visible','off');
               set(controls.tools.irhorizon,'Visible','off');
               set(controls.tools.randomnumber,'Visible','off');
               set(controls.tools.randomizedraws,'Visible','off');
               set(controls.optimizationbox,'Visible','off');
               set(controls.optimize.maxroutinetext,'Visible','off');
               set(controls.optimize.maxroutine,'Visible','off');
               set(controls.optimize.tolerancetext,'Visible','off');
               set(controls.optimize.tolerance,'Visible','off');
               set(controls.optimize.maximumiterationstext,'Visible','off');
               set(controls.optimize.maximumiterations,'Visible','off');
               set(controls.optimize.initcsminweltext,'Visible','off');
               set(controls.optimize.initcsminwel,'Visible','off');
               set(controls.optimize.csminwelextrarunstext,'Visible','off');
               set(controls.optimize.csminwelextraruns,'Visible','off');
               set(controls.optimize.steplengthtext,'Visible','off');
               set(controls.optimize.steplength,'Visible','off');
               set(controls.tools.confidencemethodtext,'Visible','off');
               set(controls.tools.confidencemethod,'Visible','off');
               set(controls.optimize.gridwidth,'Visible','off');
               set(controls.optimize.widthnumberpointsgridtext,'Visible','off');
               set(controls.optimize.numbergridpoints,'Visible','off');
               set(controls.optimize.finitediffhessian,'Visible','off');
               set(controls.optimize.checkoptimum,'Visible','off');
               set(controls.optimize.checktransformed,'Visible','off');
               set(controls.optimize.modifiedhessian,'Visible','off');
               %
               set(controls.kerneldensitybox,'Visible','off');
               set(controls.graphics.posteriorkerneltext,'Visible','off');
               set(controls.graphics.posteriorkernel,'Visible','off');
               set(controls.graphics.kerneldensitytext,'Visible','off');
               set(controls.graphics.kerneldensity,'Visible','off');
               set(controls.graphics.priorkernel,'Visible','off');
               %
               set(controls.outputselect,'Visible','off');
               set(controls.outputdirtext,'Visible','off');
               set(controls.outputdir,'Visible','off');
               set(controls.outputbutton,'Visible','off');
               set(controls.showestimationlog,'Visible','off');
               set(controls.estimationlog,'Visible','off');
               set(controls.clearlogwindow,'Visible','off');
               set(controls.estimation_log,'Visible','off');
               %
               set(controls.steadystatebox,'Visible','on');
               set(controls.bvar.steadystatefiletext,'Visible','on');
               set(controls.bvar.steadystatefile,'Visible','on');
               set(controls.bvar.steadystatefilebutton,'Visible','on');
               set(controls.bvarpriorbox,'Visible','on');
               set(controls.bvar.priorlevelmeantext,'Visible','on');
               set(controls.bvar.priorlevelmean,'Visible','on');
               set(controls.bvar.priordiffmeantext,'Visible','on');
               set(controls.bvar.priordiffmean,'Visible','on');
               set(controls.bvar.priortypetext,'Visible','on');
               set(controls.bvar.priortype,'Visible','on');
               set(controls.bvar.overalltightnesstext,'Visible','on');
               set(controls.bvar.overalltightness,'Visible','on');
               set(controls.bvar.crosseqtightnesstext,'Visible','on');
               set(controls.bvar.crosseqtightness,'Visible','on');
               set(controls.bvar.harmoniclagdecaytext,'Visible','on');
               set(controls.bvar.harmoniclagdecay,'Visible','on');
               set(controls.omegapriorbox,'Visible','on');
               set(controls.bvar.omegapriortypetext,'Visible','on');
               set(controls.bvar.omegapriortype,'Visible','on');
               set(controls.bvar.wisharttypetext,'Visible','on');
               set(controls.bvar.wisharttype,'Visible','on');
               set(controls.bvar.variancetightnesstext,'Visible','on');
               set(controls.bvar.variancetightness,'Visible','on');
               set(controls.bvar.wishartdftext,'Visible','on');
               set(controls.bvar.wishartdf,'Visible','on');
               set(controls.bvarlagbox,'Visible','on');
               set(controls.bvar.lagtext,'Visible','on');
               set(controls.bvar.lag,'Visible','on');
               set(controls.bvar.stationaryvar,'Visible','on');
            elseif newtab==6;
               %
               % Output tab
               %
               set(controls.frame3tab1,'Visible','on');
               set(controls.frame3tab2,'Visible','on');
               set(controls.frame3tab3,'Visible','on');
               set(controls.frame3tab4,'Visible','on');
               set(controls.frame3tab5,'Visible','on');
               set(controls.frame3tab6,'Visible','off');
               set(controls.frame1tab2,'Position',[118 594 102 11]);
               set(controls.frame1tab3,'Position',[221 594 102 11]);
               set(controls.frame1tab4,'Position',[324 594 102 11]);
               set(controls.frame1tab5,'Position',[427 594 102 11]);
               set(controls.frame1tab6,'Position',[529 594 104 11]);
               set(controls.tab1,'Position',[15 602 102 23]);
               set(controls.tab2,'Position',[118 602 102 23]);
               set(controls.tab3,'Position',[221 602 102 23]);
               set(controls.tab4,'Position',[324 602 102 23]);
               set(controls.tab5,'Position',[427 602 102 23]);
               set(controls.tab6,'Position',[529 602 104 25]);
               %
               set(controls.dsge.obsfilesbox,'Visible','off');
               set(controls.dsge.priorfilesbox,'Visible','off');
               set(controls.dsge.parameterfilesbox,'Visible','off');
               set(controls.dsge.aimfilesbox,'Visible','off');
               set(controls.dsge.datafiletext,'Visible','off');
               set(controls.dsge.datafile,'Visible','off');
               set(controls.dsge.datafilebutton,'Visible','off');
               set(controls.dsge.priorfiletext,'Visible','off');
               set(controls.dsge.priorfile,'Visible','off');
               set(controls.dsge.priorfilebutton,'Visible','off');
               set(controls.dsge.priorfilesheet,'Visible','off');
               set(controls.dsge.systempriorfiletext,'Visible','off');
               set(controls.dsge.systempriorfile,'Visible','off');
               set(controls.dsge.systempriorfilebutton,'Visible','off');
               set(controls.dsge.updateparameterfiletext,'Visible','off');
               set(controls.dsge.updateparameterfile,'Visible','off');
               set(controls.dsge.updateparameterfilebutton,'Visible','off');
               set(controls.dsge.initialparameterfiletext,'Visible','off');
               set(controls.dsge.initialparameterfile,'Visible','off');
               set(controls.dsge.initialparameterfilebutton,'Visible','off');
               set(controls.dsge.runinitialfirst,'Visible','off');
               set(controls.dsge.measurefiletext,'Visible','off');
               set(controls.dsge.measurefile,'Visible','off');
               set(controls.dsge.measurefilebutton,'Visible','off');
               set(controls.dsge.aimfiletext,'Visible','off');
               set(controls.dsge.aimfile,'Visible','off');
               set(controls.dsge.aimfilebutton,'Visible','off');
               set(controls.dsge.modelnametext,'Visible','off');
               set(controls.dsge.modelnameaxes,'Visible','off');
               set(controls.dsge.modelname,'Visible','off');
               set(controls.dsge.modelnamebutton,'Visible','off');
               set(controls.dsge.modelsolvertext,'Visible','off');
               set(controls.dsge.modelsolver,'Visible','off');
               %
               set(controls.dsge.posteriorsamplingbox,'Visible','off');
               set(controls.dsge.marginallikelihoodtext,'Visible','off');
               set(controls.dsge.marginallikelihood,'Visible','off');
               set(controls.dsge.sequantialmltext,'Visible','off');
               set(controls.dsge.sequentialstart,'Visible','off');
               set(controls.dsge.sequentialstep,'Visible','off');
               set(controls.dsge.coverageprobtext,'Visible','off');
               set(controls.dsge.coveragestart,'Visible','off');
               set(controls.dsge.coverageincrement,'Visible','off');
               set(controls.dsge.coverageend,'Visible','off');
               set(controls.dsge.sequentialml,'Visible','off');
               set(controls.dsge.overwritedraws,'Visible','off');
               set(controls.dsge.progressbox,'Visible','off');
               set(controls.dsge.progress,'Visible','off');
               set(controls.dsge.progressclock,'Visible','off');
               set(controls.dsge.kalmanbox,'Visible','off');
               set(controls.dsge.doublingalgorithmtext,'Visible','off');
               set(controls.dsge.doublingalgorithm,'Visible','off');
               set(controls.dsge.doublingtolerancetext,'Visible','off');
               set(controls.dsge.doublingtolerance,'Visible','off');
               set(controls.dsge.statecovariancetext,'Visible','off');
               set(controls.dsge.statecovariance,'Visible','off');
               set(controls.dsge.initializekalmantext,'Visible','off');
               set(controls.dsge.initializekalman,'Visible','off');
               set(controls.dsge.kalmanalgorithmtext,'Visible','off');
               set(controls.dsge.kalmanalgorithm,'Visible','off');
               set(controls.dsge.aimtolerancetext,'Visible','off');
               set(controls.dsge.aimtolerance,'Visible','off');
               set(controls.dsge.usedoublingalgorithmtext,'Visible','off');
               set(controls.dsge.usedoublingalgorithm,'Visible','off');
               set(controls.dsge.useowninitialstate,'Visible','off');
               set(controls.dsge.allowunitroot,'Visible','off');
               set(controls.dsge.sampleselect,'Visible','off');
               set(controls.dsge.subsample,'Visible','off');
               set(controls.dsge.subbeginyear,'Visible','off');
               set(controls.dsge.subbeginperiod,'Visible','off');
               set(controls.dsge.subsampleseparator,'Visible','off');
               set(controls.dsge.subendyear,'Visible','off');
               set(controls.dsge.subendperiod,'Visible','off');
               %
               set(controls.posteriorsamplingbox,'Visible','off');
               set(controls.posterior.posteriorsamplertext,'Visible','off');
               set(controls.posterior.posteriorsampler,'Visible','off');
               set(controls.posterior.drawstext,'Visible','off');
               set(controls.posterior.draws,'Visible','off');
               set(controls.posterior.smcdrawstext,'Visible','off');
               set(controls.posterior.batchtext,'Visible','off');
               set(controls.posterior.batch,'Visible','off');
               set(controls.posterior.temperingstagestext,'Visible','off');
               set(controls.posterior.temperingstages,'Visible','off');
               set(controls.posterior.chainstext,'Visible','off');
               set(controls.posterior.chains,'Visible','off');
               set(controls.posterior.burnintext,'Visible','off');
               set(controls.posterior.burnin,'Visible','off');
               set(controls.posterior.temperinglambdatext,'Visible','off');
               set(controls.posterior.temperinglambda,'Visible','off');
               set(controls.posterior.invhessiantext,'Visible','off');
               set(controls.posterior.invhessian,'Visible','off');
               set(controls.posterior.numparamblockstext,'Visible','off');
               set(controls.posterior.numparamblocks,'Visible','off');
               set(controls.posterior.smcmhstepstext,'Visible','off');
               set(controls.posterior.smcmhsteps,'Visible','off');
               set(controls.posterior.maxcorrelationtext,'Visible','off');
               set(controls.posterior.maxcorrelation,'Visible','off');
               set(controls.posterior.mixeddistweighttext,'Visible','off');
               set(controls.posterior.mixeddistweight,'Visible','off');
               set(controls.posterior.initialscaletext,'Visible','off');
               set(controls.posterior.initialscale,'Visible','off');
               set(controls.posterior.smcinitialscaletext,'Visible','off');
               set(controls.posterior.smcinitialscale,'Visible','off');
               set(controls.posterior.scalefactortext,'Visible','off');
               set(controls.posterior.scalefactor,'Visible','off');
               set(controls.posterior.targetacceptanceratetext,'Visible','off');
               set(controls.posterior.targetacceptancerate,'Visible','off');
               set(controls.posterior.randomweighttext,'Visible','off');
               set(controls.posterior.randomweight,'Visible','off');
               set(controls.posterior.resamplingalgorithmtext,'Visible','off');
               set(controls.posterior.resamplingalgorithm,'Visible','off');
               set(controls.posterior.resamplingthresholdtext,'Visible','off');
               set(controls.posterior.resamplingthreshold,'Visible','off');
               set(controls.posterior.postdrawsusagetext,'Visible','off');
               set(controls.posterior.postdrawsusage,'Visible','off');
               set(controls.posterior.usepostdrawstext,'Visible','off');
               set(controls.posterior.usepostdraws,'Visible','off');
               set(controls.posterior.covtolerancetext,'Visible','off');
               set(controls.posterior.covtolerance,'Visible','off');
               set(controls.posterior.ismaxmixcomptext,'Visible','off');
               set(controls.posterior.ismaxmixcomp,'Visible','off');
               set(controls.posterior.isinitialdftext,'Visible','off');
               set(controls.posterior.isinitialdf,'Visible','off');
               set(controls.posterior.isweightsharetext,'Visible','off');
               set(controls.posterior.isweightshare,'Visible','off');
               set(controls.posterior.isaddedmixweighttext,'Visible','off');
               set(controls.posterior.isaddedmixweight,'Visible','off');
               set(controls.posterior.isaddeddftext,'Visible','off');
               set(controls.posterior.isaddeddf,'Visible','off');
               set(controls.forecastbox,'Visible','off');
               set(controls.forecast.maxhorizontext,'Visible','off');
               set(controls.forecast.maxhorizon,'Visible','off');
%               set(controls.forecast.freqreesttext,'Visible','off');
%               set(controls.forecast.freqreest,'Visible','off');
               set(controls.forecast.predpathstext,'Visible','off');
               set(controls.forecast.predpaths,'Visible','off');
               set(controls.forecast.shockcontroltext,'Visible','off');
               set(controls.forecast.shockcontrol,'Visible','off');
               set(controls.forecast.adjustpredictionpaths,'Visible','off');
               set(controls.forecast.ksiuseconddata,'Visible','off');
               set(controls.toolsbox,'Visible','off');
               set(controls.tools.riccatiiterationtext,'Visible','off');
               set(controls.tools.riccatiiteration,'Visible','off');
               set(controls.tools.riccatitolerancetext,'Visible','off');
               set(controls.tools.riccatitolerance,'Visible','off');
               set(controls.tools.irhorizontext,'Visible','off');
               set(controls.tools.irhorizon,'Visible','off');
               set(controls.tools.randomnumber,'Visible','off');
               set(controls.tools.randomizedraws,'Visible','off');
               set(controls.optimizationbox,'Visible','off');
               set(controls.optimize.maxroutinetext,'Visible','off');
               set(controls.optimize.maxroutine,'Visible','off');
               set(controls.optimize.tolerancetext,'Visible','off');
               set(controls.optimize.tolerance,'Visible','off');
               set(controls.optimize.maximumiterationstext,'Visible','off');
               set(controls.optimize.maximumiterations,'Visible','off');
               set(controls.optimize.initcsminweltext,'Visible','off');
               set(controls.optimize.initcsminwel,'Visible','off');
               set(controls.optimize.csminwelextrarunstext,'Visible','off');
               set(controls.optimize.csminwelextraruns,'Visible','off');
               set(controls.optimize.steplengthtext,'Visible','off');
               set(controls.optimize.steplength,'Visible','off');
               set(controls.tools.confidencemethodtext,'Visible','off');
               set(controls.tools.confidencemethod,'Visible','off');
               set(controls.optimize.gridwidth,'Visible','off');
               set(controls.optimize.widthnumberpointsgridtext,'Visible','off');
               set(controls.optimize.numbergridpoints,'Visible','off');
               set(controls.optimize.finitediffhessian,'Visible','off');
               set(controls.optimize.checkoptimum,'Visible','off');
               set(controls.optimize.checktransformed,'Visible','off');
               set(controls.optimize.modifiedhessian,'Visible','off');
               %
               set(controls.kerneldensitybox,'Visible','off');
               set(controls.graphics.posteriorkerneltext,'Visible','off');
               set(controls.graphics.posteriorkernel,'Visible','off');
               set(controls.graphics.kerneldensitytext,'Visible','off');
               set(controls.graphics.kerneldensity,'Visible','off');
               set(controls.graphics.priorkernel,'Visible','off');
               %
               set(controls.steadystatebox,'Visible','off');
               set(controls.bvar.steadystatefiletext,'Visible','off');
               set(controls.bvar.steadystatefile,'Visible','off');
               set(controls.bvar.steadystatefilebutton,'Visible','off');
               set(controls.bvarpriorbox,'Visible','off');
               set(controls.bvar.priorlevelmeantext,'Visible','off');
               set(controls.bvar.priorlevelmean,'Visible','off');
               set(controls.bvar.priordiffmeantext,'Visible','off');
               set(controls.bvar.priordiffmean,'Visible','off');
               set(controls.bvar.priortypetext,'Visible','off');
               set(controls.bvar.priortype,'Visible','off');
               set(controls.bvar.overalltightnesstext,'Visible','off');
               set(controls.bvar.overalltightness,'Visible','off');
               set(controls.bvar.crosseqtightnesstext,'Visible','off');
               set(controls.bvar.crosseqtightness,'Visible','off');
               set(controls.bvar.harmoniclagdecaytext,'Visible','off');
               set(controls.bvar.harmoniclagdecay,'Visible','off');
               set(controls.omegapriorbox,'Visible','off');
               set(controls.bvar.omegapriortypetext,'Visible','off');
               set(controls.bvar.omegapriortype,'Visible','off');
               set(controls.bvar.wisharttypetext,'Visible','off');
               set(controls.bvar.wisharttype,'Visible','off');
               set(controls.bvar.variancetightnesstext,'Visible','off');
               set(controls.bvar.variancetightness,'Visible','off');
               set(controls.bvar.wishartdftext,'Visible','off');
               set(controls.bvar.wishartdf,'Visible','off');
               set(controls.bvarlagbox,'Visible','off');
               set(controls.bvar.lagtext,'Visible','off');
               set(controls.bvar.lag,'Visible','off');
               set(controls.bvar.stationaryvar,'Visible','off');
               %
               set(controls.outputselect,'Visible','on');
               set(controls.outputdirtext,'Visible','on');
               set(controls.outputdir,'Visible','on');
               set(controls.outputbutton,'Visible','on');
               set(controls.showestimationlog,'Visible','on');
               set(controls.estimationlog,'Visible','on');
               set(controls.clearlogwindow,'Visible','on');
               set(controls.estimation_log,'Visible','on');
            end;
         end;
         set(controls.about,'UserData',0);
%      end;
   case 'editmodelname'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % make sure to disable all run controls
         %
         OldNameOfModel = DSGEModel.NameOfModel;
         AiMEnable = get(controls.runaim,'Enable');
         StateEnable = get(controls.statevar,'Enable');
         prior_enable = get(controls.priorinfo,'Enable');
         set(controls.runaim,'Enable','off');
         set(controls.runaimmenu,'Enable','off');
         set(controls.aimmodelinfo,'Enable','off');
         set(controls.priorinfo,'Enable','off');
         set(controls.statevar,'Enable','off');
         set(controls.statevarmenu,'Enable','off');
         set(controls.stateeq,'Enable','off');
         set(controls.stateeqmenu,'Enable','off');
         set(controls.stateshock,'Enable','off');
         set(controls.stateshockmenu,'Enable','off');
         %
         % set editing on
         %
         set(controls.dsge.modelname,'Editing','on');
         waitfor(controls.dsge.modelname,'editing','off');
         new_name = RemoveIllegalChars(StringTrim(get(controls.dsge.modelname,'String')));
         %
         % check if name has changed
         %
         if (isempty(OldNameOfModel)==0)&(strcmp(lower(OldNameOfModel),lower(new_name))==0);
            txt = strvcat(['Are you sure you want to change the model name from "' OldNameOfModel '" to "' new_name '"?'],' ','NOTE: You will loose the link to estimation results obtained under the old model name when you change it to a new name. The reason is that many file names depend on the model name.');
            answer = Query(txt,'question',200,'Change Model Name',500,'no',CurrINI);
         else;
            answer = 'Yes';
         end;
         if strcmp(lower(answer),'yes')==1;
            if (strcmp(new_name,'')==0)&(ischar(new_name)==1);
               DSGEModel.NameOfModel = new_name;
            elseif (strcmp(new_name,'')==1)|(isempty(new_name)==1);
               %
               % check if an AiM file exists
               %
               if FileExist(DSGEModel.AIMFile)==0;
                  DSGEModel.NameOfModel = '';
               end;
            end;
            set(controls.dsge.modelname,'String',DSGEModel.NameOfModel);
            if strcmp(DSGEModel.NameOfModel,'')==0;
               if FileExist(CurrINI.CurrentModelFile)==1;
                  set(maingui,'Name',['YADA - ' DSGEModel.NameOfModel ' - [' GetFilename(CurrINI.CurrentModelFile) ']']);
               else;
                  set(maingui,'Name',['YADA - ' DSGEModel.NameOfModel]);
               end;
            else;
               set(maingui,'Name','YADA');
            end;
            %
            % check if AiM has already been run for the new model name
            %
            AIMDataFile = FixFilePath([DSGEModel.OutputDirectory '\' DSGEModel.NameOfModel '.mat']);
            if FileExist(AIMDataFile)==1;
               DSGEModel.AIMDataFile = AIMDataFile;
               StateEnable = 'on';
            else;
               DSGEModel.AIMDataFile = pwd;
               StateEnable = 'off';
            end;
         else;
            set(controls.dsge.modelname,'String',DSGEModel.NameOfModel);
         end;
         %
         % make sure we enable all run controls that were diabled
         %
         set(controls.runaim,'Enable',AiMEnable);
         set(controls.runaimmenu,'Enable',AiMEnable);
         set(controls.aimmodelinfo,'Enable',AiMEnable);
         set(controls.priorinfo,'Enable',prior_enable);
         set(controls.statevar,'Enable',StateEnable);
         set(controls.statevarmenu,'Enable',StateEnable);
         set(controls.stateeq,'Enable',StateEnable);
         set(controls.stateeqmenu,'Enable',StateEnable);
         set(controls.stateshock,'Enable',StateEnable);
         set(controls.stateshockmenu,'Enable',StateEnable);
         %
         % check
         %
%         if FileExist(DSGEModel.AIMFile)==1;
%            %
%            % If the modelname has changed, then output directory will also change
%            %
%            if strcmp(lower(DSGEModel.NameOfModel),lower(OldNameOfModel))==0;
%               DSGEModel.OutputDirectory = [GetPath(DSGEModel.AIMFile) DSGEModel.NameOfModel];
%               if DirExist(DSGEModel.OutputDirectory)==0;
%                  stat = dos(['mkdir ' DSGEModel.OutputDirectory]);
%               end;
%               set(controls.outputdir,'String',DSGEModel.OutputDirectory);
%               set(controls.outputdirtext,'Enable','on');
%               set(controls.outputbutton,'Enable','on','CData',CurrINI.images.browse);
%               AIMDataFile = FixFilePath([DSGEModel.OutputDirectory '\' DSGEModel.NameOfModel '.mat']);
%               if FileExist(AIMDataFile)==1;
%                  DSGEModel.AIMDataFile = AIMDataFile;
%                  StateEnable = 'on';
%               else;
%                  DSGEModel.AIMDataFile = pwd;
%                  StateEnable = 'off';
%               end;
%            end;
%            set(controls.statevar,'Enable',StateEnable);
%            set(controls.statevarmenu,'Enable',StateEnable);
%            set(controls.stateshock,'Enable',StateEnable);
%            set(controls.stateshockmenu,'Enable',StateEnable);
%         else;
%            set(controls.runaim,'Enable','off');
%            set(controls.runaimmenu,'Enable','off');
%            set(controls.aimmodelinfo,'Enable','off');
%            if FileExist(DSGEModel.DataConstructionFile)==0;
%               DSGEModel.OutputDirectory = pwd;
%               set(controls.outputdirtext,'Enable','off');
%               set(controls.outputdir,'Enable','off','String',DSGEModel.OutputDirectory);
%               set(controls.outputbutton,'Enable','off','CData',CurrINI.images.browsedisable);
%            end;
%         end;
         set(controls.about,'UserData',0);
      end;
%   case 'reorderconditionalshocks'
%      if get(controls.about,'UserData')==0;
%         set(controls.about,'UserData',1);
%         %
%         % open the dialog for selecting shocks
%         %
%         [action,ConditionalShocks] = ReOrderShockDLG('init','Conditional',DSGEModel.ZVariableNames(DSGEModel.ConditionalVariables,:),DSGEModel.StateShockNames,DSGEModel.ConditionalShocks,CurrINI);
%         if strcmp(lower(action),'ok')==1;
%            DSGEModel.ConditionalShocks = ConditionalShocks;
%         end;
%         %
%         set(controls.about,'UserData',0);
%      end;
   case 'clearlogwindow'
      if get(controls.about,'Userdata')==0;
         set(controls.about,'UserData',1);
         drawnow;
         set(controls.estimation_log,'String','','ListboxTop',1,'UserData',1);
         drawnow;
         set(controls.about,'UserData',0);
      end;
   case 'browseaim'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % Open a file open dialog
         %
         OldAIMFile = DSGEModel.AIMFile;
         status = FileBrowse(DSGEModel.AIMFile,'Open AiM Model File',controls.dsge.aimfile,'aim',CurrINI);
         if status==1;
            DSGEModel.AIMFile = get(controls.dsge.aimfile,'String');
            DSGEModel.NameOfModel = RemoveIllegalChars(GetName(DSGEModel.AIMFile));
            %
            % Setup a new base output directory. Create it if necessary
            %
            if strcmp(lower(OldAIMFile),lower(DSGEModel.AIMFile))==0;
               DirStatus = MakeDir(GetPath(DSGEModel.AIMFile),DSGEModel.NameOfModel);
               if DirStatus==1;
                  DSGEModel.OutputDirectory = [GetPath(DSGEModel.AIMFile) DSGEModel.NameOfModel];
               end;
            end;
            %
            AIMDataFile = FixFilePath([DSGEModel.OutputDirectory '\' DSGEModel.NameOfModel '.mat']);
            if FileExist(AIMDataFile)==1;
               DSGEModel.AIMDataFile = AIMDataFile;
            else;
               DSGEModel.AIMDataFile = pwd;
            end;
            if FileExist(CurrINI.CurrentModelFile)==1;
               set(maingui,'Name',['YADA - ' DSGEModel.NameOfModel ' - [' GetFilename(CurrINI.CurrentModelFile) ']']);
            else;
               set(maingui,'Name',['YADA - ' DSGEModel.NameOfModel]);
            end;
            set(controls.dsge.modelname,'String',DSGEModel.NameOfModel);
            set(controls.runaim,'Enable','on');
            set(controls.runaimmenu,'Enable','on');
            set(controls.aimmodelinfo,'Enable','on');
            set(controls.outputdirtext,'Enable','on');
            set(controls.outputdir,'Enable','on','String',DSGEModel.OutputDirectory);
            set(controls.outputbutton,'Enable','on','CData',CurrINI.images.browse);
            if FileExist(DSGEModel.AIMDataFile)==1;
               set(controls.statevar,'Enable','on');
               set(controls.statevarmenu,'Enable','on');
               set(controls.stateeq,'Enable','on');
               set(controls.stateeqmenu,'Enable','on');
               set(controls.stateshock,'Enable','on');
               set(controls.stateshockmenu,'Enable','on');
            else;
               set(controls.statevar,'Enable','off');
               set(controls.statevarmenu,'Enable','off');
               set(controls.stateeq,'Enable','off');
               set(controls.stateeqmenu,'Enable','off');
               set(controls.stateshock,'Enable','off');
               set(controls.stateshockmenu,'Enable','off');
            end;
         end;
         set(controls.about,'UserData',0);
      end;
   case 'checkaimfile'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         OldAIMFile = DSGEModel.AIMFile;
         new_aim_file = StringTrim(get(controls.dsge.aimfile,'String'));
         if strcmp(new_aim_file,'')==0;
            if (FileExist(new_aim_file)==1)&((strcmp(lower(GetExt(new_aim_file)),'.txt')==1)|(strcmp(lower(GetExt(new_aim_file)),'.aim')==1));
               DSGEModel.AIMFile = new_aim_file;
               DSGEModel.NameOfModel = RemoveIllegalChars(GetName(DSGEModel.AIMFile));
               %
               % Setup a new base output directory. Create it if necessary
               %
               if strcmp(lower(OldAIMFile),lower(DSGEModel.AIMFile))==0;
                  DirStatus = MakeDir(GetPath(DSGEModel.AIMFile),DSGEModel.NameOfModel);
                  if DirStatus==1;
                     DSGEModel.OutputDirectory = [GetPath(DSGEModel.AIMFile) DSGEModel.NameOfModel];
                  end;
               end;
               %
               AIMDataFile = FixFilePath([DSGEModel.OutputDirectory '\' DSGEModel.NameOfModel '.mat']);
               if FileExist(AIMDataFile)==1;
                  DSGEModel.AIMDataFile = AIMDataFile;
                  set(controls.statevar,'Enable','on');
                  set(controls.statevarmenu,'Enable','on');
                  set(controls.stateeq,'Enable','on');
                  set(controls.stateeqmenu,'Enable','on');
                  set(controls.stateshock,'Enable','on');
                  set(controls.stateshockmenu,'Enable','on');
               else;
                  DSGEModel.AIMDataFile = pwd;
                  set(controls.statevar,'Enable','off');
                  set(controls.statevarmenu,'Enable','off');
                  set(controls.stateeq,'Enable','off');
                  set(controls.stateeqmenu,'Enable','off');
                  set(controls.stateshock,'Enable','off');
                  set(controls.stateshockmenu,'Enable','off');
               end;
               %
               if FileExist(CurrINI.CurrentModelFile)==1;
                  set(maingui,'Name',['YADA - ' DSGEModel.NameOfModel ' - [' GetFilename(CurrINI.CurrentModelFile) ']']);
               else;
                  set(maingui,'Name',['YADA - ' DSGEModel.NameOfModel]);
               end;
               set(controls.dsge.modelname,'String',DSGEModel.NameOfModel);
               set(controls.runaim,'Enable','on');
               set(controls.runaimmenu,'Enable','on');
               set(controls.aimmodelinfo,'Enable','on');
               set(controls.outputdirtext,'Enable','on');
               set(controls.outputdir,'Enable','on','String',DSGEModel.OutputDirectory);
               set(controls.outputbutton,'Enable','on','CData',CurrINI.images.browse);
            else;
               if (strcmp(new_aim_file,'')==1)|(isempty(new_aim_file)==1);
                  DSGEModel.AIMFile = pwd;
                  DSGEModel.AIMDataFile = pwd;
                  DSGEModel.NameOfModel = '';
                  DSGEModel.OutputDirectory = pwd;
               end;
               set(controls.dsge.aimfile,'String',DSGEModel.AIMFile);
               if strcmp(DSGEModel.NameOfModel,'')==0;
                  if FileExist(CurrINI.CurrentModelFile)==1;
                     set(maingui,'Name',['YADA - ' DSGEModel.NameOfModel ' - [' GetFilename(CurrINI.CurrentModelFile) ']']);
                  else;
                     set(maingui,'Name',['YADA - ' DSGEModel.NameOfModel]);
                  end;
               else;
                  set(maingui,'Name','YADA');
               end;
               set(controls.dsge.modelname,'String',DSGEModel.NameOfModel);
               if FileExist(DSGEModel.AIMFile)==1;
                  set(controls.runaim,'Enable','on');
                  set(controls.runaimmenu,'Enable','on');
                  set(controls.aimmodelinfo,'Enable','on');
                  set(controls.outputdirtext,'Enable','on');
                  set(controls.outputdir,'Enable','on','String',DSGEModel.OutputDirectory);
                  set(controls.outputbutton,'Enable','on','CData',CurrINI.images.browse);
               else;
                  set(controls.runaim,'Enable','off');
                  set(controls.runaimmenu,'Enable','off');
                  set(controls.aimmodelinfo,'Enable','off');
                  if FileExist(DSGEModel.DataConstructionFile)==0;
                     DSGEModel.OutputDirectory = pwd;
                     set(controls.outputdirtext,'Enable','off');
                     set(controls.outputdir,'Enable','off','String',DSGEModel.OutputDirectory);
                     set(controls.outputbutton,'Enable','off','CData',CurrINI.images.browsedisable);
                  end;
               end;
            end;
         else;
            if (strcmp(new_aim_file,'')==1)|(isempty(new_aim_file)==1);
               DSGEModel.AIMFile = pwd;
               DSGEModel.AIMDataFile = pwd;
               DSGEModel.NameOfModel = '';
               DSGEModel.OutputDirectory = pwd;
            end;
            set(controls.dsge.aimfile,'String',DSGEModel.AIMFile);
            if strcmp(DSGEModel.NameOfModel,'')==0;
               if FileExist(CurrINI.CurrentModelFile)==1;
                  set(maingui,'Name',['YADA - ' DSGEModel.NameOfModel ' - [' GetFilename(CurrINI.CurrentModelFile) ']']);
               else;
                  set(maingui,'Name',['YADA - ' DSGEModel.NameOfModel]);
               end;
            else;
               set(maingui,'Name','YADA');
            end;
            set(controls.dsge.modelname,'String',DSGEModel.NameOfModel);
            if FileExist(DSGEModel.AIMFile)==1;
               set(controls.runaim,'Enable','on');
               set(controls.runaimmenu,'Enable','on');
               set(controls.aimmodelinfo,'Enable','on');
               set(controls.outputdirtext,'Enable','on');
               set(controls.outputdir,'Enable','on','String',DSGEModel.OutputDirectory);
               set(controls.outputbutton,'Enable','on','CData',CurrINI.images.browse);
            else;
               set(controls.runaim,'Enable','off');
               set(controls.runaimmenu,'Enable','off');
               set(controls.aimmodelinfo,'Enable','off');
               if FileExist(DSGEModel.DataConstructionFile)==0;
                  DSGEModel.OutputDirectory = pwd;
                  set(controls.outputdirtext,'Enable','off');
                  set(controls.outputdir,'Enable','off','String',DSGEModel.OutputDirectory);
                  set(controls.outputbutton,'Enable','off','CData',CurrINI.images.browsedisable);
               end;
            end;
         end;
         set(controls.about,'UserData',0);
      end;
   case 'browsesteadystatefile'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % Open a file open dialog
         %
         status = FileBrowse(DSGEModel.SteadyStatePriorFile,'Open Steady State Prior File',controls.bvar.steadystatefile,'m',CurrINI);
         if status==1;
            DSGEModel.SteadyStatePriorFile = get(controls.bvar.steadystatefile,'String');
         end;
         set(controls.about,'UserData',0);
      end;
   case 'checksteadystatefile'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         new_me_file = StringTrim(get(controls.bvar.steadystatefile,'String'));
         if FileExist(new_me_file)==1;
            %
            % make sure that the file is an m-file
            %
            [FilePath,FileName,FileExt] = fileparts(new_me_file);
            if (strcmp(lower(FileExt),'.m')==1)|(strcmp(lower(FileExt),'.p')==1);
               DSGEModel.SteadyStatePriorFile = new_me_file;
               %
               % Enable any controls that may be affected by this
               %
            else;
               set(controls.bvar.steadystatefile,'String',DSGEModel.SteadyStatePriorFile);
            end;
         else;
            if (strcmp(new_me_file,'')==1)|(isempty(new_me_file)==1);
               DSGEModel.SteadyStatePriorFile = pwd;
            end;
            set(controls.bvar.steadystatefile,'String',DSGEModel.SteadyStatePriorFile);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'browsemeasurefile'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % Open a file open dialog
         %
         status = FileBrowse(DSGEModel.MeasurementEquationFile,'Open Measurement Equation File',controls.dsge.measurefile,'m',CurrINI);
         if status==1;
            DSGEModel.MeasurementEquationFile = get(controls.dsge.measurefile,'String');
         end;
         set(controls.about,'UserData',0);
      end;
   case 'checkmeasurefile'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         new_me_file = StringTrim(get(controls.dsge.measurefile,'String'));
         if FileExist(new_me_file)==1;
            %
            % make sure that the file is an m-file
            %
            [FilePath,FileName,FileExt] = fileparts(new_me_file);
            if (strcmp(lower(FileExt),'.m')==1)|(strcmp(lower(FileExt),'.p')==1);
               DSGEModel.MeasurementEquationFile = new_me_file;
            else;
               set(controls.dsge.measurefile,'String',DSGEModel.MeasurementEquationFile);
            end;
         else;
            if (strcmp(new_me_file,'')==1)|(isempty(new_me_file)==1);
               DSGEModel.MeasurementEquationFile = pwd;
            end;
            set(controls.dsge.measurefile,'String',DSGEModel.MeasurementEquationFile);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'browsedatafile'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % Open a file open dialog
         %
         status = FileBrowse(DSGEModel.DataConstructionFile,'Open Data Construction File',controls.dsge.datafile,'m',CurrINI);
         if status==1;
            file = StringTrim(get(controls.dsge.datafile,'String'));
            %
            % check if the path for file is equal to pwd, else copy to pwd and overwrite if necessary
            %
            [FilePath,FileName,FileExt] = fileparts(file);
            if strcmp(lower(FilePath),lower(FixFilePath([pwd '\tmp'])))==0;
               [stat,msg] = CopyFile(file,[pwd '\tmp']);
               file = FixFilePath([pwd '\tmp\' FileName FileExt]);
            end;
            %
            % check the file to see if we can retrieve the necessary information
            %
            if FileExist(file)==1;
               ErrorStr = '';
               if MatlabNumber>=8.0;
                  try;
                     DataStructure = feval(FileName);
                  catch ME;
                     ErrorStr = ['Error found in data construction file "' FileName '". The error message caught is: ' YADALastError(ME)];
                  end;
               else;
                  try;
                     DataStructure = feval(FileName);
                  catch;
                     ErrorStr = ['Error found in data construction file "' FileName '". The error message caught is: ' YADALastError];
                  end;
               end;
               if isempty(ErrorStr)==1;
                  %
                  % now we check if DataStructure is valid
                  %
                  [stat,YNaNs] = CheckObservedDataFile(DataStructure,controls.dsge.datafile,DSGEModel.DataConstructionFile,[FileName FileExt],CurrINI);
                  if stat>=1;
                     %
                     % error messages have already been reported by CheckObservedDataFile with stat = 0
                     %
                     % make the necessary changes to the DSGEModel structure
                     %
                     DSGEModel.DataConstructionFile = get(controls.dsge.datafile,'String');
                     DSGEModel.T = length(DataStructure.Y.data);
                     DSGEModel.n = length(DataStructure.Y.names);
                     if isempty(DataStructure.X.names)==0
                        DSGEModel.k = length(DataStructure.X.names)*(1-isempty(DataStructure.X.names{1,1}));
                     else;
                        DSGEModel.k = 0;
                     end;
                     DSGEModel.Y = DataStructure.Y.data;
                     DSGEModel.YNaNs = YNaNs;
                     if isfield(DataStructure.Y,'actuals')==1;
                        DSGEModel.Actuals = VerifyActualsData(DataStructure.Y.actuals,DSGEModel.n,DSGEModel.T);
                     else;
                        DSGEModel.Actuals = [];
                     end;
                     if isfield(DataStructure.Y,'comparisondata')==1;
                        DSGEModel.CompY = DataStructure.Y.comparisondata;
                     else;
                        DSGEModel.CompY = [];
                     end;
                     DSGEModel.DataFrequency = lower(DataStructure.frequency(1,1));
                     ForecastStr = get(controls.forecast.maxhorizon,'UserData');
                     if strcmp(lower(DSGEModel.DataFrequency),'q')==1;
                        set(controls.forecast.maxhorizon,'String',ForecastStr.quarter);
                     elseif strcmp(lower(DSGEModel.DataFrequency),'m')==1;
                        set(controls.forecast.maxhorizon,'String',ForecastStr.month);
                     else;
                        set(controls.forecast.maxhorizon,'String',ForecastStr.annual);
                     end;
                     if (isfield(DataStructure.Y,'BVAR')==1)&(length(DataStructure.Y.BVAR)<=DSGEModel.n);
                        DSGEModel.BVARY = VerifyVector(DataStructure.Y.BVAR,DSGEModel.n);
                     else;
                        DSGEModel.BVARY = (1:DSGEModel.n);
                     end;
                     if (isfield(DataStructure.X,'BVAR')==1)&(length(DataStructure.X.BVAR)<=DSGEModel.k);
                        DSGEModel.BVARX = VerifyVector(DataStructure.X.BVAR,DSGEModel.k);
                     else;
                        DSGEModel.BVARX = (1:DSGEModel.k);
                     end;
                     if isfield(DataStructure.Y,'policyrate')==1;
                        DSGEModel.ZLBPosition = VerifyVector(DataStructure.Y.policyrate,DSGEModel.n);
                        if IsInteger(DSGEModel.ZLBPosition)==0;
                           DSGEModel.ZLBPosition = [];
                        end;
                     else;
                        DSGEModel.ZLBPosition = [];
                     end;
                     if isfield(DataStructure.Y,'ZLBdata')==1;
                        DSGEModel.ZLBData = DataStructure.Y.ZLBdata(1,:)';
                     else;
                        DSGEModel.ZLBData = 0;
                     end;
                     if isfield(DataStructure.X,'extradata')==1;
                        %
                        % we need to test if this data is valid
                        %
                        if size(DataStructure.X.extradata,1)==DSGEModel.k;
                           DSGEModel.PredictedX = DataStructure.X.extradata;
                        else;
                           DSGEModel.PredictedX = [];
                        end;
                     else;
                        DSGEModel.PredictedX = [];
                     end;
                     if isfield(DataStructure,'percentiles')==1;
                        Ptiles = unique(DataStructure.percentiles);
                        %
                        % make sure that all entries are greater than 0, less than a 100, and integers
                        %
                        Ptiles = Ptiles(Ptiles>0);
                        Ptiles = Ptiles(Ptiles<100);
                        if length(Ptiles)>1;
                           if IsOdd(length(Ptiles))==1;
                              Pmiddle = Ptiles(ceil(length(Ptiles)/2));
                              Ptiles = Ptiles(Ptiles~=Pmiddle);
                           end;
                           DSGEModel.Percentiles = Ptiles;
                        else;
                           DSGEModel.Percentiles = [5 15 85 95];
                        end;
                     else;
                        DSGEModel.Percentiles = [5 15 85 95];
                     end;
                     if stat==1;
                        DSGEModel.levels = DataStructure.Y.levels;
                        if (isfield(DataStructure.Y,'annual')==1)&(length(DataStructure.Y.annual)==DSGEModel.n);
                           if strcmp(DSGEModel.DataFrequency,'q')==1;
                              SampleFreq = 4;
                           elseif strcmp(DSGEModel.DataFrequency,'m')==1;
                              SampleFreq = 12;
                           else;
                              SampleFreq = 1;
                           end;
                           DSGEModel.annual = ((DataStructure.Y.annual)*(SampleFreq-1))+ones(1,DSGEModel.n);
                        else;
                           DSGEModel.annual = ones(1,DSGEModel.n);
                        end;
                        if (isfield(DataStructure.Y,'annualscale')==1)&(length(DataStructure.Y.annualscale)==DSGEModel.n);
                           DSGEModel.annualscale = ReplaceData(DataStructure.Y.annualscale,0,1);
                        else;
                           DSGEModel.annualscale = ones(1,DSGEModel.n);
                        end;
                     elseif stat==2;
                        DSGEModel.levels = ones(1,DSGEModel.n);
                        DSGEModel.annual = ones(1,DSGEModel.n);
                        DSGEModel.annualscale = ones(1,DSGEModel.n);
                     end;
                     if size(DSGEModel.Y,1)>size(DSGEModel.Y,2);
                        DSGEModel.Y = DSGEModel.Y';
                     end;
                     if size(DSGEModel.CompY,1)>size(DSGEModel.CompY,2);
                        DSGEModel.CompY = DSGEModel.CompY';
                     end;
                     if size(DSGEModel.Y)~=size(DSGEModel.CompY);
                        DSGEModel.CompY = [];
                     end;
                     DSGEModel.X = DataStructure.X.data;
                     if size(DSGEModel.X,1)>size(DSGEModel.X,2);
                        DSGEModel.X = DSGEModel.X';
                     end;
                     DSGEModel.YData = DSGEModel.Y;
                     DSGEModel.YDataOriginal = DSGEModel.Y;
                     DSGEModel.BeginYear = num2str(floor(DataStructure.sample(1)));
                     DSGEModel.BeginPeriod = num2str(floor(DataStructure.sample(2)));
                     DSGEModel.EndYear = num2str(floor(DataStructure.sample(3)));
                     DSGEModel.EndPeriod = num2str(floor(DataStructure.sample(4)));
                     DSGEModel.SubBeginYear = num2str(floor(DataStructure.sample(1)));
                     DSGEModel.SubBeginPeriod = num2str(floor(DataStructure.sample(2)));
                     DSGEModel.SubEndYear = num2str(floor(DataStructure.sample(3)));
                     DSGEModel.SubEndPeriod = num2str(floor(DataStructure.sample(4)));
                     DSGEModel.VariableNames = '';
                     for i=1:DSGEModel.n;
                        DSGEModel.VariableNames = strvcat(DSGEModel.VariableNames,DataStructure.Y.names{i});
                     end;
                     DSGEModel.XVariableNames = '';
                     for i=1:DSGEModel.k;
                        DSGEModel.XVariableNames = strvcat(DSGEModel.XVariableNames,DataStructure.X.names{i});
                     end;
                     if isfield(DataStructure.Y,'transformation')==1;
                        if VerifyDataTransformation(DSGEModel.VariableNames,DataStructure.Y.transformation,0)==1;
                           DSGEModel.YTransformation = DataStructure.Y.transformation;
                           if isfield(DataStructure.Y,'TransMatrix')==1;
                              if (rank(DataStructure.Y.TransMatrix)==DSGEModel.n)&(size(DataStructure.Y.TransMatrix,1)==DSGEModel.n)&(size(DataStructure.Y.TransMatrix,2)==DSGEModel.n);
                                 DSGEModel.YTransMatrix = DataStructure.Y.TransMatrix;
                              else;
                                 DSGEModel.YTransMatrix = [];
                              end;
                           else;
                              DSGEModel.YTransMatrix = [];
                           end;
                        else;
                           DSGEModel.YTransformation = [];
                           DSGEModel.YTransMatrix = [];
                        end;
                     else;
                        DSGEModel.YTransformation = [];
                        DSGEModel.YTransMatrix = [];
                     end;
                     %
                     if isfield(DataStructure,'Lambda')==1;
                        DSGEModel.Lambda = DataStructure.Lambda;
                        if isempty(DSGEModel.Lambda)==0;
                           DSGEModel.Lambda = sort(DSGEModel.Lambda);
                           if isinf(DSGEModel.Lambda(length(DSGEModel.Lambda)))==0;
                              DSGEModel.Lambda = [DSGEModel.Lambda Inf];
                           end;
                        else;
                           DSGEModel.Lambda = [0.25 0.5 0.75 1 5 Inf];
                        end;
                     else;
                        DSGEModel.Lambda = [0.25 0.5 0.75 1 5 Inf];
                     end;
                     %
                     DSGEModel.ObsVarGroups = (1:DSGEModel.n);
                     DSGEModel.ObsVarGroupNames = DSGEModel.VariableNames;
                     %
                     % now we need to set the controls with the correct entries
                     %
                     [DSGEModel.SubBeginYearValue,DSGEModel.SubBeginPeriodValue,DSGEModel.SubEndYearValue,DSGEModel.SubEndPeriodValue,DSGEModel.YearStrMatrix,DSGEModel.PeriodStrMatrix] = CreateEstimationSampleValues(DSGEModel);
                     %
                     set(controls.dsge.subbeginyear,'String',DSGEModel.YearStrMatrix,'Value',DSGEModel.SubBeginYearValue);
                     set(controls.dsge.subbeginperiod,'String',DSGEModel.PeriodStrMatrix,'Value',DSGEModel.SubBeginPeriodValue);
                     set(controls.dsge.subendyear,'String',DSGEModel.YearStrMatrix,'Value',DSGEModel.SubEndYearValue);
                     set(controls.dsge.subendperiod,'String',DSGEModel.PeriodStrMatrix,'Value',DSGEModel.SubEndPeriodValue);
                     %
                     [FirstPeriod,LastPeriod,EstSample] = CreateSubSample(DSGEModel);
                     DSGEModel.KalmanFirstObservation = 1;
                     set(controls.dsge.initializekalman,'String',EstSample,'Value',DSGEModel.KalmanFirstObservation);
                     %
                     % check if there is conditioning information
                     %
                     DSGEModel = VerifyConditioningInformation(DSGEModel,DataStructure);
                     %
                     DSGEModel = VerifyStateCondInformation(DSGEModel,DataStructure);
                     %
                     % check if there is observed variable scenario information
                     %
                     DSGEModel = VerifyScenarioInformation(DSGEModel,DataStructure);
                     %
                     % check if there is state variable scenario information
                     %
                     DSGEModel = VerifyStateScenarioInformation(DSGEModel,DataStructure);
                     %
                     % Enable any controls that may be affected by this
                     %
                     set(controls.datainfo,'Enable','on');
                     set(controls.outputdirtext,'Enable','on');
                     set(controls.outputdir,'Enable','on');
                     set(controls.outputbutton,'Enable','on','CData',CurrINI.images.browse);
                  else;
                     set(controls.dsge.datafile,'String',DSGEModel.DataConstructionFile);
                     if (FileExist(DSGEModel.DataConstructionFile)==0)&(FileExist(DSGEModel.AIMFile)==0);
                        set(controls.outputdirtext,'Enable','off');
                        set(controls.outputdir,'Enable','off');
                        set(controls.outputbutton,'Enable','off','CData',CurrINI.images.browsedisable);
                        DSGEModel.OutputDirectory = pwd;
                     end;
                  end;
               else;
                  set(controls.dsge.datafile,'String',DSGEModel.DataConstructionFile);
                  About(ErrorStr,'error',['Error - ' FileName],500,600,CurrINI);
               end;
            end;
         else;
            %
            % Check if we need to disable any controls
            %
            if FileExist(DSGEModel.DataConstructionFile)==0;
               ForecastStr = get(controls.forecast.maxhorizon,'UserData');
               DSGEModel.MaxForecastHorizon = 1;
               set(controls.forecast.maxhorizon,'String',ForecastStr.annual,'Value',DSGEModel.MaxForecastHorizon);
               DSGEModel.T = 0;
               DSGEModel.n = 0;
               DSGEModel.k = 0;
               DSGEModel.Y = [];
               DSGEModel.Actuals = [];
               DSGEModel.YNaNs = 0;
               DSGEModel.YData = [];
               DSGEModel.YDataOriginal = [];
               DSGEModel.CompY = [];
               DSGEModel.BVARY = [];
               DSGEModel.BVARX = [];
               DSGEModel.levels = [];
               DSGEModel.annualscale = [];
               DSGEModel.annual = [];
               DSGEModel.X = [];
               DSGEModel.PredictedX = [];
               DSGEModel.ZLBData = 0;
               DSGEModel.ZLBPosition = [];
               DSGEModel.Percentiles = [5 15 85 95];
               DSGEModel.ConfidenceBandBaseColor = [1 1 1];
               DSGEModel.DataFrequency = '';
               DSGEModel.BeginYear = '';
               DSGEModel.BeginPeriod = '';
               DSGEModel.EndYear = '';
               DSGEModel.EndPeriod = '';
               DSGEModel.SubBeginYear = '';
               DSGEModel.SubBeginPeriod = '';
               DSGEModel.SubEndYear = '';
               DSGEModel.SubEndPeriod = '';
               DSGEModel.VariableNames = '';
               DSGEModel.XVariableNames = '';
               DSGEModel.Z = [];
               DSGEModel.ZVariableNames = '';
               DSGEModel.K1 = [];
               DSGEModel.K2 = [];
               DSGEModel.U = [];
               DSGEModel.Zeta = [];
               DSGEModel.ZetaVariableNames = '';
               DSGEModel.K3 = [];
               DSGEModel.C = [];
               DSGEModel.CData = [];
               DSGEModel.CDataComment = '';
               DSGEModel.CVariableNames = '';
               DSGEModel.ObsVariableScenarioFile = '';
               DSGEModel.C1 = [];
               DSGEModel.C2 = [];
               DSGEModel.CBar = [];
               DSGEModel.CDataOriginal = [];
               DSGEModel.CompData = [];
               DSGEModel.CompCBar = [];
               DSGEModel.CDataCommentOriginal = '';
               DSGEModel.CVariableNamesOriginal = '';
               DSGEModel.C1Original = [];
               DSGEModel.C2Original = [];
               DSGEModel.CBarOriginal = [];
               DSGEModel.YTransformation = [];
               DSGEModel.YTransMatrix = [];
               DSGEModel.CTransformation = [];
               DSGEModel.CTransformationOriginal = [];
               DSGEModel.ZTransformation = [];
               DSGEModel.ZTransformationOriginal = [];
               DSGEModel.CExport = [];
               DSGEModel.CExportVariables = [];
               DSGEModel.CCreateData = [];
               DSGEModel.COrder = [];
               DSGEModel.S = [];
               DSGEModel.SData = [];
               DSGEModel.SVariableNames = '';
               DSGEModel.ObsVarGroups = [];
               DSGEModel.ObsVarGroupNames = '';
               DSGEModel.ObsVarGroupColors = [];
               DSGEModel.Lambda = [0.25 0.5 0.75 1 5 Inf];
               set(controls.datainfo,'Enable','off');
               [DSGEModel.SubBeginYearValue,DSGEModel.SubBeginPeriodValue,DSGEModel.SubEndYearValue,DSGEModel.SubEndPeriodValue,DSGEModel.YearStrMatrix,DSGEModel.PeriodStrMatrix] = CreateEstimationSampleValues(DSGEModel);
               %
               DSGEModel.KalmanFirstObservation = 1;
               set(controls.dsge.initializekalman,'String',' ','Value',DSGEModel.KalmanFirstObservation);
               %
               set(controls.dsge.subbeginyear,'String',DSGEModel.YearStrMatrix,'Value',DSGEModel.SubBeginYearValue);
               set(controls.dsge.subbeginperiod,'String',DSGEModel.PeriodStrMatrix,'Value',DSGEModel.SubBeginPeriodValue);
               set(controls.dsge.subendyear,'String',DSGEModel.YearStrMatrix,'Value',DSGEModel.SubEndYearValue);
               set(controls.dsge.subendperiod,'String',DSGEModel.PeriodStrMatrix,'Value',DSGEModel.SubEndPeriodValue);
               %
               if FileExist(DSGEModel.AIMFile)==0;
                  set(controls.outputdirtext,'Enable','off');
                  set(controls.outputdir,'Enable','off');
                  set(controls.outputbutton,'Enable','off','CData',CurrINI.images.browsedisable);
                  DSGEModel.OutputDirectory = pwd;
               end;
            end;
         end;
         set(controls.about,'UserData',0);
      end;
   case 'checkdatafile'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         NewDataFile = StringTrim(get(controls.dsge.datafile,'String'));
         if FileExist(NewDataFile)==1;
            %
            % make sure that the file is an m-file
            %
            [FilePath,FileName,FileExt] = fileparts(NewDataFile);
            if (strcmp(lower(FileExt),'.m')==1)|(strcmp(lower(FileExt),'.p')==1);
               %
               % we can now check the file
               %
               if strcmp(lower(FilePath),lower(FixFilePath([pwd '\tmp'])))==0;
                  [stat,msg] = CopyFile(NewDataFile,[pwd '\tmp']);
                  file = FixFilePath([pwd '\tmp\' FileName FileExt]);
               else;
                  file = NewDataFile;
               end;
               if FileExist(file)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        DataStructure = feval(FileName);
                     catch ME;
                        ErrorStr = ['Error found in data construction file "' FileName '". The error message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        DataStructure = feval(FileName);
                     catch;
                        ErrorStr = ['Error found in data construction file "' FileName '". The error message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     %
                     % now we check if DataStructure is valid
                     %
                     [stat,YNaNs] = CheckObservedDataFile(DataStructure,controls.dsge.datafile,DSGEModel.DataConstructionFile,[FileName FileExt],CurrINI);
                     if stat>=1;
                        %
                        % error messages have already been reported by CheckObservedDataFile with stat = 0
                        %
                        % make the necessary changes to the DSGEModel structure
                        %
                        DSGEModel.DataConstructionFile = NewDataFile;
                        DSGEModel.T = length(DataStructure.Y.data);
                        DSGEModel.n = length(DataStructure.Y.names);
                        if isempty(DataStructure.X.names)==0
                           DSGEModel.k = length(DataStructure.X.names)*(1-isempty(DataStructure.X.names{1,1}));
                        else;
                           DSGEModel.k = 0;
                        end;
                        DSGEModel.Y = DataStructure.Y.data;
                        DSGEModel.YNaNs = YNaNs;
                        if isfield(DataStructure.Y,'actuals')==1;
                           DSGEModel.Actuals = VerifyActualsData(DataStructure.Y.actuals,DSGEModel.n,DSGEModel.T);
                        else;
                           DSGEModel.Actuals = [];
                        end;
                        if isfield(DataStructure.Y,'comparisondata')==1;
                           DSGEModel.CompY = DataStructure.Y.comparisondata;
                        else;
                           DSGEModel.CompY = [];
                        end;
                        DSGEModel.DataFrequency = lower(DataStructure.frequency(1,1));
                        ForecastStr = get(controls.forecast.maxhorizon,'UserData');
                        if strcmp(lower(DSGEModel.DataFrequency),'q')==1;
                           set(controls.forecast.maxhorizon,'String',ForecastStr.quarter);
                        elseif strcmp(lower(DSGEModel.DataFrequency),'m')==1;
                           set(controls.forecast.maxhorizon,'String',ForecastStr.month);
                        else;
                           set(controls.forecast.maxhorizon,'String',ForecastStr.annual);
                        end;
                        if (isfield(DataStructure.Y,'BVAR')==1)&(length(DataStructure.Y.BVAR)<=DSGEModel.n);
                           DSGEModel.BVARY = VerifyVector(DataStructure.Y.BVAR,DSGEModel.n);
                        else;
                           DSGEModel.BVARY = (1:DSGEModel.n);
                        end;
                        if (isfield(DataStructure.X,'BVAR')==1)&(length(DataStructure.X.BVAR)<=DSGEModel.k);
                           DSGEModel.BVARX = VerifyVector(DataStructure.X.BVAR,DSGEModel.k);
                        else;
                           DSGEModel.BVARX = (1:DSGEModel.k);
                        end;
                        if isfield(DataStructure.Y,'policyrate')==1;
                           DSGEModel.ZLBPosition = VerifyVector(DataStructure.Y.policyrate,DSGEModel.n);
                           if IsInteger(DSGEModel.ZLBPosition)==0;
                              DSGEModel.ZLBPosition = [];
                           end;
                        else;
                           DSGEModel.ZLBPosition = [];
                        end;
                        if isfield(DataStructure.Y,'ZLBdata')==1;
                           DSGEModel.ZLBData = DataStructure.Y.ZLBdata(1,:)';
                        else;
                           DSGEModel.ZLBData = 0;
                        end;
                        if isfield(DataStructure.X,'extradata')==1;
                           %
                           % we need to test if this data is valid
                           %
                           if size(DataStructure.X.extradata,1)==DSGEModel.k;
                              DSGEModel.PredictedX = DataStructure.X.extradata;
                           else;
                              DSGEModel.PredictedX = [];
                           end;
                        else;
                           DSGEModel.PredictedX = [];
                        end;
                        if isfield(DataStructure,'percentiles')==1;
                           Ptiles = unique(DataStructure.percentiles);
                           %
                           % make sure that all entries are greater than 0, less than a 100, and integers
                           %
                           Ptiles = Ptiles(Ptiles>0);
                           Ptiles = Ptiles(Ptiles<100);
                           if length(Ptiles)>1;
                              if IsOdd(length(Ptiles))==1;
                                 Pmiddle = Ptiles(ceil(length(Ptiles)/2));
                                 Ptiles = Ptiles(Ptiles~=Pmiddle);
                              end;
                              DSGEModel.Percentiles = Ptiles;
                           else;
                              DSGEModel.Percentiles = [5 15 85 95];
                           end;
                        else;
                           DSGEModel.Percentiles = [5 15 85 95];
                        end;
                        if stat==1;
                           DSGEModel.levels = DataStructure.Y.levels;
                           if (isfield(DataStructure.Y,'annual')==1)&(length(DataStructure.Y.annual)==DSGEModel.n);
                              if strcmp(DSGEModel.DataFrequency,'q')==1;
                                 SampleFreq = 4;
                              elseif strcmp(DSGEModel.DataFrequency,'m')==1;
                                 SampleFreq = 12;
                              else;
                                 SampleFreq = 1;
                              end;
                              DSGEModel.annual = ((DataStructure.Y.annual)*(SampleFreq-1))+ones(1,DSGEModel.n);
                           else;
                              DSGEModel.annual = ones(1,DSGEModel.n);
                           end;
                           if (isfield(DataStructure.Y,'annualscale')==1)&(length(DataStructure.Y.annualscale)==DSGEModel.n);
                              DSGEModel.annualscale = ReplaceData(DataStructure.Y.annualscale,0,1);
                           else;
                              DSGEModel.annualscale = ones(1,DSGEModel.n);
                           end;
                        elseif stat==2;
                           DSGEModel.levels = ones(1,DSGEModel.n);
                           DSGEModel.annual = ones(1,DSGEModel.n);
                           DSGEModel.annualscale = ones(1,DSGEModel.n);
                        end;
                        if size(DSGEModel.Y,1)>size(DSGEModel.Y,2);
                           DSGEModel.Y = DSGEModel.Y';
                        end;
                        if size(DSGEModel.CompY,1)>size(DSGEModel.CompY,2);
                           DSGEModel.CompY = DSGEModel.CompY';
                        end;
                        if size(DSGEModel.Y)~=size(DSGEModel.CompY);
                           DSGEModel.CompY = [];
                        end;
                        DSGEModel.X = DataStructure.X.data;
                        if size(DSGEModel.X,1)>size(DSGEModel.X,2);
                           DSGEModel.X = DSGEModel.X';
                        end;
                        DSGEModel.YData = DSGEModel.Y;
                        DSGEModel.YDataOriginal = DSGEModel.Y;
                        DSGEModel.BeginYear = num2str(floor(DataStructure.sample(1)));
                        DSGEModel.BeginPeriod = num2str(floor(DataStructure.sample(2)));
                        DSGEModel.EndYear = num2str(floor(DataStructure.sample(3)));
                        DSGEModel.EndPeriod = num2str(floor(DataStructure.sample(4)));
                        DSGEModel.SubBeginYear = num2str(floor(DataStructure.sample(1)));
                        DSGEModel.SubBeginPeriod = num2str(floor(DataStructure.sample(2)));
                        DSGEModel.SubEndYear = num2str(floor(DataStructure.sample(3)));
                        DSGEModel.SubEndPeriod = num2str(floor(DataStructure.sample(4)));
                        DSGEModel.VariableNames = '';
                        for i=1:DSGEModel.n;
                           DSGEModel.VariableNames = strvcat(DSGEModel.VariableNames,DataStructure.Y.names{i});
                        end;
                        DSGEModel.XVariableNames = '';
                        for i=1:DSGEModel.k;
                           DSGEModel.XVariableNames = strvcat(DSGEModel.XVariableNames,DataStructure.X.names{i});
                        end;
                        if isfield(DataStructure.Y,'transformation')==1;
                           if VerifyDataTransformation(DSGEModel.VariableNames,DataStructure.Y.transformation,0)==1;
                              DSGEModel.YTransformation = DataStructure.Y.transformation;
                              if isfield(DataStructure.Y,'TransMatrix')==1;
                                 if (rank(DataStructure.Y.TransMatrix)==DSGEModel.n)&(size(DataStructure.Y.TransMatrix,1)==DSGEModel.n)&(size(DataStructure.Y.TransMatrix,2)==DSGEModel.n);
                                    DSGEModel.YTransMatrix = DataStructure.Y.TransMatrix;
                                 else;
                                    DSGEModel.YTransMatrix = [];
                                 end;
                              else;
                                 DSGEModel.YTransMatrix = [];
                              end;
                           else;
                              DSGEModel.YTransformation = [];
                              DSGEModel.YTransMatrix = [];
                           end;
                        else;
                           DSGEModel.YTransformation = [];
                           DSGEModel.YTransMatrix = [];
                        end;
                        %
                        if isfield(DataStructure,'Lambda')==1;
                           DSGEModel.Lambda = DataStructure.Lambda;
                           if isempty(DSGEModel.Lambda)==0;
                              DSGEModel.Lambda = sort(DSGEModel.Lambda);
                              if isinf(DSGEModel.Lambda(length(DSGEModel.Lambda)))==0;
                                 DSGEModel.Lambda = [DSGEModel.Lambda Inf];
                              end;
                           else;
                              DSGEModel.Lambda = [0.25 0.5 0.75 1 5 Inf];
                           end;
                        else;
                           DSGEModel.Lambda = [0.25 0.5 0.75 1 5 Inf];
                        end;
                        DSGEModel.ObsVarGroups = (1:DSGEModel.n);
                        DSGEModel.ObsVarGroupNames = DSGEModel.VariableNames;
                        %
                        % create the subsample strings and values
                        %
                        [DSGEModel.SubBeginYearValue,DSGEModel.SubBeginPeriodValue,DSGEModel.SubEndYearValue,DSGEModel.SubEndPeriodValue,DSGEModel.YearStrMatrix,DSGEModel.PeriodStrMatrix] = CreateEstimationSampleValues(DSGEModel);
                        %
                        set(controls.dsge.subbeginyear,'String',DSGEModel.YearStrMatrix,'Value',DSGEModel.SubBeginYearValue);
                        set(controls.dsge.subbeginperiod,'String',DSGEModel.PeriodStrMatrix,'Value',DSGEModel.SubBeginPeriodValue);
                        set(controls.dsge.subendyear,'String',DSGEModel.YearStrMatrix,'Value',DSGEModel.SubEndYearValue);
                        set(controls.dsge.subendperiod,'String',DSGEModel.PeriodStrMatrix,'Value',DSGEModel.SubEndPeriodValue);
                        %
                        [FirstPeriod,LastPeriod,EstSample] = CreateSubSample(DSGEModel);
                        DSGEModel.KalmanFirstObservation = 1;
                        set(controls.dsge.initializekalman,'String',EstSample,'Value',DSGEModel.KalmanFirstObservation);
                        %
                        % check if there is conditioning information
                        %
                        DSGEModel = VerifyConditioningInformation(DSGEModel,DataStructure);
                        %
                        DSGEModel = VerifyStateCondInformation(DSGEModel,DataStructure);
                        %
                        % check if there is observed variable scenario information
                        %
                        DSGEModel = VerifyScenarioInformation(DSGEModel,DataStructure);
                        %
                        % check if there is state variable scenario information
                        %
                        DSGEModel = VerifyStateScenarioInformation(DSGEModel,DataStructure);
                        %
                        % Enable any controls that may be affected by this
                        %
                        set(controls.datainfo,'Enable','on');
                        set(controls.outputdirtext,'Enable','on');
                        set(controls.outputdir,'Enable','on');
                        set(controls.outputbutton,'Enable','on','CData',CurrINI.images.browse);
                     else;
                        set(controls.dsge.datafile,'String',DSGEModel.DataConstructionFile);
                        if (FileExist(DSGEModel.DataConstructionFile)==0)&(FileExist(DSGEModel.AIMFile)==0);
                           set(controls.outputdirtext,'Enable','off');
                           set(controls.outputdir,'Enable','off');
                           set(controls.outputbutton,'Enable','off','CData',CurrINI.images.browsedisable);
                           DSGEModel.OutputDirectory = pwd;
                        end;
                     end;
                  else;
                     set(controls.dsge.datafile,'String',DSGEModel.DataConstructionFile);
                     About(ErrorStr,'error',['Error - ' FileName],500,600,CurrINI);
                  end;
               end;
            else;
               set(controls.dsge.datafile,'String',DSGEModel.DataConstructionFile);
            end;
         else;
            if (strcmp(NewDataFile,'')==1)|isempty(NewDataFile)==1;
               ForecastStr = get(controls.forecast.maxhorizon,'UserData');
               DSGEModel.MaxForecastHorizon = 1;
               set(controls.forecast.maxhorizon,'String',ForecastStr.annual,'Value',DSGEModel.MaxForecastHorizon);
               DSGEModel.DataConstructionFile = pwd;
               DSGEModel.T = 0;
               DSGEModel.n = 0;
               DSGEModel.k = 0;
               DSGEModel.Y = [];
               DSGEModel.Actuals = [];
               DSGEModel.YNaNs = 0;
               DSGEModel.YData = [];
               DSGEModel.YDataOriginal = [];
               DSGEModel.CompY = [];
               DSGEModel.BVARY = [];
               DSGEModel.BVARX = [];
               DSGEModel.levels = [];
               DSGEModel.annual = [];
               DSGEModel.annualscale = [];
               DSGEModel.X = [];
               DSGEModel.PredictedX = [];
               DSGEModel.ZLBData = 0;
               DSGEModel.ZLBPosition = [];
               DSGEModel.Percentiles = [5 15 85 95];
               DSGEModel.ConfidenceBandBaseColor = [1 1 1];
               DSGEModel.DataFrequency = '';
               DSGEModel.BeginYear = '';
               DSGEModel.BeginPeriod = '';
               DSGEModel.EndYear = '';
               DSGEModel.EndPeriod = '';
               DSGEModel.SubBeginYear = '';
               DSGEModel.SubBeginPeriod = '';
               DSGEModel.SubEndYear = '';
               DSGEModel.SubEndPeriod = '';
               DSGEModel.VariableNames = '';
               DSGEModel.XVariableNames = '';
               DSGEModel.Z = [];
               DSGEModel.ZVariableNames = '';
               DSGEModel.K1 = [];
               DSGEModel.K2 = [];
               DSGEModel.U = [];
               DSGEModel.Zeta = [];
               DSGEModel.ZetaVariableNames = '';
               DSGEModel.K3 = [];
               DSGEModel.C = [];
               DSGEModel.CData = [];
               DSGEModel.CDataComment = '';
               DSGEModel.CVariableNames = '';
               DSGEModel.ObsVariableScenarioFile = '';
               DSGEModel.C1 = [];
               DSGEModel.C2 = [];
               DSGEModel.CBar = [];
               DSGEModel.CDataOriginal = [];
               DSGEModel.CompData = [];
               DSGEModel.CompCBar = [];
               DSGEModel.CDataCommentOriginal = '';
               DSGEModel.CVariableNamesOriginal = '';
               DSGEModel.C1Original = [];
               DSGEModel.C2Original = [];
               DSGEModel.CBarOriginal = [];
               DSGEModel.YTransformation = [];
               DSGEModel.YTransMatrix = [];
               DSGEModel.CTransformation = [];
               DSGEModel.CTransformationOriginal = [];
               DSGEModel.ZTransformation = [];
               DSGEModel.ZTransformationOriginal = [];
               DSGEModel.CExport = [];
               DSGEModel.CExportVariables = [];
               DSGEModel.CCreateData = [];
               DSGEModel.COrder = [];
               DSGEModel.S = [];
               DSGEModel.SData = [];
               DSGEModel.SVariableNames = '';
               DSGEModel.ObsVarGroups = [];
               DSGEModel.ObsVarGroupNames = '';
               DSGEModel.ObsVarGroupColors = [];
               DSGEModel.Lambda = [0.25 0.5 0.75 1 5 Inf];
            end;
            set(controls.dsge.datafile,'String',DSGEModel.DataConstructionFile);
            %
            % check if we need to disable any controls
            %
            if FileExist(DSGEModel.DataConstructionFile)==0;
               set(controls.datainfo,'Enable','off');
               if FileExist(DSGEModel.AIMFile)==0;
                  set(controls.outputdirtext,'Enable','off');
                  set(controls.outputdir,'Enable','off');
                  set(controls.outputbutton,'Enable','off','CData',CurrINI.images.browsedisable);
                  DSGEModel.OutputDirectory = pwd;
               end;
               %
               % create the subsample strings and value
               %
               [DSGEModel.SubBeginYearValue,DSGEModel.SubBeginPeriodValue,DSGEModel.SubEndYearValue,DSGEModel.SubEndPeriodValue,DSGEModel.YearStrMatrix,DSGEModel.PeriodStrMatrix] = CreateEstimationSampleValues(DSGEModel);
               %
               set(controls.dsge.subbeginyear,'String',DSGEModel.YearStrMatrix,'Value',DSGEModel.SubBeginYearValue);
               set(controls.dsge.subbeginperiod,'String',DSGEModel.PeriodStrMatrix,'Value',DSGEModel.SubBeginPeriodValue);
               set(controls.dsge.subendyear,'String',DSGEModel.YearStrMatrix,'Value',DSGEModel.SubEndYearValue);
               set(controls.dsge.subendperiod,'String',DSGEModel.PeriodStrMatrix,'Value',DSGEModel.SubEndPeriodValue);
               %
               DSGEModel.KalmanFirstObservation = 1;
               set(controls.dsge.initializekalman,'String',' ','Value',DSGEModel.KalmanFirstObservation);
            end;
         end;
         set(controls.about,'UserData',0);
      end;
   case 'browsepriorfile'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % Open a file open dialog
         %
         status = FileBrowse(DSGEModel.PriorFile,'Open Prior Dist Specification File',controls.dsge.priorfile,'wk1',CurrINI);
         if status==1;
            [FilePath,FileName,FileExt] = fileparts(get(controls.dsge.priorfile,'String'));
            %
            % check if the file is an excel spreadsheet. if so we need to check which sheets there are
            %
            if strncmp(lower(FileExt),'.xls',4)==1;
               %
               % we must matlab version 6 or later. Check the spreadsheet for sheets
               %
               ErrorValue = [];
               file = FixFilePath([FilePath '\' FileName FileExt]);
               try;
                  [fok,sheets] = xlsfinfo(file);
               catch;
                  ErrorValue = 1;
               end;
               if (isempty(ErrorValue)==1)&(isempty(fok)==0);
                  if length(sheets)>1;
                     mysheets = sheets{1};
                     for i=2:length(sheets);
                        mysheets = [mysheets '|' sheets{i}];
                     end;
                     [action,selsheet] = SheetDlg(mysheets,file,CurrINI);
                     if strcmp(action,'Cancel')==1;
                        new_sheet = '';
                     else;
                        new_sheet = sheets{selsheet};
                     end;
                  else;
                     if iscell(sheets)==1;
                        new_sheet = char(sheets);
                     else;
                        new_sheet = sheets;
                     end;
                  end;
                  if strcmp(new_sheet,'')==0;
                     DSGEModel.PriorFile = file;
                     DSGEModel.PriorFileSheet = new_sheet;
                     set(controls.dsge.priorfilesheet,'String',['Sheet: ' new_sheet]);
                  else;
                     %
                     % cancelled
                     %
                     set(controls.dsge.priorfile,'String',DSGEModel.PriorFile);
                  end;
               else;
                  %
                  % The excel spreadsheet was not readable
                  %
                  set(controls.dsge.priorfile,'String',DSGEModel.PriorFile);
                  txt = ['The excel spreadsheet you selected "' FileName FileExt '" cannot be read by YADA. Please select another file.'];
                  About(txt,'information','Bad Excel Spreadsheet',120,500,CurrINI);
               end;
            else;
               %
               % Check to make sure the file is a Lotus 1-2-3 spreadsheet
               %
               if strcmp(lower(FileExt),'.wk1')==0;
                  set(controls.dsge.priorfile,'String',DSGEModel.PriorFile);
                  txt = ['The file you selected "' FileName FileExt '" is not a valid file for prior distribution specification. Please select a valid file for this purpose.'];
                  About(txt,'information','Invalid File Format',120,500,CurrINI);
               else;
                  ErrorValue = [];
                  try;
                     [fok,chk] = wk1finfo(FixFilePath([FilePath '\' FileName FileExt]));
                  catch;
                     ErrorValue = 1;
                  end;
                  if (isempty(ErrorValue)==1)&(isempty(fok)==0);
                     DSGEModel.PriorFile = FixFilePath([FilePath '\' FileName FileExt]);
                     DSGEModel.PriorFileSheet = 'None';
                     set(controls.dsge.priorfilesheet,'String','Sheet: None');
                  else;
                     %
                     % The Lotus spreadsheet was not readable
                     %
                     set(controls.dsge.priorfile,'String',DSGEModel.PriorFile);
                     txt = ['The Lotus 1-2-3 spreadsheet you selected "' FileName FileExt '" cannot be read by YADA. Please select another file.'];
                     About(txt,'information','Bad Lotus Spreadsheet',120,500,CurrINI);
                  end;
               end;
            end;
         end;
         set(controls.about,'UserData',0);
      end;
   case 'checkpriorfile'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % Check if the prior file exists, and if it's either a proper Excel or Lotus 1-2-3 spreadsheet
         %
         new_prior_file = FixFilePath(StringTrim(get(controls.dsge.priorfile,'String')));
         if FileExist(new_prior_file)==1;
            %
            % Now we try to verify that the file is valid
            %
            [FilePath,FileName,FileExt] = fileparts(new_prior_file);
            if strncmp(lower(FileExt),'.xls',4)==1;
               %
               % is the file a valid Excel spreadsheet
               %
               if MatlabNumber>=6;
                  %
                  % is the file a valid Excel spreadsheet
                  %
                  ErrorValue = [];
                  try;
                     [fok,sheets] = xlsfinfo(new_prior_file);
                  catch;
                     ErrorValue = 1;
                  end;
                  if (isempty(ErrorValue)==1)&(isempty(fok)==0);
                     %
                     % File is OK. If sheets has more than 1 element, open the SheetDlg dialog
                     %
                     if length(sheets)>1;
                        mysheets = sheets{1};
                        for i=2:length(sheets);
                           mysheets = [mysheets '|' sheets{i}];
                        end;
                        [action,selsheet] = SheetDlg(mysheets,new_prior_file,CurrINI);
                        if strcmp(action,'Cancel')==1;
                           new_sheet = '';
                        else;
                           new_sheet = sheets{selsheet};
                        end;
                     else;
                        if iscell(sheets)==1;
                           new_sheet = char(sheets);
                        else;
                           new_sheet = sheets;
                        end;
                     end;
                     if strcmp(new_sheet,'')==0;
                        DSGEModel.PriorFile = new_prior_file;
                        DSGEModel.PriorFileSheet = new_sheet;
                        set(controls.dsge.priorfilesheet,'String',['Sheet: ' new_sheet]);
                     else;
                        %
                        % cancelled
                        %
                        set(controls.dsge.priorfile,'String',DSGEModel.PriorFile);
                     end;
                  else;
                     %
                     % The file can't be read by YADA
                     %
                     set(controls.dsge.priorfile,'String',DSGEModel.PriorFile);
                     txt = ['The excel spreadsheet you selected "' FileName FileExt '" cannot be read by YADA. Please select another file.'];
                     About(txt,'information','Bad Excel Spreadsheet',120,500,CurrINI);
                  end;
               else;
                  %
                  % Excel spreadsheet are not supported
                  %
                  set(controls.dsge.priorfile,'String',DSGEModel.PriorFile);
                  txt = 'Your version of Matlab does not support Excel spreadsheets. Please use a different file format.';
                  About(txt,'information','Invalid File Format',100,400,CurrINI);
               end;
            elseif strcmp(lower(FileExt),'.wk1')==1;
               %
               % is the file a valid Lotus 1-2-3 spreadsheet
               %
               ErrorValue = [];
               try;
                  [fok,chk] = wk1finfo(new_prior_file);
               catch;
                  ErrorValue = 1;
               end;
               if (isempty(ErrorValue)==1)&(isempty(fok)==0);
                  %
                  % yes, the file can be read by YADA
                  %
                  DSGEModel.PriorFile = FixFilePath([FilePath '\' FileName FileExt]);
                  DSGEModel.PriorFileSheet = 'None';
                  set(controls.dsge.priorfilesheet,'String','Sheet: None');
               else;
                  %
                  % No, the Lotus spreadsheet was not readable
                  %
                  set(controls.dsge.priorfile,'String',DSGEModel.PriorFile);
                  txt = ['The Lotus 1-2-3 spreadsheet you selected "' FileName FileExt '" cannot be read by YADA. Please select another file.'];
                  About(txt,'information','Bad Lotus Spreadsheet',120,500,CurrINI);
               end;
            else;
               %
               % we don't have a valid spreadsheet
               %
               set(controls.dsge.priorfile,'String',DSGEModel.PriorFile);
               txt = ['The file you selected "' FileName FileExt '" is not a valid file for prior distribution  specifications. Please select a valid file for this purpose.'];
               About(txt,'information','Invalid File Format',120,500,CurrINI);
            end;
         else;
            if (strcmp(new_prior_file,'')==1)|(isempty(new_prior_file)==1);
               DSGEModel.PriorFile = pwd;
               DSGEModel.PriorFileSheet = 'None';
               set(controls.dsge.priorfilesheet,'String','Sheet: None');
            end;
            set(controls.dsge.priorfile,'String',DSGEModel.PriorFile);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'browsesystempriorfile'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % Open a file open dialog
         %
         status = FileBrowse(DSGEModel.SystemPriorFile,'Open System Prior Density File',controls.dsge.systempriorfile,'m',CurrINI);
         if status==1;
            DSGEModel.SystemPriorFile = get(controls.dsge.systempriorfile,'String');
         end;
         set(controls.about,'UserData',0);
      end;
   case 'checksystempriorfile'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         NewSystemPriorFile = StringTrim(get(controls.dsge.systempriorfile,'String'));
         if FileExist(NewSystemPriorFile)==1;
            %
            % make sure that the file is an m-file
            %
            [FilePath,FileName,FileExt] = fileparts(NewSystemPriorFile);
            if (strcmp(lower(FileExt),'.m')==1)|(strcmp(lower(FileExt),'.p')==1);
               DSGEModel.SystemPriorFile = NewSystemPriorFile;
            else;
               set(controls.dsge.systempriorfile,'String',DSGEModel.SystemPriorFile);
            end;
         else;
            if (strcmp(NewSystemPriorFile,'')==1)|(isempty(NewSystemPriorFile)==1);
               DSGEModel.SystemPriorFile = pwd;
            end;
            set(controls.dsge.systempriorfile,'String',DSGEModel.SystemPriorFile);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'browseparameterfile'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         CurrField = strrep(get(gco,'Tag'),'Button','');
         if strcmp(CurrField,'UpdateParameterFile')==1;
            CurrControl = controls.dsge.updateparameterfile;
            OtherControl = controls.dsge.initialparameterfile;
            CurrStr = 'Open Update Parameters File';
         else;
            CurrControl = controls.dsge.initialparameterfile;
            OtherControl = controls.dsge.updateparameterfile;
            CurrStr = 'Open Initialize Parameters File';
         end;
         %
         % Open a file open dialog
         %
         status = FileBrowse(getfield(DSGEModel,CurrField),CurrStr,CurrControl,'m',CurrINI);
         if (status==1)&(strcmp(lower(GetName(StringTrim(get(CurrControl,'String')))),lower(GetName(StringTrim(get(OtherControl,'String')))))==0);
            DSGEModel = setfield(DSGEModel,CurrField,get(CurrControl,'String'));
         end;
         %
         if FileExist(DSGEModel.InitializeParameterFile)==1;
            set(controls.dsge.runinitialfirst,'Enable','on');
         else;
            DSGEModel.RunInitializeFirst = 0;
            set(controls.dsge.runinitialfirst,'Enable','off','Value',0);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'checkparameterfile'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         CurrField = strrep(get(gco,'Tag'),'EditBox','');
         if strcmp(CurrField,'UpdateParameterFile')==1;
            CurrControl = controls.dsge.updateparameterfile;
            OtherControl = controls.dsge.initialparameterfile;
            CurrStr = 'Open Update Parameters File';
         else;
            CurrControl = controls.dsge.initialparameterfile;
            OtherControl = controls.dsge.updateparameterfile;
            CurrStr = 'Open Initialize Parameters File';
         end;
         %
         new_me_file = StringTrim(get(CurrControl,'String'));
         if FileExist(new_me_file)==1;
            %
            % make sure that the file is an m-file
            %
            [FilePath,FileName,FileExt] = fileparts(new_me_file);
            if ((strcmp(lower(FileExt),'.m')==1)|(strcmp(lower(FileExt),'.p')==1))&(strcmp(lower(FileName),lower(GetName(StringTrim(get(OtherControl,'String')))))==0);
               DSGEModel = setfield(DSGEModel,CurrField,new_me_file);
            else;
               set(CurrControl,'String',getfield(DSGEModel,CurrField));
            end;
         else;
            if (strcmp(new_me_file,'')==1)|(isempty(new_me_file)==1)|(strcmp(lower(new_me_file),lower(pwd))==1)|(strcmp(lower(new_me_file),lower(FixFilePath([pwd '\'])))==1);
               DSGEModel = setfield(DSGEModel,CurrField,pwd);
            end;
            set(CurrControl,'String',getfield(DSGEModel,CurrField));
         end;
         if FileExist(DSGEModel.InitializeParameterFile)==1;
            set(controls.dsge.runinitialfirst,'Enable','on');
         else;
            DSGEModel.RunInitializeFirst = 0;
            set(controls.dsge.runinitialfirst,'Enable','off','Value',0);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'initializefirst'
      if get(controls.about,'UserData')==0;
         DSGEModel.RunInitializeFirst = get(controls.dsge.runinitialfirst,'Value');
      else;
         set(controls.dsge.runinitialfirst,'Value',DSGEModel.RunInitializeFirst);
      end;
   case 'showestimationlog'
      if get(controls.about,'UserData')==0;
         DSGEModel.ShowEstimationLog = get(controls.showestimationlog,'Value');
      else;
         set(controls.showestimationlog,'Value',DSGEModel.ShowEstimationLog);
      end;
   case 'usedoublingalgorithm'
      if get(controls.about,'UserData')==0;
         DSGEModel.UseDoublingAlgorithm = get(controls.dsge.usedoublingalgorithm,'Value');
         if (DSGEModel.UseDoublingAlgorithm>=3)&(DSGEModel.KalmanAlgorithm==4);
            DSGEModel.KalmanAlgorithm = 1;
            set(controls.dsge.kalmanalgorithm,'Value',DSGEModel.KalmanAlgorithm);
            txt = 'The Chandrasekhar recursions require that: (1) There are no unit roots in the model; (2) The filter is initialized with the steady-state covariance matrix; (3) There are no missing observations; and (4) The selection matrix H in the measurement equation is constant over time. Your settings, data, or model violates these conditions.';
            About(txt,'information','Chandrasekhar Recursion Requirements',250,550,CurrINI);
         end;
      else;
         set(controls.dsge.usedoublingalgorithm,'Value',DSGEModel.UseDoublingAlgorithm);
      end;
      if DSGEModel.UseDoublingAlgorithm==2;
         set(controls.dsge.doublingalgorithmtext,'Enable','on');
         set(controls.dsge.doublingalgorithm,'Enable','on');
         set(controls.dsge.doublingtolerancetext,'Enable','on');
         set(controls.dsge.doublingtolerance,'Enable','on');
         set(controls.dsge.statecovariancetext,'Enable','off');
         set(controls.dsge.statecovariance,'Enable','off');
      elseif DSGEModel.UseDoublingAlgorithm==3;
         set(controls.dsge.doublingalgorithmtext,'Enable','off');
         set(controls.dsge.doublingalgorithm,'Enable','off');
         set(controls.dsge.doublingtolerancetext,'Enable','off');
         set(controls.dsge.doublingtolerance,'Enable','off');
         set(controls.dsge.statecovariancetext,'Enable','on');
         set(controls.dsge.statecovariance,'Enable','on');
      else;
         set(controls.dsge.doublingalgorithmtext,'Enable','off');
         set(controls.dsge.doublingalgorithm,'Enable','off');
         set(controls.dsge.doublingtolerancetext,'Enable','off');
         set(controls.dsge.doublingtolerance,'Enable','off');
         set(controls.dsge.statecovariancetext,'Enable','off');
         set(controls.dsge.statecovariance,'Enable','off');
      end;
   case 'showprogressclock'
      if get(controls.about,'UserData')==0;
         DSGEModel.ShowProgressClock = get(controls.dsge.progressclock,'Value');
      else;
         set(controls.dsge.progressclock,'Value',DSGEModel.ShowProgressClock);
      end;
   case 'sequentialsteplength'
      if get(controls.about,'UserData')==0;
         DSGEModel.SequentialStepLength = get(controls.dsge.sequentialstep,'Value');
      else;
         set(controls.dsge.sequentialstep,'Value',DSGEModel.SequentialStepLength);
      end;
   case 'sequentialstartiteration'
      if get(controls.about,'UserData')==0;
         DSGEModel.SequentialStartIteration = get(controls.dsge.sequentialstart,'Value');
      else;
         set(controls.dsge.sequentialstart,'Value',DSGEModel.SequentialStartIteration);
      end;
   case 'modelsolver'
      if get(controls.about,'UserData')==0;
         if get(controls.dsge.modelsolver,'Value')<=3;
            DSGEModel.ModelSolver = get(controls.dsge.modelsolver,'Value');
            set(controls.dsge.modelsolver,'String','Anderson & Moore''s algorithm (AiM)|Paul Klein''s algorithm (solab)|Christopher Sims'' algorithm (gensys)|Other');
            MSF = FixFilePath([pwd '\tmp\' GetFilename(DSGEModel.ModelSolverFile)]);
            if FileExist(MSF)==1;
               delete(MSF);
            end;
            DSGEModel.ModelSolverFile = pwd;
         else;
            %
            % the user now has to select an m-file
            %
            if FileExist(DSGEModel.ModelSolverFile)==1;
               ModelSolverFile = DSGEModel.ModelSolverFile;
            else;
               if MatlabNumber>=6;
                  ModelSolverFile = '';
               else;
                  ModelSolverFile = [DSGEModel.ModelSolverFile '\*.m;*.p'];
               end;
            end;
            if MatlabNumber>=6;
               FileType = {'*.m', 'Matlab M-Files (*.m)'; ...
                           '*.p', 'Matlab P-Files (*.p)'};
               [FileName,FilePath] = uigetfile(FileType,'DSGE Model Solver - Select File',ModelSolverFile);
            else;
               [FileName,FilePath] = uigetfile(ModelSolverFile,'DSGE Model Solver - Select File');
            end;
            drawnow;
            pause(0.02);
            if (isnumeric(FileName)==0)&(isunix==1);
               if strcmp(FilePath(1,length(FilePath)),'/')==0;
                  FilePath = [FilePath '/'];
               end;
            end;
            ModelSolverFile = [FilePath FileName];
            if (isnumeric(FileName)==0)&(FileExist(ModelSolverFile)==1);
               DSGEModel.ModelSolverFile = ModelSolverFile;
               DSGEModel.ModelSolver = 4;
               set(controls.dsge.modelsolver,'String',['Anderson & Moore''s algorithm (AiM)|Paul Klein''s algorithm (solab)|Christopher Sims'' algorithm (gensys)|Other (' GetName(DSGEModel.ModelSolverFile) ')']);
            else;
               set(controls.dsge.modelsolver,'Value',DSGEModel.ModelSolver);
            end;
         end;
      else;
         set(controls.dsge.modelsolver,'Value',DSGEModel.ModelSolver);
      end;
   case 'marginallikelihood'
      if get(controls.about,'UserData')==0;
         DSGEModel.MarginalLikelihoodValue = get(controls.dsge.marginallikelihood,'Value');
         if (DSGEModel.PosteriorSampler==2)&(DSGEModel.MarginalLikelihoodValue==4);
            txt = 'You have selected that only the Chib and Jeliazkov algorithm should be used for computing the marginal likelihood, yet your current choice for posterior sampling is the slice sampler. Please keep in mind that the Chib and Jeliazkov estimator is only intended for Metropolis-Hastings samplers and will therefore not be used under the slice sampler.';
            About(txt,'information','Marginal Likelihood Algorithm',300,500,CurrINI);
         end;
      else;
         set(controls.dsge.marginallikelihood,'Value',DSGEModel.MarginalLikelihoodValue);
      end;
   case 'coverageprobability'
      if get(controls.about,'UserData')==0;
         DSGEModel.CoverageStart = get(controls.dsge.coveragestart,'Value');
         DSGEModel.CoverageIncrement = get(controls.dsge.coverageincrement,'Value');
         DSGEModel.CoverageEnd = get(controls.dsge.coverageend,'Value');
      else;
         set(controls.dsge.coveragestart,'Value',DSGEModel.CoverageStart);
         set(controls.dsge.coverageincrement,'Value',DSGEModel.CoverageIncrement);
         set(controls.dsge.coverageend,'Value',DSGEModel.CoverageEnd);
      end;
   case 'sequentialml'
      if get(controls.about,'UserData')==0;
         DSGEModel.SequentialML = get(controls.dsge.sequentialml,'Value');
      else;
         set(controls.dsge.sequentialml,'Value',DSGEModel.SequentialML);
      end;
   case 'overwritedraws'
      if get(controls.about,'UserData')==0;
         DSGEModel.OverwriteDraws = get(controls.dsge.overwritedraws,'Value');
      else;
         set(controls.dsge.overwritedraws,'Value',DSGEModel.OverwriteDraws);
      end;
   case 'showprogress'
      if get(controls.about,'UserData')==0;
         DSGEModel.ShowProgress = get(controls.dsge.progress,'Value');
      else;
         set(controls.dsge.progress,'Value',DSGEModel.ShowProgress);
      end;
      if DSGEModel.ShowProgress==1;
         set(controls.dsge.progressclock,'Enable','on');
      else;
         set(controls.dsge.progressclock,'Enable','off');
      end;
   case 'useowninitialstate'
      if get(controls.about,'UserData')==0;
         DSGEModel.UseOwnInitialState = get(controls.dsge.useowninitialstate,'Value');
      else;
         set(controls.dsge.useowninitialstate,'Value',DSGEModel.UseOwnInitialState);
      end;
   case 'allowunitroot'
      if get(controls.about,'UserData')==0;
         DSGEModel.AllowUnitRoot = get(controls.dsge.allowunitroot,'Value');
         if (DSGEModel.AllowUnitRoot==1)&(DSGEModel.KalmanAlgorithm==4);
            DSGEModel.KalmanAlgorithm = 1;
            set(controls.dsge.kalmanalgorithm,'Value',DSGEModel.KalmanAlgorithm);
            txt = 'The Chandrasekhar recursions require that: (1) There are no unit roots in the model; (2) The filter is initialized with the steady-state covariance matrix; (3) There are no missing observations; and (4) The selection matrix H in the measurement equation is constant over time. Your settings, data, or model violates these conditions.';
            About(txt,'information','Chandrasekhar Recursion Requirements',250,550,CurrINI);
         end;
      else;
         set(controls.dsge.allowunitroot,'Value',DSGEModel.AllowUnitRoot);
      end;
   case 'initializekalman'
      if get(controls.about,'UserData')==0;
         DSGEModel.KalmanFirstObservation = get(controls.dsge.initializekalman,'Value');
      else;
         set(controls.dsge.initializekalman,'Value',DSGEModel.KalmanFirstObservation);
      end;
   case 'kalmanalgorithm'
      if get(controls.about,'UserData')==0;
         if get(controls.dsge.kalmanalgorithm,'Value')~=4;
            DSGEModel.KalmanAlgorithm = get(controls.dsge.kalmanalgorithm,'Value');
         else;
            if (isempty(DSGEModel.UnitRootStates)==0)|(DSGEModel.AllowUnitRoot==1)|(DSGEModel.UseDoublingAlgorithm>=3)|(DSGEModel.YNaNs==1)|(CheckHMatrix(DSGEModel,CurrINI)==0);
               set(controls.dsge.kalmanalgorithm,'Value',DSGEModel.KalmanAlgorithm);
               txt = 'The Chandrasekhar recursions require that: (1) There are no unit roots in the model; (2) The filter is initialized with the steady-state covariance matrix; (3) There are no missing observations; and (4) The selection matrix H in the measurement equation is constant over time. Your settings, data, or model violates these conditions.';
               About(txt,'information','Chandrasekhar Recursion Requirements',250,550,CurrINI);
            else;
               DSGEModel.KalmanAlgorithm = 4;
            end;
         end;
      else;
         set(controls.dsge.kalmanalgorithm,'Value',DSGEModel.KalmanAlgorithm);
      end;
   case 'aimtolerance'
      if get(controls.about,'UserData')==0;
         DSGEModel.AIMTolerance = get(controls.dsge.aimtolerance,'Value')+1;
      else;
         set(controls.dsge.aimtolerance,'Value',DSGEModel.AIMTolerance-1);
      end;
   case 'doublingalgorithm'
      if get(controls.about,'UserData')==0;
         DSGEModel.DAMaximumIterationsValue = get(controls.dsge.doublingalgorithm,'Value');
      else;
         set(controls.dsge.doublingalgorithm,'Value',DSGEModel.DAMaximumIterationsValue);
      end;
   case 'predpaths'
      if get(controls.about,'UserData')==0;
         DSGEModel.NumPredPathsValue = get(controls.forecast.predpaths,'Value');
      else;
         set(controls.forecast.predpaths,'Value',DSGEModel.NumPredPathsValue);
      end;
   case 'shockcontrol'
      if get(controls.about,'UserData')==0;
         if (get(controls.forecast.shockcontrol,'Value')~=3)|((isfield(controls,'setconditionalshocksmixed')==1)&(strcmp(get(controls.setconditionalshocksmixed,'Enable'),'off')==0))|((isfield(controls,'setstateconditionalshocksmixed')==1)&(strcmp(get(controls.setstateconditionalshocksmixed,'Enable'),'off')==0));
            DSGEModel.ShockControlMethod = get(controls.forecast.shockcontrol,'Value');
         else;
            set(controls.forecast.shockcontrol,'Value',DSGEModel.ShockControlMethod);
         end;
      else;
         set(controls.forecast.shockcontrol,'Value',DSGEModel.ShockControlMethod);
      end;
   case 'maxforecasthorizon'
      if get(controls.about,'UserData')==0;
         DSGEModel.MaxForecastHorizon = get(controls.forecast.maxhorizon,'Value');
      else;
         set(controls.forecast.maxhorizon,'Value',DSGEModel.MaxForecastHorizon);
      end;
   case 'riccati_maximumiterations'
      if get(controls.about,'UserData')==0;
         DSGEModel.RiccatiMaxIterations = get(controls.tools.riccatiiteration,'Value');
      else;
         set(controls.tools.riccatiiteration,'Value',DSGEModel.RiccatiMaxIterations);
      end;
   case 'maximumiterations'
      if get(controls.about,'UserData')==0;
         DSGEModel.OptMaxIterationsValue = get(controls.optimize.maximumiterations,'Value');
      else;
         set(controls.optimize.maximumiterations,'Value',DSGEModel.OptMaxIterationsValue);
      end;
   case 'tolerance'
      if get(controls.about,'UserData')==0;
         DSGEModel.OptToleranceValue = get(controls.optimize.tolerance,'Value');
      else;
         set(controls.optimize.tolerance,'Value',DSGEModel.OptToleranceValue);
      end;
   case 'statecov'
      if get(controls.about,'UserData')==0;
         DSGEModel.StateCovConst = get(controls.dsge.statecovariance,'Value');
         StateCStr = get(controls.dsge.statecovariance,'String');
         DSGEModel.StateCovConstValue = str2num(strrep(StringTrim(StateCStr(DSGEModel.StateCovConst,:)),',',''));
      else;
         set(controls.dsge.statecovariance,'Value',DSGEModel.StateCovConst);
      end;
   case 'da_tolerance'
      if get(controls.about,'UserData')==0;
         DSGEModel.DAToleranceValue = get(controls.dsge.doublingtolerance,'Value');
      else;
         set(controls.dsge.doublingtolerance,'Value',DSGEModel.DAToleranceValue);
      end;
   case 'riccati_tolerance'
      if get(controls.about,'UserData')==0;
         DSGEModel.RiccatiToleranceValue = get(controls.tools.riccatitolerance,'Value');
      else;
         set(controls.tools.riccatitolerance,'Value',DSGEModel.RiccatiToleranceValue);
      end;
   case 'randomweight'
      if get(controls.about,'UserData')==0;
         DSGEModel.RandomWeightValue = get(controls.posterior.randomweight,'Value');
      else;
         set(controls.posterior.randomweight,'Value',DSGEModel.RandomWeightValue);
      end;
   case 'scalefactor'
      if get(controls.about,'UserData')==0;
         DSGEModel.MHScaleFactor = get(controls.posterior.scalefactor,'Value');
      else;
         set(controls.posterior.scalefactor,'Value',DSGEModel.MHScaleFactor);
      end;
   case 'initialscalefactor'
      if get(controls.about,'UserData')==0;
         DSGEModel.MHInitialScaleFactor = get(controls.posterior.initialscale,'Value');
      else;
         set(controls.posterior.initialscale,'Value',DSGEModel.MHInitialScaleFactor);
      end;
   case 'resamplingthreshold'
      if get(controls.about,'UserData')==0;
         DSGEModel.ResamplingThresholdValue = get(controls.posterior.resamplingthreshold,'Value');
      else;
         set(controls.posterior.resamplingthreshold,'Value',DSGEModel.ResamplingThresholdValue);
      end;
   case 'resamplingalgorithm'
      if get(controls.about,'UserData')==0;
         DSGEModel.ResamplingAlgorithm = get(controls.posterior.resamplingalgorithm,'Value');
      else;
         set(controls.posterior.resamplingalgorithm,'Value',DSGEModel.ResamplingAlgorithm);
      end;
   case 'targetacceptancerate'
      if get(controls.about,'UserData')==0;
         DSGEModel.TargetAcceptanceRateValue = get(controls.posterior.targetacceptancerate,'Value');
      else;
         set(controls.posterior.targetacceptancerate,'Value',DSGEModel.TargetAcceptanceRateValue);
      end;
   case 'smcinitialscalefactor'
      if get(controls.about,'UserData')==0;
         DSGEModel.SMCInitialScaleFactor = get(controls.posterior.smcinitialscale,'Value');
      else;
         set(controls.posterior.smcinitialscale,'Value',DSGEModel.SMCInitialScaleFactor);
      end;
   case 'smcmhsteps'
      if get(controls.about,'UserData')==0;
         DSGEModel.SMCNumMHSteps = get(controls.posterior.smcmhsteps,'Value');
      else;
         set(controls.posterior.smcmhsteps,'Value',DSGEModel.SMCNumMHSteps);
      end;
   case 'ismaxmixcomp'
      if get(controls.about,'UserData')==0;
         DSGEModel.ISMaxMixCompValue = get(controls.posterior.ismaxmixcomp,'Value');
      else;
         set(controls.posterior.ismaxmixcomp,'Value',DSGEModel.ISMaxMixCompValue);
      end;
   case 'isinitialdf'
      if get(controls.about,'UserData')==0;
         DSGEModel.ISInitialDF = get(controls.posterior.isinitialdf,'Value');
      else;
         set(controls.posterior.isinitialdf,'Value',DSGEModel.ISInitialDF);
      end;
   case 'isweightshare'
      if get(controls.about,'UserData')==0;
         DSGEModel.ISWeightShareValue = get(controls.posterior.isweightshare,'Value');
      else;
         set(controls.posterior.isweightshare,'Value',DSGEModel.ISWeightShareValue);
      end;
   case 'isaddedmixweight'
      if get(controls.about,'UserData')==0;
         DSGEModel.ISAddedMixWeightValue = get(controls.posterior.isaddedmixweight,'Value');
      else;
         set(controls.posterior.isaddedmixweight,'Value',DSGEModel.ISAddedMixWeightValue);
      end;
   case 'isaddeddf'
      if get(controls.about,'UserData')==0;
         DSGEModel.ISAddedDF = get(controls.posterior.isaddeddf,'Value');
      else;
         set(controls.posterior.isaddeddf,'Value',DSGEModel.ISAddedDF);
      end;
   case 'numparamblocks'
      if get(controls.about,'UserData')==0;
         m = 100;
         if VerifyPosteriorModeEstimation(DSGEModel)==1;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames] = InitializeDSGEModelSimulation(DSGEModel,CurrINI,0);
            if InitStatus==1;
               m = length(theta);
            end;
         end;
         NumParamBlocks = get(controls.posterior.numparamblocks,'Value');
         if m>=NumParamBlocks;
            DSGEModel.NumParamBlocks = get(controls.posterior.numparamblocks,'Value');
         else;
            txt = ['The number of parameter blocks that you have selected (' int2str(NumParamBlocks) ') for the mutation step of the SMC with likelihood tempering algorithm is greater than the number of model parameters (' int2str(m) '). Please select another value.'];
            About(txt,'information','Number Of Parameter Parameter Blocks',300,600,CurrINI);
            set(controls.posterior.numparamblocks,'Value',DSGEModel.NumParamBlocks);
         end;
      else;
         set(controls.posterior.numparamblocks,'Value',DSGEModel.NumParamBlocks);
      end;
   case 'invhessian'
      if get(controls.about,'UserData')==0;
         CurrValue = get(controls.posterior.invhessian,'Value');
         if CurrValue<=3;
            DSGEModel.InverseHessianEstimator = CurrValue;
         else;
            %
            % user wants to use own covariance matrix estimator
            %
            if FileExist(DSGEModel.ParameterCovMatrix)==1;
               ParameterCovMatrix = DSGEModel.ParameterCovMatrix;
            else;
               %
               % suggest a mat-file and check if it exists
               %
               BurninStr = get(controls.posterior.burnin,'String');
               NumBurnin = str2num(strrep(StringTrim(BurninStr(DSGEModel.BurnInValue,:)),',',''));
               %
               DrawsStr = get(controls.posterior.draws,'String');
               NumDraws = str2num(StringTrim(strrep(DrawsStr(DSGEModel.PosteriorDrawsValue,:),',','')));
               %
               ParameterCovMatrix = FixFilePath([DSGEModel.OutputDirectory '\' DSGEModel.NameOfModel '-EstParamCovarianceMatrix-' int2str(NumBurnin) '.' int2str(NumDraws) '.1.mat']);
               if FileExist(ParameterCovMatrix)==0;
                  if MatlabNumber>=6;
                     ParameterCovMatrix = '';
                  else;
                     ParameterCovMatrix = FixFilePath([pwd '\*.mat']);
                  end;
               end;
            end;
            %
            % select the file
            %
            if MatlabNumber>=6;
               FileType = {'*.mat', 'Matlab MAT-Files (*.mat)'};
               [FileName,FilePath] = uigetfile(FileType,'Parameter Covariance Matrix - Select File',ParameterCovMatrix);
            else;
               [FileName,FilePath] = uigetfile(ParameterCovMatrix,'Parameter Covariance Matrix - Select File');
            end;
            drawnow;
            pause(0.02);
            %
            if (isnumeric(FileName)==0)&(isunix==1);
               if strcmp(FilePath(1,length(FilePath)),'/')==0;
                  FilePath = [FilePath '/'];
               end;
            end;
            SelectedFile = [FilePath FileName];
            if (isnumeric(FileName)==0)&(FileExist(SelectedFile)==1);
               if strcmp(lower(GetExt(SelectedFile)),'.mat')==1;
                  %
                  % check if the file has the required field.
                  %
                  DataTest = load(SelectedFile);
                  if isfield(DataTest,'ParameterCovarianceMatrix')==1;
                     DSGEModel.ParameterCovMatrix = SelectedFile;
                     DSGEModel.InverseHessianEstimator = CurrValue;
                     set(controls.posterior.invhessian,'String',['Output from optimization routine|Fit quadratic to evaluated log posterior|Finite difference|My estimate ("' GetName(DSGEModel.ParameterCovMatrix) '")']);
                  else;
                     set(controls.posterior.invhessian,'Value',DSGEModel.InverseHessianEstimator);
                     txt = ['The file you selected "' GetFilename(SelectedFile) '" doesn''t have a variable called "ParameterCovarianceMatrix". YADA is therefore unable to accept the data.'];
                     About(txt,'information','Parameter Covariance Matrix - Bad Data',200,500,CurrINI);
                  end;
               else;
                  %
                  % bad file format
                  %
                  set(controls.posterior.invhessian,'Value',DSGEModel.InverseHessianEstimator);
                  txt = ['YADA requires that the file with the parameter covariance matrix is a mat-file. The one you selected "' GetFilename(SelectedFile) '" is not.'];
                  About(txt,'information','Parameter Covariance Matrix - Bad Format',200,500,CurrINI);
               end;
            else;
               set(controls.posterior.invhessian,'Value',DSGEModel.InverseHessianEstimator);
            end;
         end;
      else;
         set(controls.posterior.invhessian,'Value',DSGEModel.InverseHessianEstimator);
      end;
   case 'maxhesscorrelation'
      if get(controls.about,'UserData')==0;
         DSGEModel.MaxCorrelationValue = get(controls.posterior.maxcorrelation,'Value');
      else;
         set(controls.posterior.maxcorrelation,'Value',DSGEModel.MaxCorrelationValue);
      end;
   case 'mixeddistweight'
      if get(controls.about,'UserData')==0;
         DSGEModel.MixedDistWeightValue = get(controls.posterior.mixeddistweight,'Value');
      else;
         set(controls.posterior.mixeddistweight,'Value',DSGEModel.MixedDistWeightValue);
      end;
   case 'covtolerance'
      if get(controls.about,'UserData')==0;
         DSGEModel.CoVToleranceValue = get(controls.posterior.covtolerance,'Value');
      else;
         set(controls.posterior.covtolerance,'Value',DSGEModel.CoVToleranceValue);
      end;
   case 'temperinglambda'
      if get(controls.about,'UserData')==0;
         DSGEModel.TemperingLambdaValue = get(controls.posterior.temperinglambda,'Value');
      else;
         set(controls.posterior.temperinglambda,'Value',DSGEModel.TemperingLambdaValue);
      end;
   case 'burnin'
      if get(controls.about,'UserData')==0;
         TmpValue = get(controls.posterior.burnin,'Value');
         if TmpValue<142;
            DSGEModel.BurnInValue = TmpValue;
            if isempty(DSGEModel.BurnIn)==0;
               DSGEModel.BurnIn = [];
               DrawsStr = cellstr(get(controls.posterior.burnin,'String'));
               DrawsStr{142} = 'Other';
               set(controls.posterior.burnin,'String',char(DrawsStr));
            end;
         else;
            RunEdit = 1;
            while RunEdit==1;
               [action,ResStr] = EditDLG('Burnin Draws Selection','Select the number of burnin draws:',int2str(DSGEModel.BurnIn),500,CurrINI);
               if strcmp(lower(action),'ok')==1;
                  ResStr = strrep(ResStr,',','');
                  TmpBI = str2num(ResStr);
                  if (IsInteger(TmpBI)==1)&(TmpBI>=0);
                     if IsInteger(TmpBI/100)==1;
                        DSGEModel.BurnInValue = TmpValue;
                        DSGEModel.BurnIn = TmpBI;
                        %
                        % change the DrawsStr
                        %
                        DrawsStr = cellstr(get(controls.posterior.burnin,'String'));
                        DrawsStr{142} = int2str(DSGEModel.BurnIn);
                        set(controls.posterior.burnin,'String',char(DrawsStr));
                        RunEdit = 0;
                     else;
                        txt = 'YADA requires that the number of burnin draws divided by 100 is an integer. This means that you must select 0 or, when positive, at least 100 burnin draws and the number must end with at least two zeros.';
                        About(txt,'information','Burnin Draws Selection',300,500,CurrINI);
                     end;
                  else;
                     txt = ['YADA requires that the number of burnin draws is a nonnegative integer. You selected ' num2str(TmpBI) '. Please select another value.'];
                     About(txt,'information','Burnin Draws Selection',200,500,CurrINI);
                  end;
               else;
                  RunEdit = 0;
                  set(controls.posterior.burnin,'Value',DSGEModel.BurnInValue);
               end;
            end;
         end;
      else;
         set(controls.posterior.burnin,'Value',DSGEModel.BurnInValue);
      end;
   case 'parallelchains'
      if get(controls.about,'UserData')==0;
         DSGEModel.ParallelChainsValue = get(controls.posterior.chains,'Value');
      else;
         set(controls.posterior.chains,'Value',DSGEModel.ParallelChainsValue);
      end;
   case 'samplebatches'
      if get(controls.about,'UserData')==0;
         DSGEModel.SampleBatchValue = get(controls.posterior.batch,'Value');
      else;
         set(controls.posterior.batch,'Value',DSGEModel.SampleBatchValue);
      end;
   case 'temperingstages'
      if get(controls.about,'UserData')==0;
         DSGEModel.TemperingStagesValue = get(controls.posterior.temperingstages,'Value');
      else;
         set(controls.posterior.temperingstages,'Value',DSGEModel.TemperingStagesValue);
      end;
   case 'usepostdraws'
      if get(controls.about,'UserData')==0;
         DSGEModel.PostDrawsPercentValue = get(controls.posterior.usepostdraws,'Value');
      else;
         set(controls.posterior.usepostdraws,'Value',DSGEModel.PostDrawsPercentValue);
      end;
   case 'postdrawsusage'
      if get(controls.about,'UserData')==0;
         DSGEModel.PostDrawsUsageValue = get(controls.posterior.postdrawsusage,'Value');
      else;
         set(controls.posterior.postdrawsusage,'Value',DSGEModel.PostDrawsUsageValue);
      end;
   case 'posteriorsampler'
      if get(controls.about,'UserData')==0;
         OldPosteriorSampler = DSGEModel.PosteriorSampler;
         DSGEModel.PosteriorSampler = get(controls.posterior.posteriorsampler,'Value');
         if (DSGEModel.PosteriorSampler==2)&(DSGEModel.MarginalLikelihoodValue==4);
            txt = 'You have selected to use the slice sampler for posterior sampling, yet your current choice for computing the marginal likelihood is the Chib and Jeliazkov algorithm. Please keep in mind that the Chib and Jeliazkov estimator is only intended for Metropolis-Hastings samplers and will therefore not be used under the slice sampler.';
            About(txt,'information','Posterior Sampler',300,500,CurrINI);
         end;
         EnableTxt = 'on';
         StringTxt = 'Resampling threshold of the effective sample size (selection step):';
         if DSGEModel.PosteriorSampler<3;
            DSGEModel.StudenttDegFree = [];
            DSGEModel.FixedNumParamBlocks = [];
            DSGEModel.BlockSize = [];
            set(controls.posterior.posteriorsampler,'String','Random Walk Metropolis, normal proposal|Slice sampler|Random Walk Metropolis, t proposal|Fixed block RWM, normal proposal|Fixed block RWM, t proposal|Random block RWM, normal proposal|Random block RWM, t proposal|Sequential Monte Carlo, likelihood tempering|Sequential Monte Carlo, data tempering|Importance sampling based on MitISEM');
         elseif DSGEModel.PosteriorSampler==3;
            %
            % need to select the number of degrees of freedom.
            %
            [action,OutValue] = EditDLG('Random Walk Metropolis - Student-t Proposal Density','Select the number of degrees of freedom',int2str(DSGEModel.StudenttDegFree),600,CurrINI);
            drawnow;
            if strcmp(lower(action),'ok')==1;
               OutValue = str2num(StringTrim(OutValue));
               if isempty(OutValue)==0;
                  if (IsInteger(OutValue)==1)&(OutValue>0)&(isinf(OutValue)==0);
                     DSGEModel.StudenttDegFree = OutValue;
                     DSGEModel.FixedNumParamBlocks = [];
                     DSGEModel.BlockSize = [];
                     set(controls.posterior.posteriorsampler,'String',['Random Walk Metropolis, normal proposal|Slice sampler|Random Walk Metropolis, t proposal, ' int2str(DSGEModel.StudenttDegFree) ' df|Fixed block RWM, normal proposal|Fixed block RWM, t proposal|Random block RWM, normal proposal|Random block RWM, t proposal|Sequential Monte Carlo, likelihood tempering|Sequential Monte Carlo, data tempering|Importance sampling based on MitISEM']);
                  else;
                     txt = 'You must choose a finite, positive integer value for the number of degrees of freedom of the Student-t proposal density. YADA keeps your old selection.';
                     About(txt,'information','Posterior Sampler',300,500,CurrINI);
                     DSGEModel.PosteriorSampler = OldPosteriorSampler;
                     set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
                  end;
               else;
                  txt = 'You haven''t selected the number of degrees of freedom properly for use with the Student-t proposal density. YADA keeps your old selection.';
                  About(txt,'information','Posterior Sampler',300,500,CurrINI);
                  DSGEModel.PosteriorSampler = OldPosteriorSampler;
                  set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
               end;
            else;
               DSGEModel.PosteriorSampler = OldPosteriorSampler;
               set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
            end;
         elseif DSGEModel.PosteriorSampler==4;
            %
            % the fixed blocking RWM algorithm with a normal proposal
            %
            m = 100;
            if VerifyPosteriorModeEstimation(DSGEModel)==1;
               [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames] = InitializeDSGEModelSimulation(DSGEModel,CurrINI,0);
               if InitStatus==1;
                  m = length(theta);
               end;
            end;
            if isempty(DSGEModel.FixedNumParamBlocks)==0;
               NumBlocks = DSGEModel.FixedNumParamBlocks;
            else;
               NumBlocks = min(3,m);
            end;
            [action,NewNumBlocks] = EditDLG('Fixed Block RWM - Normal Proposal Density','Select the number of blocks',int2str(NumBlocks),600,CurrINI);
            drawnow;
            if strcmp(lower(action),'ok')==1;
               NewNumBlocks = str2num(StringTrim(NewNumBlocks));
               if isempty(NewNumBlocks)==0;
                  if (IsInteger(NewNumBlocks)==1)&(NewNumBlocks>=2)&(NewNumBlocks<=m);
                     DSGEModel.FixedNumParamBlocks = NewNumBlocks;
                     DSGEModel.StudenttDegFree = [];
                     DSGEModel.BlockSize = [];
                     set(controls.posterior.posteriorsampler,'String',['Random Walk Metropolis, normal proposal|Slice sampler|Random Walk Metropolis, t proposal|' int2str(DSGEModel.FixedNumParamBlocks) ' block RWM, normal proposal|Fixed block RWM, t proposal|Random block RWM, normal proposal|Random block RWM, t proposal|Sequential Monte Carlo, likelihood tempering|Sequential Monte Carlo, data tempering|Importance sampling based on MitISEM']);
                  else;
                     txt = ['You must choose a positive integer value at least equal to 2 and no greater than ' int2str(m) ' for the number of fixed parameter blocks for use with the normal proposal density. YADA keeps your old selection.'];
                     About(txt,'information','Posterior Sampler',300,500,CurrINI);
                     DSGEModel.PosteriorSampler = OldPosteriorSampler;
                     set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
                  end;
               else;
                  txt = 'You haven''t selected the number of fixed parameter blocks for use with the normal proposal density. YADA keeps your old selection.';
                  About(txt,'information','Posterior Sampler',300,500,CurrINI);
                  DSGEModel.PosteriorSampler = OldPosteriorSampler;
                  set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
               end;
            else;
               DSGEModel.PosteriorSampler = OldPosteriorSampler;
               set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
            end;
         elseif DSGEModel.PosteriorSampler==5;
            %
            % the fixed blocking RWM algorithm with a normal proposal
            %
            m = 100;
            if VerifyPosteriorModeEstimation(DSGEModel)==1;
               [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames] = InitializeDSGEModelSimulation(DSGEModel,CurrINI,0);
               if InitStatus==1;
                  m = length(theta);
               end;
            end;
            if isempty(DSGEModel.FixedNumParamBlocks)==0;
               NumBlocks = DSGEModel.FixedNumParamBlocks;
            else;
               NumBlocks = min(3,m);
            end;
            [action,NewNumBlocks] = EditDLG('Fixed Block RWM - Student-t Proposal Density','Select the number of blocks',int2str(NumBlocks),600,CurrINI);
            drawnow;
            if strcmp(lower(action),'ok')==1;
               NewNumBlocks = str2num(StringTrim(NewNumBlocks));
               if isempty(NewNumBlocks)==0;
                  if (IsInteger(NewNumBlocks)==1)&(NewNumBlocks>=2)&(NewNumBlocks<=m);
                     %
                     % the selected number of blocks is Kosher
                     % now select the number of degrees of freedom
                     %
                     [action,OutValue] = EditDLG('Fixed Block RWM - Student-t Proposal Density','Select the number of degrees of freedom',int2str(DSGEModel.StudenttDegFree),600,CurrINI);
                     drawnow;
                     if strcmp(lower(action),'ok')==1;
                        OutValue = str2num(StringTrim(OutValue));
                        if isempty(OutValue)==0;
                           if (IsInteger(OutValue)==1)&(OutValue>0)&(isinf(OutValue)==0);
                              DSGEModel.StudenttDegFree = OutValue;
                              DSGEModel.FixedNumParamBlocks = NewNumBlocks;
                              DSGEModel.BlockSize = [];
                              set(controls.posterior.posteriorsampler,'String',['Random Walk Metropolis, normal proposal|Slice sampler|Random Walk Metropolis, t proposal|Fixed block RWM, normal proposal|' int2str(DSGEModel.FixedNumParamBlocks) ' block RWM, t proposal, ' int2str(DSGEModel.StudenttDegFree) ' df|Random block RWM, normal proposal|Random block RWM, t proposal|Sequential Monte Carlo, likelihood tempering|Sequential Monte Carlo, data tempering|Importance sampling based on MitISEM']);
                           else;
                              txt = 'You must choose a finite, positive integer value for the number of degrees of freedom of the Student-t proposal density. YADA keeps your old selection.';
                              About(txt,'information','Posterior Sampler',300,500,CurrINI);
                              DSGEModel.PosteriorSampler = OldPosteriorSampler;
                              set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
                           end;
                        else;
                           txt = 'You haven''t selected the number of degrees of freedom properly for use with the Student-t proposal density. YADA keeps your old selection.';
                           About(txt,'information','Posterior Sampler',300,500,CurrINI);
                           DSGEModel.PosteriorSampler = OldPosteriorSampler;
                           set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
                        end;
                     else;
                        DSGEModel.PosteriorSampler = OldPosteriorSampler;
                        set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
                     end;
                  else;
                     txt = ['You must choose a positive integer value at least equal to 2 and no greater than ' int2str(m) ' for the number of fixed parameter blocks for use with the Student-t proposal density. YADA keeps your old selection.'];
                     About(txt,'information','Posterior Sampler',300,500,CurrINI);
                     DSGEModel.PosteriorSampler = OldPosteriorSampler;
                     set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
                  end;
               else;
                  txt = 'You haven''t selected the number of fixed parameter blocks for use with the Student-t proposal density. YADA keeps your old selection.';
                  About(txt,'information','Posterior Sampler',300,500,CurrINI);
                  DSGEModel.PosteriorSampler = OldPosteriorSampler;
                  set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
               end;
            else;
               DSGEModel.PosteriorSampler = OldPosteriorSampler;
               set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
            end;
         elseif DSGEModel.PosteriorSampler==6;
            %
            % the random blocking RWM algorithm with a normal proposal
            %
            m = 100;
            if VerifyPosteriorModeEstimation(DSGEModel)==1;
               [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames] = InitializeDSGEModelSimulation(DSGEModel,CurrINI,0);
               if InitStatus==1;
                  m = length(theta);
               end;
            end;
            if isempty(DSGEModel.BlockSize)==0;
               BlockSize = DSGEModel.BlockSize;
            else;
               BlockSize = [1 min(5,m)];
            end;
            %
            % now display a selection dialog for the upper and lower limits
            %
            TextStr{1} = int2str(BlockSize(1));
            TextStr{2} = int2str(BlockSize(2));
            EditTitle{1} = 'Lower Limit:';
            EditTitle{2} = 'Upper Limit:';
            [action,OutTextStr] = TwoSelectionsDlg('Random Block RWM - Normal Proposal Density',EditTitle,TextStr,600,CurrINI);
            drawnow;
            if strcmp(lower(action),'ok')==1;
               BlockSizeOne = str2num(OutTextStr{1});
               BlockSizeTwo = str2num(OutTextStr{2});
               if (isempty(BlockSizeOne)==0)&(isempty(BlockSizeOne)==0);
                  if (IsInteger(BlockSizeOne)==1)&(BlockSizeOne>=1)&(IsInteger(BlockSizeTwo)==1)&(BlockSizeOne<BlockSizeTwo)&(BlockSizeTwo<=m);
                     DSGEModel.FixedNumParamBlocks = [];
                     DSGEModel.StudenttDegFree = [];
                     DSGEModel.BlockSize = [BlockSizeOne BlockSizeTwo];
                     set(controls.posterior.posteriorsampler,'string',['Random Walk Metropolis, normal proposal|Slice sampler|Random Walk Metropolis, t proposal|Fixed block RWM, normal proposal|Fixed block RWM, t proposal|Random block (' int2str(DSGEModel.BlockSize(1)) ' to ' int2str(DSGEModel.BlockSize(2)) ') RWM, normal proposal|Random block RWM, t proposal|Sequential Monte Carlo, likelihood tempering|Sequential Monte Carlo, data tempering|Importance sampling based on MitISEM']);
                  else;
                     txt = 'You must select positive integer values for the lower and upper limits, such that the lower limit is at least 1, the upper limit is not larger than the number of parameters, and the lower limit is below the upper limit for the number of random blocks for use with the normal proposal density. YADA keeps your old selection.';
                     About(txt,'information','Posterior Sampler',300,500,CurrINI);
                     DSGEModel.PosteriorSampler = OldPosteriorSampler;
                     set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
                  end;
               else;
                  txt = 'You haven''t selected the lower or the upper limit for the number of random blocks for use with the normal proposal density. YADA keeps your old selection.';
                  About(txt,'information','Posterior Sampler',300,500,CurrINI);
                  DSGEModel.PosteriorSampler = OldPosteriorSampler;
                  set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
               end;
            else;
               DSGEModel.PosteriorSampler = OldPosteriorSampler;
               set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
            end;
         elseif DSGEModel.PosteriorSampler==7;
            %
            % the random blocking RWM algorithm with a t proposal
            %
            m = 100;
            if VerifyPosteriorModeEstimation(DSGEModel)==1;
               [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames] = InitializeDSGEModelSimulation(DSGEModel,CurrINI,0);
               if InitStatus==1;
                  m = length(theta);
               end;
            end;
            if isempty(DSGEModel.BlockSize)==0;
               BlockSize = DSGEModel.BlockSize;
            else;
               BlockSize = [1 min(5,m)];
            end;
            %
            % now display a selection dialog for the upper and lower limits
            %
            TextStr{1} = int2str(BlockSize(1));
            TextStr{2} = int2str(BlockSize(2));
            EditTitle{1} = 'Lower Limit:';
            EditTitle{2} = 'Upper Limit:';
            [action,OutTextStr] = TwoSelectionsDlg('Random Block RWM - Student-t Proposal Density',EditTitle,TextStr,600,CurrINI);
            drawnow;
            if strcmp(lower(action),'ok')==1;
               BlockSizeOne = str2num(OutTextStr{1});
               BlockSizeTwo = str2num(OutTextStr{2});
               if (isempty(BlockSizeOne)==0)&(isempty(BlockSizeOne)==0);
                  if (IsInteger(BlockSizeOne)==1)&(BlockSizeOne>=1)&(IsInteger(BlockSizeTwo)==1)&(BlockSizeOne<BlockSizeTwo)&(BlockSizeTwo<=m);
                     %
                     % now the degrees of freedom
                     %
                     [action,OutValue] = EditDLG('Random Block RWM - Student-t Proposal Density','Select the number of degrees of freedom',int2str(DSGEModel.StudenttDegFree),600,CurrINI);
                     drawnow;
                     if strcmp(lower(action),'ok')==1;
                        OutValue = str2num(StringTrim(OutValue));
                        if isempty(OutValue)==0;
                           if (IsInteger(OutValue)==1)&(OutValue>0)&(isinf(OutValue)==0);
                              DSGEModel.StudenttDegFree = OutValue;
                              DSGEModel.FixedNumParamBlocks = [];
                              DSGEModel.BlockSize = [BlockSizeOne BlockSizeTwo];
                              set(controls.posterior.posteriorsampler,'String',['Random Walk Metropolis, normal proposal|Slice sampler|Random Walk Metropolis, t proposal|Fixed block RWM, normal proposal|Fixed block RWM, t proposal|Random block RWM, normal proposal|Random block (' int2str(DSGEModel.BlockSize(1)) ' to ' int2str(DSGEModel.BlockSize(2)) ') RWM, t proposal, ' int2str(DSGEModel.StudenttDegFree) ' df|Sequential Monte Carlo, likelihood tempering|Sequential Monte Carlo, data tempering|Importance sampling based on MitISEM']);
                           else;
                              txt = 'You must choose a finite, positive integer value for the number of degrees of freedom of the Student-t proposal density. YADA keeps your old selection.';
                              About(txt,'information','Posterior Sampler',300,500,CurrINI);
                              DSGEModel.PosteriorSampler = OldPosteriorSampler;
                              set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
                           end;
                        else;
                           txt = 'You haven''t selected the number of degrees of freedom properly for use with the Student-t proposal density. YADA keeps your old selection.';
                           About(txt,'information','Posterior Sampler',300,500,CurrINI);
                           DSGEModel.PosteriorSampler = OldPosteriorSampler;
                           set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
                        end;
                     else;
                        DSGEModel.PosteriorSampler = OldPosteriorSampler;
                        set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
                     end;
                  else;
                     txt = 'You must select positive integer values for the lower and upper limits, such that the lower limit is at least 1, the upper limit is not larger than the number of parameters, and the lower limit is below the upper limit for the number of random blocks for use with the Student-t proposal density. YADA keeps your old selection.';
                     About(txt,'information','Posterior Sampler',300,500,CurrINI);
                     DSGEModel.PosteriorSampler = OldPosteriorSampler;
                     set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
                  end;
               else;
                  txt = 'You haven''t selected the lower or the upper limit for the number of random blocks for use with the Student-t proposal density. YADA keeps your old selection.';
                  About(txt,'information','Posterior Sampler',300,500,CurrINI);
                  DSGEModel.PosteriorSampler = OldPosteriorSampler;
                  set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
               end;
            else;
               DSGEModel.PosteriorSampler = OldPosteriorSampler;
               set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
            end;
         elseif (DSGEModel.PosteriorSampler==8)|(DSGEModel.PosteriorSampler==9);
            DSGEModel.StudenttDegFree = [];
            DSGEModel.FixedNumParamBlocks = [];
            DSGEModel.BlockSize = [];
            %DSGEModel.SampleBatchValue = 1;
            set(controls.posterior.posteriorsampler,'String','Random Walk Metropolis, normal proposal|Slice sampler|Random Walk Metropolis, t proposal|Fixed block RWM, normal proposal|Fixed block RWM, t proposal|Random block RWM, normal proposal|Random block RWM, t proposal|Sequential Monte Carlo, likelihood tempering|Sequential Monte Carlo, data tempering|Importance sampling based on MitISEM');
            %set(controls.posterior.batch,'Value',DSGEModel.SampleBatchValue);
            if DSGEModel.PosteriorSampler==9;
               EnableTxt = 'off';
               StringTxt = 'Recursion threshold of the effective sample size (correction step):';
            end;
         elseif DSGEModel.PosteriorSampler==10;
            %
            % importance sampling case
            %
            DSGEModel.StudenttDegFree = [];
            DSGEModel.FixedNumParamBlocks = [];
            DSGEModel.BlockSize = [];
            set(controls.posterior.posteriorsampler,'String','Random Walk Metropolis, normal proposal|Slice sampler|Random Walk Metropolis, t proposal|Fixed block RWM, normal proposal|Fixed block RWM, t proposal|Random block RWM, normal proposal|Random block RWM, t proposal|Sequential Monte Carlo, likelihood tempering|Sequential Monte Carlo, data tempering|Importance sampling based on MitISEM');
         end;
         %
         % make sure that sampler based controls are shown and hidden depending on the selected algorithm
         %
         if DSGEModel.PosteriorSampler<=7;
            set(controls.posterior.drawstext,'Visible','on');
            set(controls.posterior.batchtext,'Visible','on','Enable','on');
            set(controls.posterior.batch,'Visible','on','Enable','on');
            set(controls.posterior.burnintext,'Visible','on');
            set(controls.posterior.burnin,'Visible','on');
            set(controls.posterior.invhessiantext,'Visible','on');
            set(controls.posterior.invhessian,'Visible','on');
            set(controls.posterior.maxcorrelationtext,'Visible','on');
            set(controls.posterior.maxcorrelation,'Visible','on');
            set(controls.posterior.initialscaletext,'Visible','on');
            set(controls.posterior.initialscale,'Visible','on');
            set(controls.posterior.scalefactortext,'Visible','on');
            set(controls.posterior.scalefactor,'Visible','on');
            set(controls.posterior.randomweighttext,'Visible','on');
            set(controls.posterior.randomweight,'Visible','on');
            set(controls.posterior.usepostdrawstext,'Visible','on');
            set(controls.posterior.usepostdraws,'Visible','on');
            set(controls.posterior.postdrawsusagetext,'Visible','on');
            set(controls.posterior.postdrawsusage,'Visible','on');
            set(controls.posterior.smcdrawstext,'Visible','off');
            set(controls.posterior.temperingstagestext,'Visible','off','Enable','on');
            set(controls.posterior.temperingstages,'Visible','off','Enable','on');
            set(controls.posterior.temperinglambdatext,'Visible','off','Enable','on');
            set(controls.posterior.temperinglambda,'Visible','off','Enable','on');
            set(controls.posterior.numparamblockstext,'Visible','off');
            set(controls.posterior.numparamblocks,'Visible','off');
            set(controls.posterior.smcmhstepstext,'Visible','off');
            set(controls.posterior.smcmhsteps,'Visible','off');
            set(controls.posterior.mixeddistweighttext,'Visible','off');
            set(controls.posterior.mixeddistweight,'Visible','off');
            set(controls.posterior.smcinitialscaletext,'Visible','off');
            set(controls.posterior.smcinitialscale,'Visible','off');
            set(controls.posterior.targetacceptanceratetext,'Visible','off');
            set(controls.posterior.targetacceptancerate,'Visible','off');
            set(controls.posterior.resamplingalgorithmtext,'Visible','off');
            set(controls.posterior.resamplingalgorithm,'Visible','off');
            set(controls.posterior.resamplingthresholdtext,'Visible','off','String',StringTxt);
            set(controls.posterior.resamplingthreshold,'Visible','off');
            set(controls.posterior.covtolerancetext,'Visible','off');
            set(controls.posterior.covtolerance,'Visible','off');
            set(controls.posterior.ismaxmixcomptext,'Visible','off');
            set(controls.posterior.ismaxmixcomp,'Visible','off');
            set(controls.posterior.isinitialdftext,'Visible','off');
            set(controls.posterior.isinitialdf,'Visible','off');
            set(controls.posterior.isweightsharetext,'Visible','off');
            set(controls.posterior.isweightshare,'Visible','off');
            set(controls.posterior.isaddedmixweighttext,'Visible','off');
            set(controls.posterior.isaddedmixweight,'Visible','off');
            set(controls.posterior.isaddeddftext,'Visible','off');
            set(controls.posterior.isaddeddf,'Visible','off');
         elseif (DSGEModel.PosteriorSampler==8)|(DSGEModel.PosteriorSampler==9);
            set(controls.posterior.smcdrawstext,'Visible','on');
            set(controls.posterior.temperingstagestext,'Visible','on','Enable',EnableTxt);
            set(controls.posterior.temperingstages,'Visible','on','Enable',EnableTxt);
            set(controls.posterior.temperinglambdatext,'Visible','on','Enable',EnableTxt);
            set(controls.posterior.temperinglambda,'Visible','on','Enable',EnableTxt);
            set(controls.posterior.numparamblockstext,'Visible','on');
            set(controls.posterior.numparamblocks,'Visible','on');
            set(controls.posterior.smcmhstepstext,'Visible','on');
            set(controls.posterior.smcmhsteps,'Visible','on');
            set(controls.posterior.mixeddistweighttext,'Visible','on');
            set(controls.posterior.mixeddistweight,'Visible','on');
            set(controls.posterior.smcinitialscaletext,'Visible','on');
            set(controls.posterior.smcinitialscale,'Visible','on');
            set(controls.posterior.targetacceptanceratetext,'Visible','on');
            set(controls.posterior.targetacceptancerate,'Visible','on');
            set(controls.posterior.resamplingalgorithmtext,'Visible','on');
            set(controls.posterior.resamplingalgorithm,'Visible','on');
            set(controls.posterior.resamplingthresholdtext,'Visible','on','String',StringTxt);
            set(controls.posterior.resamplingthreshold,'Visible','on');
            set(controls.posterior.drawstext,'Visible','off');
            set(controls.posterior.batchtext,'Visible','off');
            set(controls.posterior.batch,'Visible','off');
            set(controls.posterior.burnintext,'Visible','off');
            set(controls.posterior.burnin,'Visible','off');
            set(controls.posterior.invhessiantext,'Visible','off');
            set(controls.posterior.invhessian,'Visible','off');
            set(controls.posterior.maxcorrelationtext,'Visible','off');
            set(controls.posterior.maxcorrelation,'Visible','off');
            set(controls.posterior.initialscaletext,'Visible','off');
            set(controls.posterior.initialscale,'Visible','off');
            set(controls.posterior.scalefactortext,'Visible','off');
            set(controls.posterior.scalefactor,'Visible','off');
            set(controls.posterior.randomweighttext,'Visible','off');
            set(controls.posterior.randomweight,'Visible','off');
            set(controls.posterior.usepostdrawstext,'Visible','off');
            set(controls.posterior.usepostdraws,'Visible','off');
            set(controls.posterior.postdrawsusagetext,'Visible','off');
            set(controls.posterior.postdrawsusage,'Visible','off');
            set(controls.posterior.covtolerancetext,'Visible','off');
            set(controls.posterior.covtolerance,'Visible','off');
            set(controls.posterior.ismaxmixcomptext,'Visible','off');
            set(controls.posterior.ismaxmixcomp,'Visible','off');
            set(controls.posterior.isinitialdftext,'Visible','off');
            set(controls.posterior.isinitialdf,'Visible','off');
            set(controls.posterior.isweightsharetext,'Visible','off');
            set(controls.posterior.isweightshare,'Visible','off');
            set(controls.posterior.isaddedmixweighttext,'Visible','off');
            set(controls.posterior.isaddedmixweight,'Visible','off');
            set(controls.posterior.isaddeddftext,'Visible','off');
            set(controls.posterior.isaddeddf,'Visible','off');
         elseif DSGEModel.PosteriorSampler==10;
            set(controls.posterior.drawstext,'Visible','on');
            set(controls.posterior.batchtext,'Visible','on','Enable','off');
            set(controls.posterior.batch,'Visible','on','Enable','off');
            set(controls.posterior.covtolerancetext,'Visible','on');
            set(controls.posterior.covtolerance,'Visible','on');
            set(controls.posterior.invhessiantext,'Visible','on');
            set(controls.posterior.invhessian,'Visible','on');
            set(controls.posterior.maxcorrelationtext,'Visible','on');
            set(controls.posterior.maxcorrelation,'Visible','on');
            set(controls.posterior.ismaxmixcomptext,'Visible','on');
            set(controls.posterior.ismaxmixcomp,'Visible','on');
            set(controls.posterior.isinitialdftext,'Visible','on');
            set(controls.posterior.isinitialdf,'Visible','on');
            set(controls.posterior.isweightsharetext,'Visible','on');
            set(controls.posterior.isweightshare,'Visible','on');
            set(controls.posterior.isaddedmixweighttext,'Visible','on');
            set(controls.posterior.isaddedmixweight,'Visible','on');
            set(controls.posterior.isaddeddftext,'Visible','on');
            set(controls.posterior.isaddeddf,'Visible','on');
            set(controls.posterior.burnintext,'Visible','off');
            set(controls.posterior.burnin,'Visible','off');
            set(controls.posterior.initialscaletext,'Visible','off');
            set(controls.posterior.initialscale,'Visible','off');
            set(controls.posterior.scalefactortext,'Visible','off');
            set(controls.posterior.scalefactor,'Visible','off');
            set(controls.posterior.randomweighttext,'Visible','off');
            set(controls.posterior.randomweight,'Visible','off');
            set(controls.posterior.usepostdrawstext,'Visible','off');
            set(controls.posterior.usepostdraws,'Visible','off');
            set(controls.posterior.postdrawsusagetext,'Visible','off');
            set(controls.posterior.postdrawsusage,'Visible','off');
            set(controls.posterior.smcdrawstext,'Visible','off');
            set(controls.posterior.temperingstagestext,'Visible','off','Enable','on');
            set(controls.posterior.temperingstages,'Visible','off','Enable','on');
            set(controls.posterior.temperinglambdatext,'Visible','off','Enable','on');
            set(controls.posterior.temperinglambda,'Visible','off','Enable','on');
            set(controls.posterior.numparamblockstext,'Visible','off');
            set(controls.posterior.numparamblocks,'Visible','off');
            set(controls.posterior.smcmhstepstext,'Visible','off');
            set(controls.posterior.smcmhsteps,'Visible','off');
            set(controls.posterior.mixeddistweighttext,'Visible','off');
            set(controls.posterior.mixeddistweight,'Visible','off');
            set(controls.posterior.smcinitialscaletext,'Visible','off');
            set(controls.posterior.smcinitialscale,'Visible','off');
            set(controls.posterior.targetacceptanceratetext,'Visible','off');
            set(controls.posterior.targetacceptancerate,'Visible','off');
            set(controls.posterior.resamplingalgorithmtext,'Visible','off');
            set(controls.posterior.resamplingalgorithm,'Visible','off');
            set(controls.posterior.resamplingthresholdtext,'Visible','off','String',StringTxt);
            set(controls.posterior.resamplingthreshold,'Visible','off');
         end;
         drawnow;
      else;
         set(controls.posterior.posteriorsampler,'Value',DSGEModel.PosteriorSampler);
      end;
   case 'posteriordraws'
      if get(controls.about,'UserData')==0;
         TmpValue = get(controls.posterior.draws,'Value');
         if TmpValue<174;
            DSGEModel.PosteriorDrawsValue = TmpValue;
            if isempty(DSGEModel.PosteriorDraws)==0;
               DSGEModel.PosteriorDraws = [];
               DrawsStr = cellstr(get(controls.posterior.draws,'String'));
               DrawsStr{174} = 'Other';
               set(controls.posterior.draws,'String',char(DrawsStr));
            end;
         else;
            RunEdit = 1;
            while RunEdit==1;
               [action,ResStr] = EditDLG('Posterior Draws Selection','Select the number of posterior draws to use:',int2str(DSGEModel.PosteriorDraws),500,CurrINI);
               if strcmp(lower(action),'ok')==1;
                  ResStr = strrep(ResStr,',','');
                  TmpPD = str2num(ResStr);
                  if (IsInteger(TmpPD)==1)&(TmpPD>0);
                     if IsInteger(TmpPD/1000)==1;
                        DSGEModel.PosteriorDrawsValue = TmpValue;
                        DSGEModel.PosteriorDraws = TmpPD;
                        %
                        % check if it is consistent with the number of sample batches
                        %
                        if DSGEModel.PosteriorSampler<=7;
                           SBValue = get(controls.posterior.batch,'Value');
                        else;
                           SBValue = 1;
                        end;
                        if IsInteger(TmpPD/SBValue)==0;
                           set(controls.posterior.batch,'Value',1);
                           DSGEModel.SampleBatchValue = 1;
                           txt = ['The number of posterior draws you selected, ' int2str(TmpPD) ', cannot be matched with the number of sample batches, i.e. the ratio "num posterior draws/num sample batches" is not an integer. YADA have therefore set the number of sample batches to 1.'];
                           About(txt,'information','Posterior Draws Selection',200,500,CurrINI);
                        end;
                        %
                        % change the DrawsStr
                        %
                        DrawsStr = cellstr(get(controls.posterior.draws,'String'));
                        DrawsStr{174} = int2str(DSGEModel.PosteriorDraws);
                        set(controls.posterior.draws,'String',char(DrawsStr));
                        RunEdit = 0;
                     else;
                        txt = 'YADA requires that the number of posterior draws divided by 1,000 is an integer. This means that you must select at least 1,000 posterior draws and the number must end with at least three zeros.';
                        About(txt,'information','Posterior Draws Selection',300,500,CurrINI);
                     end;
                  else;
                     txt = ['YADA requires that the number of posterior draws is a positive integer. You selected ' num2str(TmpPD) '. Please select another value.'];
                     About(txt,'information','Posterior Draws Selection',200,500,CurrINI);
                  end;
               else;
                  RunEdit = 0;
                  set(controls.posterior.draws,'Value',DSGEModel.PosteriorDrawsValue);
               end;
            end;
         end;
      else;
         set(controls.posterior.draws,'Value',DSGEModel.PosteriorDrawsValue);
      end;
   case 'irhorizon'
      if get(controls.about,'UserData')==0;
         DSGEModel.IRHorizon = get(controls.tools.irhorizon,'Value');
      else;
         set(controls.tools.irhorizon,'Value',DSGEModel.IRHorizon);
      end;
   case 'randomnumbervalue'
      if get(controls.about,'UserData')==0;
         DSGEModel.RandomNumberValue = get(controls.tools.randomnumber,'Value');
      else;
         set(controls.tools.randomnumber,'Value',DSGEModel.RandomNumberValue);
      end;
   case 'randomizedraws'
      if get(controls.about,'UserData')==0;
         DSGEModel.RandomizeDraws = get(controls.tools.randomizedraws,'Value');
      else;
         set(controls.tools.randomizedraws,'Value',DSGEModel.RandomizeDraws);
      end;
   case 'maxroutine'
      if get(controls.about,'UserData')==0;
         DSGEModel.MaximizeAlgorithmValue = get(controls.optimize.maxroutine,'Value');
      else;
         set(controls.optimize.maxroutine,'Value',DSGEModel.MaximizeAlgorithmValue);
      end;
   case 'hessiansteplength'
      if get(controls.about,'UserData')==0;
         DSGEModel.StepLengthHessian = get(controls.optimize.steplength,'Value');
      else;
         set(controls.optimize.steplength,'Value',DSGEModel.StepLengthHessian);
      end;
   case 'confidencemethod'
      if get(controls.about,'UserData')==0;
         DSGEModel.ConfidenceRegionMethod = get(controls.tools.confidencemethod,'Value');
      else;
         set(controls.tools.confidencemethod,'Value',DSGEModel.ConfidenceRegionMethod);
      end;
   case 'initcsminwel'
      if get(controls.about,'UserData')==0;
         DSGEModel.InitializeHessian = get(controls.optimize.initcsminwel,'Value');
      else;
         set(controls.optimize.initcsminwel,'Value',DSGEModel.InitializeHessian);
      end;
   case 'csminwelextraruns'
      if get(controls.about,'UserData')==0;
         DSGEModel.CsminwelExtraRuns = get(controls.optimize.csminwelextraruns,'Value');
      else;
         set(controls.optimize.csminwelextraruns,'Value',DSGEModel.CsminwelExtraRuns);
      end;
   case 'gridwidth'
      if get(controls.about,'UserData')==0;
         DSGEModel.GridWidth = get(controls.optimize.gridwidth,'Value');
      else;
         set(controls.optimize.gridwidth,'Value',DSGEModel.GridWidth);
      end;
   case 'numbergridpoints'
      if get(controls.about,'UserData')==0;
         DSGEModel.NumberOfGridPoints = get(controls.optimize.numbergridpoints,'Value');
      else;
         set(controls.optimize.numbergridpoints,'Value',DSGEModel.NumberOfGridPoints);
      end;
   case 'finitediffhessian'
      if get(controls.about,'UserData')==0;
         DSGEModel.FiniteDifferenceHessian = get(controls.optimize.finitediffhessian,'Value');
      else;
         set(controls.optimize.finitediffhessian,'Value',DSGEModel.FiniteDifferenceHessian);
      end;
   case 'checkadjustpredictionpaths'
      if get(controls.about,'UserData')==0;
         DSGEModel.AdjustPredictionPaths = get(controls.forecast.adjustpredictionpaths,'Value');
      else;
         set(controls.forecast.adjustpredictionpaths,'Value',DSGEModel.AdjustPredictionPaths);
      end;
   case 'checkksiuseconddata'
      if get(controls.about,'UserData')==0;
         DSGEModel.KsiUseCondData = get(controls.forecast.ksiuseconddata,'Value');
      else;
         set(controls.forecast.ksiuseconddata,'Value',DSGEModel.KsiUseCondData);
      end;
   case 'checkoptimum'
      if get(controls.about,'UserData')==0;
         DSGEModel.CheckOptimum = get(controls.optimize.checkoptimum,'Value');
      else;
         set(controls.optimize.checkoptimum,'Value',DSGEModel.CheckOptimum);
      end;
   case 'checktransformedoptimum'
      if get(controls.about,'UserData')==0;
         DSGEModel.CheckTransformedOptimum = get(controls.optimize.checktransformed,'Value');
      else;
         set(controls.optimize.checktransformed,'Value',DSGEModel.CheckTransformedOptimum);
      end;
   case 'checkmodifiedhessian'
      if get(controls.about,'UserData')==0;
         if DSGEModel.ModifiedHessian==1;
            txt = 'Are you sure you don''t want to scale the estimated conditional standard deviations of the modified inverse Hessian with the correlations from the inverse Hessian at the posterior mode when running the random-walk Metropolis algorithm?';
         else;
            txt = 'Are you sure you want to scale the estimated conditional standard deviations of the modified inverse Hessian with the correlations from the inverse Hessian at the posterior mode when running the random-walk Metropolis algorithm?';
         end;
         answer = Query(txt,'question',200,'Posterior Sampling - Modified Inverse Hessian',500,'no',CurrINI);
         if strcmp(lower(answer),'yes')==1;
            DSGEModel.ModifiedHessian = get(controls.optimize.modifiedhessian,'Value');
         else;
            set(controls.optimize.modifiedhessian,'Value',DSGEModel.ModifiedHessian);
         end;
      else;
         set(controls.optimize.modifiedhessian,'Value',DSGEModel.ModifiedHessian);
      end;
   case 'priorlevelmean'
      if get(controls.about,'UserData')==0;
         DSGEModel.PriorLevelMeanValue = get(controls.bvar.priorlevelmean,'Value');
      else;
         set(controls.bvar.priorlevelmean,'Value',DSGEModel.PriorLevelMeanValue);
      end;
   case 'priordiffmean'
      if get(controls.about,'UserData')==0;
         DSGEModel.PriorDiffMeanValue = get(controls.bvar.priordiffmean,'Value');
      else;
         set(controls.bvar.priordiffmean,'Value',DSGEModel.PriorDiffMeanValue);
      end;
   case 'priortype'
      if get(controls.about,'UserData')==0;
         DSGEModel.PriorType = get(controls.bvar.priortype,'Value');
      else;
         set(controls.bvar.priortype,'Value',DSGEModel.PriorType);
      end;
      if DSGEModel.PriorType~=3;
         set(controls.bvar.priorlevelmeantext,'Enable','on');
         set(controls.bvar.priorlevelmean,'Enable','on');
         set(controls.bvar.priordiffmeantext,'Enable','on');
         set(controls.bvar.priordiffmean,'Enable','on');
         set(controls.bvar.overalltightnesstext,'Enable','on');
         set(controls.bvar.overalltightness,'Enable','on');
         set(controls.bvar.crosseqtightnesstext,'Enable','on');
         set(controls.bvar.crosseqtightness,'Enable','on');
         set(controls.bvar.harmoniclagdecaytext,'Enable','on');
         set(controls.bvar.harmoniclagdecay,'Enable','on');
      else;
         set(controls.bvar.priorlevelmeantext,'Enable','off');
         set(controls.bvar.priorlevelmean,'Enable','off');
         set(controls.bvar.priordiffmeantext,'Enable','off');
         set(controls.bvar.priordiffmean,'Enable','off');
         set(controls.bvar.overalltightnesstext,'Enable','off');
         set(controls.bvar.overalltightness,'Enable','off');
         set(controls.bvar.crosseqtightnesstext,'Enable','off');
         set(controls.bvar.crosseqtightness,'Enable','off');
         set(controls.bvar.harmoniclagdecaytext,'Enable','off');
         set(controls.bvar.harmoniclagdecay,'Enable','off');
      end;
   case 'overalltightness'
      if get(controls.about,'UserData')==0;
         DSGEModel.OverallTightnessValue = get(controls.bvar.overalltightness,'Value');
      else;
         set(controls.bvar.overalltightness,'Value',DSGEModel.OverallTightnessValue);
      end;
   case 'crossequationtightness'
      if get(controls.about,'UserData')==0;
         DSGEModel.CrossEqTightnessValue = get(controls.bvar.crosseqtightness,'Value');
      else;
         set(controls.bvar.crosseqtightness,'Value',DSGEModel.CrossEqTightnessValue);
      end;
   case 'harmoniclagdecay'
      if get(controls.about,'UserData')==0;
         DSGEModel.HarmonicLagDecayValue = get(controls.bvar.harmoniclagdecay,'Value');
      else;
         set(controls.bvar.harmoniclagdecay,'Value',DSGEModel.HarmonicLagDecayValue);
      end;
   case 'bvarlags'
      if get(controls.about,'UserData')==0;
         DSGEModel.BVARLags = get(controls.bvar.lag,'Value');
      else;
         set(controls.bvar.lag,'Value',DSGEModel.BVARLags);
      end;
   case 'stationaryvar'
      if get(controls.about,'UserData')==0;
         DSGEModel.StationaryVAR = get(controls.bvar.stationaryvar,'Value');
      else;
         set(controls.bvar.stationaryvar,'Value',DSGEModel.StationaryVAR);
      end;
   case 'wishartdf'
      if get(controls.about,'UserData')==0;
         DSGEModel.WishartDFValue = get(controls.bvar.wishartdf,'Value');
      else;
         set(controls.bvar.wishartdf,'Value',DSGEModel.WishartDFValue);
      end;
   case 'variancetightness'
      if get(controls.about,'UserData')==0;
         DSGEModel.VarianceTightnessValue = get(controls.bvar.variancetightness,'Value');
      else;
         set(controls.bvar.variancetightness,'Value',DSGEModel.VarianceTightnessValue);
      end;
   case 'wisharttype'
      if get(controls.about,'UserData')==0;
         DSGEModel.WishartType = get(controls.bvar.wisharttype,'Value');
      else;
         set(controls.bvar.wisharttype,'Value',DSGEModel.WishartType);
      end;
      if DSGEModel.WishartType==1;
         %
         % controls to disable
         %
         set(controls.bvar.variancetightnesstext,'Enable','off');
         set(controls.bvar.variancetightness,'Enable','off');
      else;
         %
         % controls to enable
         %
         set(controls.bvar.variancetightnesstext,'Enable','on');
         set(controls.bvar.variancetightness,'Enable','on');
      end;
   case 'omegapriortype'
      if get(controls.about,'UserData')==0;
         DSGEModel.OmegaPriorType = get(controls.bvar.omegapriortype,'Value');
      else;
         set(controls.bvar.omegapriortype,'Value',DSGEModel.OmegaPriorType);
      end;
      if DSGEModel.OmegaPriorType==1;
         %
         % controls to disable
         %
         set(controls.bvar.wisharttypetext,'Enable','off');
         set(controls.bvar.wisharttype,'Enable','off');
         set(controls.bvar.variancetightnesstext,'Enable','off');
         set(controls.bvar.variancetightness,'Enable','off');
         set(controls.bvar.wishartdftext,'Enable','off');
         set(controls.bvar.wishartdf,'Enable','off');
      else;
         %
         % controls to enable
         %
         set(controls.bvar.wisharttypetext,'Enable','on');
         set(controls.bvar.wisharttype,'Enable','on');
         set(controls.bvar.wishartdftext,'Enable','on');
         set(controls.bvar.wishartdf,'Enable','on');
         if DSGEModel.WishartType==1;
            set(controls.bvar.variancetightnesstext,'Enable','off');
            set(controls.bvar.variancetightness,'Enable','off');
         else;
            set(controls.bvar.variancetightnesstext,'Enable','on');
            set(controls.bvar.variancetightness,'Enable','on');
         end;
      end;
   case 'kerneldensity'
      if get(controls.about,'UserData')==0;
         DSGEModel.KernelDensityValue = get(controls.graphics.kerneldensity,'Value');
         DensityEstimators = strvcat('knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
         DSGEModel.KernelDensityEstimator = StringTrim(DensityEstimators(DSGEModel.KernelDensityValue,:));
      else;
         set(controls.graphics.kerneldensity,'Value',DSGEModel.KernelDensityValue);
      end;
   case 'posteriorkerneldensity'
      if get(controls.about,'UserData')==0;
         DSGEModel.PosteriorDensityValue = get(controls.graphics.posteriorkernel,'Value');
      else;
         set(controls.graphics.posteriorkernel,'Value',DSGEModel.PosteriorDensityValue);
      end;
   case 'priorkernel'
      if get(controls.about,'UserData')==0;
         DSGEModel.PriorKernel = get(controls.graphics.priorkernel,'Value');
      else;
         set(controls.graphics.priorkernel,'Value',DSGEModel.PriorKernel);
      end;
      if DSGEModel.PriorKernel==1;
         set(controls.graphics.kerneldensitytext,'Enable','on');
         set(controls.graphics.kerneldensity,'Enable','on');
      else;
         set(controls.graphics.kerneldensitytext,'Enable','off');
         set(controls.graphics.kerneldensity,'Enable','off');
      end;
   case 'browseoutput'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         if MatlabNumber>=6.5;
            %
            % Use the matlab function
            %
            NewDirectory = uigetdir(DSGEModel.OutputDirectory,'Select Base Output Directory');
         else;
            NewDirectory = UIGetDirectory(DSGEModel.OutputDirectory,'Select Base Output Directory',CurrINI);
         end;
         if ischar(NewDirectory)==1;
            %
            % check if the last character is \
            %
            if (ispc==1)&(strcmp(NewDirectory(1,length(NewDirectory)),'\')==1);
               NewDirectory = NewDirectory(1,1:length(NewDirectory)-1);
            elseif (isunix==1)&(strcmp(NewDirectory(1,length(NewDirectory)),'/')==1);
               NewDirectory = NewDirectory(1,1:length(NewDirectory)-1);
            end;
            DSGEModel.OutputDirectory = NewDirectory;
            set(controls.outputdir,'String',DSGEModel.OutputDirectory);
            %
            % check if aim file exists
            %
            if FileExist(DSGEModel.AIMFile)==1;
               AIMDataFile = FixFilePath([DSGEModel.OutputDirectory '\' DSGEModel.NameOfModel '.mat']);
               if FileExist(AIMDataFile)==1;
                  DSGEModel.AIMDataFile = AIMDataFile;
                  StateEnable = 'on';
               else;
                  DSGEModel.AIMDataFile = pwd;
                  StateEnable = 'off';
               end;
               set(controls.statevar,'Enable',StateEnable);
               set(controls.statevarmenu,'Enable',StateEnable);
               set(controls.stateeq,'Enable',StateEnable);
               set(controls.stateeqmenu,'Enable',StateEnable);
               set(controls.stateshock,'Enable',StateEnable);
               set(controls.stateshockmenu,'Enable',StateEnable);
            else;
               DSGEModel.AIMDataFile = pwd;
               set(controls.statevar,'Enable','off');
               set(controls.statevarmenu,'Enable','off');
               set(controls.stateeq,'Enable','off');
               set(controls.stateeqmenu,'Enable','off');
               set(controls.stateshock,'Enable','off');
               set(controls.stateshockmenu,'Enable','off');
            end;
         end;
         set(controls.about,'UserData',0);
      end;
   case 'checkoutput'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         new_dir = StringTrim(get(controls.outputdir,'String'));
         %
         % check if we have a valid directory
         %
         if (strcmp(new_dir,'')==0)|(isempty(new_dir)==1);
            if length(new_dir)>3;
               if (strcmp(new_dir(1,2:3),':\')==1)|(strcmp(new_dir(1,1),'/')==1);
                  if (DirExist(new_dir(1,1:3))==1)|(isunix==1);
                     %
                     % we have a valid drive
                     %
                     if DirExist(new_dir)==0;
                        if ispc==1;
                           stat = dos(['mkdir ' new_dir]);
                        else;
                           stat = unix(['mkdir ' FixFilePath(new_dir)]);
                        end;
                     end;
                     if (ispc==1)&(strcmp(new_dir(1,length(new_dir)),'\')==1);
                        new_dir = new_dir(1,1:length(new_dir)-1);
                     elseif (isunix==1)&(strcmp(new_dir(1,length(new_dir)),'/')==1);
                        new_dir = new_dir(1,1:length(new_dir)-1);
                     end;
                     DSGEModel.OutputDirectory = new_dir;
                     set(controls.outputdir,'String',DSGEModel.OutputDirectory);
                     %
                     % check if aim file exists
                     %
                     if FileExist(DSGEModel.AIMFile)==1;
                        AIMDataFile = FixFilePath([DSGEModel.OutputDirectory '\' DSGEModel.NameOfModel '.mat']);
                        if FileExist(AIMDataFile)==1;
                           DSGEModel.AIMDataFile = AIMDataFile;
                           StateEnable = 'on';
                        else;
                           DSGEModel.AIMDataFile = pwd;
                           StateEnable = 'off';
                        end;
                        set(controls.statevar,'Enable',StateEnable);
                        set(controls.statevarmenu,'Enable',StateEnable);
                        set(controls.stateeq,'Enable',StateEnable);
                        set(controls.stateeqmenu,'Enable',StateEnable);
                        set(controls.stateshock,'Enable',StateEnable);
                        set(controls.stateshockmenu,'Enable',StateEnable);
                     else;
                        DSGEModel.AIMDataFile = pwd;
                        set(controls.statevar,'Enable','off');
                        set(controls.statevarmenu,'Enable','off');
                        set(controls.stateeq,'Enable','off');
                        set(controls.stateeqmenu,'Enable','off');
                        set(controls.stateshock,'Enable','off');
                        set(controls.stateshockmenu,'Enable','off');
                     end;
                  else;
                     set(controls.outputdir,'String',DSGEModel.OutputDirectory);
                  end;
               else;
                  set(controls.outputdir,'String',DSGEModel.OutputDirectory);
               end;
            else;
               set(controls.outputdir,'String',DSGEModel.OutputDirectory);
            end;
         else;
            set(controls.outputdir,'String',DSGEModel.OutputDirectory);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'checksample'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         if DSGEModel.T>0;
            %
            % get the information from the sample selection controls
            %
            subbeginyearstr = get(controls.dsge.subbeginyear,'String');
            subbeginyearvalue = get(controls.dsge.subbeginyear,'Value');
            subbeginperiodvalue = get(controls.dsge.subbeginperiod,'Value');
            subendyearstr = get(controls.dsge.subendyear,'String');
            subendyearvalue = get(controls.dsge.subendyear,'Value');
            subendperiodvalue = get(controls.dsge.subendperiod,'Value');
            %
            % compute the selected sample values
            %
            subbeginyear = floor(str2num(StringTrim(subbeginyearstr(subbeginyearvalue,:))));
            subbeginperiod = subbeginperiodvalue;
            subendyear = floor(str2num(StringTrim(subendyearstr(subendyearvalue,:))));
            subendperiod = subendperiodvalue;
            SubSample = [subbeginyear subbeginperiod subendyear subendperiod];
            %
            % check the sub sample
            %
            if (length(SubSample)==4)&(SubSample(1)<=SubSample(3));
               if strcmp(DSGEModel.DataFrequency,'q')==1;
                  TestSample = (SubSample(1)+(SubSample(2)/4):(1/4):SubSample(3)+(SubSample(4)/4));
                  SubFirstPeriod = SubSample(1)+(SubSample(2)/4);
                  SubLastPeriod = SubSample(3)+(SubSample(4)/4);
                  FirstPeriod = str2num(DSGEModel.BeginYear)+(str2num(DSGEModel.BeginPeriod)/4);
                  LastPeriod = str2num(DSGEModel.EndYear)+(str2num(DSGEModel.EndPeriod)/4);
               elseif strcmp(DSGEModel.DataFrequency,'m')==1;
                  TestSample = (SubSample(1)+(SubSample(2)/12):(1/12):SubSample(3)+(SubSample(4)/12));
                  SubFirstPeriod = SubSample(1)+(SubSample(2)/12);
                  SubLastPeriod = SubSample(3)+(SubSample(4)/12);
                  FirstPeriod = str2num(DSGEModel.BeginYear)+(str2num(DSGEModel.BeginPeriod)/12);
                  LastPeriod = str2num(DSGEModel.EndYear)+(str2num(DSGEModel.EndPeriod)/12);
               else;
                  TestSample = (SubSample(1):1:SubSample(3));
                  SubFirstPeriod = SubSample(1);
                  SubLastPeriod = SubSample(3);
                  FirstPeriod = str2num(DSGEModel.BeginYear);
                  LastPeriod = str2num(DSGEModel.EndYear);
               end;
               %
               % Test if we have a valid sample
               %
               MatchSample = (length(TestSample)>0)&(FirstPeriod<=SubFirstPeriod)&(LastPeriod>=SubLastPeriod);
               if MatchSample==1;
                  %
                  % we can now change the DSGEModel structure information
                  %
                  DSGEModel.SubBeginYear = num2str(subbeginyear);
                  DSGEModel.SubBeginPeriod = num2str(subbeginperiod);
                  DSGEModel.SubEndYear = num2str(subendyear);
                  DSGEModel.SubEndPeriod = num2str(subendperiod);
                  %
                  DSGEModel.SubBeginYearValue = subbeginyearvalue;
                  DSGEModel.SubBeginPeriodValue = subbeginperiodvalue;
                  DSGEModel.SubEndYearValue = subendyearvalue;
                  DSGEModel.SubEndPeriodValue = subendperiodvalue;
                  %
                  % make sure things are set up correctly
                  %
                  set(controls.dsge.subbeginyear,'Value',DSGEModel.SubBeginYearValue);
                  set(controls.dsge.subbeginperiod,'Value',DSGEModel.SubBeginPeriodValue);
                  set(controls.dsge.subendyear,'Value',DSGEModel.SubEndYearValue);
                  set(controls.dsge.subendperiod,'Value',DSGEModel.SubEndPeriodValue);
                  %
                  % make sure that we can reset the KalmanFirstObservation
                  %
                  KalmanStrMat = get(controls.dsge.initializekalman,'String');
                  KalmanFOStr = StringTrim(KalmanStrMat(DSGEModel.KalmanFirstObservation,:));
                  [FirstPeriod,LastPeriod,EstSample] = CreateSubSample(DSGEModel);
                  DSGEModel.YNaNs = max(max(isnan(DSGEModel.Y(:,FirstPeriod:LastPeriod))));
                  pos = LocateStr(EstSample,KalmanFOStr);
                  KalmanFirstObservation = DSGEModel.KalmanFirstObservation;
                  if pos>0;
                     DSGEModel.KalmanFirstObservation = pos;
                  else;
                     DSGEModel.KalmanFirstObservation = 1;
                  end;
                  set(controls.dsge.initializekalman,'String',EstSample,'Value',DSGEModel.KalmanFirstObservation);
                  if (pos>1)&(KalmanFirstObservation~=DSGEModel.KalmanFirstObservation);
                     if MatlabNumber>=7;
                        uicontrol(controls.dsge.initializekalman);
                     end;
                     txt = 'Note that you have changed the selected sub-sample, while a corresponding change has not been made to the selection of the first observation after the Kalman filter training sample in the Kalman Filter Selections frame on the Settings tab.';
                     About(txt,'information','Sub-Sample Change',250,550,CurrINI);
                  end;
               else;
                  %
                  % bad sub-sample
                  %
                  set(controls.dsge.subbeginyear,'Value',DSGEModel.SubBeginYearValue);
                  set(controls.dsge.subbeginperiod,'Value',DSGEModel.SubBeginPeriodValue);
                  set(controls.dsge.subendyear,'Value',DSGEModel.SubEndYearValue);
                  set(controls.dsge.subendperiod,'Value',DSGEModel.SubEndPeriodValue);
                  txt = 'The sample and frequency information regarding sample length doesn''t match the number of observations for the observed variables.';
                  About(txt,'information','Invalid Sub-Sample',120,500,CurrINI);
               end;
            else;
               %
               % bad sub-sample
               %
               set(controls.dsge.subbeginyear,'Value',DSGEModel.SubBeginYearValue);
               set(controls.dsge.subbeginperiod,'Value',DSGEModel.SubBeginPeriodValue);
               set(controls.dsge.subendyear,'Value',DSGEModel.SubEndYearValue);
               set(controls.dsge.subendperiod,'Value',DSGEModel.SubEndPeriodValue);
               txt = 'The sample and frequency information regarding sample length doesn''t match the number of observations for the observed variables.';
               About(txt,'information','Invalid Sub-Sample',120,500,CurrINI);
            end;
         else;
            %
            % Fix all controls regarding sample and report a message regarding having to select a data constructions file first
            %
            set(controls.dsge.subbeginyear,'Value',DSGEModel.SubBeginYearValue);
            set(controls.dsge.subbeginperiod,'Value',DSGEModel.SubBeginPeriodValue);
            set(controls.dsge.subendyear,'Value',DSGEModel.SubEndYearValue);
            set(controls.dsge.subendperiod,'Value',DSGEModel.SubEndPeriodValue);
            txt = 'You have to select a data construction file before you can edit the sample.';
            About(txt,'information','Sample Information',120,500,CurrINI);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'Quit'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check if DSGEModel and OrigDSGEModel structures are equal. If not suggest that DSGE model should be saved
         %
         [status,DiffField] = CompareDSGEModel(DSGEModel,OrigDSGEModel);
         %
         if strcmp(get(controls.leave,'UserData'),'done')==0
            if status==1;
               txt = 'Are you sure you want to quit?';
            else;
               txt = strvcat(['Your DSGE model settings have changed. The field "' DiffField '" differs. Are you sure you want to quit anyway?'],' ','NOTE: The field names are explained in the file "ExtendingYADA.pdf" in the "doc" directory.');
            end;
            answer = Query(txt,'exit',300,'Exit YADA',500,'yes',CurrINI);
            if strcmp(lower(answer),'yes')==1;
               set(controls.leave,'UserData','done');
            end;
         else;
            %
            % we use this as a backup for delete the figure
            %
            SaveINIFile(CurrINI);
            delete(gcf);
         end;
         if IsHandle(controls.about)==1;
            set(controls.about,'UserData',0);
         end;
      else;
         if MatlabNumber<7;
            if isempty(lasterr)==0
               %
               % we use this as a backup for delete the figure
               %
               SaveINIFile(CurrINI);
               delete(gcf);
            end;
         end;
      end;
   case 'done'
      drawnow;
      %
      % store relevant entries of the CurrINI structure to file
      %
      if exist('CurrINI')==1;
         SaveINIFile(CurrINI);
         set(controls.leave,'UserData','done');
      end;
end;
%
% make sure that controls are enabled and disabled as they should
%
if IsHandle(maingui)==1;
   %
   % check if we should display the dialog
   %
   if strcmp(selector,'init')==1;
      YADAEnableControls(DSGEModel,controls);
      if isempty(optcmd)==1;
         set(maingui,'Visible','on');
         drawnow;
         pause(0.02);
         SetYADAIcon(maingui,CurrINI.ShowYADAIcon);
      end;
   else;
      if (exist('controls')==1)&(isfield(controls,'open')==1);
         set(controls.open,'UserData',DSGEModel);
         set(controls.filemenu,'UserData',CurrINI);
         YADAEnableControls(DSGEModel,controls);
      end;
   end;
   if nargout==1;
      YADAHandle = maingui;
   end;
   %
   if strcmp(selector,'init')==1;
      if isempty(optcmd)==1;
         waitfor(controls.leave,'UserData','done');
         if MatlabNumber<7;
            lasterr = '';
         end;
      else;
         if strcmp(lower(optcmd),'--driver')==1;
            %
            % run the driver
            %
            ShowEstimationLog = DSGEModel.ShowEstimationLog;
            DSGEModel.ShowEstimationLog = 0;
            set(controls.open,'UserData',DSGEModel);
            OldDSGEModel = get(controls.openmenu,'UserData');
            set(controls.openmenu,'UserData',DSGEModel);
            FileMenuFunctions('RunDriverFunctions',maingui);
            DSGEModel.ShowEstimationLog = ShowEstimationLog;
            set(controls.open,'UserData',DSGEModel);
            set(controls.openmenu,'UserData',OldDSGEModel);
         elseif strcmp(lower(optcmd),'--seq-driver')==1;
            %
            % run the driver for the selected model sequence
            %
            ShowEstimationLog = DSGEModel.ShowEstimationLog;
            DSGEModel.RunSequentialDriver = 1;
            DSGEModel.ShowEstimationLog = 0;
            set(controls.open,'UserData',DSGEModel);
            OldDSGEModel = get(controls.openmenu,'UserData');
            set(controls.openmenu,'UserData',DSGEModel);
            FileMenuFunctions('RunModelSequence',maingui);
            DSGEModel.ShowEstimationLog = ShowEstimationLog;
            set(controls.open,'UserData',DSGEModel);
            set(controls.openmenu,'UserData',OldDSGEModel);
         end;
         disp('Closing YADA.');
      end;
   end;
end;

%
% end of YADAGUI.m
%
