function YADAEnableControls(DSGEModel,controls)
% YADAEnableControls: Determines which controls on the YADA GUI should be enabled and which should be disabled.
%
% USAGE:
%
%       YADAEnableControls(DSGEModel,controls)
%
% REQUIRED INPUT: DSGEModel (structure) whose fields contain all required information
%                           about the model, such as input files, variable and sample
%                           data. Actual observations are not stored in this file.
%
%                 controls (structure) whose fields give the handles to all controls on the YADA GUI.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2025 European Central Bank.
%
%                       First version: February 13, 2010.
%                        This version: January 13, 2025.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 14-02-2010: Updated the documentation.
%
% * 16-02-2010: Swapped the order of the input variables to match "VerifyProjectMenu".
%
% * 18-02-2010: Added the DSGE-VAR prior sampling handle check.
%
% * 19-02-2010: Added the view VAR model handle checks for initial values, marginal posterior mode,
%               and joint posterior mode.
%
% * 20-02-2010: Added the DSGE-VAR posterior mode results and summary handle checks.
%
% * 22-02-2010: Added the DSGE-VAR "Check posterior mode" handle checks.
%
% * 23-02-2010: Added the DSGE-VAR "Impulse responses" handle checks for single parameter values.
%
% * 24-02-2010: Added the DSGE-VAR "Optimization Error Summary" handle checks.
%
% * 25-02-2010: Added the DSGE-VAR "Structural Shocks" and "Posterior Sampling" handle checks.
%
% * 02-03-2010: Added the DSGE-VAR "Posterior Sampling Summary" and "Raw Posterior Draws" handle checks.
%
% * 03-03-2010: Added the DSGE-VAR "Posterior Densities" handle check for the DSGE parameters, and the
%               "Estimated Parameters" handle checks.
%
% * 04-03-2010: Added the DSGE-VAR "VAR Posterior Sampling" handle check.
%
% * 05-03-2010: Added the handle checks for viewing scenario variables.
%
% * 09-03-2010: Added the DSGE-VAR "VAR Posterior Sampling Summary" and VAR parameter prior and posterior
%               densities handle checks.
%
% * 19-03-2010: Added the DSGE-VAR "Compare Marginal Likelihood" handle checks.
%
% * 23-03-2010: Took into account that the DSGE-VAR "Compare Marginal Likelihood" controls appear
%               before all posterior density controls on the View submenu.
%
% * 12-04-2010: Added the DSGE-VAR "Compare Estimated Parameters" handle checks for the posterior
%               distribution.
%
% * 15-04-2010: Added the DSGE-VAR "Impulse Responses" handle checks for the posterior distribution.
%
% * 16-04-2010: Added the DSGE-VAR "Impulse Responses" handle checks for the prior distribution.
%
% * 21-04-2010: Added the "Structural Form" handle checks for initial values and posterior mode values.
%
% * 26-04-2010: Added the DSGE-VAR "Structural Shocks" handle checks for the posterior distribution.
%
% * 27-04-2010: Added the DSGE-VAR "Structural Shocks" handle checks for the prior distribution.
%
% * 05-05-2010: Added the Tools "Frequency Domain Information Matrix" handle checks for initial
%               values and posterior mode values.
%
% * 09-05-2010: Added the Tools "Frequency Domain Coherence" handle checks for initial values,
%               posterior mode values, prior and posterior distribution.
%
% * 12-05-2010: Fixed some issues with the coherence controls, making sure that the number of variables
%               is at least 2 for the different cases.
%
% * 14-05-2010: Took into account that the names of cotrols for observed variable correlations and coherence
%               based on draws from the prior have changed.
%
% * 19-05-2010: Added the DSGE-VAR "Variance Decompositions" handle checks for initial values, posterior mode
%               values, prior and posterior distribution for both the original data and the levels data.
%
% * 24-05-2010: Added the DSGE-VAR "Observed variable decompositions" handle checks for initial values and
%               posterior mode values.
%
% * 26-05-2010: Added the DSGE-VAR "Observed variable decomposition paths" handle checks for initial values,
%               posterior mode values, prior and posterior distribution for both the original data and the
%               annualized data.
%
% * 28-05-2010: Added the DSGE-VAR "Spectral Decompositions" handle checks for initial values and posterior
%               mode values.
%
% * 01-06-2010: Added the DSGE-VAR "Unconditional Predictive Distributions" handle checks for initial values,
%               marginal and joint posterior mode values, prior and posterior distribution.
%
% * 15-06-2010: Added the DSGE-VAR "Observed Variable Correlations" handle checks for the time domain controls
%               for initial values, marginal and joint posterior mode values, prior and posterior distribution.
%
% * 21-06-2010: Added the DSGE-VAR "Coherence" handle checks for initial values, marginal and joint posterior
%               mode, prior and posterior distribution.
%
% * 23-06-2010: Added the handle checks for "Constrained filters".
%
% * 09-07-2010: Added the handle checks for "Properties" on controllability and observability.
%
% * 04-08-2010: Added the handle checks for "Set State Constraints".
%
% * 03-11-2010: Added the DSGE-VAR "Simulate Data" handle checks for initial values, marginal and joint
%               posterior mode values.
%
% * 01-12-2010: Removed the handle checks for "Save Annualized Data". Added handle checks for "Laplace
%               Posterior densities".
%
% * 08-12-2010: The "conditional variance decompositions" menu item is now disabled when the model has or
%               is allowed to have unit roots.
%
% * 09-12-2010: Changed my mind about the change made yesterday. This should be handled directly when
%               attempting to compute a long-run variance.
%
% * 04-01-2011: Updated the documentation.
%
% * 05-01-2011: The function now performs handle checks for modesty results based on state variable
%               assumptions.
%
% * 09-01-2011: Changed the dos delete command to a delete command.
%
% * 11-01-2011: Added support for unix and mac paths.
%
% * 12-01-2011: The function now supports unix and mac paths.
%
% * 17-01-2011: Added handle checks for "Correlation decompositions" for the DSGE model.
%
% * 18-01-2011: Added handle checks for the DSGE-VAR "Correlation decompositions".
%
% * 20-01-2011: Added handle checks for the DSGE-VAR "Conditional correlations".
%
% * 21-01-2011: The conditional correlations for the DSGE model can now only be enabled when
%               the model has at least 2 observed variables.
%
% * 18-02-2011: Added handle checks for the DSGE-VAR "Conditional predictive distributions".
%
% * 27-02-2011: Added a handle check for DSGE-VAR Model Equations for "DSGE posterior mode" case,
%               and for the Simulate Data for the same parameter values.
%
% * 02-03-2011: Began work on handle checks for modesty statistics from the DSGE-VAR models.
%
% * 03-03-2011: Finished the code for handle checks of the DSGE-VAR modesty statistics controls.
%
% * 04-03-2011: Added handle checks for BVAR conditional predictive distributions controls.
%
% * 08-03-2011: Added handle checks for BVAR modesty statistics.
%
% * 10-03-2011: Added handle checks when the observed variables data contains NaNs.
%
% * 21-03-2011: Added handle checks for determining when shocks for the mixed conditioning method
%               can be selected.
%
% * 22-03-2011: Added handle checks for determining when shocks for the mixed conditioning method
%               can be selected for state variable assumptions.
%
% * 23-03-2011: The function now supports "DSGEModel.ShockControlMethod" taking the value 3, i.e.,
%               the subset shock method.
%
% * 05-04-2011: Added handle checks for shock configuration, i.e., setting a shock color and
%               an alias.
%
% * 06-04-2011: Added handle check also for the toolbar function for shock configuration.
%
% * 26-04-2011: Added handle checks for DSGE-VAR based observed variable scenarios.
%
% * 17-06-2011: Made sure that prior sampling and viewing the prior is only possible when
%               the PriorFile exists.
%
% * 21-06-2011: Added handle checks for "Parameter Values" functions for the DSGE model.
%
% * 14-12-2011: Added handle check for "Monte Carlo Filtering" function.
%
% * 04-01-2012: Updated the documentation.
%
% * 02-02-2012: Added handle checks for reordering shocks control under the direct method for conditional
%               forecasting.
%
% * 03-02-2012: Updated the documentation.
%
% * 07-02-2012: Changed the conditions for enabling the control "controls.setconditionalshocksmixed".
%
% * 08-02-2012: Changed the conditions for enabling the control "controls.setstateconditionalshocksmixed".
%               Added handle checks for redordering state conditioning shocks.
%
% * 09-02-2012: Added handle checks for the DSGE-VAR Eigenvalues functions.
%
% * 24-02-2012: Added handle checks for the DSGE-VAR functions for estimating the marginal likelihood
%               including a sequential estimation.
%
% * 29-02-2012: Took into account that the number of simulated paths per parameter value when forecasting
%               can be unity.
%
% * 02-03-2012: Added handle checks for the prior distribution function for showing the state-space form.
%
% * 06-02-2012: Added handle checks for the Laplace approximation functions.
%
% * 19-03-2012: Added handle checks for the DSGE-VAR Laplace approximation functions.
%
% * 20-03-2012: Added handle checks for DSGE model predictive likelihood controls.
%
% * 02-04-2012: Added handle checks for the DSGE-VAR predictive likelihood controls.
%
% * 07-05-2012: Added handle checks for the DSGE model predictive likelihood controls
%               when annualizing.
%
% * 11-05-2012: Added handle checks for the DSGE-VAR predictive likelihood controls under
%               annualization.
%
% * 30-11-2012: Added handle check for the DSGE model marginal likelihood calculation with the
%               Sims, Waggoner and Zha trunctated elliptical version of the modified harmonic mean.
%
% * 10-12-2012: Added handle check for the DSGE-VAR model marginal likelihood calculation with the
%               Sims, Waggoner and Zha truncated elliptical version of the modified harmonic mean.
%
% * 13-12-2012: Added handle check for the DSGE-VAR compare marginal likelihood function using the
%               Sims, Waggoner and Zha version of the modified harmonic mean.
%
% * 02-01-2013: Updated the documentation.
%
% * 17-07-2013: The function checks all state conditioning controls.
%
% * 13-08-2013: Added handle checks for DSGE model predictive checks of the one-step-ahead forecast
%               errors.
%
% * 24-01-2014: Updated the documentation.
%
% * 20-02-2014: Added handle checks for DSGE model raw posterior draws of the log posterior kernel values.
%
% * 21-02-2014: Added handle checks for DSGE-VAR model plotting of the log posterior kernel values.
%
% * 24-02-2014: Added handle checks for DSGE-VAR model scatter plots of the posterior draws.
%
% * 25-02-2014: Added handle checka for DSGE-VAR plots of convergence for the acceptance ratio, the posterior
%               mean, and the posterior median. Also, added handle checks for CUSUM plots of the log posterior
%               kernel, the original and the transformed parameters. Finally, added handle checks for the
%               DSGE-VAR model estimates of the separated partial means tests of the log posterior kernel,
%               the original and the transformed parameters.
%
% * 26-02-2014: Added handle checks for the DSGE-VAR MANOVA convergence statistics.
%
% * 07-03-2014: Added handle checks for the DSGE-VAR Laplace approximation of the posterior densities for the
%               DSGE model parameters.
%
% * 11-03-2014: Added handle checkd for the DSGE-VAR plots of the log-likelihood function.
%
% * 14-03-2014: Added handle checks for the DSGE-VAR shock correlations.
%
% * 20-03-2014: Added handle check for the DSGE model parameter change effects on the population moments of the
%               observed variables.
%
% * 18-08-2014: Added handle checks for the DSGE model zero lower bound controls for conditional forecasting with
%               initial values and posterior mode values.
%
% * 17-12-2104: Added handle checks for the DSGE model impulse responses for the state variables.
%
% * 05-01-2015: Updated the documentation.
%
% * 24-08-2015: Took the Student-t proposal density into account.
%
% * 27-08-2015: Fixed a few remaining issues to fully take the Student-t proposal density into account for
%               posterior sampling.
%
% * 20-01-2016: Updated the documentation.
%
% * 09-02-2017: Updated the documentation.
%
% * 01-04-2017: The function now supports the fixed blocking RWM posterior sampler with a normal
%               proposal density.
%
% * 10-04-2017: The function now supports the fixed blocking RWM posterior sampler with a Student-t
%               proposal density.
%
% * 13-04-2017: The function now supports the random blocking RWM posterior sampler with a normal
%               proposal density.
%
% * 19-04-2017: The function now supports the random blocking RWM posterior sampler with a Student-t
%               proposal density.
%
% * 03-05-2017: Added handle checks for conditional variance decompositions of the state variables.
%
% * 02-06-2017: Added handle checks for the system prior mode estimation item.
%
% * 20-06-2017: Added handle checks for the marginal predictive moments for prior and posterior draws
%               for the DSGE model.
%
% * 23-06-2017: Added handle checks for the marginal predictive moments for prior and posterior draws
%               for the DSGE-VAR models.
%
% * 11-08-2017: The function now supports the SMC with likelihood tempering posterior sampler.
%
% * 14-08-2017: Made sure that controls related to modified harmonic mean and Chib & Jeliazkov estimators
%               of the marginal likelihood are not enabled when the SMC posterior sampler is selected.
%
% * 28-08-2017: Added handle checks for raw posterior plots of the importance weights for the SMC with
%               likelihood tempering posterior sampler for DSGE models.
%
% * 11-09-2017: Added handle checks for raw posterior plots of the importance weights for the SMC with
%               likelihood tempering posterior sampler for DSGE-VAR models.
%
% * 12-09-2017: Added handle checks for comparing marginal likelihoods in DSGE-VAR models using the
%               SMC estimates.
%
% * 15-09-2017: Added handle checks for SMC adaption graph for DSGE and DSGE-VAR models.
%
% * 15-12-2017: Added handle checks for variance decompositions of state variables.
%
% * 05-01-2018: Updated the documentation.
%
% * 29-08-2018: Updated the documentation.
%
% * 10-10-2018: Added handle checks for bivariate posterior densities for DSGE model.
%
% * 16-10-2018: The function now supports SMC with data tempering.
%
% * 19-10-2018: Made sure that the control for show raw posterior draws of the particle weights
%               is not enabled under SMC with data tempering.
%
% * 23-20-2018: Added handle checks for bivariate posterior densities for DSGE-VAR models.
%
% * 24-10-2018: Added handle checks for bivariate prior densities for DSGE models.
%
% * 25-10-2018: Made sure that the name of the prior draws file reflects using a system prior.
%
% * 31-10-2018: Added handle checks for system prior correlations among the prior draws.
%
% * 05-11-2018: Added handle check for the correlations between the posterior draws of the
%               parameters.
%
% * 30-11-2018: The function should now support IS based on MitISEM.
%
% * 03-12-2018: Added some IS related DSGEModel options to the PostSampleTextFile.
%
% * 04-12-2018: The function now supports all IS based on MitISEM features.
%
% * 03-01-2019: Made sure that the control for raw plotting of particle and importance weights
%               is appropriately named.
%
% * 04-01-2019: Fixed a cosmetic issue with the previous change.
%
% * 17-01-2019: Fixed the same cosmetic issue for the plots of raw weights when using either SMC
%               with likelihood tempering or IS based on MitISEM.
%
% * 21-03-2019: Added handle checks for the computation of predictive variances from the stationary
%               predictive distribution and its decomposition for DSGE models.
%
% * 27-03-2019: Added handle checks for the computation of predictive variances from the stationary
%               predictive distribution and its decomposition for DSGE-VAR models.
%
% * 15-04-2019: Added handle checks for the computation of parameter change effects on the state
%               variable moments.
%
% * 16-04-2019: Added handle checks for the calculation of parameter change effect on the observed
%               variable moments of DSGE-VAR models.
%
% * 07-01-2020: Updated the documentation.
%
% * 05-03-2019: Added handle checks for selecting the belief system from the learning menu.
%
% * 06-03-2020: Added further checks when selecting the belief system including setting the
%               forward looking variables.
%
% * 09-03-2020: Added handle checks for selecting a user defined belief system prior.
%
% * 11-03-2020: Added handle checks for the Tools and View items on the learning menu, and checks
%               for the DSGE Posterior mode item on the Log-likelihood menu on Learning|Tools.
%
% * 30-03-2020: Added handle check for the initial values case of the log-likelihood on
%               Learning|Tools, and to the posterior mode estimation case on the learning menu.
%
% * 02-04-2020: Added handle check for the adaptive learning posterior mode case of the
%               log-likelihood on Learning|Tools; handle checks for the posterior mode
%               results and summary controls on Learning|View; and handle checks for the
%               system prior mode estimation on the Learning menu.
%
% * 03-04-2020: Added handle check for estimates of state variables and state shocks at
%               posterior mode values for the adaptive learning case on the Learning|Tools menu.
%
% * 06-04-2020: Added handle check for estimates of belief coefficients at posterior mode
%               values for the adaptive learning case on the Learning|Tools menu.
%
% * 16-04-2020: Added handle checks for viewing the log prior and the log Jacobian under
%               initial values, DSGE posteriro mode and posterior mode for the adaptive
%               learning case on the Learning|View menu. Furthermore, added handle checks
%               for controls to view the belief coefficients at the initial values and
%               at the DSGE posterior mode values on the Learning|Tools menu.
%
% * 17-04-2020: Added handle checks for displaying the state shocks and the state variables
%               at initial values and at the DSGE posterior mode values on the Learning|Tools
%               menu. Added handle checks for observed variable decompositions on the same
%               menu.
%
% * 21-04-2020: Added handle checks for observed variable decompositions at initial values
%               and at DSGE posterior mode values.
%
% * 22-04-2020: Added handle checks for state variable decompositions at initial values,
%               DSGE posterior mode and posterior mode values.
%
% * 06-05-2020: Added handle checks for the impulse responses of the original data at initial
%               values, DSGE posterior mode and posterior mode values on the Learning|Tools
%               menu.
%
% * 08-05-2020: Added handle checks for options and using a non-central GLS matrix when
%               initializing the belief system Kalman filter.
%
% * 11-05-2020: Added handle checks for options item of not using the smoothed states for
%               the belief coefficient Kalman filter.
%
% * 12-05-2020: Added handle checks for the impulse responses of the annualized data and the
%               levels data at initial values, DSGE posterior mode and posterior mode values
%               on the Learning|Tools menu.
%
% * 14-05-2020: Added handle checks for the laws of motions of the forward looking variables
%               based on initial values, DSGE posterior mode values and the posterior mode values
%               on the Laerning|Tools menu.
%
% * 15-05-2020: Added handle checks for the measurement errors based on the initial values, DSGE
%               posterior mode values and the posterior mode values on the Learning|Tools
%               menu.
%
% * 18-05-2020: Added handle checks for the posterior sampling functionality on the Learning
%               menu.
%
% * 27-05-2020: Added handle checks for the prior sampling functionality on the Learning menu, and
%               for the posterior sampling summary and raw posterior draws on the View submenu of
%               the Learning menu.
%
% * 28-05-2020: Added handle checks for the marginal and bivariate posterior densities as well as
%               the posterior correlations for scatter-plots of posterior draws, and for sequential
%               marginal likelihood estimation on the View submenu of the Learning menu.
%
% * 02-07-2020: Removed the field "NonCentralGLSMatrix". Added handle checks for unconditional
%               predictive distribution at initial values, DSGE posterior mode and posterior mode
%               values on the View submenu of the Learning menu.
%
% * 03-07-2020: Added the remaining (annual and transformed) handle checks for the unconditional
%               predictive distribution at initial values, DSGE posterior mode and posterior mode
%               values on the View submenu of the Learning menu. Added handle check for the option
%               of having fixed belief coefficients while projecting from a fixed time period under
%               adaptive learning.
%
% * 31-07-2020: Fixed a small bug where a set command for the deleted control "controls.learning.options.noncentralglsmatrix"
%               remained.
%
% * 25-08-2020: Added handle checks for the PIT controls for the DSGE model on the Tools menu.
%
% * 28-08-2020: Added handle checks for the CRPS controls for the DSGE model on the Tools menu.
%
% * 22-01-2021: Updated the documentation.
%
% * 08-02-2021: Added handle chgecks for the check posterior mode, the iterated parameter estimates and the
%               prior distribution information functions on the Learning menu.
%
% * 09-02-2021: Added handle checks for the view Laplace posterior densities and the posterior mode
%               surface functions on the Learning menu.
%
% * 22-02-2021: Added handle checks for permanent shocks IRFs at initial values and at posterior mode.
%
% * 14-04-2021: The reorder conditioning shocks for observed and state variables are now enabled if there
%               is at least one (rather than two) conditioning assumptions.
%
% * 15-04-2021: The reordering of scenario variable shocks and state scenario variable shocks is now
%               also enabled when there is at least one assumption.
%
% * 28-04-2021: Updated the documentation.
%
% * 03-05-2021: Added handle checks for computing the predictive likelihood with the posterior draws
%               on the Learning menu.
%
% * 14-05-2021: Added handle checks for computing the predictive moments, PITs and CRPS with the
%               posterior draws on the Learning menu.
%
% * 19-05-2021: Added handle checks for computing the unconditional predictive distribution with
%               posterior draws on the Learning menu.
%
% * 04-08-2021: Added handle checks for import prior data on the Learning menu.
%
% * 03-01-2022: Updated the documentation.
%
% * 24-08-2022: Added handle checks for unconditional forecasts subjext to the ZLB for the initial
%               values and the posterior mode values.
%
% * 26-08-2022: Added handle checks for unconditional forecasts subject to the ZLB for the posterior
%               draws.
%
% * 05-10-2022: Added handle checks for unconditional forecasts subject to the ZLB for the prior draws.
%
% * 23-11-2022: Added handle check for running the dynare parser.
%
% * 30-11-2022: Took into account that the dynare parser uses data from the CurrINI structure.
%
% * 06-12-2022: Added handle check for viewing the dynare model file.
%
% * 07-12-2022: Commented out the ZLB handle checks for conditional forecasts.
%
% * 02-01-2023: Updated the documentation.
%
% * 11-01-2023: Added handle checks for the three persistence functions under adaptive learning.
%
% * 17-01-2023: Added handle checks for observed variable scenarios under adaptive learning.
%
% * 27-01-2023: Added handle checks for state variable scenarios under adaptive learning.
%
% * 13-02-2023: Added handle checks for viewing parameter values and for the time domain estimates
%               of the information matrix under adaptive learning.
%
% * 14-02-2023: Added handle checks for the frequency domain estimates of the information matrix
%               under adaptive learning.
%
% * 23-02-2023: Reinstated the ZLB handle checks for conditional forecasts at posterior mode.
%
% * 14-03-2023: Reinstated the ZLB handle checks for conditional forecasts at the initial values.
%
% * 16-03-2023: Added handle check for the conditional forecasts subject to the ZLB and using prior
%               or posterior draws.
%
% * 29-03-2023: Added handle check for the save inverse Hessian function under adaptive learning.
%
% * 30-03-2023: Added handle check for the save inverse Hessian function under rational expectations.
%
% * 04-04-2023: Added handle check for run dynare parser toolbar button.
%
% * 10-05-2023: Added handle check for viewing actuals data.
%
% * 19-06-2023: Added support for the option to show the YADA icon or not.
%
% * 25-07-2023: Added handle checks for the observation weight decompositions of the unconditional
%               point forecasts at initial values and at posterior mode.
%
% * 05-10-2023: Added handle checks for the Monte Carlo filtering function under adaptive learning.
%
% * 25-10-2023: Added handle checks for the DSGE eigenvalues functions under adaptive learning.
%
% * 11-12-2023: Added handle checks for the DSGE observed variable decompositions using the prior
%               and the posterior draws.
%
% * 02-12-2024: Added handle checks for the CRPS and ES computations using the conditional forecasts
%               from the rational expectations DSGE model.
%
% * 16-01-2024: Added handle checks for the CRPS and ES computations using the unconditional forecasts
%               subject to the ZLB from the rational expectations DSGE model.
%
% * 29-01-2024: Added handle checks for the predictive likelihood computations using the unconditional
%               forecasts subject to the ZLB from the rational expectations DSGE model.
%
% * 06-02-2024: Added handle checks for the predictive likelihood computations using the conditional
%               forecasts subject to the ZLB from the rational expectations DSGE model.
%
% * 07-02-2024: Added handle checks for the CRPS and ES calculations using the conditional forecasts
%               subject to the ZLB from the rational expectations DSGE model. Added handle checks for
%               the predictive likelihood computations using the conditional forecasts from the
%               rational expectations DSGE model.
%
% * 22-02-2024: Added handle checks for unconditional predictive distributions subject to the ZLB for
%               the adaptive learning case.
%
% * 06-03-2024: Added handle checks for the predictive likelihood and CRPS/ES calculations based on the
%               unconditional predictive distributions subject to the ZLB for the adaptive learning case
%               using the posterior draws.
%
% * 08-03-2024: Added handle checks for the predictive likelihood and CRPS/ES calculations based on the
%               unconditional predictive distributions subject to the ZLB for the adaptive learning case
%               using the prior draws.
%
% * 11-03-2024: Added handle checks for the unconditional predictive distribution for the adaptive learning
%               case and using the prior draws.
%
% * 12-03-2024: Added handle checks for the predictive likelihood computations in the case of adaptive learning
%               and using the prior draws.
%
% * 13-03-2024: Added handle checks for the annual controls when computing the predictive likelihood in the
%               case of adaptive learning and using either the prior or the posterior draws.
%
% * 14-03-2024: Added handle checks for the CRPS and ES calculations using the adaptive learning model with
%               the prior draws.
%
% * 19-03-2024: Added handle checks for the marginal predictive moments and the PITs using the adaptive learning
%               model with the prior draws.
%
% * 11-04-2024: Added handle checks for the conditional predictive distributions at posterior mode for the
%               adaptive learning model.
%
% * 19-04-2024: Added handle checks for the modesty test results file for the adaptive learning model and posterior
%               mode estimates.
%
% * 23-04-2024: Added handle checks for the conditional predictive distribtion and modesty statistics at the initial
%               values and at the DSGE posterior mode values.
%
% * 24-04-2024: Added handle checks for the conditional predictive distribution and the modesty statistics for the
%               posterior draws.
%
% * 26-04-2024: Took into account that "DSGEModel.FixedBeliefsForProj" affects the modesty statistics under adaptive
%               learning.
%
% * 31-05-2024: Added handle checks for the conditional predictive distribution and the modesty statistics for the
%               prior draws.
%
% * 04-06-2024: Added handle checks for the predictive likelihood calculations using the conditional predictive
%               distributions based on the prior and the posterior draws.
%
% * 05-06-2024: Added handle checks for the CRPS & ES calculations using the conditional predictive distributions
%               based on the prior and the posterior draws.
%
% * 26-06-2024: Added handle checks for the steady-state belief coefficient controls.
%
% * 04-07-2024: Added handle checks for the steady-state-space form controls.
%
% * 17-07-2024: Added handle checks for the steady-state structural form controls under adaptive learning.
%
% * 29-07-2024: Added handle checks for the marginal predictive moments of the conditional forecasts for the
%               rational expectations cases with either prior or posterior draws.
%
% * 31-07-2024: Added handle checks for the PIT calculations based on the conditional forecasts for the rational
%               expectations cases with either prior or posterior draws.
%
% * 05-08-2024: Added handle checks for the marginal predictive moments of the conditional forecasts for the
%               adaptive learning cases with either prior or posterior draws.
%
% * 09-08-2024: Added handle checks for the PIT calculations based on the conditional forecasts for the adaptive
%               learning cases with either prior or posterior draws.
%
% * 21-08-2024: Added handle checks for the parameter change functions using the impact on IRFs for the rational
%               expectations case with initial values or posterior mode values.
%
% * 26-08-2024: Added handle checks for the parameter change functions using the Laplace approximation of the log
%               marginallikelihood at initial values and at posterior model values.
%
% * 28-08-2024: Added handle checks for the steady-state correlations of the observed/state variables in the DSGE
%               model subject to adaptive learning for fixed parameters.
%
% * 24-10-2024: Added handle checks for writing a PLM based on the RE solution at initial values.
%
% * 26-11-2024: Added handle checks for the unconditional predictive distributions at fixed parameters and subject
%               to the ZLB for the adaptive learning case.
%
% * 29-11-2024: Added handle check for the conditional predictive distributions at fixed parameters and subject to
%               the ZLB for the adaptive learning case.
%
% * 06-12-2024: Added handle checks for the conditional predictive distribution using prior or posterior draws and
%               subject to the ZLB for the adaptive learning case.
%
% * 07-01-2025: Updated the documentation.
%
% * 13-01-2025: Added handle checks for the predictive likelihood and CRPS calculations based on the conditional
%               forecasts subject to the ZLB for the adaptive learning case using prior or posterior draws.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% check if we can run dynare
%
CurrINI = get(controls.filemenu,'UserData');
if FileExist([CurrINI.DynarePath 'dynare.m'])==1;
   set(controls.dynarejobs.rundynareparser,'Enable','on');
   set(controls.dynarejobs.viewdynaremodel,'Enable','on');
   set(controls.rundynareparser,'Enable','on');
else;
   set(controls.dynarejobs.rundynareparser,'Enable','off');
   set(controls.dynarejobs.viewdynaremodel,'Enable','off');
   set(controls.rundynareparser,'Enable','off');
end;
%
% check if we allow for displaying the YADA icon
%
if FileExist(FixFilePath([pwd '\addons\ovs\OVSFunctions.m']))==1;
   if CurrINI.ShowYADAIcon==1;
      set(controls.showyadaiconmenu,'Checked','on');
   else;
      set(controls.showyadaiconmenu,'Checked','off');
   end;
end;
%
% test if we have specified any unit-roots
%
if (isempty(DSGEModel.UnitRootStates)==1)&(DSGEModel.AllowUnitRoot==0);
   set(controls.informationmatrix.frequencydomain.parent,'Enable','on');
   set(controls.obsvarcorrs.frequencydomain.parent,'Enable','on');
   set(controls.statevarcorrs.frequencydomain.parent,'Enable','on');
   set(controls.obsvarcorrs.parent,'Enable','on');
   set(controls.statevarcorrs.parent,'Enable','on');
   set(controls.spectraldecomp.parent,'Enable','on');
   if (exist('YADAdare')==2)|(exist('dare')==2);
      set(controls.fevd.parent,'Enable','on');
   else;
      set(controls.fevd.parent,'Enable','off');
   end;
   if DSGEModel.YNaNs==0;
      set(controls.dsgevarmenu,'Enable','on');
   else;
      set(controls.dsgevarmenu,'Enable','off');
   end;
else;
   set(controls.informationmatrix.frequencydomain.parent,'Enable','off');
   set(controls.obsvarcorrs.frequencydomain.parent,'Enable','off');
   set(controls.statevarcorrs.frequencydomain.parent,'Enable','off');
   set(controls.obsvarcorrs.parent,'Enable','off');
   set(controls.statevarcorrs.parent,'Enable','off');
   set(controls.spectraldecomp.parent,'Enable','off');
   set(controls.fevd.parent,'Enable','off');
   set(controls.dsgevarmenu,'Enable','off');
end;
if DSGEModel.YNaNs==0;
   set(controls.bvarmenu,'Enable','on');
else;
   set(controls.bvarmenu,'Enable','off');
end;
if isempty(DSGEModel.ZLBPosition)==0;
   set(controls.predict.unconditional.original.zlbmenu,'Enable','on');
   set(controls.predict.unconditional.annual.zlbmenu,'Enable','on');
   set(controls.predict.unconditional.transformed.zlbmenu,'Enable','on');
   set(controls.predict.conditional.original.zlbmenu,'Enable','on');
   set(controls.predict.conditional.annual.zlbmenu,'Enable','on');
   set(controls.predict.conditional.transformed.zlbmenu,'Enable','on');
   set(controls.learningtools.predictivedist.unconditional.original.zlbmenu,'Enable','on');
   set(controls.learningtools.predictivedist.unconditional.annual.zlbmenu,'Enable','on');
   set(controls.learningtools.predictivedist.unconditional.transformed.zlbmenu,'Enable','on');
   set(controls.learningtools.predictivedist.conditional.original.zlbmenu,'Enable','on');
   set(controls.learningtools.predictivedist.conditional.annual.zlbmenu,'Enable','on');
   set(controls.learningtools.predictivedist.conditional.transformed.zlbmenu,'Enable','on');
else;
   set(controls.predict.unconditional.original.zlbmenu,'Enable','off');
   set(controls.predict.unconditional.annual.zlbmenu,'Enable','off');
   set(controls.predict.unconditional.transformed.zlbmenu,'Enable','off');
   set(controls.predict.conditional.original.zlbmenu,'Enable','off');
   set(controls.predict.conditional.annual.zlbmenu,'Enable','off');
   set(controls.predict.conditional.transformed.zlbmenu,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.zlbmenu,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.zlbmenu,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.transformed.zlbmenu,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.zlbmenu,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.zlbmenu,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.transformed.zlbmenu,'Enable','off');
end;
if DSGEModel.ModelSolver==4;
   set(controls.learning.options.modelsolver,'Enable','on');
   if FileExist(DSGEModel.AdaptiveLearningModelSolverFile)==1;
      set(controls.learning.options.modelsolver,'Label',['&Select Model Solver (' GetName(DSGEModel.AdaptiveLearningModelSolverFile) ')...']);
   else;
      set(controls.learning.options.modelsolver,'Label','&Select Model Solver...');
   end;
else;
   set(controls.learning.options.modelsolver,'Label','&Select Model Solver...','Enable','off');
end;
%
% test if prior draws exist
%
if FileExist(DSGEModel.SystemPriorFile)==0;
   PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
else;
   PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
end;
if (VerifyPosteriorModeEstimation(DSGEModel)==1)&(FileExist(PriorDrawsFile)==1);
   MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
   if DSGEModel.n>1;
      set(controls.obsvarcorrs.frequencydomain.prior,'Enable','on');
      set(controls.condcorrs.prior,'Enable','on');
   else;
      set(controls.obsvarcorrs.frequencydomain.prior,'Enable','off');
      set(controls.condcorrs.prior,'Enable','off');
   end;
   set(controls.obsvarcorrs.timedomain.prior,'Enable','on');
   set(controls.obsvarcorrs.parameterchange.prior,'Enable','on');
   if length(DSGEModel.StateVariablePositions)>1;
      set(controls.statevarcorrs.frequencydomain.prior,'Enable','on');
   else;
      set(controls.statevarcorrs.frequencydomain.prior,'Enable','off');
   end;
   set(controls.statespacepriordist,'Enable','on');
   set(controls.statevarcorrs.timedomain.prior,'Enable','on');
   set(controls.statevarcorrs.parameterchange.prior,'Enable','on');
   set(controls.stateshockcorrs.prior,'Enable','on');
   set(controls.measurementerrorcorrs.prior,'Enable','on');
   set(controls.obsvar.predchecks.prior,'Enable','on');
   set(controls.obsvar.prior,'Enable','on');
   set(controls.statevariables.prior,'Enable','on');
   set(controls.stateshocks.prior,'Enable','on');
   set(controls.measurementerror.prior,'Enable','on');
   set(controls.hd.prior,'Enable','on');
   set(controls.irfunctions.prior,'Enable','on');
   set(controls.ovd.prior,'Enable','on');
   set(controls.ovp.prior,'Enable','on');
   set(controls.cvd.prior,'Enable','on');
   set(controls.cvd.state.prior,'Enable','on');
   set(controls.fevd.prior,'Enable','on');
   set(controls.fevd.state.prior,'Enable','on');
   set(controls.irfunctions.statevariables.prior,'Enable','on');
   if max(DSGEModel.annual)>1;
      set(controls.irfunctions.ann_prior,'Enable','on');
      set(controls.cvd.ann_prior,'Enable','on');
      set(controls.ovd.annprior,'Enable','on');
      set(controls.ovp.annprior,'Enable','on');
   else;
      set(controls.irfunctions.ann_prior,'Enable','off');
      set(controls.cvd.ann_prior,'Enable','off');
      set(controls.ovd.annprior,'Enable','off');
      set(controls.ovp.annprior,'Enable','off');
   end;
   if sum(DSGEModel.levels)<DSGEModel.n;
      set(controls.irfunctions.lev_prior,'Enable','on');
      set(controls.cvd.lev_prior,'Enable','on');
      set(controls.fevd.lev_prior,'Enable','on');
   else;
      set(controls.irfunctions.lev_prior,'Enable','off');
      set(controls.cvd.lev_prior,'Enable','off');
      set(controls.fevd.lev_prior,'Enable','off');
   end;
   if isfield(controls,'shockscenarios')==1;
      if MaxFH>0;
         set(controls.shockscenarios.prior,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.shockscenarios.annprior,'Enable','on');
         else;
            set(controls.shockscenarios.annprior,'Enable','off');
         end;
      else;
         set(controls.shockscenarios.prior,'Enable','off');
         set(controls.shockscenarios.annprior,'Enable','off');
      end;
   end;
   if isfield(controls,'ovs')==1;
      if CheckScenarioData(DSGEModel)==1;
         set(controls.ovs.prior,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.ovs.ann_prior,'Enable','on');
         else;
            set(controls.ovs.ann_prior,'Enable','off');
         end;
      else;
         set(controls.ovs.prior,'Enable','off');
         set(controls.ovs.ann_prior,'Enable','off');
      end;
   end;
   if isfield(controls,'svs')==1;
      if CheckStateScenarioData(DSGEModel)==1;
         set(controls.svs.prior,'Enable','on');
         set(controls.tunedfilters.statevariables.prior,'Enable','on');
         set(controls.tunedfilters.stateshocks.prior,'Enable','on');
         set(controls.tunedfilters.measurement.prior,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.svs.ann_prior,'Enable','on');
         else;
            set(controls.svs.ann_prior,'Enable','off');
         end;
      else;
         set(controls.svs.prior,'Enable','off');
         set(controls.svs.ann_prior,'Enable','off');
         set(controls.tunedfilters.statevariables.prior,'Enable','off');
         set(controls.tunedfilters.stateshocks.prior,'Enable','off');
         set(controls.tunedfilters.measurement.prior,'Enable','off');
      end;
   end;
   if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
      set(controls.predict.unconditional_original_prior,'Enable','off');
      set(controls.predict.unconditional_transformed_prior,'Enable','off');
      set(controls.predict.unconditional_annual_prior,'Enable','off');
      set(controls.predict.unconditional.original.zlb.height.prior,'Enable','off');
      set(controls.predict.unconditional.annual.zlb.height.prior,'Enable','off');
      set(controls.predict.unconditional.original.zlb.crps.prior,'Enable','off');
      set(controls.predict.unconditional.annual.zlb.crps.prior,'Enable','off');
      set(controls.predict.unconditional.original.zlb.prior,'Enable','off');
      set(controls.predict.unconditional.annual.zlb.prior,'Enable','off');
      set(controls.predict.unconditional.transformed.zlb.prior,'Enable','off');
      set(controls.predict.conditional.original.zlb.height.prior,'Enable','off');
      set(controls.predict.conditional.annual.zlb.height.prior,'Enable','off');
      set(controls.predict.conditional.original.zlb.crps.prior,'Enable','off');
      set(controls.predict.conditional.annual.zlb.crps.prior,'Enable','off');
      set(controls.predict.conditional.original.zlb.prior,'Enable','off');
      set(controls.predict.conditional.annual.zlb.prior,'Enable','off');
      set(controls.predict.conditional.transformed.zlb.prior,'Enable','off');
      set(controls.predict.conditional_original_prior,'Enable','off');
      set(controls.predict.conditional_annual_prior,'Enable','off');
      set(controls.predict.conditional_transformed_prior,'Enable','off');
      set(controls.predict.conditional.original.height.prior,'Enable','off');
      set(controls.predict.conditional.annual.height.prior,'Enable','off');
      set(controls.predict.conditional.original.crps.prior,'Enable','off');
      set(controls.predict.conditional.annual.crps.prior,'Enable','off');
      set(controls.predict.conditional.original.moments.prior,'Enable','off');
      set(controls.predict.conditional.original.pit.prior,'Enable','off');
      set(controls.modesty.prior,'Enable','off','UserData','');
      if isfield(controls.modesty,'state')==1;
         set(controls.modesty.state.prior,'Enable','off','UserData','');
      end;
      set(controls.predict.unconditional.original.height.prior,'Enable','off');
      set(controls.predict.unconditional.annual.height.prior,'Enable','off');
      set(controls.predict.unconditional.original.crps.prior,'Enable','off');
      set(controls.predict.unconditional.annual.crps.prior,'Enable','off');
      set(controls.predict.unconditional.original.moments.prior,'Enable','off');
      set(controls.predict.unconditional.original.pit.prior,'Enable','off');
      set(controls.predict.unconditional.original.variancedecomp.prior,'Enable','off');
   else;
      set(controls.predict.unconditional_original_prior,'Enable','on');
      if isempty(DSGEModel.ZLBPosition)==0;
         set(controls.predict.unconditional.original.zlb.prior,'Enable','on');
         if CurrINI.KSDensityExist==1;
            set(controls.predict.unconditional.original.zlb.height.prior,'Enable','on');
         else;
            set(controls.predict.unconditional.original.zlb.height.prior,'Enable','off');
         end;
         set(controls.predict.unconditional.original.zlb.crps.prior,'Enable','on');
         if CheckConditioningData(DSGEModel)==1;
            set(controls.predict.conditional.original.zlb.prior,'Enable','on');
            if CurrINI.KSDensityExist==1;
               set(controls.predict.conditional.original.zlb.height.prior,'Enable','on');
            else;
               set(controls.predict.conditional.original.zlb.height.prior,'Enable','off');
            end;
            set(controls.predict.conditional.original.zlb.crps.prior,'Enable','on');
         else;
            set(controls.predict.conditional.original.zlb.height.prior,'Enable','off');
            set(controls.predict.conditional.original.zlb.crps.prior,'Enable','off');
            set(controls.predict.conditional.original.zlb.prior,'Enable','off');
         end;
      else;
         set(controls.predict.unconditional.original.zlb.height.prior,'Enable','off');
         set(controls.predict.unconditional.original.zlb.crps.prior,'Enable','off');
         set(controls.predict.unconditional.original.zlb.prior,'Enable','off');
         set(controls.predict.conditional.original.zlb.height.prior,'Enable','off');
         set(controls.predict.conditional.original.zlb.crps.prior,'Enable','off');
         set(controls.predict.conditional.original.zlb.prior,'Enable','off');
      end;
      if isempty(DSGEModel.YTransformation)==0;
         set(controls.predict.unconditional_transformed_prior,'Enable','on');
         if isempty(DSGEModel.ZLBPosition)==0;
            set(controls.predict.unconditional.transformed.zlb.prior,'Enable','on');
            if CheckConditioningData(DSGEModel)==1;
               set(controls.predict.conditional.transformed.zlb.prior,'Enable','on');
            else;
               set(controls.predict.conditional.transformed.zlb.prior,'Enable','off');
            end;
         else;
            set(controls.predict.unconditional.transformed.zlb.prior,'Enable','off');
            set(controls.predict.conditional.transformed.zlb.prior,'Enable','off');
         end;
      else;
         set(controls.predict.unconditional_transformed_prior,'Enable','off');
         set(controls.predict.unconditional.transformed.zlb.prior,'Enable','off');
         set(controls.predict.conditional.transformed.zlb.prior,'Enable','off');
      end;
      if max(DSGEModel.annual)>1;
         set(controls.predict.unconditional_annual_prior,'Enable','on');
         if isempty(DSGEModel.ZLBPosition)==0;
            if CurrINI.KSDensityExist==1;
               set(controls.predict.unconditional.annual.zlb.height.prior,'Enable','on');
            else;
               set(controls.predict.unconditional.annual.zlb.height.prior,'Enable','off');
            end;
            set(controls.predict.unconditional.annual.zlb.crps.prior,'Enable','on');
            set(controls.predict.unconditional.annual.zlb.prior,'Enable','on');
            if CheckConditioningData(DSGEModel)==1;
               if CurrINI.KSDensityExist==1;
                  set(controls.predict.conditional.annual.zlb.height.prior,'Enable','on');
               else;
                  set(controls.predict.conditional.annual.zlb.height.prior,'Enable','off');
               end;
               set(controls.predict.conditional.annual.zlb.crps.prior,'Enable','on');
               set(controls.predict.conditional.annual.zlb.prior,'Enable','on');
            else;
               set(controls.predict.conditional.annual.zlb.height.prior,'Enable','off');
               set(controls.predict.conditional.annual.zlb.crps.prior,'Enable','off');
               set(controls.predict.conditional.annual.zlb.prior,'Enable','off');
            end;
         else;
            set(controls.predict.unconditional.annual.zlb.height.prior,'Enable','off');
            set(controls.predict.unconditional.annual.zlb.crps.prior,'Enable','off');
            set(controls.predict.unconditional.annual.zlb.prior,'Enable','off');
            set(controls.predict.conditional.annual.zlb.height.prior,'Enable','off');
            set(controls.predict.conditional.annual.zlb.crps.prior,'Enable','off');
            set(controls.predict.conditional.annual.zlb.prior,'Enable','off');
         end;
      else;
         set(controls.predict.unconditional_annual_prior,'Enable','off');
         set(controls.predict.unconditional.annual.zlb.height.prior,'Enable','off');
         set(controls.predict.unconditional.annual.zlb.crps.prior,'Enable','off');
         set(controls.predict.unconditional.annual.zlb.prior,'Enable','off');
         set(controls.predict.conditional.annual.zlb.height.prior,'Enable','off');
         set(controls.predict.conditional.annual.zlb.crps.prior,'Enable','off');
         set(controls.predict.conditional.annual.zlb.prior,'Enable','off');
      end;
      if MaxFH>0;
         set(controls.predict.unconditional.original.height.prior,'Enable','on');
         set(controls.predict.unconditional.original.crps.prior,'Enable','on');
         set(controls.predict.unconditional.original.moments.prior,'Enable','on');
         if exist('normcdf')~=0;
            set(controls.predict.unconditional.original.pit.prior,'Enable','on');
         else;
            set(controls.predict.unconditional.original.pit.prior,'Enable','off');
         end;
         if max(DSGEModel.annual)>1;
            set(controls.predict.unconditional.annual.height.prior,'Enable','on');
            set(controls.predict.unconditional.annual.crps.prior,'Enable','on');
         else;
            set(controls.predict.unconditional.annual.height.prior,'Enable','off');
            set(controls.predict.unconditional.annual.crps.prior,'Enable','off');
         end;
      else;
         set(controls.predict.unconditional.original.height.prior,'Enable','off');
         set(controls.predict.unconditional.annual.height.prior,'Enable','off');
         set(controls.predict.unconditional.original.crps.prior,'Enable','off');
         set(controls.predict.unconditional.annual.crps.prior,'Enable','off');
         set(controls.predict.unconditional.original.moments.prior,'Enable','off');
         set(controls.predict.unconditional.original.pit.prior,'Enable','off');
      end;
      set(controls.predict.unconditional.original.variancedecomp.prior,'Enable','on');
      %
      if CheckConditioningData(DSGEModel)==1;
         set(controls.predict.conditional_original_prior,'Enable','on');
         if isempty(DSGEModel.YTransformation)==0;
            set(controls.predict.conditional_transformed_prior,'Enable','on');
         else;
            set(controls.predict.conditional_transformed_prior,'Enable','off');
         end;
         if max(DSGEModel.annual)>1;
            set(controls.predict.conditional_annual_prior,'Enable','on');
         else;
            set(controls.predict.conditional_annual_prior,'Enable','off');
         end;
         %
         if MaxFH>0;
            if CurrINI.KSDensityExist==1;
               set(controls.predict.conditional.original.height.prior,'Enable','on');
            else;
               set(controls.predict.conditional.original.height.prior,'Enable','off');
            end;
            set(controls.predict.conditional.original.crps.prior,'Enable','on');
            set(controls.predict.conditional.original.moments.prior,'Enable','on');
            set(controls.predict.conditional.original.pit.prior,'Enable','on');
            if max(DSGEModel.annual)>1;
               if CurrINI.KSDensityExist==1;
                  set(controls.predict.conditional.annual.height.prior,'Enable','on');
               else;
                  set(controls.predict.conditional.annual.height.prior,'Enable','off');
               end;
               set(controls.predict.conditional.annual.crps.prior,'Enable','on');
            else;
               set(controls.predict.conditional.annual.height.prior,'Enable','off');
               set(controls.predict.conditional.annual.crps.prior,'Enable','off');
            end;
         else;
            set(controls.predict.conditional.original.height.prior,'Enable','off');
            set(controls.predict.conditional.annual.height.prior,'Enable','off');
            set(controls.predict.conditional.original.crps.prior,'Enable','off');
            set(controls.predict.conditional.annual.crps.prior,'Enable','off');
            set(controls.predict.conditional.original.moments.prior,'Enable','off');
            set(controls.predict.conditional.original.pit.prior,'Enable','off');
         end;
         %
         % check if modesty files exists
         %
         if DSGEModel.ShockControlMethod==1;
            ShockMethod = 'Direct-';
         elseif DSGEModel.ShockControlMethod==2;
            ShockMethod = 'WaggonerZha-';
         else;
            ShockMethod = 'Subset-';
         end;
         NumPredPathsStr = get(controls.forecast.predpaths,'String');
         NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
         [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
         ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-ModestyStatistics-' ShockMethod DSGEModel.NameOfModel '-' num2str(MaxPH,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-Prior.txt']);
         if FileExist(ModestyFile)==1;
            set(controls.modesty.prior,'Enable','on','UserData',ModestyFile);
         else;
            set(controls.modesty.prior,'Enable','off','UserData','');
         end;
         if isfield(controls.modesty,'state')==1;
            ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-ModestyStatistics-State-' ShockMethod DSGEModel.NameOfModel '-' num2str(MaxPH,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-Prior.txt']);
            if FileExist(ModestyFile)==1;
               set(controls.modesty.state.prior,'Enable','on','UserData',ModestyFile);
            else;
               set(controls.modesty.state.prior,'Enable','off','UserData','');
            end;
         end;
      else;
         set(controls.predict.conditional_original_prior,'Enable','off');
         set(controls.predict.conditional_annual_prior,'Enable','off');
         set(controls.predict.conditional_transformed_prior,'Enable','off');
         set(controls.predict.conditional.original.height.prior,'Enable','off');
         set(controls.predict.conditional.annual.height.prior,'Enable','off');
         set(controls.predict.conditional.original.crps.prior,'Enable','off');
         set(controls.predict.conditional.annual.crps.prior,'Enable','off');
         set(controls.predict.conditional.original.moments.prior,'Enable','off');
         set(controls.predict.conditional.original.pit.prior,'Enable','off');
         set(controls.modesty.prior,'Enable','off','UserData','');
         if isfield(controls.modesty,'state')==1;
            set(controls.modesty.state.prior,'Enable','off','UserData','');
         end;
      end;
   end;
else;
   set(controls.statespacepriordist,'Enable','off');
   set(controls.obsvarcorrs.frequencydomain.prior,'Enable','off');
   set(controls.obsvarcorrs.timedomain.prior,'Enable','off');
   set(controls.obsvarcorrs.parameterchange.prior,'Enable','off');
   set(controls.condcorrs.prior,'Enable','off');
   set(controls.statevarcorrs.frequencydomain.prior,'Enable','off');
   set(controls.statevarcorrs.timedomain.prior,'Enable','off');
   set(controls.statevarcorrs.parameterchange.prior,'Enable','off');
   set(controls.stateshockcorrs.prior,'Enable','off');
   set(controls.measurementerrorcorrs.prior,'Enable','off');
   set(controls.obsvar.predchecks.prior,'Enable','off');
   set(controls.obsvar.prior,'Enable','off');
   set(controls.statevariables.prior,'Enable','off');
   set(controls.stateshocks.prior,'Enable','off');
   set(controls.measurementerror.prior,'Enable','off');
   set(controls.hd.prior,'Enable','off');
   set(controls.irfunctions.prior,'Enable','off');
   set(controls.ovd.prior,'Enable','off');
   set(controls.ovp.prior,'Enable','off');
   set(controls.irfunctions.ann_prior,'Enable','off');
   set(controls.ovd.annprior,'Enable','off');
   set(controls.ovp.annprior,'Enable','off');
   set(controls.irfunctions.lev_prior,'Enable','off');
   set(controls.irfunctions.statevariables.prior,'Enable','off');
   set(controls.cvd.prior,'Enable','off');
   set(controls.cvd.ann_prior,'Enable','off');
   set(controls.cvd.lev_prior,'Enable','off');
   set(controls.cvd.state.prior,'Enable','off');
   set(controls.fevd.prior,'Enable','off');
   set(controls.fevd.state.prior,'Enable','off');
   set(controls.fevd.lev_prior,'Enable','off');
   if isfield(controls,'shockscenarios')==1;
      set(controls.shockscenarios.prior,'Enable','off');
      set(controls.shockscenarios.annprior,'Enable','off');
   end;
   if isfield(controls,'ovs')==1;
      set(controls.ovs.prior,'Enable','off');
      set(controls.ovs.ann_prior,'Enable','off');
   end;
   if isfield(controls,'svs')==1;
      set(controls.svs.prior,'Enable','off');
      set(controls.svs.ann_prior,'Enable','off');
      set(controls.tunedfilters.statevariables.prior,'Enable','off');
      set(controls.tunedfilters.stateshocks.prior,'Enable','off');
      set(controls.tunedfilters.measurement.prior,'Enable','off');
   end;
   set(controls.predict.unconditional_original_prior,'Enable','off');
   set(controls.predict.unconditional_transformed_prior,'Enable','off');
   set(controls.predict.unconditional_annual_prior,'Enable','off');
   set(controls.predict.unconditional.original.zlb.height.prior,'Enable','off');
   set(controls.predict.unconditional.annual.zlb.height.prior,'Enable','off');
   set(controls.predict.unconditional.original.zlb.crps.prior,'Enable','off');
   set(controls.predict.unconditional.annual.zlb.crps.prior,'Enable','off');
   set(controls.predict.unconditional.original.zlb.prior,'Enable','off');
   set(controls.predict.unconditional.annual.zlb.prior,'Enable','off');
   set(controls.predict.unconditional.transformed.zlb.prior,'Enable','off');
   set(controls.predict.conditional.original.zlb.height.prior,'Enable','off');
   set(controls.predict.conditional.annual.zlb.height.prior,'Enable','off');
   set(controls.predict.conditional.original.zlb.crps.prior,'Enable','off');
   set(controls.predict.conditional.annual.zlb.crps.prior,'Enable','off');
   set(controls.predict.conditional.original.zlb.prior,'Enable','off');
   set(controls.predict.conditional.annual.zlb.prior,'Enable','off');
   set(controls.predict.conditional.transformed.zlb.prior,'Enable','off');
   set(controls.predict.conditional_original_prior,'Enable','off');
   set(controls.predict.conditional_annual_prior,'Enable','off');
   set(controls.predict.conditional_transformed_prior,'Enable','off');
   set(controls.predict.conditional.original.height.prior,'Enable','off');
   set(controls.predict.conditional.annual.height.prior,'Enable','off');
   set(controls.predict.conditional.original.crps.prior,'Enable','off');
   set(controls.predict.conditional.annual.crps.prior,'Enable','off');
   set(controls.predict.conditional.original.moments.prior,'Enable','off');
   set(controls.predict.conditional.original.pit.prior,'Enable','off');
   set(controls.modesty.prior,'Enable','off','UserData','');
   if isfield(controls.modesty,'state')==1;
      set(controls.modesty.state.prior,'Enable','off','UserData','');
   end;
   set(controls.predict.unconditional.original.height.prior,'Enable','off');
   set(controls.predict.unconditional.annual.height.prior,'Enable','off');
   set(controls.predict.unconditional.original.crps.prior,'Enable','off');
   set(controls.predict.unconditional.annual.crps.prior,'Enable','off');
   set(controls.predict.unconditional.original.moments.prior,'Enable','off');
   set(controls.predict.unconditional.original.pit.prior,'Enable','off');
   set(controls.predict.unconditional.original.variancedecomp.prior,'Enable','off');
end;
%
% adaptive learning and prior draws
%
if FileExist(DSGEModel.SystemPriorFile)==0;
   ALPriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-AdaptiveLearning-' DSGEModel.NameOfModel '.mat']);
else;
   ALPriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-AdaptiveLearning-' DSGEModel.NameOfModel '.mat']);
end;
if FileExist(ALPriorDrawsFile)==1;
   if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
      set(controls.learningtools.predictivedist.unconditional.original.height.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.height.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.crps.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.crps.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.moments.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.pit.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.zlb.height.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.zlb.crps.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.zlb.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.zlb.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.transformed.zlb.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.prior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.transformed.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.height.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.height.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.crps.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.crps.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.moments.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.pit.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.transformed.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.zlb.height.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.zlb.height.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.zlb.crps.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.zlb.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.zlb.prior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.transformed.zlb.prior,'Enable','off');
      set(controls.learning.viewmenu.modesty.prior,'Enable','off','UserData','');
   else;
      if exist('MaxFH')==0;
         MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
      end;
      if MaxFH>0;
         set(controls.learningtools.predictivedist.unconditional.original.height.prior,'Enable','on');
         set(controls.learningtools.predictivedist.unconditional.original.crps.prior,'Enable','on');
         set(controls.learningtools.predictivedist.unconditional.original.moments.prior,'Enable','on');
         set(controls.learningtools.predictivedist.unconditional.original.pit.prior,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.learningtools.predictivedist.unconditional.annual.height.prior,'Enable','on');
            set(controls.learningtools.predictivedist.unconditional.annual.crps.prior,'Enable','on');
         else;
            set(controls.learningtools.predictivedist.unconditional.annual.height.prior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.crps.prior,'Enable','off');
         end;
         if isempty(DSGEModel.ZLBPosition)==0;
            set(controls.learningtools.predictivedist.unconditional.original.zlb.height.prior,'Enable','on');
            set(controls.learningtools.predictivedist.unconditional.original.zlb.crps.prior,'Enable','on');
            set(controls.learningtools.predictivedist.unconditional.original.zlb.prior,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.prior,'Enable','on');
               set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.prior,'Enable','on');
               set(controls.learningtools.predictivedist.unconditional.annual.zlb.prior,'Enable','on');
            else;
               set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.prior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.prior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.annual.zlb.prior,'Enable','off');
            end;
            if isempty(DSGEModel.YTransformation)==0;
               set(controls.learningtools.predictivedist.unconditional.transformed.zlb.prior,'Enable','on');
            else;
               set(controls.learningtools.predictivedist.unconditional.transformed.zlb.prior,'Enable','off');
            end;
         else;
            set(controls.learningtools.predictivedist.unconditional.original.zlb.height.prior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.prior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.original.zlb.crps.prior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.prior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.original.zlb.prior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.zlb.prior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.transformed.zlb.prior,'Enable','off');
         end;
         set(controls.learningtools.predictivedist.unconditional.original.prior,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.learningtools.predictivedist.unconditional.annual.prior,'Enable','on');
         else;
            set(controls.learningtools.predictivedist.unconditional.annual.prior,'Enable','off');
         end;
         if isempty(DSGEModel.YTransformation)==0;
            set(controls.learningtools.predictivedist.unconditional.transformed.prior,'Enable','on');
         else;
            set(controls.learningtools.predictivedist.unconditional.transformed.prior,'Enable','off');
         end;
         if CheckConditioningData(DSGEModel)==1;
            set(controls.learningtools.predictivedist.conditional.original.height.prior,'Enable','on');
            set(controls.learningtools.predictivedist.conditional.original.crps.prior,'Enable','on');
            set(controls.learningtools.predictivedist.conditional.original.moments.prior,'Enable','on');
            set(controls.learningtools.predictivedist.conditional.original.pit.prior,'Enable','on');
            set(controls.learningtools.predictivedist.conditional.original.prior,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.learningtools.predictivedist.conditional.annual.height.prior,'Enable','on');
               set(controls.learningtools.predictivedist.conditional.annual.crps.prior,'Enable','on');
               set(controls.learningtools.predictivedist.conditional.annual.prior,'Enable','on');
            else;
               set(controls.learningtools.predictivedist.conditional.annual.height.prior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.crps.prior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.prior,'Enable','off');
            end;
            if isempty(DSGEModel.YTransformation)==0;
               set(controls.learningtools.predictivedist.conditional.transformed.prior,'Enable','on');
            else;
               set(controls.learningtools.predictivedist.conditional.transformed.prior,'Enable','off');
            end;
            %
            if isempty(DSGEModel.ZLBPosition)==0;
               set(controls.learningtools.predictivedist.conditional.original.zlb.height.prior,'Enable','on');
               set(controls.learningtools.predictivedist.conditional.original.zlb.crps.prior,'Enable','on');
               set(controls.learningtools.predictivedist.conditional.original.zlb.prior,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.learningtools.predictivedist.conditional.annual.zlb.height.prior,'Enable','on');
                  set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.prior,'Enable','on');
                  set(controls.learningtools.predictivedist.conditional.annual.zlb.prior,'Enable','on');
               else;
                  set(controls.learningtools.predictivedist.conditional.annual.zlb.height.prior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.prior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.annual.zlb.prior,'Enable','off');
               end;
               if isempty(DSGEModel.YTransformation)==0;
                  set(controls.learningtools.predictivedist.conditional.transformed.zlb.prior,'Enable','on');
               else;
                  set(controls.learningtools.predictivedist.conditional.transformed.zlb.prior,'Enable','off');
               end;
            else;
               set(controls.learningtools.predictivedist.conditional.original.zlb.height.prior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.zlb.height.prior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.zlb.crps.prior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.prior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.zlb.prior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.zlb.prior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.transformed.zlb.prior,'Enable','off');
            end;
            %
            % check if we have a file for the modesty statistic at the posterior mode
            %
            [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
            NumPredPathsStr = get(controls.forecast.predpaths,'String');
            NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
            if DSGEModel.ShockControlMethod==1;
               ShockMethod = 'Direct-';
            elseif DSGEModel.ShockControlMethod==2;
               ShockMethod = 'WaggonerZha-';
            else;
               ShockMethod = 'Subset-';
            end;
            ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-ModestyStatistics-AdaptiveLearning-' int2str(DSGEModel.FixedBeliefsForProj) '-' ShockMethod DSGEModel.NameOfModel '-' num2str(MaxPH,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-Prior.txt']);
            if FileExist(ModestyFile)==1;
               set(controls.learning.viewmenu.modesty.prior,'Enable','on','UserData',ModestyFile);
            else;
               set(controls.learning.viewmenu.modesty.prior,'Enable','off','UserData','');
            end;
         else;
            set(controls.learningtools.predictivedist.conditional.original.height.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.height.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.crps.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.crps.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.moments.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.pit.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.transformed.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.zlb.height.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.zlb.height.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.zlb.crps.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.zlb.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.zlb.prior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.transformed.zlb.prior,'Enable','off');
            set(controls.learning.viewmenu.modesty.prior,'Enable','off','UserData','');
         end;
      else;
         set(controls.learningtools.predictivedist.unconditional.original.height.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.height.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.crps.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.crps.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.moments.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.pit.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.zlb.height.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.zlb.crps.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.zlb.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.zlb.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.transformed.zlb.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.prior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.transformed.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.height.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.height.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.crps.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.crps.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.moments.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.pit.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.transformed.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.zlb.height.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.zlb.height.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.zlb.crps.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.zlb.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.zlb.prior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.transformed.zlb.prior,'Enable','off');
         set(controls.learning.viewmenu.modesty.prior,'Enable','off','UserData','');
      end;
   end;
else;
   set(controls.learningtools.predictivedist.unconditional.original.height.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.height.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.crps.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.crps.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.moments.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.pit.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.zlb.height.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.zlb.crps.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.zlb.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.zlb.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.transformed.zlb.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.prior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.transformed.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.height.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.height.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.crps.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.crps.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.moments.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.pit.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.transformed.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.zlb.height.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.zlb.height.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.zlb.crps.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.zlb.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.zlb.prior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.transformed.zlb.prior,'Enable','off');
   set(controls.learning.viewmenu.modesty.prior,'Enable','off','UserData','');
end;
%
% test if we should enable the posterior mode functions
%
if VerifyPosteriorModeEstimation(DSGEModel)==1;
   MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
   %
   if FileExist(DSGEModel.PriorFile)==1;
      set(controls.postmode,'Enable','on');
      set(controls.postmodemenu,'Enable','on');
      set(controls.dsgevarmargmodemenu,'Enable','on');
      set(controls.dsgevarjointmodemenu,'Enable','on');
   else;
      set(controls.postmode,'Enable','off');
      set(controls.postmodemenu,'Enable','off');
      set(controls.dsgevarmargmodemenu,'Enable','off');
      set(controls.dsgevarjointmodemenu,'Enable','off');
   end;
   set(controls.configureshocks,'Enable','on');
   set(controls.configureshocksmenu,'Enable','on');
   set(controls.shockgroupmenu,'Enable','on');
   set(controls.shockgroup,'Enable','on');
   set(controls.initialstatevaluesmenu,'Enable','on');
   set(controls.unitrootstatemenu,'Enable','on');
   if CheckConditioningData(DSGEModel)==1;
      if MaxFH>0;
         set(controls.viewconditionalvars,'Enable','on');
      else;
         set(controls.viewconditionalvars,'Enable','off');
      end;
      set(controls.setconditionalshocks,'Enable','on');
      set(controls.setconditionalvars,'Enable','on');
      if isfield(controls,'setconditionalshocksmixed')==1;
         set(controls.setconditionalshocksmixed,'Enable','on');
      end;
      if length(DSGEModel.ConditionalShocks)>=1;
         set(controls.reorderconditionalshocks,'Enable','on');
      else;
         set(controls.reorderconditionalshocks,'Enable','off');
      end;
   else;
      set(controls.setconditionalshocks,'Enable','off');
      set(controls.setconditionalvars,'Enable','off');
      set(controls.viewconditionalvars,'Enable','off');
      if isfield(controls,'setconditionalshocksmixed')==1;
         set(controls.setconditionalshocksmixed,'Enable','off');
      end;
      set(controls.reorderconditionalshocks,'Enable','off');
   end;
   if CheckStateCondData(DSGEModel)==1;
      if MaxFH>0;
         set(controls.viewstateconditionalvars,'Enable','on');
      else;
         set(controls.viewstateconditionalvars,'Enable','off');
      end;
      set(controls.setstateconditionalshocks,'Enable','on');
      set(controls.setstateconditionalvars,'Enable','on');
      set(controls.setstateconditionalshocksmixed,'Enable','on');
      if length(DSGEModel.ZetaConditionalShocks)>=1;
         set(controls.reorderstateconditionalshocks,'Enable','on');
      else;
         set(controls.reorderstateconditionalshocks,'Enable','off');
      end;
   else;
      if isfield(controls,'viewstateconditionalvars')==1;
         set(controls.viewstateconditionalvars,'Enable','off');
         set(controls.setstateconditionalshocks,'Enable','off');
         set(controls.setstateconditionalvars,'Enable','off');
         set(controls.setstateconditionalshocksmixed,'Enable','off');
         set(controls.reorderstateconditionalshocks,'Enable','off');
      end;
   end;
   if isfield(controls,'ovs')==1;
      if CheckScenarioData(DSGEModel)==1;
         set(controls.ovs.viewscenariovars,'Enable','on');
         set(controls.ovs.setscenariovars,'Enable','on');
         set(controls.ovs.setscenarioshocks,'Enable','on');
         if isfield(controls.ovs,'scenariodata')==1;
            set(controls.ovs.savescenariodata,'Enable','on');
            set(controls.ovs.editscenariodata,'Enable','on');
            set(controls.ovs.viewscenariodata,'Enable','on');
            set(controls.ovs.exportscenariodata,'Enable','on');
            if (isempty(GetFiles(FixFilePath([DSGEModel.OutputDirectory '\ovsdata']),'mat'))==0)|(isempty(DSGEModel.CompData)==0);
               set(controls.ovs.openscenariodata,'Enable','on');
            else;
               set(controls.ovs.openscenariodata,'Enable','off');
            end;
         end;
         if length(DSGEModel.ScenarioShocks)>=1;
            set(controls.ovs.reorderscenarioshocks,'Enable','on');
         else;
            set(controls.ovs.reorderscenarioshocks,'Enable','off');
         end;
      else;
         set(controls.ovs.viewscenariovars,'Enable','off');
         set(controls.ovs.setscenariovars,'Enable','off');
         set(controls.ovs.setscenarioshocks,'Enable','off');
         set(controls.ovs.reorderscenarioshocks,'Enable','off');
         if isfield(controls.ovs,'scenariodata')==1;
            set(controls.ovs.savescenariodata,'Enable','off');
            set(controls.ovs.editscenariodata,'Enable','off');
            set(controls.ovs.viewscenariodata,'Enable','off');
            set(controls.ovs.exportscenariodata,'Enable','off');
            set(controls.ovs.openscenariodata,'Enable','off');
         end;
      end;
   end;
   if isfield(controls,'svs')==1;
      if CheckStateScenarioData(DSGEModel)==1;
         set(controls.svs.viewstatescenariovars,'Enable','on');
         set(controls.svs.setstatescenariovars,'Enable','on');
         set(controls.svs.setstatescenarioshocks,'Enable','on');
         if length(DSGEModel.StateScenarioShocks)>=1;
            set(controls.svs.reorderstatescenarioshocks,'Enable','on');
         else;
            set(controls.svs.reorderstatescenarioshocks,'Enable','off');
         end;
         set(controls.svs.stateconstraints,'Enable','on');
      else;
         set(controls.svs.viewstatescenariovars,'Enable','off');
         set(controls.svs.setstatescenariovars,'Enable','off');
         set(controls.svs.setstatescenarioshocks,'Enable','off');
         set(controls.svs.reorderstatescenarioshocks,'Enable','off');
         set(controls.svs.stateconstraints,'Enable','off');
      end;
   end;
   ModeTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeResults-' DSGEModel.NameOfModel '.txt']);
   if FileExist(ModeTextFile)==1;
      set(controls.modeinfo,'Enable','on','UserData',ModeTextFile);
   else;
      set(controls.modeinfo,'Enable','off','UserData','');
   end;
   ModeSummaryTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeSummary-' DSGEModel.NameOfModel '.txt']);
   if FileExist(ModeSummaryTextFile)==1;
      set(controls.modesummary,'Enable','on','UserData',ModeSummaryTextFile);
   else;
      set(controls.modesummary,'Enable','off','UserData','');
   end;
   TxtFileName = FixFilePath([DSGEModel.OutputDirectory '\OptErrorReport-' DSGEModel.NameOfModel '.txt']);
   if FileExist(TxtFileName)==1;
      set(controls.opterrorsummary,'Enable','on','UserData',TxtFileName);
   else;
      set(controls.opterrorsummary,'Enable','off','UserData','');
   end;
   set(controls.postsample.laplace.parameterchange.initialvalues,'Enable','on');
   set(controls.postsample.laplaceinitval,'Enable','on');
   set(controls.dsgeeigenvalues.initialvalues,'Enable','on');
   set(controls.viewpriorvalue.initialvalues,'Enable','on');
   set(controls.dsgetovareigenvalues.initialvalues,'Enable','on');
   set(controls.informationmatrix.frequencydomain.initialvalues,'Enable','on');
   set(controls.informationmatrix.timedomain.initialvalues,'Enable','on');
   set(controls.statespaceinitialvalues,'Enable','on');
   set(controls.parametervalues.initialvalues,'Enable','on');
   set(controls.properties.initialvalues,'Enable','on');
   set(controls.structuralforminitialvalues,'Enable','on');
   set(controls.statespacesaveinitialvalues,'Enable','on');
   set(controls.saveinversehessian,'Enable','on');
   if DSGEModel.n>1;
      set(controls.obsvarcorrs.frequencydomain.initialvalues,'Enable','on');
      set(controls.condcorrs.initialvalues,'Enable','on');
   else;
      set(controls.obsvarcorrs.frequencydomain.initialvalues,'Enable','off');
      set(controls.condcorrs.initialvalues,'Enable','off');
   end;
   set(controls.obsvarcorrs.timedomain.initialvalues,'Enable','on');
   set(controls.obsvarcorrs.parameterchange.initialvalues,'Enable','on');
   set(controls.simulatedata.initialvalues,'Enable','on');
   if length(DSGEModel.StateVariablePositions)>1;
      set(controls.statevarcorrs.frequencydomain.initialvalues,'Enable','on');
   else;
      set(controls.statevarcorrs.frequencydomain.initialvalues,'Enable','off');
   end;
   set(controls.statevarcorrs.timedomain.initialvalues,'Enable','on');
   set(controls.statevarcorrs.parameterchange.initialvalues,'Enable','on');
   set(controls.irfunctions.initialvalues,'Enable','on');
   set(controls.irfunctions.permanentshock.initialvalues,'Enable','on');
   set(controls.irfunctions.parameterchange.initialvalues,'Enable','on');
   if max(DSGEModel.annual)>1;
      set(controls.irfunctions.ann_initialvalues,'Enable','on');
      set(controls.cvd.ann_initialvalues,'Enable','on');
      set(controls.ovd.anninitialvalues,'Enable','on');
      set(controls.ovp.anninitialvalues,'Enable','on');
   else;
      set(controls.irfunctions.ann_initialvalues,'Enable','off');
      set(controls.cvd.ann_initialvalues,'Enable','off');
      set(controls.ovd.anninitialvalues,'Enable','off');
      set(controls.ovp.anninitialvalues,'Enable','off');
   end;
   set(controls.hd.initialvalues,'Enable','on');
   set(controls.obsweights.decomp.states.initialvalues,'Enable','on');
   set(controls.obsweights.decomp.shocks.initialvalues,'Enable','on');
   set(controls.obsweights.weights.states.initialvalues,'Enable','on');
   set(controls.obsweights.weights.shocks.initialvalues,'Enable','on');
   set(controls.ovd.initialvalues,'Enable','on');
   set(controls.ovp.initialvalues,'Enable','on');
   set(controls.svd.initialvalues,'Enable','on');
   set(controls.corrdecomp.obsvar.initialvalues,'Enable','on');
   set(controls.corrdecomp.statevar.initialvalues,'Enable','on');
   set(controls.spectraldecomp.obsvar.initialvalues,'Enable','on');
   set(controls.spectraldecomp.statevar.initialvalues,'Enable','on');
   set(controls.fevd.initialvalues,'Enable','on');
   set(controls.fevd.lev_initialvalues,'Enable','on');
   set(controls.cvd.initialvalues,'Enable','on');
   set(controls.cvd.state.initialvalues,'Enable','on');
   set(controls.fevd.state.initialvalues,'Enable','on');
   if sum(DSGEModel.levels)<DSGEModel.n;
      set(controls.cvd.lev_initialvalues,'Enable','on');
      set(controls.irfunctions.lev_initialvalues,'Enable','on');
   else;
      set(controls.cvd.lev_initialvalues,'Enable','off');
      set(controls.irfunctions.lev_initialvalues,'Enable','off');
   end;
   set(controls.ps.initialvalues,'Enable','on');
   if max(DSGEModel.annual)>1;
      set(controls.ps.anninitialvalues,'Enable','on');
   else;
      set(controls.ps.anninitialvalues,'Enable','off');
   end;
   set(controls.statevariables.initialvalues,'Enable','on');
   set(controls.obsvar.initialvalues,'Enable','on');
   set(controls.stateshocks.initialvalues,'Enable','on');
   set(controls.measurementerror.initialvalues,'Enable','on');
   set(controls.loglikelihood.initialvalues,'Enable','on');
   if isfield(controls,'ovs')==1;
      if CheckScenarioData(DSGEModel)==1;
         set(controls.ovs.initialvalues,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.ovs.anninitialvalues,'Enable','on');
         else;
            set(controls.ovs.anninitialvalues,'Enable','off');
         end;
      else;
         set(controls.ovs.initialvalues,'Enable','off');
         set(controls.ovs.anninitialvalues,'Enable','off');
      end;
   end;
   if isfield(controls,'svs')==1;
      if CheckStateScenarioData(DSGEModel)==1;
         set(controls.svs.initialvalues,'Enable','on');
         set(controls.tunedfilters.statevariables.initialvalues,'Enable','on');
         set(controls.tunedfilters.stateshocks.initialvalues,'Enable','on');
         set(controls.tunedfilters.measurement.initialvalues,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.svs.anninitialvalues,'Enable','on');
         else;
            set(controls.svs.anninitialvalues,'Enable','off');
         end;
      else;
         set(controls.svs.initialvalues,'Enable','off');
         set(controls.svs.anninitialvalues,'Enable','off');
         set(controls.tunedfilters.statevariables.initialvalues,'Enable','off');
         set(controls.tunedfilters.stateshocks.initialvalues,'Enable','off');
         set(controls.tunedfilters.measurement.initialvalues,'Enable','off');
      end;
   end;
   if isfield(controls,'shockscenarios')==1;
      if MaxFH>0;
         set(controls.shockscenarios.initialvalues,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.shockscenarios.anninitialvalues,'Enable','on');
         else;
            set(controls.shockscenarios.anninitialvalues,'Enable','off');
         end;
      else;
         set(controls.shockscenarios.initialvalues,'Enable','off');
         set(controls.shockscenarios.anninitialvalues,'Enable','off');
      end;
   end;
   if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
      set(controls.predict.unconditional_original_initialvalues,'Enable','off');
      set(controls.predict.unconditional_annual_initialvalues,'Enable','off');
      set(controls.predict.unconditional_transformed_initialvalues,'Enable','off');
      set(controls.predict.conditional_original_initialvalues,'Enable','off');
      set(controls.predict.conditional_annual_initialvalues,'Enable','off');
      set(controls.predict.conditional_transformed_initialvalues,'Enable','off');
      set(controls.modesty.initialvalues,'Enable','off','UserData','');
      set(controls.predict.unconditional.original.zlb.initialvalues,'Enable','off');
      set(controls.predict.unconditional.annual.zlb.initialvalues,'Enable','off');
      set(controls.predict.unconditional.transformed.zlb.initialvalues,'Enable','off');
      set(controls.predict.conditional.original.zlb.initialvalues,'Enable','off');
      set(controls.predict.conditional.annual.zlb.initialvalues,'Enable','off');
      set(controls.predict.conditional.transformed.zlb.initialvalues,'Enable','off');
      set(controls.predict.unconditional.original.obsweightdecomp.initialvalues,'Enable','off');
      set(controls.predict.unconditional.annual.obsweightdecomp.initialvalues,'Enable','off');
      if isfield(controls.modesty,'state')==1;
         set(controls.modesty.state.initialvalues,'Enable','off','UserData','');
      end;
      set(controls.predict.unconditional.original.height.initialvalues,'Enable','off');
      set(controls.predict.unconditional.annual.height.initialvalues,'Enable','off');
   else;
      set(controls.predict.unconditional_original_initialvalues,'Enable','on');
      set(controls.predict.unconditional.original.obsweightdecomp.initialvalues,'Enable','on');
      if isempty(DSGEModel.ZLBPosition)==0;
         set(controls.predict.unconditional.original.zlb.initialvalues,'Enable','on');
      else;
         set(controls.predict.unconditional.original.zlb.initialvalues,'Enable','off');
      end;
      if isempty(DSGEModel.YTransformation)==0;
         set(controls.predict.unconditional_transformed_initialvalues,'Enable','on');
         if isempty(DSGEModel.ZLBPosition)==0;
            set(controls.predict.unconditional.transformed.zlb.initialvalues,'Enable','on');
         else;
            set(controls.predict.unconditional.transformed.zlb.initialvalues,'Enable','off');
         end;
      else;
         set(controls.predict.unconditional_transformed_initialvalues,'Enable','off');
         set(controls.predict.unconditional.transformed.zlb.initialvalues,'Enable','off');
      end;
      if max(DSGEModel.annual)>1;
         set(controls.predict.unconditional_annual_initialvalues,'Enable','on');
         set(controls.predict.unconditional.annual.obsweightdecomp.initialvalues,'Enable','on');
         if isempty(DSGEModel.ZLBPosition)==0;
            set(controls.predict.unconditional.annual.zlb.initialvalues,'Enable','on');
         else;
            set(controls.predict.unconditional.annual.zlb.initialvalues,'Enable','off');
         end;
      else;
         set(controls.predict.unconditional_annual_initialvalues,'Enable','off');
         set(controls.predict.unconditional.annual.zlb.initialvalues,'Enable','off');
         set(controls.predict.unconditional.annual.obsweightdecomp.initialvalues,'Enable','off');
      end;
      if MaxFH>0;
         set(controls.predict.unconditional.original.height.initialvalues,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.predict.unconditional.annual.height.initialvalues,'Enable','on');
         else;
            set(controls.predict.unconditional.annual.height.initialvalues,'Enable','off');
         end;
      else;
         set(controls.predict.unconditional.original.height.initialvalues,'Enable','off');
         set(controls.predict.unconditional.annual.height.initialvalues,'Enable','off');
      end;
      if CheckConditioningData(DSGEModel)==1;
         set(controls.predict.conditional_original_initialvalues,'Enable','on');
         if isempty(DSGEModel.ZLBPosition)==0;
            set(controls.predict.conditional.original.zlb.initialvalues,'Enable','on');
         else;
            set(controls.predict.conditional.original.zlb.initialvalues,'Enable','off');
         end;
         if isempty(DSGEModel.YTransformation)==0;
            set(controls.predict.conditional_transformed_initialvalues,'Enable','on');
            if isempty(DSGEModel.ZLBPosition)==0;
               set(controls.predict.conditional.transformed.zlb.initialvalues,'Enable','on');
            else;
               set(controls.predict.conditional.transformed.zlb.initialvalues,'Enable','off');
            end;
         else;
            set(controls.predict.conditional_transformed_initialvalues,'Enable','off');
            set(controls.predict.conditional.transformed.zlb.initialvalues,'Enable','off');
         end;
         %
         % check if we have a file for the modesty statistic at the posterior mode
         %
         [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
         NumPredPathsStr = get(controls.forecast.predpaths,'String');
         NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
         if DSGEModel.ShockControlMethod==1;
            ShockMethod = 'Direct-';
         elseif DSGEModel.ShockControlMethod==2;
            ShockMethod = 'WaggonerZha-';
         else;
            ShockMethod = 'Subset-';
         end;
         ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-ModestyStatistics-' ShockMethod DSGEModel.NameOfModel '-' num2str(MaxPH,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-InitialValues.txt']);
         if FileExist(ModestyFile)==1;
            set(controls.modesty.initialvalues,'Enable','on','UserData',ModestyFile);
         else;
            set(controls.modesty.initialvalues,'Enable','off','UserData','');
         end;
         if isfield(controls.modesty,'state')==1;
            ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-ModestyStatistics-State-' ShockMethod DSGEModel.NameOfModel '-' num2str(MaxPH,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-InitialValues.txt']);
            if FileExist(ModestyFile)==1;
               set(controls.modesty.state.initialvalues,'Enable','on','UserData',ModestyFile);
            else;
               set(controls.modesty.state.initialvalues,'Enable','off','UserData','');
            end;
         end;
         if max(DSGEModel.annual)>1;
            set(controls.predict.conditional_annual_initialvalues,'Enable','on');
            if isempty(DSGEModel.ZLBPosition)==0;
               set(controls.predict.conditional.annual.zlb.initialvalues,'Enable','on');
            else;
               set(controls.predict.conditional.annual.zlb.initialvalues,'Enable','off');
            end;
         else;
            set(controls.predict.conditional_annual_initialvalues,'Enable','off');
            set(controls.predict.conditional.annual.zlb.initialvalues,'Enable','off');
         end;
      else;
         set(controls.predict.conditional_original_initialvalues,'Enable','off');
         set(controls.predict.conditional_annual_initialvalues,'Enable','off');
         set(controls.predict.conditional_transformed_initialvalues,'Enable','off');
         set(controls.modesty.initialvalues,'Enable','off','UserData','');
         set(controls.predict.conditional.original.zlb.initialvalues,'Enable','off');
         set(controls.predict.conditional.annual.zlb.initialvalues,'Enable','off');
         set(controls.predict.conditional.transformed.zlb.initialvalues,'Enable','off');
         if isfield(controls.modesty,'state')==1;
            set(controls.modesty.state.initialvalues,'Enable','off','UserData','');
         end;
      end;
   end;
   set(controls.stateshockcorrs.initialvalues,'Enable','on');
   set(controls.measurementerrorcorrs.initialvalues,'Enable','on');
   if FileExist(DSGEModel.PriorFile)==1;
      set(controls.viewprior,'Enable','on');
      if FileExist(DSGEModel.SystemPriorFile)==1;
         set(controls.viewbivariateprior,'Enable','on');
         set(controls.systempriormodemenu,'Enable','on');
         set(controls.systempriorcorrelations,'Enable','on');
      else;
         set(controls.viewbivariateprior,'Enable','off');
         set(controls.systempriormodemenu,'Enable','off');
         set(controls.systempriorcorrelations,'Enable','off');
      end;
      set(controls.priorsampling,'Enable','on');
      set(controls.priorsamplingmenu,'Enable','on');
      set(controls.montecarlofiltering,'Enable','on');
   else;
      set(controls.viewprior,'Enable','off');
      set(controls.viewbivariateprior,'Enable','off');
      set(controls.systempriormodemenu,'Enable','off');
      set(controls.systempriorcorrelations,'Enable','off');
      set(controls.priorsampling,'Enable','off');
      set(controls.priorsamplingmenu,'Enable','off');
      set(controls.montecarlofiltering,'Enable','off');
   end;
   if DSGEModel.n==length(DSGEModel.DSGEVARShocks);
      set(controls.dsgevarshocksmenu,'Enable','on');
   else;
      set(controls.dsgevarshocksmenu,'Enable','off');
   end;
   set(controls.dsgevarpriorsamplingmenu,'Enable','on');
   set(controls.dsgevarview.varmodel.initialvalues,'Enable','on');
   set(controls.dsgevarview.eigenvalues.initialvalues,'Enable','on');
   set(controls.dsgevarview.sequentialmarglike.laplace.initialvalues,'Enable','on');
   set(controls.dsgevarview.priordensity.varparameter,'Enable','on');
   set(controls.dsgevarview.priordensity.sigmaparameter,'Enable','on');
   set(controls.dsgevarview.priordensity.a0parameter,'Enable','on');
   set(controls.dsgevartools.simulatedata.initialvalues,'Enable','on');
   if DSGEModel.n>1;
      set(controls.dsgevartools.obscorr.frequencydomain.initialvalues,'Enable','on');
      set(controls.dsgevartools.condcorr.initialvalues,'Enable','on');
   else;
      set(controls.dsgevartools.obscorr.frequencydomain.initialvalues,'Enable','off');
      set(controls.dsgevartools.condcorr.initialvalues,'Enable','off');
   end;
   set(controls.dsgevartools.obscorr.timedomain.initialvalues,'Enable','on');
   set(controls.dsgevartools.obscorr.parameterchange.initialvalues,'Enable','on');
   set(controls.dsgevartools.loglikelihood.initialvalues,'Enable','on');
   if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
      set(controls.dsgevartools.forecast.unconditional.original.initialvalues,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.annual.initialvalues,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.transformed.initialvalues,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.height.initialvalues,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.annual.height.initialvalues,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.original.initialvalues,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.annual.initialvalues,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.transformed.initialvalues,'Enable','off');
      set(controls.dsgevarview.modesty.initialvalues,'Enable','off','UserData','');
   else;
      set(controls.dsgevartools.forecast.unconditional.original.initialvalues,'Enable','on');
      if MaxFH>0;
         set(controls.dsgevartools.forecast.unconditional.original.height.initialvalues,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.dsgevartools.forecast.unconditional.annual.height.initialvalues,'Enable','on');
         else;
            set(controls.dsgevartools.forecast.unconditional.annual.height.initialvalues,'Enable','off');
         end;
      else;
         set(controls.dsgevartools.forecast.unconditional.original.height.initialvalues,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.annual.height.initialvalues,'Enable','off');
      end;
      if max(DSGEModel.annual)>1;
         set(controls.dsgevartools.forecast.unconditional.annual.initialvalues,'Enable','on');
      else;
         set(controls.dsgevartools.forecast.unconditional.annual.initialvalues,'Enable','off');
      end;
      if isempty(DSGEModel.YTransformation)==0;
         set(controls.dsgevartools.forecast.unconditional.transformed.initialvalues,'Enable','on');
      else;
         set(controls.dsgevartools.forecast.unconditional.transformed.initialvalues,'Enable','off');
      end;
      if CheckConditioningData(DSGEModel)==1;
         set(controls.dsgevartools.forecast.conditional.original.initialvalues,'Enable','on');
         [ModestyStatus,ModestyResults] = GetDSGEVARModestyResults(DSGEModel,controls,MaxPH,'InitialValues');
         if ModestyStatus==1;
            set(controls.dsgevarview.modesty.initialvalues,'Enable','on','UserData',ModestyResults);
         else;
            set(controls.dsgevarview.modesty.initialvalues,'Enable','off','UserData','');
         end;
         if max(DSGEModel.annual)>1;
            set(controls.dsgevartools.forecast.conditional.annual.initialvalues,'Enable','on');
         else;
            set(controls.dsgevartools.forecast.conditional.annual.initialvalues,'Enable','off');
         end;
         if isempty(DSGEModel.YTransformation)==0;
            set(controls.dsgevartools.forecast.conditional.transformed.initialvalues,'Enable','on');
         else;
            set(controls.dsgevartools.forecast.conditional.transformed.initialvalues,'Enable','off');
         end;
      else;
         set(controls.dsgevartools.forecast.conditional.original.initialvalues,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.annual.initialvalues,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.transformed.initialvalues,'Enable','off');
         set(controls.dsgevarview.modesty.initialvalues,'Enable','off','UserData','');
      end;
   end;
   if DSGEModel.n==length(DSGEModel.DSGEVARShocks);
      set(controls.dsgevartools.shocks.initialvalues,'Enable','on');
      set(controls.dsgevartools.shockcorr.initialvalues,'Enable','on');
      set(controls.dsgevartools.decomposition.ovd.decomp.original.initialvalues,'Enable','on');
      set(controls.dsgevartools.decomposition.ovd.paths.original.initialvalues,'Enable','on');
      set(controls.dsgevartools.decomposition.corrdecomp.initialvalues,'Enable','on');
      set(controls.dsgevartools.decomposition.spectraldecomp.initialvalues,'Enable','on');
      set(controls.dsgevartools.decomposition.fevd.original.initialvalues,'Enable','on');
      set(controls.dsgevartools.irfunction.original.initialvalues,'Enable','on');
      if max(DSGEModel.annual)>1;
         set(controls.dsgevartools.decomposition.ovd.decomp.annual.initialvalues,'Enable','on');
         set(controls.dsgevartools.decomposition.ovd.paths.annual.initialvalues,'Enable','on');
         set(controls.dsgevartools.irfunction.annual.initialvalues,'Enable','on');
      else;
         set(controls.dsgevartools.decomposition.ovd.decomp.annual.initialvalues,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.paths.annual.initialvalues,'Enable','off');
         set(controls.dsgevartools.irfunction.annual.initialvalues,'Enable','off');
      end;
      if sum(DSGEModel.levels)<DSGEModel.n;
         set(controls.dsgevartools.decomposition.fevd.levels.initialvalues,'Enable','on');
         set(controls.dsgevartools.irfunction.levels.initialvalues,'Enable','on');
      else;
         set(controls.dsgevartools.decomposition.fevd.levels.initialvalues,'Enable','off');
         set(controls.dsgevartools.irfunction.levels.initialvalues,'Enable','off');
      end;
      if isfield(controls.dsgevartools,'obsvarscenario')==1;
         if CheckScenarioData(DSGEModel)==1;
            set(controls.dsgevartools.obsvarscenario.original.initialvalues,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.dsgevartools.obsvarscenario.annual.initialvalues,'Enable','on');
            else;
               set(controls.dsgevartools.obsvarscenario.annual.initialvalues,'Enable','off');
            end;
         else;
            set(controls.dsgevartools.obsvarscenario.original.initialvalues,'Enable','off');
            set(controls.dsgevartools.obsvarscenario.annual.initialvalues,'Enable','off');
         end;
      end;
   else;
      set(controls.dsgevartools.shocks.initialvalues,'Enable','off');
      set(controls.dsgevartools.shockcorr.initialvalues,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.decomp.original.initialvalues,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.decomp.annual.initialvalues,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.paths.original.initialvalues,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.paths.annual.initialvalues,'Enable','off');
      set(controls.dsgevartools.decomposition.corrdecomp.initialvalues,'Enable','off');
      set(controls.dsgevartools.decomposition.spectraldecomp.initialvalues,'Enable','off');
      set(controls.dsgevartools.decomposition.fevd.original.initialvalues,'Enable','off');
      set(controls.dsgevartools.decomposition.fevd.levels.initialvalues,'Enable','off');
      set(controls.dsgevartools.irfunction.original.initialvalues,'Enable','off');
      set(controls.dsgevartools.irfunction.annual.initialvalues,'Enable','off');
      set(controls.dsgevartools.irfunction.levels.initialvalues,'Enable','off');
      if isfield(controls.dsgevartools,'obsvarscenario')==1;
         set(controls.dsgevartools.obsvarscenario.original.initialvalues,'Enable','off');
         set(controls.dsgevartools.obsvarscenario.annual.initialvalues,'Enable','off');
      end;
   end;
   if VerifyVARDSGEPriorDraws(DSGEModel)==1;
      if DSGEModel.n>1;
         set(controls.dsgevartools.obscorr.frequencydomain.prior,'Enable','on');
         set(controls.dsgevartools.condcorr.prior,'Enable','on');
      else;
         set(controls.dsgevartools.obscorr.frequencydomain.prior,'Enable','off');
         set(controls.dsgevartools.condcorr.prior,'Enable','off');
      end;
      set(controls.dsgevartools.obscorr.timedomain.prior,'Enable','on');
      set(controls.dsgevartools.obscorr.parameterchange.prior,'Enable','on');
      if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
         set(controls.dsgevartools.forecast.unconditional.original.prior,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.annual.prior,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.transformed.prior,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.original.height.prior,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.annual.height.prior,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.original.moments.prior,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.original.statpredvar.prior,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.original.prior,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.annual.prior,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.transformed.prior,'Enable','off');
         set(controls.dsgevarview.modesty.prior,'Enable','off','UserData','');
      else;
         set(controls.dsgevartools.forecast.unconditional.original.prior,'Enable','on');
         set(controls.dsgevartools.forecast.unconditional.original.statpredvar.prior,'Enable','on');
         if MaxFH>0;
            set(controls.dsgevartools.forecast.unconditional.original.height.prior,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.dsgevartools.forecast.unconditional.annual.height.prior,'Enable','on');
            else;
               set(controls.dsgevartools.forecast.unconditional.annual.height.prior,'Enable','off');
            end;
            set(controls.dsgevartools.forecast.unconditional.original.moments.prior,'Enable','on');
         else;
            set(controls.dsgevartools.forecast.unconditional.original.height.prior,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.annual.height.prior,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.original.moments.prior,'Enable','off');
         end;
         if max(DSGEModel.annual)>1;
            set(controls.dsgevartools.forecast.unconditional.annual.prior,'Enable','on');
         else;
            set(controls.dsgevartools.forecast.unconditional.annual.prior,'Enable','off');
         end;
         if isempty(DSGEModel.YTransformation)==0;
            set(controls.dsgevartools.forecast.unconditional.transformed.prior,'Enable','on');
         else;
            set(controls.dsgevartools.forecast.unconditional.transformed.prior,'Enable','off');
         end;
         if CheckConditioningData(DSGEModel)==1;
            set(controls.dsgevartools.forecast.conditional.original.prior,'Enable','on');
            [ModestyStatus,ModestyResults] = GetDSGEVARModestyResults(DSGEModel,controls,MaxPH,'Prior');
            if ModestyStatus==1;
               set(controls.dsgevarview.modesty.prior,'Enable','on','UserData',ModestyResults);
            else;
               set(controls.dsgevarview.modesty.prior,'Enable','off','UserData','');
            end;
            if max(DSGEModel.annual)>1;
               set(controls.dsgevartools.forecast.conditional.annual.prior,'Enable','on');
            else;
               set(controls.dsgevartools.forecast.conditional.annual.prior,'Enable','off');
            end;
            if isempty(DSGEModel.YTransformation)==0;
               set(controls.dsgevartools.forecast.conditional.transformed.prior,'Enable','on');
            else;
               set(controls.dsgevartools.forecast.conditional.transformed.prior,'Enable','off');
            end;
         else;
            set(controls.dsgevartools.forecast.conditional.original.prior,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.annual.prior,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.transformed.prior,'Enable','off');
            set(controls.dsgevarview.modesty.prior,'Enable','off','UserData','');
         end;
      end;
      if DSGEModel.n==length(DSGEModel.DSGEVARShocks);
         set(controls.dsgevartools.shockcorr.prior,'Enable','on');
         set(controls.dsgevartools.shocks.prior,'Enable','on');
         set(controls.dsgevartools.decomposition.ovd.paths.original.prior,'Enable','on');
         set(controls.dsgevartools.decomposition.fevd.original.prior,'Enable','on');
         set(controls.dsgevartools.irfunction.original.prior,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.dsgevartools.decomposition.ovd.paths.annual.prior,'Enable','on');
            set(controls.dsgevartools.irfunction.annual.prior,'Enable','on');
         else;
            set(controls.dsgevartools.decomposition.ovd.paths.annual.prior,'Enable','off');
            set(controls.dsgevartools.irfunction.annual.prior,'Enable','off');
         end;
         if sum(DSGEModel.levels)<DSGEModel.n;
            set(controls.dsgevartools.decomposition.fevd.levels.prior,'Enable','on');
            set(controls.dsgevartools.irfunction.levels.prior,'Enable','on');
         else;
            set(controls.dsgevartools.decomposition.fevd.levels.prior,'Enable','off');
            set(controls.dsgevartools.irfunction.levels.prior,'Enable','off');
         end;
         if isfield(controls.dsgevartools,'obsvarscenario')==1;
            if CheckScenarioData(DSGEModel)==1;
               set(controls.dsgevartools.obsvarscenario.original.prior,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.dsgevartools.obsvarscenario.annual.prior,'Enable','on');
               else;
                  set(controls.dsgevartools.obsvarscenario.annual.prior,'Enable','off');
               end;
            else;
               set(controls.dsgevartools.obsvarscenario.original.prior,'Enable','off');
               set(controls.dsgevartools.obsvarscenario.annual.prior,'Enable','off');
            end;
         end;
      else;
         set(controls.dsgevartools.obscorr.frequencydomain.prior,'Enable','off');
         set(controls.dsgevartools.obscorr.timedomain.prior,'Enable','off');
         set(controls.dsgevartools.obscorr.parameterchange.prior,'Enable','off');
         set(controls.dsgevartools.condcorr.prior,'Enable','off');
         set(controls.dsgevartools.shockcorr.prior,'Enable','off');
         set(controls.dsgevartools.shocks.prior,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.paths.original.prior,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.paths.annual.prior,'Enable','off');
         set(controls.dsgevartools.decomposition.fevd.original.prior,'Enable','off');
         set(controls.dsgevartools.decomposition.fevd.levels.prior,'Enable','off');
         set(controls.dsgevartools.irfunction.original.prior,'Enable','off');
         set(controls.dsgevartools.irfunction.annual.prior,'Enable','off');
         set(controls.dsgevartools.irfunction.levels.prior,'Enable','off');
         if isfield(controls.dsgevartools,'obsvarscenario')==1;
            set(controls.dsgevartools.obsvarscenario.original.prior,'Enable','off');
            set(controls.dsgevartools.obsvarscenario.annual.prior,'Enable','off');
         end;
      end;
   else;
      set(controls.dsgevartools.obscorr.frequencydomain.prior,'Enable','off');
      set(controls.dsgevartools.obscorr.timedomain.prior,'Enable','off');
      set(controls.dsgevartools.obscorr.parameterchange.prior,'Enable','off');
      set(controls.dsgevartools.condcorr.prior,'Enable','off');
      set(controls.dsgevartools.shockcorr.prior,'Enable','off');
      set(controls.dsgevartools.shocks.prior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.prior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.annual.prior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.transformed.prior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.height.prior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.annual.height.prior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.moments.prior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.statpredvar.prior,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.original.prior,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.annual.prior,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.transformed.prior,'Enable','off');
      set(controls.dsgevarview.modesty.prior,'Enable','off','UserData','');
      set(controls.dsgevartools.decomposition.ovd.paths.original.prior,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.paths.annual.prior,'Enable','off');
      set(controls.dsgevartools.decomposition.fevd.original.prior,'Enable','off');
      set(controls.dsgevartools.decomposition.fevd.levels.prior,'Enable','off');
      set(controls.dsgevartools.irfunction.original.prior,'Enable','off');
      set(controls.dsgevartools.irfunction.annual.prior,'Enable','off');
      set(controls.dsgevartools.irfunction.levels.prior,'Enable','off');
      if isfield(controls.dsgevartools,'obsvarscenario')==1;
         set(controls.dsgevartools.obsvarscenario.original.prior,'Enable','off');
         set(controls.dsgevartools.obsvarscenario.annual.prior,'Enable','off');
      end;
   end;
   if VerifyDSGEVARMarginalMode(DSGEModel)==1;
      set(controls.dsgevarview.varmodel.margmode,'Enable','on');
      set(controls.dsgevarview.eigenvalues.margmode,'Enable','on');
      set(controls.dsgevarview.sequentialmarglike.laplace.margmode,'Enable','on');
      set(controls.dsgevarview.postmoderes.margmode,'Enable','on');
      set(controls.dsgevarview.postmodesum.margmode,'Enable','on');
      set(controls.dsgevarview.compareparameters.margmode,'Enable','on')
      set(controls.dsgevarview.checkpostmode.margmode,'Enable','on');
      set(controls.dsgevarview.viewlaplaceposterior.margmode,'Enable','on');
      set(controls.dsgevartools.simulatedata.margmode,'Enable','on');
      if DSGEModel.n>1;
         set(controls.dsgevartools.obscorr.frequencydomain.margmode,'Enable','on');
         set(controls.dsgevartools.condcorr.margmode,'Enable','on');
      else;
         set(controls.dsgevartools.obscorr.frequencydomain.margmode,'Enable','off');
         set(controls.dsgevartools.condcorr.margmode,'Enable','off');
      end;
      set(controls.dsgevartools.obscorr.timedomain.margmode,'Enable','on');
      set(controls.dsgevartools.obscorr.parameterchange.margmode,'Enable','on');
      set(controls.dsgevartools.loglikelihood.margmode,'Enable','on');
      if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
         set(controls.dsgevartools.forecast.unconditional.original.margmode,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.annual.margmode,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.transformed.margmode,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.original.height.margmode,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.annual.height.margmode,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.original.margmode,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.annual.margmode,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.transformed.margmode,'Enable','off');
         set(controls.dsgevarview.modesty.margmode,'Enable','off','UserData','');
      else;
         set(controls.dsgevartools.forecast.unconditional.original.margmode,'Enable','on');
         if MaxFH>0;
            set(controls.dsgevartools.forecast.unconditional.original.height.margmode,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.dsgevartools.forecast.unconditional.annual.height.margmode,'Enable','on');
            else;
               set(controls.dsgevartools.forecast.unconditional.annual.height.margmode,'Enable','off');
            end;
         else;
            set(controls.dsgevartools.forecast.unconditional.original.height.margmode,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.annual.height.margmode,'Enable','off');
         end;
         if max(DSGEModel.annual)>1;
            set(controls.dsgevartools.forecast.unconditional.annual.margmode,'Enable','on');
         else;
            set(controls.dsgevartools.forecast.unconditional.annual.margmode,'Enable','off');
         end;
         if isempty(DSGEModel.YTransformation)==0;
            set(controls.dsgevartools.forecast.unconditional.transformed.margmode,'Enable','on');
         else;
            set(controls.dsgevartools.forecast.unconditional.transformed.margmode,'Enable','off');
         end;
         if CheckConditioningData(DSGEModel)==1;
            set(controls.dsgevartools.forecast.conditional.original.margmode,'Enable','on');
            [ModestyStatus,ModestyResults] = GetDSGEVARModestyResults(DSGEModel,controls,MaxPH,'MarginalPosteriorMode');
            if ModestyStatus==1;
               set(controls.dsgevarview.modesty.margmode,'Enable','on','UserData',ModestyResults);
            else;
               set(controls.dsgevarview.modesty.margmode,'Enable','off','UserData','');
            end;
            if max(DSGEModel.annual)>1;
               set(controls.dsgevartools.forecast.conditional.annual.margmode,'Enable','on');
            else;
               set(controls.dsgevartools.forecast.conditional.annual.margmode,'Enable','off');
            end;
            if isempty(DSGEModel.YTransformation)==0;
               set(controls.dsgevartools.forecast.conditional.transformed.margmode,'Enable','on');
            else;
               set(controls.dsgevartools.forecast.conditional.transformed.margmode,'Enable','off');
            end;
         else;
            set(controls.dsgevartools.forecast.conditional.original.margmode,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.annual.margmode,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.transformed.margmode,'Enable','off');
            set(controls.dsgevarview.modesty.margmode,'Enable','off','UserData','');
         end;
      end;
      if DSGEModel.n==length(DSGEModel.DSGEVARShocks);
         set(controls.dsgevartools.shockcorr.margmode,'Enable','on');
         set(controls.dsgevartools.shocks.margmode,'Enable','on');
         set(controls.dsgevartools.decomposition.ovd.decomp.original.margmode,'Enable','on');
         set(controls.dsgevartools.decomposition.ovd.paths.original.margmode,'Enable','on');
         set(controls.dsgevartools.decomposition.corrdecomp.margmode,'Enable','on');
         set(controls.dsgevartools.decomposition.spectraldecomp.margmode,'Enable','on');
         set(controls.dsgevartools.decomposition.fevd.original.margmode,'Enable','on');
         set(controls.dsgevartools.irfunction.original.margmode,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.dsgevartools.decomposition.ovd.decomp.annual.margmode,'Enable','on');
            set(controls.dsgevartools.decomposition.ovd.paths.annual.margmode,'Enable','on');
            set(controls.dsgevartools.irfunction.annual.margmode,'Enable','on');
         else;
            set(controls.dsgevartools.decomposition.ovd.decomp.annual.margmode,'Enable','off');
            set(controls.dsgevartools.decomposition.ovd.paths.annual.margmode,'Enable','off');
            set(controls.dsgevartools.irfunction.annual.margmode,'Enable','off');
         end;
         if sum(DSGEModel.levels)<DSGEModel.n;
            set(controls.dsgevartools.decomposition.fevd.levels.margmode,'Enable','on');
            set(controls.dsgevartools.irfunction.levels.margmode,'Enable','on');
         else;
            set(controls.dsgevartools.decomposition.fevd.levels.margmode,'Enable','off');
            set(controls.dsgevartools.irfunction.levels.margmode,'Enable','off');
         end;
         if isfield(controls.dsgevartools,'obsvarscenario')==1;
            if CheckScenarioData(DSGEModel)==1;
               set(controls.dsgevartools.obsvarscenario.original.margmode,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.dsgevartools.obsvarscenario.annual.margmode,'Enable','on');
               else;
                  set(controls.dsgevartools.obsvarscenario.annual.margmode,'Enable','off');
               end;
            else;
               set(controls.dsgevartools.obsvarscenario.original.margmode,'Enable','off');
               set(controls.dsgevartools.obsvarscenario.annual.margmode,'Enable','off');
            end;
         end;
      else;
         set(controls.dsgevartools.shockcorr.margmode,'Enable','off');
         set(controls.dsgevartools.shocks.margmode,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.decomp.original.margmode,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.decomp.annual.margmode,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.paths.original.margmode,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.paths.annual.margmode,'Enable','off');
         set(controls.dsgevartools.decomposition.corrdecomp.margmode,'Enable','off');
         set(controls.dsgevartools.decomposition.spectraldecomp.margmode,'Enable','off');
         set(controls.dsgevartools.decomposition.fevd.original.margmode,'Enable','off');
         set(controls.dsgevartools.decomposition.fevd.levels.margmode,'Enable','off');
         set(controls.dsgevartools.irfunction.original.margmode,'Enable','off');
         set(controls.dsgevartools.irfunction.annual.margmode,'Enable','off');
         set(controls.dsgevartools.irfunction.levels.margmode,'Enable','off');
         if isfield(controls.dsgevartools,'obsvarscenario')==1;
            set(controls.dsgevartools.obsvarscenario.original.margmode,'Enable','off');
            set(controls.dsgevartools.obsvarscenario.annual.margmode,'Enable','off');
         end;
      end;
      if VerifyDSGEVAROptErrorFiles(DSGEModel,'Marg')==1;
         set(controls.dsgevarview.opterror.margmode,'Enable','on');
      else;
         set(controls.dsgevarview.opterror.margmode,'Enable','off');
      end;
   else;
      set(controls.dsgevarview.varmodel.margmode,'Enable','off');
      set(controls.dsgevarview.eigenvalues.margmode,'Enable','off');
      set(controls.dsgevarview.sequentialmarglike.laplace.margmode,'Enable','off');
      set(controls.dsgevarview.postmoderes.margmode,'Enable','off');
      set(controls.dsgevarview.postmodesum.margmode,'Enable','off');
      set(controls.dsgevarview.opterror.margmode,'Enable','off');
      set(controls.dsgevarview.compareparameters.margmode,'Enable','off')
      set(controls.dsgevarview.checkpostmode.margmode,'Enable','off');
      set(controls.dsgevarview.viewlaplaceposterior.margmode,'Enable','off');
      set(controls.dsgevartools.simulatedata.margmode,'Enable','off');
      set(controls.dsgevartools.obscorr.frequencydomain.margmode,'Enable','off');
      set(controls.dsgevartools.obscorr.timedomain.margmode,'Enable','off');
      set(controls.dsgevartools.obscorr.parameterchange.margmode,'Enable','off');
      set(controls.dsgevartools.condcorr.margmode,'Enable','off');
      set(controls.dsgevartools.shockcorr.margmode,'Enable','off');
      set(controls.dsgevartools.shocks.margmode,'Enable','off');
      set(controls.dsgevartools.loglikelihood.margmode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.margmode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.annual.margmode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.transformed.margmode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.height.margmode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.annual.height.margmode,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.original.margmode,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.annual.margmode,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.transformed.margmode,'Enable','off');
      set(controls.dsgevarview.modesty.margmode,'Enable','off','UserData','');
      set(controls.dsgevartools.decomposition.ovd.decomp.original.margmode,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.decomp.annual.margmode,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.paths.original.margmode,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.paths.annual.margmode,'Enable','off');
      set(controls.dsgevartools.decomposition.corrdecomp.margmode,'Enable','off');
      set(controls.dsgevartools.decomposition.spectraldecomp.margmode,'Enable','off');
      set(controls.dsgevartools.decomposition.fevd.original.margmode,'Enable','off');
      set(controls.dsgevartools.decomposition.fevd.levels.margmode,'Enable','off');
      set(controls.dsgevartools.irfunction.original.margmode,'Enable','off');
      set(controls.dsgevartools.irfunction.annual.margmode,'Enable','off');
      set(controls.dsgevartools.irfunction.levels.margmode,'Enable','off');
      if isfield(controls.dsgevartools,'obsvarscenario')==1;
         set(controls.dsgevartools.obsvarscenario.original.margmode,'Enable','off');
         set(controls.dsgevartools.obsvarscenario.annual.margmode,'Enable','off');
      end;
   end;
   if VerifyDSGEVARJointMode(DSGEModel)==1;
      set(controls.dsgevarview.varmodel.jointmode,'Enable','on');
      set(controls.dsgevarview.eigenvalues.jointmode,'Enable','on');
      set(controls.dsgevarview.sequentialmarglike.laplace.jointmode,'Enable','on');
      set(controls.dsgevarview.postmoderes.jointmode,'Enable','on');
      set(controls.dsgevarview.postmodesum.jointmode,'Enable','on');
      set(controls.dsgevarview.compareparameters.jointmode,'Enable','on');
      set(controls.dsgevarview.checkpostmode.jointmode,'Enable','on');
      set(controls.dsgevarview.viewlaplaceposterior.jointmode,'Enable','on');
      set(controls.dsgevartools.simulatedata.jointmode,'Enable','on');
      if DSGEModel.n>1;
         set(controls.dsgevartools.obscorr.frequencydomain.jointmode,'Enable','on');
         set(controls.dsgevartools.condcorr.jointmode,'Enable','on');
      else;
         set(controls.dsgevartools.obscorr.frequencydomain.jointmode,'Enable','off');
         set(controls.dsgevartools.condcorr.jointmode,'Enable','off');
      end;
      set(controls.dsgevartools.obscorr.timedomain.jointmode,'Enable','on');
      set(controls.dsgevartools.obscorr.parameterchange.jointmode,'Enable','on');
      set(controls.dsgevartools.loglikelihood.jointmode,'Enable','on');
      if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
         set(controls.dsgevartools.forecast.unconditional.original.jointmode,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.annual.jointmode,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.transformed.jointmode,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.original.height.jointmode,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.annual.height.jointmode,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.original.jointmode,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.annual.jointmode,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.transformed.jointmode,'Enable','off');
         set(controls.dsgevarview.modesty.jointmode,'Enable','off','UserData','');
      else;
         set(controls.dsgevartools.forecast.unconditional.original.jointmode,'Enable','on');
         if MaxFH>0;
            set(controls.dsgevartools.forecast.unconditional.original.height.jointmode,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.dsgevartools.forecast.unconditional.annual.height.jointmode,'Enable','on');
            else;
               set(controls.dsgevartools.forecast.unconditional.annual.height.jointmode,'Enable','off');
            end;
         else;
            set(controls.dsgevartools.forecast.unconditional.original.height.jointmode,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.annual.height.jointmode,'Enable','off');
         end;
         if max(DSGEModel.annual)>1
            set(controls.dsgevartools.forecast.unconditional.annual.jointmode,'Enable','on');
         else;
            set(controls.dsgevartools.forecast.unconditional.annual.jointmode,'Enable','off');
         end;
         if isempty(DSGEModel.YTransformation)==0;
            set(controls.dsgevartools.forecast.unconditional.transformed.jointmode,'Enable','on');
         else;
            set(controls.dsgevartools.forecast.unconditional.transformed.jointmode,'Enable','off');
         end;
         if CheckConditioningData(DSGEModel)==1;
            set(controls.dsgevartools.forecast.conditional.original.jointmode,'Enable','on');
            [ModestyStatus,ModestyResults] = GetDSGEVARModestyResults(DSGEModel,controls,MaxPH,'JointPosteriorMode');
            if ModestyStatus==1;
               set(controls.dsgevarview.modesty.jointmode,'Enable','on','UserData',ModestyResults);
            else;
               set(controls.dsgevarview.modesty.jointmode,'Enable','off','UserData','');
            end;
            if max(DSGEModel.annual)>1
               set(controls.dsgevartools.forecast.conditional.annual.jointmode,'Enable','on');
            else;
               set(controls.dsgevartools.forecast.conditional.annual.jointmode,'Enable','off');
            end;
            if isempty(DSGEModel.YTransformation)==0;
               set(controls.dsgevartools.forecast.conditional.transformed.jointmode,'Enable','on');
            else;
               set(controls.dsgevartools.forecast.conditional.transformed.jointmode,'Enable','off');
            end;
         else;
            set(controls.dsgevartools.forecast.conditional.original.jointmode,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.annual.jointmode,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.transformed.jointmode,'Enable','off');
            set(controls.dsgevarview.modesty.jointmode,'Enable','off','UserData','');
         end;
      end;
      if DSGEModel.n==length(DSGEModel.DSGEVARShocks);
         set(controls.dsgevartools.shockcorr.jointmode,'Enable','on');
         set(controls.dsgevartools.shocks.jointmode,'Enable','on');
         set(controls.dsgevartools.decomposition.ovd.decomp.original.jointmode,'Enable','on');
         set(controls.dsgevartools.decomposition.ovd.paths.original.jointmode,'Enable','on');
         set(controls.dsgevartools.decomposition.corrdecomp.jointmode,'Enable','on');
         set(controls.dsgevartools.decomposition.spectraldecomp.jointmode,'Enable','on');
         set(controls.dsgevartools.decomposition.fevd.original.jointmode,'Enable','on');
         set(controls.dsgevartools.irfunction.original.jointmode,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.dsgevartools.decomposition.ovd.decomp.annual.jointmode,'Enable','on');
            set(controls.dsgevartools.decomposition.ovd.paths.annual.jointmode,'Enable','on');
            set(controls.dsgevartools.irfunction.annual.jointmode,'Enable','on');
         else;
            set(controls.dsgevartools.decomposition.ovd.decomp.annual.jointmode,'Enable','off');
            set(controls.dsgevartools.decomposition.ovd.paths.annual.jointmode,'Enable','off');
            set(controls.dsgevartools.irfunction.annual.jointmode,'Enable','off');
         end;
         if sum(DSGEModel.levels)<DSGEModel.n;
            set(controls.dsgevartools.decomposition.fevd.levels.jointmode,'Enable','on');
            set(controls.dsgevartools.irfunction.levels.jointmode,'Enable','on');
         else;
            set(controls.dsgevartools.decomposition.fevd.levels.jointmode,'Enable','off');
            set(controls.dsgevartools.irfunction.levels.jointmode,'Enable','off');
         end;
         if isfield(controls.dsgevartools,'obsvarscenario')==1;
            if CheckScenarioData(DSGEModel)==1;
               set(controls.dsgevartools.obsvarscenario.original.jointmode,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.dsgevartools.obsvarscenario.annual.jointmode,'Enable','on');
               else;
                  set(controls.dsgevartools.obsvarscenario.annual.jointmode,'Enable','off');
               end;
            else;
               set(controls.dsgevartools.obsvarscenario.original.jointmode,'Enable','off');
               set(controls.dsgevartools.obsvarscenario.annual.jointmode,'Enable','off');
            end;
         end;
      else;
         set(controls.dsgevartools.obscorr.frequencydomain.jointmode,'Enable','off');
         set(controls.dsgevartools.obscorr.timedomain.jointmode,'Enable','off');
         set(controls.dsgevartools.obscorr.parameterchange.jointmode,'Enable','off');
         set(controls.dsgevartools.condcorr.jointmode,'Enable','off');
         set(controls.dsgevartools.shockcorr.jointmode,'Enable','off');
         set(controls.dsgevartools.shocks.jointmode,'Enable','off');
         set(controls.dsgevartools.loglikelihood.jointmode,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.decomp.original.jointmode,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.decomp.annual.jointmode,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.paths.original.jointmode,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.paths.annual.jointmode,'Enable','off');
         set(controls.dsgevartools.decomposition.corrdecomp.jointmode,'Enable','off');
         set(controls.dsgevartools.decomposition.spectraldecomp.jointmode,'Enable','off');
         set(controls.dsgevartools.decomposition.fevd.original.jointmode,'Enable','off');
         set(controls.dsgevartools.decomposition.fevd.levels.jointmode,'Enable','off');
         set(controls.dsgevartools.irfunction.original.jointmode,'Enable','off');
         set(controls.dsgevartools.irfunction.annual.jointmode,'Enable','off');
         set(controls.dsgevartools.irfunction.levels.jointmode,'Enable','off');
         if isfield(controls.dsgevartools,'obsvarscenario')==1;
            set(controls.dsgevartools.obsvarscenario.original.jointmode,'Enable','off');
            set(controls.dsgevartools.obsvarscenario.annual.jointmode,'Enable','off');
         end;
      end;
      if VerifyDSGEVAROptErrorFiles(DSGEModel,'Joint')==1;
         set(controls.dsgevarview.opterror.jointmode,'Enable','on');
      else;
         set(controls.dsgevarview.opterror.jointmode,'Enable','off');
      end;
   else;
      set(controls.dsgevarview.varmodel.jointmode,'Enable','off');
      set(controls.dsgevarview.eigenvalues.jointmode,'Enable','off');
      set(controls.dsgevarview.sequentialmarglike.laplace.jointmode,'Enable','off');
      set(controls.dsgevarview.postmoderes.jointmode,'Enable','off');
      set(controls.dsgevarview.postmodesum.jointmode,'Enable','off');
      set(controls.dsgevarview.opterror.jointmode,'Enable','off');
      set(controls.dsgevarview.compareparameters.jointmode,'Enable','off');
      set(controls.dsgevarview.checkpostmode.jointmode,'Enable','off');
      set(controls.dsgevarview.viewlaplaceposterior.jointmode,'Enable','off');
      set(controls.dsgevartools.simulatedata.jointmode,'Enable','off');
      set(controls.dsgevartools.obscorr.frequencydomain.jointmode,'Enable','off');
      set(controls.dsgevartools.obscorr.timedomain.jointmode,'Enable','off');
      set(controls.dsgevartools.obscorr.parameterchange.jointmode,'Enable','off');
      set(controls.dsgevartools.condcorr.jointmode,'Enable','off');
      set(controls.dsgevartools.shockcorr.jointmode,'Enable','off');
      set(controls.dsgevartools.shocks.jointmode,'Enable','off');
      set(controls.dsgevartools.loglikelihood.jointmode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.jointmode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.annual.jointmode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.transformed.jointmode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.height.jointmode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.annual.height.jointmode,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.original.jointmode,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.annual.jointmode,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.transformed.jointmode,'Enable','off');
      set(controls.dsgevarview.modesty.jointmode,'Enable','off','UserData','');
      set(controls.dsgevartools.decomposition.ovd.decomp.original.jointmode,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.decomp.annual.jointmode,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.paths.original.jointmode,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.paths.annual.jointmode,'Enable','off');
      set(controls.dsgevartools.decomposition.corrdecomp.jointmode,'Enable','off');
      set(controls.dsgevartools.decomposition.spectraldecomp.jointmode,'Enable','off');
      set(controls.dsgevartools.decomposition.fevd.original.jointmode,'Enable','off');
      set(controls.dsgevartools.decomposition.fevd.levels.jointmode,'Enable','off');
      set(controls.dsgevartools.irfunction.original.jointmode,'Enable','off');
      set(controls.dsgevartools.irfunction.annual.jointmode,'Enable','off');
      set(controls.dsgevartools.irfunction.levels.jointmode,'Enable','off');
      if isfield(controls.dsgevartools,'obsvarscenario')==1;
         set(controls.dsgevartools.obsvarscenario.original.jointmode,'Enable','off');
         set(controls.dsgevartools.obsvarscenario.annual.jointmode,'Enable','off');
      end;
   end;
   ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
   if (FileExist(ModeFile)==1)|(VerifyDSGEVARMarginalMode(DSGEModel)==1)|(VerifyDSGEVARJointMode(DSGEModel)==1);
      set(controls.dsgevarpostsamplingmenu,'Enable','on');
      if VerifyDSGEVARPosteriorDraws(DSGEModel,1,controls)==1;
         set(controls.dsgevarvarpostsamplingmenu,'Enable','on');
         set(controls.dsgevarview.rawdraws.originalparameters,'Enable','on');
         set(controls.dsgevarview.rawdraws.transformedparameters,'Enable','on');
         set(controls.dsgevarview.rawdraws.logposterior,'Enable','on');
         set(controls.dsgevarview.scatterplots.originalparameters,'Enable','on');
         set(controls.dsgevarview.scatterplots.transformedparameters,'Enable','on');
         if (DSGEModel.PosteriorSampler<=7)|(DSGEModel.PosteriorSampler==9);
            set(controls.dsgevarview.sequentialmarglike.mhm,'Enable','on');
            set(controls.dsgevarview.sequentialmarglike.swz,'Enable','on');
            set(controls.dsgevarview.rawdraws.weights,'Enable','off','Label','&Particle Weights...');
         elseif (DSGEModel.PosteriorSampler==8)|(DSGEModel.PosteriorSampler==10);
            set(controls.dsgevarview.sequentialmarglike.mhm,'Enable','off');
            set(controls.dsgevarview.sequentialmarglike.swz,'Enable','off');
            set(controls.dsgevarview.rawdraws.weights,'Enable','on');
            if DSGEModel.PosteriorSampler==8;
               set(controls.dsgevarview.rawdraws.weights,'Label','&Particle Weights...');
            else;
               set(controls.dsgevarview.rawdraws.weights,'Label','Im&portance Weights...');
            end;
         end;
         set(controls.dsgevarview.convergence.cusumplots.logposterior,'Enable','on');
         set(controls.dsgevarview.convergence.cusumplots.original,'Enable','on');
         set(controls.dsgevarview.convergence.cusumplots.transformed,'Enable','on');
         set(controls.dsgevarview.convergence.spmt.logposterior,'Enable','on');
         set(controls.dsgevarview.convergence.spmt.original,'Enable','on');
         set(controls.dsgevarview.convergence.spmt.transformed,'Enable','on');
         if (DSGEModel.PosteriorSampler==1)|(DSGEModel.PosteriorSampler>=3);
            set(controls.dsgevarview.convergence.acceptancerate,'Enable','on');
         elseif DSGEModel.PosteriorSampler==2;
            set(controls.dsgevarview.convergence.acceptancerate,'Enable','off');
         end;
         if DSGEModel.PosteriorSampler<=7;
            set(controls.dsgevarview.convergence.smcadaption,'Enable','off');
         else;
            set(controls.dsgevarview.convergence.smcadaption,'Enable','on');
         end;
         if (DSGEModel.ParallelChainsValue>1)&(VerifyDSGEVARSamplingTxtFiles(DSGEModel,2,controls)==1);
            set(controls.dsgevarview.convergence.manova,'Enable','on');
         else;
            set(controls.dsgevarview.convergence.manova,'Enable','off');
         end;
         set(controls.dsgevarview.convergence.posteriormean,'Enable','on');
         set(controls.dsgevarview.convergence.posteriormedian,'Enable','on');
         set(controls.dsgevarview.compareparameters.posterior,'Enable','on');
         if DSGEModel.PosteriorSampler<=7;
            set(controls.dsgevarview.marglike.modifiedharmonic,'Enable','on');
            set(controls.dsgevarview.marglike.swzmodifiedharmonic,'Enable','on');
            if (DSGEModel.PosteriorSampler==1)|(DSGEModel.PosteriorSampler>=3);
               set(controls.dsgevarview.marglike.chibjeliazkov,'Enable','on');
               set(controls.dsgevarview.sequentialmarglike.chibjeliazkov,'Enable','on');
            elseif DSGEModel.PosteriorSampler==2;
               set(controls.dsgevarview.marglike.chibjeliazkov,'Enable','off');
               set(controls.dsgevarview.sequentialmarglike.chibjeliazkov,'Enable','off');
            end;
            set(controls.dsgevarview.marglike.smc,'Enable','off');
         else;
            set(controls.dsgevarview.marglike.modifiedharmonic,'Enable','off');
            set(controls.dsgevarview.marglike.swzmodifiedharmonic,'Enable','off');
            set(controls.dsgevarview.marglike.chibjeliazkov,'Enable','off');
            set(controls.dsgevarview.sequentialmarglike.chibjeliazkov,'Enable','off');
            set(controls.dsgevarview.marglike.smc,'Enable','on');
         end;
         set(controls.dsgevarview.postdensity.dsgeparameter,'Enable','on');
         set(controls.dsgevarview.postdensity.bivariatedsgeparameter,'Enable','on');
      else;
         set(controls.dsgevarvarpostsamplingmenu,'Enable','off');
         set(controls.dsgevarview.rawdraws.originalparameters,'Enable','off');
         set(controls.dsgevarview.rawdraws.transformedparameters,'Enable','off');
         set(controls.dsgevarview.rawdraws.logposterior,'Enable','off');
         set(controls.dsgevarview.rawdraws.weights,'Enable','off');
         if DSGEModel.PosteriorSampler==10;
            set(controls.dsgevarview.rawdraws.weights,'Label','Im&portance Weights...');
         else;
            set(controls.dsgevarview.rawdraws.weights,'Label','&Particle Weights...');
         end;
         set(controls.dsgevarview.scatterplots.originalparameters,'Enable','off');
         set(controls.dsgevarview.scatterplots.transformedparameters,'Enable','off');
         set(controls.dsgevarview.sequentialmarglike.mhm,'Enable','off');
         set(controls.dsgevarview.sequentialmarglike.swz,'Enable','off');
         set(controls.dsgevarview.sequentialmarglike.chibjeliazkov,'Enable','off');
         set(controls.dsgevarview.convergence.cusumplots.logposterior,'Enable','off');
         set(controls.dsgevarview.convergence.cusumplots.original,'Enable','off');
         set(controls.dsgevarview.convergence.cusumplots.transformed,'Enable','off');
         set(controls.dsgevarview.convergence.spmt.logposterior,'Enable','off');
         set(controls.dsgevarview.convergence.spmt.original,'Enable','off');
         set(controls.dsgevarview.convergence.spmt.transformed,'Enable','off');
         set(controls.dsgevarview.convergence.acceptancerate,'Enable','off');
         set(controls.dsgevarview.convergence.smcadaption,'Enable','off');
         set(controls.dsgevarview.convergence.manova,'Enable','off');
         set(controls.dsgevarview.convergence.posteriormean,'Enable','off');
         set(controls.dsgevarview.convergence.posteriormedian,'Enable','off');
         set(controls.dsgevarview.compareparameters.posterior,'Enable','off');
         set(controls.dsgevarview.marglike.modifiedharmonic,'Enable','off');
         set(controls.dsgevarview.marglike.swzmodifiedharmonic,'Enable','off');
         set(controls.dsgevarview.marglike.chibjeliazkov,'Enable','off');
         set(controls.dsgevarview.marglike.smc,'Enable','off');
         set(controls.dsgevarview.postdensity.dsgeparameter,'Enable','off');
         set(controls.dsgevarview.postdensity.bivariatedsgeparameter,'Enable','off');
      end;
      if VerifyDSGEVARSamplingTxtFiles(DSGEModel,1,controls)==1;
         set(controls.dsgevarview.posteriorsamplingsummary,'Enable','on');
      else;
         set(controls.dsgevarview.posteriorsamplingsummary,'Enable','off');
      end;
      if VerifyVARDSGEPosteriorDraws(DSGEModel,1,controls)==1;
         set(controls.dsgevarview.postdensity.varparameter,'Enable','on');
         set(controls.dsgevarview.postdensity.sigmaparameter,'Enable','on');
         set(controls.dsgevarview.postdensity.a0parameter,'Enable','on');
         if DSGEModel.n>1;
            set(controls.dsgevartools.obscorr.frequencydomain.posterior,'Enable','on');
            set(controls.dsgevartools.condcorr.posterior,'Enable','on');
         else;
            set(controls.dsgevartools.obscorr.frequencydomain.posterior,'Enable','off');
            set(controls.dsgevartools.condcorr.posterior,'Enable','off');
         end;
         set(controls.dsgevartools.obscorr.timedomain.posterior,'Enable','on');
         set(controls.dsgevartools.obscorr.parameterchange.posterior,'Enable','on');
         if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
            set(controls.dsgevartools.forecast.unconditional.original.posterior,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.annual.posterior,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.transformed.posterior,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.original.predevent,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.annual.predevent,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.transformed.predevent,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.original.height.posterior,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.annual.height.posterior,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.original.moments.posterior,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.original.statpredvar.posterior,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.original.posterior,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.annual.posterior,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.transformed.posterior,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.original.predevent,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.annual.predevent,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.transformed.predevent,'Enable','off');
            for i=1:10;
               set(getfield(controls.dsgevarview.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
            end;
         else;
            set(controls.dsgevartools.forecast.unconditional.original.posterior,'Enable','on');
            set(controls.dsgevartools.forecast.unconditional.original.predevent,'Enable','on');
            set(controls.dsgevartools.forecast.unconditional.original.statpredvar.posterior,'Enable','on');
            if MaxFH>0;
               set(controls.dsgevartools.forecast.unconditional.original.height.posterior,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.dsgevartools.forecast.unconditional.annual.height.posterior,'Enable','on');
               else;
                  set(controls.dsgevartools.forecast.unconditional.annual.height.posterior,'Enable','off');
               end;
               set(controls.dsgevartools.forecast.unconditional.original.moments.posterior,'Enable','on');
            else;
               set(controls.dsgevartools.forecast.unconditional.original.height.posterior,'Enable','off');
               set(controls.dsgevartools.forecast.unconditional.annual.height.posterior,'Enable','off');
               set(controls.dsgevartools.forecast.unconditional.original.moments.posterior,'Enable','off');
            end;
            if max(DSGEModel.annual)>1;
               set(controls.dsgevartools.forecast.unconditional.annual.posterior,'Enable','on');
               set(controls.dsgevartools.forecast.unconditional.annual.predevent,'Enable','on');
            else;
               set(controls.dsgevartools.forecast.unconditional.annual.posterior,'Enable','off');
               set(controls.dsgevartools.forecast.unconditional.annual.predevent,'Enable','off');
            end;
            if isempty(DSGEModel.YTransformation)==0;
               set(controls.dsgevartools.forecast.unconditional.transformed.posterior,'Enable','on');
               set(controls.dsgevartools.forecast.unconditional.transformed.predevent,'Enable','on');
            else;
               set(controls.dsgevartools.forecast.unconditional.transformed.posterior,'Enable','off');
               set(controls.dsgevartools.forecast.unconditional.transformed.predevent,'Enable','off');
            end;
            if CheckConditioningData(DSGEModel)==1;
               set(controls.dsgevartools.forecast.conditional.original.posterior,'Enable','on');
               set(controls.dsgevartools.forecast.conditional.original.predevent,'Enable','on');
               for i=1:10;
                  [ModestyStatus,ModestyResults] = GetDSGEVARModestyResults(DSGEModel,controls,MaxPH,int2str(i));
                  if ModestyStatus==1;
                     set(getfield(controls.dsgevarview.modesty,['chain' int2str(i)]),'Enable','on','UserData',ModestyResults);
                  else;
                     set(getfield(controls.dsgevarview.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
                  end;
               end;
               if max(DSGEModel.annual)>1;
                  set(controls.dsgevartools.forecast.conditional.annual.posterior,'Enable','on');
                  set(controls.dsgevartools.forecast.conditional.annual.predevent,'Enable','on');
               else;
                  set(controls.dsgevartools.forecast.conditional.annual.posterior,'Enable','off');
                  set(controls.dsgevartools.forecast.conditional.annual.predevent,'Enable','off');
               end;
               if isempty(DSGEModel.YTransformation)==0;
                  set(controls.dsgevartools.forecast.conditional.transformed.posterior,'Enable','on');
                  set(controls.dsgevartools.forecast.conditional.transformed.predevent,'Enable','on');
               else;
                  set(controls.dsgevartools.forecast.conditional.transformed.posterior,'Enable','off');
                  set(controls.dsgevartools.forecast.conditional.transformed.predevent,'Enable','off');
               end;
            else;
               set(controls.dsgevartools.forecast.conditional.original.posterior,'Enable','off');
               set(controls.dsgevartools.forecast.conditional.annual.posterior,'Enable','off');
               set(controls.dsgevartools.forecast.conditional.transformed.posterior,'Enable','off');
               set(controls.dsgevartools.forecast.conditional.original.predevent,'Enable','off');
               set(controls.dsgevartools.forecast.conditional.annual.predevent,'Enable','off');
               set(controls.dsgevartools.forecast.conditional.transformed.predevent,'Enable','off');
               for i=1:10;
                  set(getfield(controls.dsgevarview.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
               end;
            end;
         end;
         if DSGEModel.n==length(DSGEModel.DSGEVARShocks);
            set(controls.dsgevartools.shockcorr.posterior,'Enable','on');
            set(controls.dsgevartools.shocks.posterior,'Enable','on');
            set(controls.dsgevartools.decomposition.ovd.paths.original.posterior,'Enable','on');
            set(controls.dsgevartools.decomposition.fevd.original.posterior,'Enable','on');
            set(controls.dsgevartools.irfunction.original.posterior,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.dsgevartools.decomposition.ovd.paths.annual.posterior,'Enable','on');
               set(controls.dsgevartools.irfunction.annual.posterior,'Enable','on');
            else;
               set(controls.dsgevartools.decomposition.ovd.paths.annual.posterior,'Enable','off');
               set(controls.dsgevartools.irfunction.annual.posterior,'Enable','off');
            end;
            if sum(DSGEModel.levels)<DSGEModel.n;
               set(controls.dsgevartools.decomposition.fevd.levels.posterior,'Enable','on');
               set(controls.dsgevartools.irfunction.levels.posterior,'Enable','on');
            else;
               set(controls.dsgevartools.decomposition.fevd.levels.posterior,'Enable','off');
               set(controls.dsgevartools.irfunction.levels.posterior,'Enable','off');
            end;
            if isfield(controls.dsgevartools,'obsvarscenario')==1;
               if CheckScenarioData(DSGEModel)==1;
                  set(controls.dsgevartools.obsvarscenario.original.posterior,'Enable','on');
                  if max(DSGEModel.annual)>1;
                     set(controls.dsgevartools.obsvarscenario.annual.posterior,'Enable','on');
                  else;
                     set(controls.dsgevartools.obsvarscenario.annual.posterior,'Enable','off');
                  end;
               else;
                  set(controls.dsgevartools.obsvarscenario.original.posterior,'Enable','off');
                  set(controls.dsgevartools.obsvarscenario.annual.posterior,'Enable','off');
               end;
            end;
         else;
            set(controls.dsgevartools.shockcorr.posterior,'Enable','off');
            set(controls.dsgevartools.shocks.posterior,'Enable','off');
            set(controls.dsgevartools.decomposition.ovd.paths.original.posterior,'Enable','off');
            set(controls.dsgevartools.decomposition.ovd.paths.annual.posterior,'Enable','off');
            set(controls.dsgevartools.decomposition.fevd.original.posterior,'Enable','off');
            set(controls.dsgevartools.decomposition.fevd.levels.posterior,'Enable','off');
            set(controls.dsgevartools.irfunction.original.posterior,'Enable','off');
            set(controls.dsgevartools.irfunction.annual.posterior,'Enable','off');
            set(controls.dsgevartools.irfunction.levels.posterior,'Enable','off');
            if isfield(controls.dsgevartools,'obsvarscenario')==1;
               set(controls.dsgevartools.obsvarscenario.original.posterior,'Enable','off');
               set(controls.dsgevartools.obsvarscenario.annual.posterior,'Enable','off');
            end;
         end;
      else;
         set(controls.dsgevarview.postdensity.varparameter,'Enable','off');
         set(controls.dsgevarview.postdensity.sigmaparameter,'Enable','off');
         set(controls.dsgevarview.postdensity.a0parameter,'Enable','off');
         set(controls.dsgevartools.obscorr.frequencydomain.posterior,'Enable','off');
         set(controls.dsgevartools.obscorr.timedomain.posterior,'Enable','off');
         set(controls.dsgevartools.obscorr.parameterchange.posterior,'Enable','off');
         set(controls.dsgevartools.condcorr.posterior,'Enable','off');
         set(controls.dsgevartools.shockcorr.posterior,'Enable','off');
         set(controls.dsgevartools.shocks.posterior,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.original.posterior,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.annual.posterior,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.transformed.posterior,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.original.predevent,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.annual.predevent,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.transformed.predevent,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.original.height.posterior,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.annual.height.posterior,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.original.moments.posterior,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.original.statpredvar.posterior,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.original.posterior,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.annual.posterior,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.transformed.posterior,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.original.predevent,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.annual.predevent,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.transformed.predevent,'Enable','off');
         for i=1:10;
            set(getfield(controls.dsgevarview.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
         end;
         set(controls.dsgevartools.decomposition.ovd.paths.original.posterior,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.paths.annual.posterior,'Enable','off');
         set(controls.dsgevartools.decomposition.fevd.original.posterior,'Enable','off');
         set(controls.dsgevartools.decomposition.fevd.levels.posterior,'Enable','off');
         set(controls.dsgevartools.irfunction.original.posterior,'Enable','off');
         set(controls.dsgevartools.irfunction.annual.posterior,'Enable','off');
         set(controls.dsgevartools.irfunction.levels.posterior,'Enable','off');
         if isfield(controls.dsgevartools,'obsvarscenario')==1;
            set(controls.dsgevartools.obsvarscenario.original.posterior,'Enable','off');
            set(controls.dsgevartools.obsvarscenario.annual.posterior,'Enable','off');
         end;
      end;
      if VerifyVARDSGESamplingTxtFiles(DSGEModel,1,controls)==1;
         set(controls.dsgevarview.varposteriorsamplingsummary,'Enable','on');
      else;
         set(controls.dsgevarview.varposteriorsamplingsummary,'Enable','off');
      end;
   else;
      set(controls.dsgevarpostsamplingmenu,'Enable','off');
      set(controls.dsgevarvarpostsamplingmenu,'Enable','off');
      set(controls.dsgevarview.posteriorsamplingsummary,'Enable','off');
      set(controls.dsgevarview.varposteriorsamplingsummary,'Enable','off');
      set(controls.dsgevarview.rawdraws.originalparameters,'Enable','off');
      set(controls.dsgevarview.rawdraws.transformedparameters,'Enable','off');
      set(controls.dsgevarview.rawdraws.logposterior,'Enable','off');
      set(controls.dsgevarview.rawdraws.weights,'Enable','off');
      if DSGEModel.PosteriorSampler==10;
         set(controls.dsgevarview.rawdraws.weights,'Label','Im&portance Weights...');
      else;
         set(controls.dsgevarview.rawdraws.weights,'Label','&Particle Weights...');
      end;
      set(controls.dsgevarview.scatterplots.originalparameters,'Enable','off');
      set(controls.dsgevarview.scatterplots.transformedparameters,'Enable','off');
      set(controls.dsgevarview.sequentialmarglike.mhm,'Enable','off');
      set(controls.dsgevarview.sequentialmarglike.swz,'Enable','off');
      set(controls.dsgevarview.sequentialmarglike.chibjeliazkov,'Enable','off');
      set(controls.dsgevarview.convergence.cusumplots.logposterior,'Enable','off');
      set(controls.dsgevarview.convergence.cusumplots.original,'Enable','off');
      set(controls.dsgevarview.convergence.cusumplots.transformed,'Enable','off');
      set(controls.dsgevarview.convergence.spmt.logposterior,'Enable','off');
      set(controls.dsgevarview.convergence.spmt.original,'Enable','off');
      set(controls.dsgevarview.convergence.spmt.transformed,'Enable','off');
      set(controls.dsgevarview.convergence.acceptancerate,'Enable','off');
      set(controls.dsgevarview.convergence.smcadaption,'Enable','off');
      set(controls.dsgevarview.convergence.manova,'Enable','off');
      set(controls.dsgevarview.convergence.posteriormean,'Enable','off');
      set(controls.dsgevarview.convergence.posteriormedian,'Enable','off');
      set(controls.dsgevarview.compareparameters.posterior,'Enable','off');
      set(controls.dsgevarview.marglike.modifiedharmonic,'Enable','off');
      set(controls.dsgevarview.marglike.swzmodifiedharmonic,'Enable','off');
      set(controls.dsgevarview.marglike.chibjeliazkov,'Enable','off');
      set(controls.dsgevarview.marglike.smc,'Enable','off');
      set(controls.dsgevarview.postdensity.dsgeparameter,'Enable','off');
      set(controls.dsgevarview.postdensity.bivariatedsgeparameter,'Enable','off');
      set(controls.dsgevarview.postdensity.varparameter,'Enable','off');
      set(controls.dsgevarview.postdensity.sigmaparameter,'Enable','off');
      set(controls.dsgevarview.postdensity.a0parameter,'Enable','off');
      set(controls.dsgevartools.obscorr.frequencydomain.posterior,'Enable','off');
      set(controls.dsgevartools.obscorr.timedomain.posterior,'Enable','off');
      set(controls.dsgevartools.obscorr.parameterchange.posterior,'Enable','off');
      set(controls.dsgevartools.condcorr.posterior,'Enable','off');
      set(controls.dsgevartools.shockcorr.posterior,'Enable','off');
      set(controls.dsgevartools.shocks.posterior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.posterior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.annual.posterior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.transformed.posterior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.predevent,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.annual.predevent,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.transformed.predevent,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.height.posterior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.annual.height.posterior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.moments.posterior,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.statpredvar.posterior,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.original.posterior,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.annual.posterior,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.transformed.posterior,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.original.predevent,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.annual.predevent,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.transformed.predevent,'Enable','off');
      for i=1:10;
         set(getfield(controls.dsgevarview.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
      end;
      set(controls.dsgevartools.decomposition.ovd.paths.original.posterior,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.paths.annual.posterior,'Enable','off');
      set(controls.dsgevartools.decomposition.fevd.original.posterior,'Enable','off');
      set(controls.dsgevartools.decomposition.fevd.levels.posterior,'Enable','off');
      set(controls.dsgevartools.irfunction.original.posterior,'Enable','off');
      set(controls.dsgevartools.irfunction.annual.posterior,'Enable','off');
      set(controls.dsgevartools.irfunction.levels.posterior,'Enable','off');
      if isfield(controls.dsgevartools,'obsvarscenario')==1;
         set(controls.dsgevartools.obsvarscenario.original.posterior,'Enable','off');
         set(controls.dsgevartools.obsvarscenario.annual.posterior,'Enable','off');
      end;
   end;
   if FileExist(ModeFile)==1;
      set(controls.dsgevarview.varmodel.dsgemode,'Enable','on');
      set(controls.dsgevarview.eigenvalues.dsgemode,'Enable','on');
      set(controls.dsgevarview.sequentialmarglike.laplace.dsgemode,'Enable','on');
      set(controls.dsgevartools.simulatedata.dsgemode,'Enable','on');
      set(controls.dsgevartools.obscorr.timedomain.dsgemode,'Enable','on');
      set(controls.dsgevartools.obscorr.parameterchange.dsgemode,'Enable','on');
      set(controls.dsgevartools.loglikelihood.dsgemode,'Enable','on');
      if DSGEModel.n==length(DSGEModel.DSGEVARShocks);
         set(controls.dsgevartools.shockcorr.dsgemode,'Enable','on');
         set(controls.dsgevartools.shocks.dsgemode,'Enable','on');
         set(controls.dsgevartools.decomposition.ovd.decomp.original.dsgemode,'Enable','on');
         set(controls.dsgevartools.decomposition.ovd.paths.original.dsgemode,'Enable','on');
         set(controls.dsgevartools.decomposition.corrdecomp.dsgemode,'Enable','on');
         set(controls.dsgevartools.decomposition.spectraldecomp.dsgemode,'Enable','on');
         set(controls.dsgevartools.decomposition.fevd.original.dsgemode,'Enable','on');
         set(controls.dsgevartools.irfunction.original.dsgemode,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.dsgevartools.decomposition.ovd.decomp.annual.dsgemode,'Enable','on');
            set(controls.dsgevartools.decomposition.ovd.paths.annual.dsgemode,'Enable','on');
            set(controls.dsgevartools.irfunction.annual.dsgemode,'Enable','on');
         else;
            set(controls.dsgevartools.decomposition.ovd.decomp.annual.dsgemode,'Enable','off');
            set(controls.dsgevartools.decomposition.ovd.paths.annual.dsgemode,'Enable','off');
            set(controls.dsgevartools.irfunction.annual.dsgemode,'Enable','off');
         end;
         if sum(DSGEModel.levels)<DSGEModel.n;
            set(controls.dsgevartools.decomposition.fevd.levels.dsgemode,'Enable','on');
            set(controls.dsgevartools.irfunction.levels.dsgemode,'Enable','on');
         else;
            set(controls.dsgevartools.decomposition.fevd.levels.dsgemode,'Enable','off');
            set(controls.dsgevartools.irfunction.levels.dsgemode,'Enable','off');
         end;
         if isfield(controls.dsgevartools,'obsvarscenario')==1;
            if CheckScenarioData(DSGEModel)==1;
               set(controls.dsgevartools.obsvarscenario.original.dsgemode,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.dsgevartools.obsvarscenario.annual.dsgemode,'Enable','on');
               else;
                  set(controls.dsgevartools.obsvarscenario.annual.dsgemode,'Enable','off');
               end;
            else;
               set(controls.dsgevartools.obsvarscenario.original.dsgemode,'Enable','off');
               set(controls.dsgevartools.obsvarscenario.annual.dsgemode,'Enable','off');
            end;
         end;
      else;
         set(controls.dsgevartools.shockcorr.dsgemode,'Enable','off');
         set(controls.dsgevartools.shocks.dsgemode,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.decomp.original.dsgemode,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.paths.original.dsgemode,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.decomp.annual.dsgemode,'Enable','off');
         set(controls.dsgevartools.decomposition.ovd.paths.annual.dsgemode,'Enable','off');
         set(controls.dsgevartools.decomposition.corrdecomp.dsgemode,'Enable','off');
         set(controls.dsgevartools.decomposition.spectraldecomp.dsgemode,'Enable','off');
         set(controls.dsgevartools.decomposition.fevd.original.dsgemode,'Enable','off');
         set(controls.dsgevartools.decomposition.fevd.levels.dsgemode,'Enable','off');
         set(controls.dsgevartools.irfunction.original.dsgemode,'Enable','off');
         set(controls.dsgevartools.irfunction.annual.dsgemode,'Enable','off');
         set(controls.dsgevartools.irfunction.levels.dsgemode,'Enable','off');
         if isfield(controls.dsgevartools,'obsvarscenario')==1;
            set(controls.dsgevartools.obsvarscenario.original.dsgemode,'Enable','off');
            set(controls.dsgevartools.obsvarscenario.annual.dsgemode,'Enable','off');
         end;
      end;
      if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
         set(controls.predict.unconditional_original_postmode,'Enable','off');
         set(controls.predict.unconditional_annual_postmode,'Enable','off');
         set(controls.predict.conditional_original_postmode,'Enable','off');
         set(controls.predict.conditional_annual_postmode,'Enable','off');
         set(controls.predict.unconditional_transformed_postmode,'Enable','off');
         set(controls.predict.conditional_transformed_postmode,'Enable','off');
         set(controls.predict.unconditional.original.zlb.postmode,'Enable','off');
         set(controls.predict.unconditional.annual.zlb.postmode,'Enable','off');
         set(controls.predict.unconditional.transformed.zlb.postmode,'Enable','off');
         set(controls.predict.conditional.original.zlb.postmode,'Enable','off');
         set(controls.predict.conditional.annual.zlb.postmode,'Enable','off');
         set(controls.predict.conditional.transformed.zlb.postmode,'Enable','off');
         set(controls.predict.unconditional.original.obsweightdecomp.postmode,'Enable','off');
         set(controls.predict.unconditional.annual.obsweightdecomp.postmode,'Enable','off');
         set(controls.modesty.postmode,'Enable','off','UserData','');
         if isfield(controls.modesty,'state')==1;
            set(controls.modesty.state.postmode,'Enable','off','UserData','');
         end;
         set(controls.predict.unconditional.original.height.postmode,'Enable','off');
         set(controls.predict.unconditional.annual.height.postmode,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.original.dsgemode,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.annual.dsgemode,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.transformed.dsgemode,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.original.height.dsgemode,'Enable','off');
         set(controls.dsgevartools.forecast.unconditional.annual.height.dsgemode,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.original.dsgemode,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.annual.dsgemode,'Enable','off');
         set(controls.dsgevartools.forecast.conditional.transformed.dsgemode,'Enable','off');
         set(controls.dsgevarview.modesty.dsgemode,'Enable','off','UserData','');
      else;
         set(controls.predict.unconditional_original_postmode,'Enable','on');
         set(controls.predict.unconditional.original.obsweightdecomp.postmode,'Enable','on');
         if isempty(DSGEModel.ZLBPosition)==0;
            set(controls.predict.unconditional.original.zlb.postmode,'Enable','on');
         else;
            set(controls.predict.unconditional.original.zlb.postmode,'Enable','off');
         end;
         set(controls.dsgevartools.forecast.unconditional.original.dsgemode,'Enable','on');
         if MaxFH>0;
            set(controls.dsgevartools.forecast.unconditional.original.height.dsgemode,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.dsgevartools.forecast.unconditional.annual.height.dsgemode,'Enable','on');
            else;
               set(controls.dsgevartools.forecast.unconditional.annual.height.dsgemode,'Enable','off');
            end;
         else;
            set(controls.dsgevartools.forecast.unconditional.original.height.dsgemode,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.annual.height.dsgemode,'Enable','off');
         end;
         if isempty(DSGEModel.YTransformation)==0;
            set(controls.predict.unconditional_transformed_postmode,'Enable','on');
            set(controls.dsgevartools.forecast.unconditional.transformed.dsgemode,'Enable','on');
            if isempty(DSGEModel.ZLBPosition)==0;
               set(controls.predict.unconditional.transformed.zlb.postmode,'Enable','on');
            else;
               set(controls.predict.unconditional.transformed.zlb.postmode,'Enable','off');
            end;
         else;
            set(controls.predict.unconditional_transformed_postmode,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.transformed.dsgemode,'Enable','off');
            set(controls.predict.unconditional.transformed.zlb.postmode,'Enable','off');
         end;
         if max(DSGEModel.annual)>1;
            set(controls.predict.unconditional_annual_postmode,'Enable','on');
            set(controls.predict.unconditional.annual.obsweightdecomp.postmode,'Enable','on');
            set(controls.dsgevartools.forecast.unconditional.annual.dsgemode,'Enable','on');
            if isempty(DSGEModel.ZLBPosition)==0;
               set(controls.predict.unconditional.annual.zlb.postmode,'Enable','on');
            else;
               set(controls.predict.unconditional.annual.zlb.postmode,'Enable','off');
            end;
         else;
            set(controls.predict.unconditional_annual_postmode,'Enable','off');
            set(controls.dsgevartools.forecast.unconditional.annual.dsgemode,'Enable','off');
            set(controls.predict.unconditional.annual.zlb.postmode,'Enable','off');
            set(controls.predict.unconditional.annual.obsweightdecomp.postmode,'Enable','off');
         end;
         if MaxFH>0;
            set(controls.predict.unconditional.original.height.postmode,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.predict.unconditional.annual.height.postmode,'Enable','on');
            else;
               set(controls.predict.unconditional.annual.height.postmode,'Enable','off');
            end;
         else;
            set(controls.predict.unconditional.original.height.postmode,'Enable','off');
            set(controls.predict.unconditional.annual.height.postmode,'Enable','off');
         end;
         if CheckConditioningData(DSGEModel)==1;
            set(controls.predict.conditional_original_postmode,'Enable','on');
            set(controls.dsgevartools.forecast.conditional.original.dsgemode,'Enable','on');
            if isempty(DSGEModel.ZLBPosition)==0;
               set(controls.predict.conditional.original.zlb.postmode,'Enable','on');
            else;
               set(controls.predict.conditional.original.zlb.postmode,'Enable','off');
            end;
            if isempty(DSGEModel.YTransformation)==0;
               set(controls.predict.conditional_transformed_postmode,'Enable','on');
               set(controls.dsgevartools.forecast.conditional.transformed.dsgemode,'Enable','on');
               if isempty(DSGEModel.ZLBPosition)==0;
                  set(controls.predict.conditional.transformed.zlb.postmode,'Enable','on');
               else;
                  set(controls.predict.conditional.transformed.zlb.postmode,'Enable','off');
               end;
            else;
               set(controls.predict.conditional_transformed_postmode,'Enable','off');
               set(controls.dsgevartools.forecast.conditional.transformed.dsgemode,'Enable','off');
               set(controls.predict.conditional.transformed.zlb.postmode,'Enable','off');
            end;
            if max(DSGEModel.annual)>1;
               set(controls.predict.conditional_annual_postmode,'Enable','on');
               set(controls.dsgevartools.forecast.conditional.annual.dsgemode,'Enable','on');
               if isempty(DSGEModel.ZLBPosition)==0;
                  set(controls.predict.conditional.annual.zlb.postmode,'Enable','on');
               else;
                  set(controls.predict.conditional.annual.zlb.postmode,'Enable','off');
               end;
            else;
               set(controls.predict.conditional_annual_postmode,'Enable','off');
               set(controls.dsgevartools.forecast.conditional.annual.dsgemode,'Enable','off');
               set(controls.predict.conditional.annual.zlb.postmode,'Enable','off');
            end;
            %
            % check if we have a file for the modesty statistic at the posterior mode
            %
            [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
            [ModestyStatus,ModestyResults] = GetDSGEVARModestyResults(DSGEModel,controls,MaxPH,'DSGEPosteriorMode');
            if ModestyStatus==1;
               set(controls.dsgevarview.modesty.dsgemode,'Enable','on','UserData',ModestyResults);
            else;
               set(controls.dsgevarview.modesty.dsgemode,'Enable','off','UserData','');
            end;
            NumPredPathsStr = get(controls.forecast.predpaths,'String');
            NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
            if DSGEModel.ShockControlMethod==1;
               ShockMethod = 'Direct-';
            elseif DSGEModel.ShockControlMethod==2;
               ShockMethod = 'WaggonerZha-';
            else;
               ShockMethod = 'Subset-';
            end;
            ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-ModestyStatistics-' ShockMethod DSGEModel.NameOfModel '-' num2str(MaxPH,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-PosteriorMode.txt']);
            if FileExist(ModestyFile)==1;
               set(controls.modesty.postmode,'Enable','on','UserData',ModestyFile);
            else;
               set(controls.modesty.postmode,'Enable','off','UserData','');
            end;
            if isfield(controls.modesty,'state')==1;
               ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-ModestyStatistics-State-' ShockMethod DSGEModel.NameOfModel '-' num2str(MaxPH,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-PosteriorMode.txt']);
               if FileExist(ModestyFile)==1;
                  set(controls.modesty.state.postmode,'Enable','on','UserData',ModestyFile);
               else;
                  set(controls.modesty.state.postmode,'Enable','off','UserData','');
               end;
            end;
         else;
            set(controls.predict.conditional_original_postmode,'Enable','off');
            set(controls.predict.conditional_annual_postmode,'Enable','off');
            set(controls.predict.conditional_transformed_postmode,'Enable','off');
            set(controls.modesty.postmode,'Enable','off','UserData','');
            set(controls.predict.conditional.original.zlb.postmode,'Enable','off');
            set(controls.predict.conditional.annual.zlb.postmode,'Enable','off');
            set(controls.predict.conditional.transformed.zlb.postmode,'Enable','off');
            if isfield(controls.modesty,'state')==1;
               set(controls.modesty.state.postmode,'Enable','off','UserData','');
            end;
            set(controls.dsgevartools.forecast.conditional.original.dsgemode,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.annual.dsgemode,'Enable','off');
            set(controls.dsgevartools.forecast.conditional.transformed.dsgemode,'Enable','off');
            set(controls.dsgevarview.modesty.dsgemode,'Enable','off','UserData','');
         end;
      end;
      if isfield(controls,'shockscenarios')==1;
         if MaxFH>0;
            set(controls.shockscenarios.postmode,'Enable','on');
            if max(DSGEModel.annual)>1
               set(controls.shockscenarios.annpostmode,'Enable','on');
            else;
               set(controls.shockscenarios.annpostmode,'Enable','off');
            end;
         else;
            set(controls.shockscenarios.postmode,'Enable','off');
            set(controls.shockscenarios.annpostmode,'Enable','off');
         end;
      end;
      if isfield(controls,'ovs')==1;
         if CheckScenarioData(DSGEModel)==1;
            set(controls.ovs.postmode,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.ovs.annpostmode,'Enable','on');
            else;
               set(controls.ovs.annpostmode,'Enable','off');
            end;
         else;
            set(controls.ovs.postmode,'Enable','off');
            set(controls.ovs.annpostmode,'Enable','off');
         end;
      end;
      if isfield(controls,'svs')==1;
         if CheckStateScenarioData(DSGEModel)==1;
            set(controls.svs.postmode,'Enable','on');
            set(controls.tunedfilters.statevariables.postmode,'Enable','on');
            set(controls.tunedfilters.stateshocks.postmode,'Enable','on');
            set(controls.tunedfilters.measurement.postmode,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.svs.annpostmode,'Enable','on');
            else;
               set(controls.svs.annpostmode,'Enable','off');
            end;
         else;
            set(controls.svs.postmode,'Enable','off');
            set(controls.svs.annpostmode,'Enable','off');
            set(controls.tunedfilters.statevariables.postmode,'Enable','off');
            set(controls.tunedfilters.stateshocks.postmode,'Enable','off');
            set(controls.tunedfilters.measurement.postmode,'Enable','off');
         end;
      end;
      set(controls.irfunctions.postmode,'Enable','on');
      set(controls.irfunctions.permanentshock.postmode,'Enable','on');
      set(controls.irfunctions.parameterchange.postmode,'Enable','on');
      if max(DSGEModel.annual)>1;
         set(controls.irfunctions.ann_postmode,'Enable','on');
         set(controls.cvd.ann_postmode,'Enable','on');
         set(controls.ovd.annpostmode,'Enable','on');
         set(controls.ovp.annpostmode,'Enable','on');
      else;
         set(controls.irfunctions.ann_postmode,'Enable','off');
         set(controls.cvd.ann_postmode,'Enable','off');
         set(controls.ovd.annpostmode,'Enable','off');
         set(controls.ovp.annpostmode,'Enable','off');
      end;
      set(controls.fevd.postmode,'Enable','on');
      set(controls.fevd.lev_postmode,'Enable','on');
      set(controls.cvd.postmode,'Enable','on');
      set(controls.cvd.state.postmode,'Enable','on');
      if sum(DSGEModel.levels)<DSGEModel.n;
         set(controls.cvd.lev_postmode,'Enable','on');
         set(controls.irfunctions.lev_postmode,'Enable','on');
      else;
         set(controls.cvd.lev_postmode,'Enable','off');
         set(controls.irfunctions.lev_postmode,'Enable','off');
      end;
      set(controls.fevd.state.postmode,'Enable','on');
      set(controls.obsweights.decomp.states.postmode,'Enable','on');
      set(controls.obsweights.decomp.shocks.postmode,'Enable','on');
      set(controls.obsweights.weights.states.postmode,'Enable','on');
      set(controls.obsweights.weights.shocks.postmode,'Enable','on');
      set(controls.hd.postmode,'Enable','on');
      set(controls.ovd.postmode,'Enable','on');
      set(controls.ovp.postmode,'Enable','on');
      set(controls.svd.postmode,'Enable','on');
      set(controls.postsampling,'Enable','on');
      set(controls.postsamplingmenu,'Enable','on');
      set(controls.checkpostmode,'Enable','on');
      set(controls.ps.postmode,'Enable','on');
      if max(DSGEModel.annual)>1;
         set(controls.ps.annpostmode,'Enable','on');
      else;
         set(controls.ps.annpostmode,'Enable','off');
      end;
      %
      % check to make sure that theta has at least 2 parameters
      %
      try;
         pm = load(ModeFile);
      catch;
         pm = [];
      end;
      if (isempty(pm)==0)&(length(pm.phiMode)>1);
         set(controls.threedeepostmode.transformed,'Enable','on');
         set(controls.threedeepostmode.original,'Enable','on');
      else;
         set(controls.threedeepostmode.transformed,'Enable','off');
         set(controls.threedeepostmode.original,'Enable','off');
      end;
      set(controls.iteratedparameters,'Enable','on');
      set(controls.statevariables.postmode,'Enable','on');
      set(controls.obsvar.postmode,'Enable','on');
      set(controls.stateshocks.postmode,'Enable','on');
      set(controls.measurementerror.postmode,'Enable','on');
      set(controls.loglikelihood.postmode,'Enable','on');
      set(controls.stateshockcorrs.postmode,'Enable','on');
      set(controls.measurementerrorcorrs.postmode,'Enable','on');
      set(controls.dsgeeigenvalues.postmode,'Enable','on');
      set(controls.postsample.laplace.parameterchange.postmode,'Enable','on');
      set(controls.postsample.laplacepostmode,'Enable','on');
      set(controls.viewlaplaceposterior,'Enable','on');
      set(controls.viewpriorvalue.postmode,'Enable','on');
      set(controls.dsgetovareigenvalues.postmode,'Enable','on');
      set(controls.informationmatrix.frequencydomain.postmode,'Enable','on');
      set(controls.informationmatrix.timedomain.postmode,'Enable','on');
      set(controls.simulatedata.postmode,'Enable','on');
      set(controls.statespacemode,'Enable','on');
      set(controls.statespacesavemode,'Enable','on');
      set(controls.parametervalues.postmode,'Enable','on');
      set(controls.properties.postmode,'Enable','on');
      set(controls.structuralformpostmode,'Enable','on');
      if DSGEModel.n>1;
         set(controls.obsvarcorrs.frequencydomain.postmode,'Enable','on');
         set(controls.condcorrs.postmode,'Enable','on');
         set(controls.dsgevartools.obscorr.frequencydomain.dsgemode,'Enable','on');
         if DSGEModel.n==length(DSGEModel.DSGEVARShocks);
            set(controls.dsgevartools.condcorr.dsgemode,'Enable','on');
         else;
            set(controls.dsgevartools.condcorr.dsgemode,'Enable','off');
         end;
      else;
         set(controls.obsvarcorrs.frequencydomain.postmode,'Enable','off');
         set(controls.condcorrs.postmode,'Enable','off');
         set(controls.dsgevartools.obscorr.frequencydomain.dsgemode,'Enable','off');
         set(controls.dsgevartools.condcorr.dsgemode,'Enable','off');
      end;
      set(controls.obsvarcorrs.timedomain.postmode,'Enable','on');
      set(controls.obsvarcorrs.parameterchange.postmode,'Enable','on');
      if length(DSGEModel.StateVariablePositions)>1;
         set(controls.statevarcorrs.frequencydomain.postmode,'Enable','on');
      else;
         set(controls.statevarcorrs.frequencydomain.postmode,'Enable','off');
      end;
      set(controls.statevarcorrs.timedomain.postmode,'Enable','on');
      set(controls.statevarcorrs.parameterchange.postmode,'Enable','on');
      set(controls.corrdecomp.obsvar.postmode,'Enable','on');
      set(controls.corrdecomp.statevar.postmode,'Enable','on');
      set(controls.spectraldecomp.obsvar.postmode,'Enable','on');
      set(controls.spectraldecomp.statevar.postmode,'Enable','on');
      %
      % check if the post sample summary file exist
      %
      DrawsStr = get(controls.posterior.draws,'String');
      NumPostDraws = str2num(StringTrim(strrep(DrawsStr(DSGEModel.PosteriorDrawsValue,:),',','')));
      %
      ChainsStr = get(controls.posterior.chains,'String');
      NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
      %
      % number of tempering stages
      %
      TempStagesStr = get(controls.posterior.temperingstages,'String');
      TempStages = str2num(StringTrim(TempStagesStr(DSGEModel.TemperingStagesValue,:)));
      %
      for CurrChain=1:10;
         if DSGEModel.PosteriorSampler==1;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorSamplingSummary-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==2;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\SlicePosteriorSamplingSummary-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==3;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorSamplingSummary-t-' int2str(DSGEModel.StudenttDegFree) '-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==4;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorSamplingSummary-Fixed-' int2str(DSGEModel.FixedNumParamBlocks) '-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==5;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorSamplingSummary-Fixed-' int2str(DSGEModel.FixedNumParamBlocks) '-t-' int2str(DSGEModel.StudenttDegFree) '-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==6;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorSamplingSummary-Random-' int2str(DSGEModel.BlockSize(1)) '-' int2str(DSGEModel.BlockSize(2)) '-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==7;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorSamplingSummary-Random-' int2str(DSGEModel.BlockSize(1)) '-' int2str(DSGEModel.BlockSize(2)) '-t-' int2str(DSGEModel.StudenttDegFree) '-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==8;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\SMCPosteriorSamplingSummary-' DSGEModel.NameOfModel '-' int2str(TempStages) '.' int2str(DSGEModel.NumParamBlocks) '.' int2str(DSGEModel.ResamplingAlgorithm) '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==9;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\SMCPosteriorSamplingSummary-' DSGEModel.NameOfModel '-' int2str(DSGEModel.NumParamBlocks) '.' int2str(DSGEModel.ResamplingAlgorithm) '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==10;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\ISPosteriorSamplingSummary-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' int2str(DSGEModel.ISMaxMixCompValue) '.' int2str(DSGEModel.ISInitialDF) '.' int2str(DSGEModel.ISWeightShareValue) '.' int2str(DSGEModel.ISAddedMixWeightValue) '.' int2str(DSGEModel.ISAddedDF) '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         end;
         if FileExist(PostSampleTextFile)==1;
            set(getfield(controls.postsamplesummary,['chain' num2str(CurrChain,'%0.0f')]),'Enable','on','UserData',PostSampleTextFile);
         else;
            set(getfield(controls.postsamplesummary,['chain' num2str(CurrChain,'%0.0f')]),'Enable','off','UserData','');
         end;
      end;
      if VerifyDSGEPosteriorDraws(DSGEModel,1,controls)==1;
         %
         % enable controls that require that we read the posterior draws data
         %
         if DSGEModel.PosteriorSampler<=7;
            set(controls.postsample.mhm,'Enable','on');
            set(controls.postsample.swz,'Enable','on');
            if (DSGEModel.PosteriorSampler==1)|(DSGEModel.PosteriorSampler>=3);
               set(controls.postsample.chibjeliazkov,'Enable','on');
            elseif DSGEModel.PosteriorSampler==2;
               set(controls.postsample.chibjeliazkov,'Enable','off');
            end;
         else;
            set(controls.postsample.mhm,'Enable','off');
            set(controls.postsample.swz,'Enable','off');
            set(controls.postsample.chibjeliazkov,'Enable','off');
         end;
         set(controls.postsample.rawplots_original,'Enable','on');
         set(controls.postsample.rawplots_transformed,'Enable','on');
         set(controls.postsample.rawplots_logpost,'Enable','on');
         if (DSGEModel.PosteriorSampler<=7)|(DSGEModel.PosteriorSampler==9);
            set(controls.postsample.rawplots_weights,'Enable','off','Label','&Particle Weights...');
         elseif (DSGEModel.PosteriorSampler==8)|(DSGEModel.PosteriorSampler==10);
            set(controls.postsample.rawplots_weights,'Enable','on');
            if DSGEModel.PosteriorSampler==8;
               set(controls.postsample.rawplots_weights,'Label','&Particle Weights...');
            else;
               set(controls.postsample.rawplots_weights,'Label','Im&portance Weights...');
            end;
         end;
         if (isempty(pm)==0)&(length(pm.phiMode)>1);
            set(controls.postsample.scatterplots_original,'Enable','on');
            set(controls.postsample.scatterplots_transformed,'Enable','on');
         else;
            set(controls.postsample.scatterplots_original,'Enable','off');
            set(controls.postsample.scatterplots_transformed,'Enable','off');
         end;
         set(controls.postsample.cusumplots.logposterior,'Enable','on');
         set(controls.postsample.cusumplots.original,'Enable','on');
         set(controls.postsample.cusumplots.transformed,'Enable','on');
         set(controls.postsample.spmt.logposterior,'Enable','on');
         set(controls.postsample.spmt.original,'Enable','on');
         set(controls.postsample.spmt.transformed,'Enable','on');
         if (DSGEModel.PosteriorSampler==1)|((DSGEModel.PosteriorSampler>=3)&(DSGEModel.PosteriorSampler<=9));
            set(controls.postsample.acceptancerate,'Enable','on');
         elseif (DSGEModel.PosteriorSampler==2)|(DSGEModel.PosteriorSampler==10);
            set(controls.postsample.acceptancerate,'Enable','off');
         end;
         if (DSGEModel.PosteriorSampler<=7)|(DSGEModel.PosteriorSampler==10);
            set(controls.postsample.smcadaption,'Enable','off');
         else;
            set(controls.postsample.smcadaption,'Enable','on');
         end;
         if (strcmp(get(controls.postsamplesummary.chain2,'Enable'),'on')==1)&(DSGEModel.ParallelChainsValue>1);
            set(controls.postsample.manova,'Enable','on');
         else;
            set(controls.postsample.manova,'Enable','off');
         end;
         set(controls.postsample.mean,'Enable','on');
         set(controls.postsample.median,'Enable','on');
         set(controls.viewposterior,'Enable','on');
         set(controls.viewbivariateposterior,'Enable','on');
         set(controls.posteriorcorrelations,'Enable','on');
         set(controls.statespaceposteriordist,'Enable','on');
         set(controls.hd.posterior,'Enable','on');
         set(controls.irfunctions.posterior,'Enable','on');
         set(controls.irfunctions.statevariables.posterior,'Enable','on');
         set(controls.ovd.posterior,'Enable','on');
         set(controls.ovp.posterior,'Enable','on');
         set(controls.obsvar.predchecks.posterior,'Enable','on');
         set(controls.obsvar.posterior,'Enable','on');
         if DSGEModel.n>1;
            set(controls.obsvarcorrs.frequencydomain.posterior,'Enable','on');
            set(controls.condcorrs.posterior,'Enable','on');
         else;
            set(controls.obsvarcorrs.frequencydomain.posterior,'Enable','off');
            set(controls.condcorrs.posterior,'Enable','off');
         end;
         set(controls.obsvarcorrs.timedomain.posterior,'Enable','on');
         set(controls.obsvarcorrs.parameterchange.posterior,'Enable','on');
         set(controls.statevariables.posterior,'Enable','on');
         if length(DSGEModel.StateVariablePositions)>1;
            set(controls.statevarcorrs.frequencydomain.posterior,'Enable','on');
         else;
            set(controls.statevarcorrs.frequencydomain.posterior,'Enable','off');
         end;
         set(controls.statevarcorrs.timedomain.posterior,'Enable','on');
         set(controls.statevarcorrs.parameterchange.posterior,'Enable','on');
         set(controls.stateshocks.posterior,'Enable','on');
         set(controls.stateshockcorrs.posterior,'Enable','on');
         set(controls.measurementerror.posterior,'Enable','on');
         set(controls.measurementerrorcorrs.posterior,'Enable','on');
         set(controls.cvd.posterior,'Enable','on');
         set(controls.cvd.state.posterior,'Enable','on');
         set(controls.fevd.state.posterior,'Enable','on');
         set(controls.estimateparamcovmat,'Enable','on');
         set(controls.fevd.posterior,'Enable','on');
         if isfield(controls,'shockscenarios')==1;
            if MaxFH>0;
               set(controls.shockscenarios.posterior,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.shockscenarios.annposterior,'Enable','on');
               else;
                  set(controls.shockscenarios.annposterior,'Enable','off');
               end;
            else;
               set(controls.shockscenarios.posterior,'Enable','off');
               set(controls.shockscenarios.annposterior,'Enable','off');
            end;
         end;
         if sum(DSGEModel.levels)<DSGEModel.n;
            set(controls.irfunctions.lev_posterior,'Enable','on');
            set(controls.cvd.lev_posterior,'Enable','on');
            set(controls.fevd.lev_posterior,'Enable','on');
         else;
            set(controls.irfunctions.lev_posterior,'Enable','off');
            set(controls.cvd.lev_posterior,'Enable','off');
            set(controls.fevd.lev_posterior,'Enable','off');
         end;
         if max(DSGEModel.annual)>1;
            set(controls.irfunctions.ann_posterior,'Enable','on');
            set(controls.ovd.annposterior,'Enable','on');
            set(controls.ovp.annposterior,'Enable','on');
            set(controls.cvd.ann_posterior,'Enable','on');
         else;
            set(controls.irfunctions.ann_posterior,'Enable','off');
            set(controls.ovd.annposterior,'Enable','off');
            set(controls.ovp.annposterior,'Enable','off');
            set(controls.cvd.ann_posterior,'Enable','off');
         end;
         if isfield(controls,'ovs')==1;
            if CheckScenarioData(DSGEModel)==1;
               set(controls.ovs.posterior,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.ovs.ann_posterior,'Enable','on');
               else;
                  set(controls.ovs.ann_posterior,'Enable','off');
               end;
            else;
               set(controls.ovs.posterior,'Enable','off');
               set(controls.ovs.ann_posterior,'Enable','off');
            end;
         end;
         if isfield(controls,'svs')==1;
            if CheckStateScenarioData(DSGEModel)==1;
               set(controls.svs.posterior,'Enable','on');
               set(controls.tunedfilters.statevariables.posterior,'Enable','on');
               set(controls.tunedfilters.stateshocks.posterior,'Enable','on');
               set(controls.tunedfilters.measurement.posterior,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.svs.ann_posterior,'Enable','on');
               else;
                  set(controls.svs.ann_posterior,'Enable','off');
               end;
            else;
               set(controls.svs.posterior,'Enable','off');
               set(controls.svs.ann_posterior,'Enable','off');
               set(controls.tunedfilters.statevariables.posterior,'Enable','off');
               set(controls.tunedfilters.stateshocks.posterior,'Enable','off');
               set(controls.tunedfilters.measurement.posterior,'Enable','off');
            end;
         end;
         if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
            set(controls.predict.unconditional_original_posterior,'Enable','off');
            set(controls.predict.unconditional_annual_posterior,'Enable','off');
            set(controls.predict.unconditional_transformed_posterior,'Enable','off');
            set(controls.predict.unconditional_original_predevent,'Enable','off');
            set(controls.predict.unconditional_annual_predevent,'Enable','off');
            set(controls.predict.unconditional_transformed_predevent,'Enable','off');
            set(controls.predict.unconditional.original.zlb.height.posterior,'Enable','off');
            set(controls.predict.unconditional.annual.zlb.height.posterior,'Enable','off');
            set(controls.predict.unconditional.original.zlb.crps.posterior,'Enable','off');
            set(controls.predict.unconditional.annual.zlb.crps.posterior,'Enable','off');
            set(controls.predict.unconditional.original.zlb.posterior,'Enable','off');
            set(controls.predict.unconditional.annual.zlb.posterior,'Enable','off');
            set(controls.predict.unconditional.transformed.zlb.posterior,'Enable','off');
            set(controls.predict.conditional.original.zlb.height.posterior,'Enable','off');
            set(controls.predict.conditional.annual.zlb.height.posterior,'Enable','off');
            set(controls.predict.conditional.original.zlb.crps.posterior,'Enable','off');
            set(controls.predict.conditional.annual.zlb.crps.posterior,'Enable','off');
            set(controls.predict.conditional.original.zlb.posterior,'Enable','off');
            set(controls.predict.conditional.annual.zlb.posterior,'Enable','off');
            set(controls.predict.conditional.transformed.zlb.posterior,'Enable','off');
            set(controls.predict.conditional_original_posterior,'Enable','off');
            set(controls.predict.conditional_annual_posterior,'Enable','off');
            set(controls.predict.conditional_transformed_posterior,'Enable','off');
            set(controls.predict.conditional_original_predevent,'Enable','off');
            set(controls.predict.conditional_annual_predevent,'Enable','off');
            set(controls.predict.conditional_transformed_predevent,'Enable','off');
            set(controls.predict.conditional.original.height.posterior,'Enable','off');
            set(controls.predict.conditional.annual.height.posterior,'Enable','off');
            set(controls.predict.conditional.original.crps.posterior,'Enable','off');
            set(controls.predict.conditional.annual.crps.posterior,'Enable','off');
            set(controls.predict.conditional.original.moments.posterior,'Enable','off');
            set(controls.predict.conditional.original.pit.posterior,'Enable','off');
            for i=1:10;
               set(getfield(controls.modesty,['chain' num2str(i,'%0.0f')]),'Enable','off','UserData','');
            end;
            if isfield(controls.modesty,'state')==1;
               for i=1:10;
                  set(getfield(controls.modesty,['chain' num2str(i,'%0.0f')]),'Enable','off','UserData','');
               end;
            end;
            set(controls.predict.unconditional.original.height.posterior,'Enable','off');
            set(controls.predict.unconditional.annual.height.posterior,'Enable','off');
            set(controls.predict.unconditional.original.crps.posterior,'Enable','off');
            set(controls.predict.unconditional.annual.crps.posterior,'Enable','off');
            set(controls.predict.unconditional.original.moments.posterior,'Enable','off');
            set(controls.predict.unconditional.original.pit.posterior,'Enable','off');
            set(controls.predict.unconditional.original.variancedecomp.posterior,'Enable','off');
         else;
            set(controls.predict.unconditional_original_posterior,'Enable','on');
            set(controls.predict.unconditional_original_predevent,'Enable','on');
            if isempty(DSGEModel.ZLBPosition)==0;
               if CurrINI.KSDensityExist==1;
                  set(controls.predict.unconditional.original.zlb.height.posterior,'Enable','on');
               else;
                  set(controls.predict.unconditional.original.zlb.height.posterior,'Enable','off');
               end;
               set(controls.predict.unconditional.original.zlb.crps.posterior,'Enable','on');
               set(controls.predict.unconditional.original.zlb.posterior,'Enable','on');
               if CheckConditioningData(DSGEModel)==1;
                  if CurrINI.KSDensityExist==1;
                     set(controls.predict.conditional.original.zlb.height.posterior,'Enable','on');
                  else;
                     set(controls.predict.conditional.original.zlb.height.posterior,'Enable','off');
                  end;
                  set(controls.predict.conditional.original.zlb.crps.posterior,'Enable','on');
                  set(controls.predict.conditional.original.zlb.posterior,'Enable','on');
               else;
                  set(controls.predict.conditional.original.zlb.height.posterior,'Enable','off');
                  set(controls.predict.conditional.original.zlb.crps.posterior,'Enable','off');
                  set(controls.predict.conditional.original.zlb.posterior,'Enable','off');
               end;
            else;
               set(controls.predict.unconditional.original.zlb.height.posterior,'Enable','off');
               set(controls.predict.unconditional.original.zlb.crps.posterior,'Enable','off');
               set(controls.predict.unconditional.original.zlb.posterior,'Enable','off');
               set(controls.predict.conditional.original.zlb.height.posterior,'Enable','off');
               set(controls.predict.conditional.original.zlb.crps.posterior,'Enable','off');
               set(controls.predict.conditional.original.zlb.posterior,'Enable','off');
            end;
            if isempty(DSGEModel.YTransformation)==0;
               set(controls.predict.unconditional_transformed_posterior,'Enable','on');
               set(controls.predict.unconditional_transformed_predevent,'Enable','on');
               if isempty(DSGEModel.ZLBPosition)==0;
                  set(controls.predict.unconditional.transformed.zlb.posterior,'Enable','on');
                  if CheckConditioningData(DSGEModel)==1;
                     set(controls.predict.conditional.transformed.zlb.posterior,'Enable','on');
                  else;
                     set(controls.predict.conditional.transformed.zlb.posterior,'Enable','off');
                  end;
               else;
                  set(controls.predict.unconditional.transformed.zlb.posterior,'Enable','off');
                  set(controls.predict.conditional.transformed.zlb.posterior,'Enable','off');
               end;
            else;
               set(controls.predict.unconditional_transformed_posterior,'Enable','off');
               set(controls.predict.unconditional_transformed_predevent,'Enable','off');
               set(controls.predict.unconditional.transformed.zlb.posterior,'Enable','off');
               set(controls.predict.conditional.transformed.zlb.posterior,'Enable','off');
            end;
            if max(DSGEModel.annual)>1;
               set(controls.predict.unconditional_annual_posterior,'Enable','on');
               set(controls.predict.unconditional_annual_predevent,'Enable','on');
               if isempty(DSGEModel.ZLBPosition)==0;
                  if CurrINI.KSDensityExist==1;
                     set(controls.predict.unconditional.annual.zlb.height.posterior,'Enable','on');
                  else;
                     set(controls.predict.unconditional.annual.zlb.height.posterior,'Enable','off');
                  end;
                  set(controls.predict.unconditional.annual.zlb.crps.posterior,'Enable','on');
                  set(controls.predict.unconditional.annual.zlb.posterior,'Enable','on');
                  if CheckConditioningData(DSGEModel)==1;
                     if CurrINI.KSDensityExist==1;
                        set(controls.predict.conditional.annual.zlb.height.posterior,'Enable','on');
                     else;
                        set(controls.predict.conditional.annual.zlb.height.posterior,'Enable','off');
                     end;
                     set(controls.predict.conditional.annual.zlb.crps.posterior,'Enable','on');
                     set(controls.predict.conditional.annual.zlb.posterior,'Enable','on');
                  else;
                     set(controls.predict.conditional.annual.zlb.height.posterior,'Enable','off');
                     set(controls.predict.conditional.annual.zlb.crps.posterior,'Enable','off');
                     set(controls.predict.conditional.annual.zlb.posterior,'Enable','off');
                  end;
               else;
                  set(controls.predict.unconditional.annual.zlb.height.posterior,'Enable','off');
                  set(controls.predict.unconditional.annual.zlb.crps.posterior,'Enable','off');
                  set(controls.predict.unconditional.annual.zlb.posterior,'Enable','off');
                  set(controls.predict.conditional.annual.zlb.height.posterior,'Enable','off');
                  set(controls.predict.conditional.annual.zlb.crps.posterior,'Enable','off');
                  set(controls.predict.conditional.annual.zlb.posterior,'Enable','off');
               end;
            else;
               set(controls.predict.unconditional_annual_posterior,'Enable','off');
               set(controls.predict.unconditional_annual_predevent,'Enable','off');
               set(controls.predict.unconditional.annual.zlb.height.posterior,'Enable','off');
               set(controls.predict.unconditional.annual.zlb.crps.posterior,'Enable','off');
               set(controls.predict.unconditional.annual.zlb.posterior,'Enable','off');
               set(controls.predict.conditional.annual.zlb.height.posterior,'Enable','off');
               set(controls.predict.conditional.annual.zlb.crps.posterior,'Enable','off');
               set(controls.predict.conditional.annual.zlb.posterior,'Enable','off');
            end;
            if MaxFH>0;
               set(controls.predict.unconditional.original.height.posterior,'Enable','on');
               set(controls.predict.unconditional.original.crps.posterior,'Enable','on');
               set(controls.predict.unconditional.original.moments.posterior,'Enable','on');
               if exist('normcdf')~=0;
                  set(controls.predict.unconditional.original.pit.posterior,'Enable','on');
               else;
                  set(controls.predict.unconditional.original.pit.posterior,'Enable','off');
               end;
               if max(DSGEModel.annual)>1;
                  set(controls.predict.unconditional.annual.height.posterior,'Enable','on');
                  set(controls.predict.unconditional.annual.crps.posterior,'Enable','on');
               else;
                  set(controls.predict.unconditional.annual.height.posterior,'Enable','off');
                  set(controls.predict.unconditional.annual.crps.posterior,'Enable','off');
               end;
            else;
               set(controls.predict.unconditional.original.height.posterior,'Enable','off');
               set(controls.predict.unconditional.annual.height.posterior,'Enable','off');
               set(controls.predict.unconditional.original.crps.posterior,'Enable','off');
               set(controls.predict.unconditional.annual.crps.posterior,'Enable','off');
               set(controls.predict.unconditional.original.moments.posterior,'Enable','off');
               set(controls.predict.unconditional.original.pit.posterior,'Enable','off');
            end;
            set(controls.predict.unconditional.original.variancedecomp.posterior,'Enable','on');
            if CheckConditioningData(DSGEModel)==1;
               set(controls.predict.conditional_original_posterior,'Enable','on');
               set(controls.predict.conditional_original_predevent,'Enable','on');
               if isempty(DSGEModel.YTransformation)==0;
                  set(controls.predict.conditional_transformed_posterior,'Enable','on');
                  set(controls.predict.conditional_transformed_predevent,'Enable','on');
               else;
                  set(controls.predict.conditional_transformed_posterior,'Enable','off');
                  set(controls.predict.conditional_transformed_predevent,'Enable','off');
               end;
               if MaxFH>0;
                  if CurrINI.KSDensityExist==1;
                     set(controls.predict.conditional.original.height.posterior,'Enable','on');
                  else;
                     set(controls.predict.conditional.original.height.posterior,'Enable','off');
                  end;
                  set(controls.predict.conditional.original.crps.posterior,'Enable','on');
                  set(controls.predict.conditional.original.moments.posterior,'Enable','on');
                  set(controls.predict.conditional.original.pit.posterior,'Enable','on');
                  if max(DSGEModel.annual)>1;
                     if CurrINI.KSDensityExist==1;
                        set(controls.predict.conditional.annual.height.posterior,'Enable','on');
                     else;
                        set(controls.predict.conditional.annual.height.posterior,'Enable','off');
                     end;
                     set(controls.predict.conditional.annual.crps.posterior,'Enable','on');
                  end;
               else;
                  set(controls.predict.conditional.original.height.posterior,'Enable','off');
                  set(controls.predict.conditional.annual.height.posterior,'Enable','off');
                  set(controls.predict.conditional.original.crps.posterior,'Enable','off');
                  set(controls.predict.conditional.annual.crps.posterior,'Enable','off');
                  set(controls.predict.conditional.original.moments.posterior,'Enable','off');
                  set(controls.predict.conditional.original.pit.posterior,'Enable','off');
               end;
               %
               % check if modesty results exists
               %
               [stat,files] = ModestyExist(DSGEModel,controls,'DSGE');
               for i=1:10;
                  if stat(i)==1;
                     set(getfield(controls.modesty,['chain' num2str(i,'%0.0f')]),'Enable','on','UserData',StringTrim(files(i,:)));
                  else;
                     set(getfield(controls.modesty,['chain' num2str(i,'%0.0f')]),'Enable','off','UserData','');
                  end;
               end;
               if isfield(controls.modesty,'state')==1;
                  [stat,files] = ModestyExist(DSGEModel,controls,'state');
                  for i=1:10;
                     if stat(i)==1;
                        set(getfield(controls.modesty.state,['chain' num2str(i,'%0.0f')]),'Enable','on','UserData',StringTrim(files(i,:)));
                     else;
                        set(getfield(controls.modesty.state,['chain' num2str(i,'%0.0f')]),'Enable','off','UserData','');
                     end;
                  end;
               end;
               if max(DSGEModel.annual)>1;
                  set(controls.predict.conditional_annual_posterior,'Enable','on');
                  set(controls.predict.conditional_annual_predevent,'Enable','on');
               else;
                  set(controls.predict.conditional_annual_posterior,'Enable','off');
                  set(controls.predict.conditional_annual_predevent,'Enable','off');
               end;
            else;
               set(controls.predict.conditional_original_posterior,'Enable','off');
               set(controls.predict.conditional_original_predevent,'Enable','off');
               set(controls.predict.conditional_annual_posterior,'Enable','off');
               set(controls.predict.conditional_annual_predevent,'Enable','off');
               set(controls.predict.conditional_transformed_posterior,'Enable','off');
               set(controls.predict.conditional_transformed_predevent,'Enable','off');
               set(controls.predict.conditional.original.height.posterior,'Enable','off');
               set(controls.predict.conditional.annual.height.posterior,'Enable','off');
               set(controls.predict.conditional.original.crps.posterior,'Enable','off');
               set(controls.predict.conditional.annual.crps.posterior,'Enable','off');
               set(controls.predict.conditional.original.moments.posterior,'Enable','off');
               set(controls.predict.conditional.original.pit.posterior,'Enable','off');
               for i=1:10;
                  set(getfield(controls.modesty,['chain' num2str(i,'%0.0f')]),'Enable','off','UserData','');
               end;
               if isfield(controls.modesty,'state')==1;
                  for i=1:10;
                     set(getfield(controls.modesty.state,['chain' num2str(i,'%0.0f')]),'Enable','off','UserData','');
                  end;
               end;
            end;
         end;
      else;
         %
         % disable controls that require that all posterior draws data exists
         %
         set(controls.postsample.mhm,'Enable','off');
         set(controls.postsample.swz,'Enable','off');
         set(controls.postsample.chibjeliazkov,'Enable','off');
         set(controls.postsample.rawplots_original,'Enable','off');
         set(controls.postsample.scatterplots_original,'Enable','off');
         set(controls.postsample.rawplots_transformed,'Enable','off');
         set(controls.postsample.rawplots_logpost,'Enable','off');
         if DSGEModel.PosteriorSampler==10;
            set(controls.postsample.rawplots_weights,'Enable','off','Label','Im&portance Weights...');
         else;
            set(controls.postsample.rawplots_weights,'Enable','off','Label','&Particle Weights...');
         end;
         set(controls.postsample.scatterplots_transformed,'Enable','off');
         set(controls.hd.posterior,'Enable','off');
         set(controls.irfunctions.posterior,'Enable','off');
         set(controls.irfunctions.statevariables.posterior,'Enable','off');
         set(controls.ovd.posterior,'Enable','off');
         set(controls.ovp.posterior,'Enable','off');
         set(controls.obsvar.predchecks.posterior,'Enable','off');
         set(controls.obsvar.posterior,'Enable','off');
         set(controls.obsvarcorrs.frequencydomain.posterior,'Enable','off');
         set(controls.obsvarcorrs.timedomain.posterior,'Enable','off');
         set(controls.obsvarcorrs.parameterchange.posterior,'Enable','off');
         set(controls.condcorrs.posterior,'Enable','off');
         set(controls.statevariables.posterior,'Enable','off');
         set(controls.statevarcorrs.frequencydomain.posterior,'Enable','off');
         set(controls.statevarcorrs.timedomain.posterior,'Enable','off');
         set(controls.statevarcorrs.parameterchange.posterior,'Enable','off');
         set(controls.stateshocks.posterior,'Enable','off');
         set(controls.stateshockcorrs.posterior,'Enable','off');
         set(controls.measurementerror.posterior,'Enable','off');
         set(controls.measurementerrorcorrs.posterior,'Enable','off');
         if isfield(controls,'ovs')==1;
            set(controls.ovs.posterior,'Enable','off');
            set(controls.ovs.ann_posterior,'Enable','off');
         end;
         if isfield(controls,'shockscenarios')==1;
            set(controls.shockscenarios.posterior,'Enable','off');
            set(controls.shockscenarios.annposterior,'Enable','off');
         end;
         if isfield(controls,'svs')==1;
            set(controls.svs.posterior,'Enable','off');
            set(controls.svs.ann_posterior,'Enable','off');
            set(controls.tunedfilters.statevariables.posterior,'Enable','off');
            set(controls.tunedfilters.stateshocks.posterior,'Enable','off');
            set(controls.tunedfilters.measurement.posterior,'Enable','off');
         end;
         set(controls.cvd.posterior,'Enable','off');
         set(controls.cvd.state.posterior,'Enable','off');
         set(controls.fevd.posterior,'Enable','off');
         set(controls.fevd.lev_posterior,'Enable','off');
         set(controls.fevd.state.posterior,'Enable','off');
         set(controls.estimateparamcovmat,'Enable','off');
         set(controls.irfunctions.ann_posterior,'Enable','off');
         set(controls.ovd.annposterior,'Enable','off');
         set(controls.ovp.annposterior,'Enable','off');
         set(controls.cvd.ann_posterior,'Enable','off');
         set(controls.irfunctions.lev_posterior,'Enable','off');
         set(controls.cvd.lev_posterior,'Enable','off');
         set(controls.postsample.cusumplots.logposterior,'Enable','off');
         set(controls.postsample.cusumplots.original,'Enable','off');
         set(controls.postsample.cusumplots.transformed,'Enable','off');
         set(controls.postsample.spmt.logposterior,'Enable','off');
         set(controls.postsample.spmt.original,'Enable','off');
         set(controls.postsample.spmt.transformed,'Enable','off');
         set(controls.postsample.acceptancerate,'Enable','off');
         set(controls.postsample.smcadaption,'Enable','off');
         set(controls.postsample.manova,'Enable','off');
         set(controls.postsample.mean,'Enable','off');
         set(controls.postsample.median,'Enable','off');
         set(controls.viewposterior,'Enable','off');
         set(controls.viewbivariateposterior,'Enable','off');
         set(controls.posteriorcorrelations,'Enable','off');
         set(controls.statespaceposteriordist,'Enable','off');
         set(controls.predict.unconditional_original_posterior,'Enable','off');
         set(controls.predict.unconditional_original_predevent,'Enable','off');
         set(controls.predict.unconditional_transformed_posterior,'Enable','off');
         set(controls.predict.unconditional_transformed_predevent,'Enable','off');
         set(controls.predict.unconditional.original.zlb.height.posterior,'Enable','off');
         set(controls.predict.unconditional.annual.zlb.height.posterior,'Enable','off');
         set(controls.predict.unconditional.original.zlb.crps.posterior,'Enable','off');
         set(controls.predict.unconditional.annual.zlb.crps.posterior,'Enable','off');
         set(controls.predict.unconditional.original.zlb.posterior,'Enable','off');
         set(controls.predict.unconditional.annual.zlb.posterior,'Enable','off');
         set(controls.predict.unconditional.transformed.zlb.posterior,'Enable','off');
         set(controls.predict.conditional.original.zlb.height.posterior,'Enable','off');
         set(controls.predict.conditional.annual.zlb.height.posterior,'Enable','off');
         set(controls.predict.conditional.original.zlb.crps.posterior,'Enable','off');
         set(controls.predict.conditional.annual.zlb.crps.posterior,'Enable','off');
         set(controls.predict.conditional.original.zlb.posterior,'Enable','off');
         set(controls.predict.conditional.annual.zlb.posterior,'Enable','off');
         set(controls.predict.conditional.transformed.zlb.posterior,'Enable','off');
         set(controls.predict.conditional_original_posterior,'Enable','off');
         set(controls.predict.conditional_original_predevent,'Enable','off');
         set(controls.predict.conditional_transformed_posterior,'Enable','off');
         set(controls.predict.conditional_transformed_predevent,'Enable','off');
         set(controls.predict.conditional.original.height.posterior,'Enable','off');
         set(controls.predict.conditional.annual.height.posterior,'Enable','off');
         set(controls.predict.conditional.original.crps.posterior,'Enable','off');
         set(controls.predict.conditional.annual.crps.posterior,'Enable','off');
         set(controls.predict.conditional.original.moments.posterior,'Enable','off');
         set(controls.predict.conditional.original.pit.posterior,'Enable','off');
         for i=1:10;
            set(getfield(controls.modesty,['chain' num2str(i,'%0.0f')]),'Enable','off','UserData','');
         end;
         if isfield(controls.modesty,'state')==1;
            for i=1:10;
               set(getfield(controls.modesty.state,['chain' num2str(i,'%0.0f')]),'Enable','off','UserData','');
            end;
         end;
         set(controls.predict.unconditional_annual_posterior,'Enable','off');
         set(controls.predict.unconditional_annual_predevent,'Enable','off');
         set(controls.predict.conditional_annual_posterior,'Enable','off');
         set(controls.predict.conditional_annual_predevent,'Enable','off');
         set(controls.predict.unconditional.original.height.posterior,'Enable','off');
         set(controls.predict.unconditional.annual.height.posterior,'Enable','off');
         set(controls.predict.unconditional.original.crps.posterior,'Enable','off');
         set(controls.predict.unconditional.annual.crps.posterior,'Enable','off');
         set(controls.predict.unconditional.original.moments.posterior,'Enable','off');
         set(controls.predict.unconditional.original.pit.posterior,'Enable','off');
         set(controls.predict.unconditional.original.variancedecomp.posterior,'Enable','off');
      end;
      clear('pm');
   else;
      set(controls.dsgevarview.varmodel.dsgemode,'Enable','off');
      set(controls.dsgevarview.eigenvalues.dsgemode,'Enable','off');
      set(controls.dsgevarview.sequentialmarglike.laplace.dsgemode,'Enable','off');
      set(controls.dsgevartools.simulatedata.dsgemode,'Enable','off');
      set(controls.dsgevartools.obscorr.timedomain.dsgemode,'Enable','off');
      set(controls.dsgevartools.obscorr.parameterchange.dsgemode,'Enable','off');
      set(controls.dsgevartools.shockcorr.dsgemode,'Enable','off');
      set(controls.dsgevartools.shocks.dsgemode,'Enable','off');
      set(controls.dsgevartools.loglikelihood.dsgemode,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.decomp.original.dsgemode,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.paths.original.dsgemode,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.decomp.annual.dsgemode,'Enable','off');
      set(controls.dsgevartools.decomposition.ovd.paths.annual.dsgemode,'Enable','off');
      set(controls.dsgevartools.decomposition.corrdecomp.dsgemode,'Enable','off');
      set(controls.dsgevartools.decomposition.spectraldecomp.dsgemode,'Enable','off');
      set(controls.dsgevartools.decomposition.fevd.original.dsgemode,'Enable','off');
      set(controls.dsgevartools.decomposition.fevd.levels.dsgemode,'Enable','off');
      set(controls.dsgevartools.irfunction.original.dsgemode,'Enable','off');
      set(controls.dsgevartools.irfunction.annual.dsgemode,'Enable','off');
      set(controls.dsgevartools.irfunction.levels.dsgemode,'Enable','off');
      if isfield(controls.dsgevartools,'obsvarscenario')==1;
         set(controls.dsgevartools.obsvarscenario.original.dsgemode,'Enable','off');
         set(controls.dsgevartools.obsvarscenario.annual.dsgemode,'Enable','off');
      end;
      if isfield(controls,'ovs')==1;
         set(controls.ovs.postmode,'Enable','off');
         set(controls.ovs.annpostmode,'Enable','off');
         set(controls.ovs.posterior,'Enable','off');
         set(controls.ovs.ann_posterior,'Enable','off');
      end;
      if isfield(controls,'svs')==1;
         set(controls.svs.postmode,'Enable','off');
         set(controls.svs.annpostmode,'Enable','off');
         set(controls.svs.posterior,'Enable','off');
         set(controls.svs.ann_posterior,'Enable','off');
         set(controls.tunedfilters.statevariables.postmode,'Enable','off');
         set(controls.tunedfilters.stateshocks.postmode,'Enable','off');
         set(controls.tunedfilters.measurement.postmode,'Enable','off');
         set(controls.tunedfilters.statevariables.posterior,'Enable','off');
         set(controls.tunedfilters.stateshocks.posterior,'Enable','off');
         set(controls.tunedfilters.measurement.posterior,'Enable','off');
      end;
      if isfield(controls,'shockscenarios')==1;
         set(controls.shockscenarios.annpostmode,'Enable','off');
         set(controls.shockscenarios.postmode,'Enable','off');
         set(controls.shockscenarios.posterior,'Enable','off');
         set(controls.shockscenarios.annposterior,'Enable','off');
      end;
      set(controls.irfunctions.postmode,'Enable','off');
      set(controls.irfunctions.permanentshock.postmode,'Enable','off');
      set(controls.irfunctions.parameterchange.postmode,'Enable','off');
      set(controls.predict.unconditional_original_postmode,'Enable','off');
      set(controls.predict.conditional_original_postmode,'Enable','off');
      set(controls.predict.unconditional_transformed_postmode,'Enable','off');
      set(controls.predict.conditional_transformed_postmode,'Enable','off');
      set(controls.modesty.postmode,'Enable','off','UserData','');
      set(controls.predict.unconditional.original.zlb.postmode,'Enable','off');
      set(controls.predict.unconditional.annual.zlb.postmode,'Enable','off');
      set(controls.predict.unconditional.transformed.zlb.postmode,'Enable','off');
      set(controls.predict.conditional.original.zlb.postmode,'Enable','off');
      set(controls.predict.conditional.annual.zlb.postmode,'Enable','off');
      set(controls.predict.conditional.transformed.zlb.postmode,'Enable','off');
      set(controls.predict.unconditional.original.obsweightdecomp.postmode,'Enable','off');
      set(controls.predict.unconditional.annual.obsweightdecomp.postmode,'Enable','off');
      if isfield(controls.modesty,'state')==1;
         set(controls.modesty.state.postmode,'Enable','off','UserData','');
      end;
      set(controls.predict.unconditional_annual_postmode,'Enable','off');
      set(controls.predict.conditional_annual_postmode,'Enable','off');
      set(controls.predict.unconditional.original.height.postmode,'Enable','off');
      set(controls.predict.unconditional.annual.height.postmode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.dsgemode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.annual.dsgemode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.transformed.dsgemode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.original.height.dsgemode,'Enable','off');
      set(controls.dsgevartools.forecast.unconditional.annual.height.dsgemode,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.original.dsgemode,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.annual.dsgemode,'Enable','off');
      set(controls.dsgevartools.forecast.conditional.transformed.dsgemode,'Enable','off');
      set(controls.dsgevarview.modesty.dsgemode,'Enable','off','UserData','');
      set(controls.irfunctions.ann_postmode,'Enable','off');
      set(controls.fevd.postmode,'Enable','off');
      set(controls.fevd.lev_postmode,'Enable','off');
      set(controls.cvd.postmode,'Enable','off');
      set(controls.cvd.ann_postmode,'Enable','off');
      set(controls.cvd.lev_postmode,'Enable','off');
      set(controls.cvd.state.postmode,'Enable','off');
      set(controls.fevd.state.postmode,'Enable','off');
      set(controls.irfunctions.lev_postmode,'Enable','off');
      set(controls.obsweights.decomp.states.postmode,'Enable','off');
      set(controls.obsweights.decomp.shocks.postmode,'Enable','off');
      set(controls.obsweights.weights.states.postmode,'Enable','off');
      set(controls.obsweights.weights.shocks.postmode,'Enable','off');
      set(controls.hd.postmode,'Enable','off');
      set(controls.ovd.postmode,'Enable','off');
      set(controls.ovp.postmode,'Enable','off');
      set(controls.ovd.annpostmode,'Enable','off');
      set(controls.ovp.annpostmode,'Enable','off');
      set(controls.svd.postmode,'Enable','off');
      set(controls.postsampling,'Enable','off');
      set(controls.postsamplingmenu,'Enable','off');
      set(controls.checkpostmode,'Enable','off');
      set(controls.ps.postmode,'Enable','off');
      set(controls.ps.annpostmode,'Enable','off');
      set(controls.threedeepostmode.transformed,'Enable','off');
      set(controls.threedeepostmode.original,'Enable','off');
      set(controls.iteratedparameters,'Enable','off');
      set(controls.statevariables.postmode,'Enable','off');
      set(controls.obsvar.postmode,'Enable','off');
      set(controls.stateshocks.postmode,'Enable','off');
      set(controls.measurementerror.postmode,'Enable','off');
      set(controls.loglikelihood.postmode,'Enable','off');
      set(controls.stateshockcorrs.postmode,'Enable','off');
      set(controls.measurementerrorcorrs.postmode,'Enable','off');
      set(controls.dsgeeigenvalues.postmode,'Enable','off');
      set(controls.postsample.laplace.parameterchange.postmode,'Enable','off');
      set(controls.postsample.laplacepostmode,'Enable','off');
      set(controls.viewlaplaceposterior,'Enable','off');
      set(controls.viewpriorvalue.postmode,'Enable','off');
      set(controls.dsgetovareigenvalues.postmode,'Enable','off');
      set(controls.informationmatrix.frequencydomain.postmode,'Enable','off');
      set(controls.informationmatrix.timedomain.postmode,'Enable','off');
      set(controls.simulatedata.postmode,'Enable','off');
      set(controls.statespacemode,'Enable','off');
      set(controls.statespacesavemode,'Enable','off');
      set(controls.parametervalues.postmode,'Enable','off');
      set(controls.properties.postmode,'Enable','off');
      set(controls.structuralformpostmode,'Enable','off');
      set(controls.obsvarcorrs.frequencydomain.postmode,'Enable','off');
      set(controls.dsgevartools.obscorr.frequencydomain.dsgemode,'Enable','off');
      set(controls.dsgevartools.condcorr.dsgemode,'Enable','off');
      set(controls.obsvarcorrs.timedomain.postmode,'Enable','off');
      set(controls.obsvarcorrs.parameterchange.postmode,'Enable','off');
      set(controls.condcorrs.postmode,'Enable','off');
      set(controls.statevarcorrs.frequencydomain.postmode,'Enable','off');
      set(controls.statevarcorrs.timedomain.postmode,'Enable','off');
      set(controls.statevarcorrs.parameterchange.postmode,'Enable','off');
      set(controls.corrdecomp.obsvar.postmode,'Enable','off');
      set(controls.corrdecomp.statevar.postmode,'Enable','off');
      set(controls.spectraldecomp.obsvar.postmode,'Enable','off');
      set(controls.spectraldecomp.statevar.postmode,'Enable','off');
      for CurrChain=1:10;
         set(getfield(controls.postsamplesummary,['chain' num2str(CurrChain,'%0.0f')]),'Enable','off','UserData','');
      end;
      set(controls.postsample.mhm,'Enable','off');
      set(controls.postsample.swz,'Enable','off');
      set(controls.postsample.chibjeliazkov,'Enable','off');
      set(controls.predict.unconditional_original_posterior,'Enable','off');
      set(controls.predict.unconditional_original_predevent,'Enable','off');
      set(controls.predict.unconditional_transformed_posterior,'Enable','off');
      set(controls.predict.unconditional_transformed_predevent,'Enable','off');
      set(controls.predict.unconditional.original.zlb.height.posterior,'Enable','off');
      set(controls.predict.unconditional.annual.zlb.height.posterior,'Enable','off');
      set(controls.predict.unconditional.original.zlb.crps.posterior,'Enable','off');
      set(controls.predict.unconditional.annual.zlb.crps.posterior,'Enable','off');
      set(controls.predict.unconditional.original.zlb.posterior,'Enable','off');
      set(controls.predict.unconditional.annual.zlb.posterior,'Enable','off');
      set(controls.predict.unconditional.transformed.zlb.posterior,'Enable','off');
      set(controls.predict.conditional.original.zlb.height.posterior,'Enable','off');
      set(controls.predict.conditional.annual.zlb.height.posterior,'Enable','off');
      set(controls.predict.conditional.original.zlb.crps.posterior,'Enable','off');
      set(controls.predict.conditional.annual.zlb.crps.posterior,'Enable','off');
      set(controls.predict.conditional.original.zlb.posterior,'Enable','off');
      set(controls.predict.conditional.annual.zlb.posterior,'Enable','off');
      set(controls.predict.conditional.transformed.zlb.posterior,'Enable','off');
      set(controls.predict.conditional_original_posterior,'Enable','off');
      set(controls.predict.conditional_original_predevent,'Enable','off');
      set(controls.predict.conditional_transformed_posterior,'Enable','off');
      set(controls.predict.conditional_transformed_predevent,'Enable','off');
      set(controls.predict.conditional.original.height.posterior,'Enable','off');
      set(controls.predict.conditional.annual.height.posterior,'Enable','off');
      set(controls.predict.conditional.original.crps.posterior,'Enable','off');
      set(controls.predict.conditional.annual.crps.posterior,'Enable','off');
      set(controls.predict.conditional.original.moments.posterior,'Enable','off');
      set(controls.predict.conditional.original.pit.posterior,'Enable','off');
      for i=1:10;
         set(getfield(controls.modesty,['chain' num2str(i,'%0.0f')]),'Enable','off','UserData','');
      end;
      if isfield(controls.modesty,'state')==1;
         for i=1:10;
            set(getfield(controls.modesty.state,['chain' num2str(i,'%0.0f')]),'Enable','off','UserData','');
         end;
      end;
      set(controls.predict.unconditional_annual_posterior,'Enable','off');
      set(controls.predict.unconditional_annual_predevent,'Enable','off');
      set(controls.predict.conditional_annual_posterior,'Enable','off');
      set(controls.predict.conditional_annual_predevent,'Enable','off');
      set(controls.predict.unconditional.original.height.posterior,'Enable','off');
      set(controls.predict.unconditional.annual.height.posterior,'Enable','off');
      set(controls.predict.unconditional.original.crps.posterior,'Enable','off');
      set(controls.predict.unconditional.annual.crps.posterior,'Enable','off');
      set(controls.predict.unconditional.original.moments.posterior,'Enable','off');
      set(controls.predict.unconditional.original.pit.posterior,'Enable','off');
      set(controls.predict.unconditional.original.variancedecomp.posterior,'Enable','off');
      set(controls.postsample.rawplots_original,'Enable','off');
      set(controls.postsample.scatterplots_original,'Enable','off');
      set(controls.postsample.rawplots_transformed,'Enable','off');
      set(controls.postsample.rawplots_logpost,'Enable','off');
      if DSGEModel.PosteriorSampler==10;
         set(controls.postsample.rawplots_weights,'Enable','off','Label','Im&portance Weights...');
      else;
         set(controls.postsample.rawplots_weights,'Enable','off','Label','&Particle Weights...');
      end;
      set(controls.postsample.scatterplots_transformed,'Enable','off');
      set(controls.hd.posterior,'Enable','off');
      set(controls.irfunctions.posterior,'Enable','off');
      set(controls.irfunctions.statevariables.posterior,'Enable','off');
      set(controls.ovd.posterior,'Enable','off');
      set(controls.ovp.posterior,'Enable','off');
      set(controls.obsvar.predchecks.posterior,'Enable','off');
      set(controls.obsvar.posterior,'Enable','off');
      set(controls.obsvarcorrs.frequencydomain.posterior,'Enable','off');
      set(controls.obsvarcorrs.timedomain.posterior,'Enable','off');
      set(controls.obsvarcorrs.parameterchange.posterior,'Enable','off');
      set(controls.condcorrs.posterior,'Enable','off');
      set(controls.statevariables.posterior,'Enable','off');
      set(controls.statevarcorrs.frequencydomain.posterior,'Enable','off');
      set(controls.statevarcorrs.timedomain.posterior,'Enable','off');
      set(controls.statevarcorrs.parameterchange.posterior,'Enable','off');
      set(controls.stateshocks.posterior,'Enable','off');
      set(controls.stateshockcorrs.posterior,'Enable','off');
      set(controls.measurementerror.posterior,'Enable','off');
      set(controls.measurementerrorcorrs.posterior,'Enable','off');
      set(controls.cvd.posterior,'Enable','off');
      set(controls.cvd.state.posterior,'Enable','off');
      set(controls.fevd.posterior,'Enable','off');
      set(controls.fevd.lev_posterior,'Enable','off');
      set(controls.fevd.state.posterior,'Enable','off');
      set(controls.estimateparamcovmat,'Enable','off');
      set(controls.irfunctions.ann_posterior,'Enable','off');
      set(controls.ovd.annposterior,'Enable','off');
      set(controls.ovp.annposterior,'Enable','off');
      set(controls.cvd.ann_posterior,'Enable','off');
      set(controls.irfunctions.lev_posterior,'Enable','off');
      set(controls.cvd.lev_posterior,'Enable','off');
      set(controls.postsample.cusumplots.logposterior,'Enable','off');
      set(controls.postsample.cusumplots.original,'Enable','off');
      set(controls.postsample.cusumplots.transformed,'Enable','off');
      set(controls.postsample.spmt.logposterior,'Enable','off');
      set(controls.postsample.spmt.original,'Enable','off');
      set(controls.postsample.spmt.transformed,'Enable','off');
      set(controls.postsample.acceptancerate,'Enable','off');
      set(controls.postsample.smcadaption,'Enable','off');
      set(controls.postsample.manova,'Enable','off');
      set(controls.postsample.mean,'Enable','off');
      set(controls.postsample.median,'Enable','off');
      set(controls.viewposterior,'Enable','off');
      set(controls.viewbivariateposterior,'Enable','off');
      set(controls.posteriorcorrelations,'Enable','off');
      set(controls.statespaceposteriordist,'Enable','off');
   end;
   set(controls.learning.belief.parent,'Enable','on');
   set(controls.learning.setforwardvariables,'Enable','on');
   set(controls.learning.retoplm,'Enable','on');
   set(controls.learning.setbeliefpriorfile,'Enable','on');
   set(controls.learning.options.parent,'Enable','on');
   if DSGEModel.BeliefSystem==1;
      set(controls.learning.belief.default,'Checked','on');
      set(controls.learning.belief.userdefined,'Checked','off');
   else;
      set(controls.learning.belief.default,'Checked','off');
      set(controls.learning.belief.userdefined,'Checked','on');
   end;
   if DSGEModel.NoSmoothedStatesForBeliefs==1;
      set(controls.learning.options.nosmoothedstatesforbeliefs,'Checked','on');
   else;
      set(controls.learning.options.nosmoothedstatesforbeliefs,'Checked','off');
   end;
   if DSGEModel.FixedBeliefsForProj==1;
      set(controls.learning.options.fixedbeliefsforproj,'Checked','on');
   else;
      set(controls.learning.options.fixedbeliefsforproj,'Checked','off');
   end;
   if isempty(DSGEModel.ForwardVariablePositions)==0;
      set(controls.learning.postmodemenu,'Enable','on');
      if FileExist(DSGEModel.PriorFile)==1;
         set(controls.learning.priorsamplingmenu,'Enable','on');
         set(controls.learningtools.montecarlofiltering,'Enable','on');
      else;
         set(controls.learning.priorsamplingmenu,'Enable','off');
         set(controls.learningtools.montecarlofiltering,'Enable','off');
      end;
      if FileExist(DSGEModel.SystemPriorFile)==1;
         set(controls.learning.systempriormodemenu,'Enable','on');
      else;
         set(controls.learning.systempriormodemenu,'Enable','off');
      end;
      set(controls.learning.saveinversehessian,'Enable','on');
      set(controls.learning.viewmenu.parent,'Enable','on');
      set(controls.learning.toolsmenu.parent,'Enable','on');
      set(controls.learning.viewmenu.priorinformation,'Enable','on');
      set(controls.learning.viewmenu.parametervalues.initialvalues,'Enable','on');
      set(controls.learning.viewmenu.structuralform.initialvalues,'Enable','on');
      set(controls.learning.viewmenu.beliefcoefficients.initialvalues,'Enable','on');
      set(controls.learning.viewmenu.steadystatespaceform.initialvalues,'Enable','on');
      set(controls.learning.viewmenu.postsample.laplace.initialvalues,'Enable','on');
      set(controls.learning.viewmenu.viewprior.initialvalues,'Enable','on');
      set(controls.learningtools.dsgeeigenvalues.initialvalues,'Enable','on');
      set(controls.learningtools.informationmatrix.frequencydomain.initialvalues,'Enable','on');
      set(controls.learningtools.informationmatrix.timedomain.initialvalues,'Enable','on');
      set(controls.learningtools.steadystatecorrelations.obsvar.timedomain.initialvalues,'Enable','on');
      set(controls.learningtools.steadystatecorrelations.statevar.timedomain.initialvalues,'Enable','on');
      set(controls.learningtools.statevariables.initialvalues,'Enable','on');
      set(controls.learningtools.stateshocks.initialvalues,'Enable','on');
      set(controls.learningtools.measurementerrors.initialvalues,'Enable','on');
      set(controls.learningtools.beliefcoefficients.initialvalues,'Enable','on');
      set(controls.learningtools.lawsofmotion.initialvalues,'Enable','on');
      set(controls.learningtools.persistence.initialvalues,'Enable','on');
      set(controls.learningtools.loglikelihood.initialvalues,'Enable','on');
      if isfield(controls.learningtools,'scenarios')==1;
         if CheckScenarioData(DSGEModel)==1;
            set(controls.learningtools.scenarios.ovs.original.initialvalues,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.learningtools.scenarios.ovs.annual.initialvalues,'Enable','on');
            else;
               set(controls.learningtools.scenarios.ovs.annual.initialvalues,'Enable','off');
            end;
         else;
            set(controls.learningtools.scenarios.ovs.original.initialvalues,'Enable','off');
            set(controls.learningtools.scenarios.ovs.annual.initialvalues,'Enable','off');
         end;
         if CheckStateScenarioData(DSGEModel)==1;
            set(controls.learningtools.scenarios.svs.original.initialvalues,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.learningtools.scenarios.svs.annual.initialvalues,'Enable','on');
            else;
               set(controls.learningtools.scenarios.svs.annual.initialvalues,'Enable','off');
            end;
         else;
            set(controls.learningtools.scenarios.svs.original.initialvalues,'Enable','off');
            set(controls.learningtools.scenarios.svs.annual.initialvalues,'Enable','off');
         end;
      end;
      if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
         set(controls.learningtools.predictivedist.unconditional.original.initialvalues,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.initialvalues,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.transformed.initialvalues,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.initialvalues,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.initialvalues,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.transformed.initialvalues,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.zlb.initialvalues,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.zlb.initialvalues,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.transformed.zlb.initialvalues,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.zlb.initialvalues,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.zlb.initialvalues,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.transformed.zlb.initialvalues,'Enable','off');
         set(controls.learning.viewmenu.modesty.initialvalues,'Enable','off','UserData','');
      else;
         if exist('MaxFH')==0;
            MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
         end;
         if MaxFH>0;
            set(controls.learningtools.predictivedist.unconditional.original.initialvalues,'Enable','on');
            if max(DSGEModel.annual)>1;
               set(controls.learningtools.predictivedist.unconditional.annual.initialvalues,'Enable','on');
            else;
               set(controls.learningtools.predictivedist.unconditional.annual.initialvalues,'Enable','off');
            end;
            if isempty(DSGEModel.YTransformation)==0;
               set(controls.learningtools.predictivedist.unconditional.transformed.initialvalues,'Enable','on');
            else;
               set(controls.learningtools.predictivedist.unconditional.transformed.initialvalues,'Enable','off');
            end;
            if isempty(DSGEModel.ZLBPosition)==0;
               set(controls.learningtools.predictivedist.unconditional.original.zlb.initialvalues,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.learningtools.predictivedist.unconditional.annual.zlb.initialvalues,'Enable','on');
               else;
                  set(controls.learningtools.predictivedist.unconditional.annual.zlb.initialvalues,'Enable','off');
               end;
               if isempty(DSGEModel.YTransformation)==0;
                  set(controls.learningtools.predictivedist.unconditional.transformed.zlb.initialvalues,'Enable','on');
               else;
                  set(controls.learningtools.predictivedist.unconditional.transformed.zlb.initialvalues,'Enable','off');
               end;
            else;
               set(controls.learningtools.predictivedist.unconditional.original.zlb.initialvalues,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.annual.zlb.initialvalues,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.transformed.zlb.initialvalues,'Enable','off');
            end;
            if CheckConditioningData(DSGEModel)==1;
               set(controls.learningtools.predictivedist.conditional.original.initialvalues,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.learningtools.predictivedist.conditional.annual.initialvalues,'Enable','on');
               else;
                  set(controls.learningtools.predictivedist.conditional.annual.initialvalues,'Enable','off');
               end;
               if isempty(DSGEModel.YTransformation)==0;
                  set(controls.learningtools.predictivedist.conditional.transformed.initialvalues,'Enable','on');
               else;
                  set(controls.learningtools.predictivedist.conditional.transformed.initialvalues,'Enable','off');
               end;
               %
               if isempty(DSGEModel.ZLBPosition)==0;
                  set(controls.learningtools.predictivedist.conditional.original.zlb.initialvalues,'Enable','on');
                  if max(DSGEModel.annual)>1;
                     set(controls.learningtools.predictivedist.conditional.annual.zlb.initialvalues,'Enable','on');
                  else;
                     set(controls.learningtools.predictivedist.conditional.annual.zlb.initialvalues,'Enable','off');
                  end;
                  if isempty(DSGEModel.YTransformation)==0;
                     set(controls.learningtools.predictivedist.conditional.transformed.zlb.initialvalues,'Enable','on');
                  else;
                     set(controls.learningtools.predictivedist.conditional.transformed.zlb.initialvalues,'Enable','off');
                  end;
               else;
                  set(controls.learningtools.predictivedist.conditional.original.zlb.initialvalues,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.annual.zlb.initialvalues,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.transformed.zlb.initialvalues,'Enable','off');
               end;
               %
               % check if we have a file for the modesty statistic at the posterior mode
               %
               [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               NumPredPathsStr = get(controls.forecast.predpaths,'String');
               NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
               if DSGEModel.ShockControlMethod==1;
                  ShockMethod = 'Direct-';
               elseif DSGEModel.ShockControlMethod==2;
                  ShockMethod = 'WaggonerZha-';
               else;
                  ShockMethod = 'Subset-';
               end;
               ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-ModestyStatistics-AdaptiveLearning-' int2str(DSGEModel.FixedBeliefsForProj) '-' ShockMethod DSGEModel.NameOfModel '-' num2str(MaxPH,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-InitialValues.txt']);
               if FileExist(ModestyFile)==1;
                  set(controls.learning.viewmenu.modesty.initialvalues,'Enable','on','UserData',ModestyFile);
               else;
                  set(controls.learning.viewmenu.modesty.initialvalues,'Enable','off','UserData','');
               end;
            else;
               set(controls.learningtools.predictivedist.conditional.original.initialvalues,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.initialvalues,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.transformed.initialvalues,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.zlb.initialvalues,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.zlb.initialvalues,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.transformed.zlb.initialvalues,'Enable','off');
               set(controls.learning.viewmenu.modesty.initialvalues,'Enable','off','UserData','');
            end;
         else;
            set(controls.learningtools.predictivedist.unconditional.original.initialvalues,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.initialvalues,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.transformed.initialvalues,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.initialvalues,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.initialvalues,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.transformed.initialvalues,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.original.zlb.initialvalues,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.zlb.initialvalues,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.transformed.zlb.initialvalues,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.zlb.initialvalues,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.zlb.initialvalues,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.transformed.zlb.initialvalues,'Enable','off');
            set(controls.learning.viewmenu.modesty.initialvalues,'Enable','off','UserData','');
         end;
      end;
      set(controls.learningtools.decompositions.obsvar.decomp.original.initialvalues,'Enable','on');
      if max(DSGEModel.annual)>1;
         set(controls.learningtools.decompositions.obsvar.decomp.annual.initialvalues,'Enable','on');
         set(controls.learningtools.irfs.annual.initialvalues,'Enable','on');
      else;
         set(controls.learningtools.decompositions.obsvar.decomp.annual.initialvalues,'Enable','off');
         set(controls.learningtools.irfs.annual.initialvalues,'Enable','off');
      end;
      set(controls.learningtools.decompositions.statevar.initialvalues,'Enable','on');
      set(controls.learningtools.irfs.original.initialvalues,'Enable','on');
      if sum(DSGEModel.levels)<DSGEModel.n;
         set(controls.learningtools.irfs.levels.initialvalues,'Enable','on');
      else;
         set(controls.learningtools.irfs.levels.initialvalues,'Enable','off');
      end;
      if FileExist(ModeFile)==1;
         set(controls.learning.viewmenu.parametervalues.dsgemode,'Enable','on');
         set(controls.learning.viewmenu.structuralform.dsgemode,'Enable','on');
         set(controls.learning.viewmenu.beliefcoefficients.dsgemode,'Enable','on');
         set(controls.learning.viewmenu.steadystatespaceform.dsgemode,'Enable','on');
         set(controls.learning.viewmenu.postsample.laplace.dsgemode,'Enable','on');
         set(controls.learning.viewmenu.viewprior.dsgemode,'Enable','on');
         set(controls.learningtools.dsgeeigenvalues.dsgemode,'Enable','on');
         set(controls.learningtools.informationmatrix.frequencydomain.dsgemode,'Enable','on');
         set(controls.learningtools.informationmatrix.timedomain.dsgemode,'Enable','on');
         set(controls.learningtools.steadystatecorrelations.obsvar.timedomain.dsgemode,'Enable','on');
         set(controls.learningtools.steadystatecorrelations.statevar.timedomain.dsgemode,'Enable','on');
         set(controls.learningtools.statevariables.dsgemode,'Enable','on');
         set(controls.learningtools.stateshocks.dsgemode,'Enable','on');
         set(controls.learningtools.measurementerrors.dsgemode,'Enable','on');
         set(controls.learningtools.beliefcoefficients.dsgemode,'Enable','on');
         set(controls.learningtools.lawsofmotion.dsgemode,'Enable','on');
         set(controls.learningtools.persistence.dsgemode,'Enable','on');
         set(controls.learningtools.loglikelihood.dsgemode,'Enable','on');
         if isfield(controls.learningtools,'scenarios')==1;
            if CheckScenarioData(DSGEModel)==1;
               set(controls.learningtools.scenarios.ovs.original.dsgemode,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.learningtools.scenarios.ovs.annual.dsgemode,'Enable','on');
               else;
                  set(controls.learningtools.scenarios.ovs.annual.dsgemode,'Enable','off');
               end;
            else;
               set(controls.learningtools.scenarios.ovs.original.dsgemode,'Enable','off');
               set(controls.learningtools.scenarios.ovs.annual.dsgemode,'Enable','off');
            end;
            if CheckStateScenarioData(DSGEModel)==1;
               set(controls.learningtools.scenarios.svs.original.dsgemode,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.learningtools.scenarios.svs.annual.dsgemode,'Enable','on');
               else;
                  set(controls.learningtools.scenarios.svs.annual.dsgemode,'Enable','off');
               end;
            else;
               set(controls.learningtools.scenarios.svs.original.dsgemode,'Enable','off');
               set(controls.learningtools.scenarios.svs.annual.dsgemode,'Enable','off');
            end;
         end;
         if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
            set(controls.learningtools.predictivedist.unconditional.original.dsgemode,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.dsgemode,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.transformed.dsgemode,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.dsgemode,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.dsgemode,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.transformed.dsgemode,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.original.zlb.dsgemode,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.zlb.dsgemode,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.transformed.zlb.dsgemode,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.zlb.dsgemode,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.zlb.dsgemode,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.transformed.zlb.dsgemode,'Enable','off');
            set(controls.learning.viewmenu.modesty.dsgemode,'Enable','off','UserData','');
         else;
            if exist('MaxFH')==0;
               MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
            end;
            if MaxFH>0;
               set(controls.learningtools.predictivedist.unconditional.original.dsgemode,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.learningtools.predictivedist.unconditional.annual.dsgemode,'Enable','on');
               else;
                  set(controls.learningtools.predictivedist.unconditional.annual.dsgemode,'Enable','off');
               end;
               if isempty(DSGEModel.YTransformation)==0;
                  set(controls.learningtools.predictivedist.unconditional.transformed.dsgemode,'Enable','on');
               else;
                  set(controls.learningtools.predictivedist.unconditional.transformed.dsgemode,'Enable','off');
               end;
               if isempty(DSGEModel.ZLBPosition)==0;
                  set(controls.learningtools.predictivedist.unconditional.original.zlb.dsgemode,'Enable','on');
                  if max(DSGEModel.annual)>1;
                     set(controls.learningtools.predictivedist.unconditional.annual.zlb.dsgemode,'Enable','on');
                  else;
                     set(controls.learningtools.predictivedist.unconditional.annual.zlb.dsgemode,'Enable','off');
                  end;
                  if isempty(DSGEModel.YTransformation)==0;
                     set(controls.learningtools.predictivedist.unconditional.transformed.zlb.dsgemode,'Enable','on');
                  else;
                     set(controls.learningtools.predictivedist.unconditional.transformed.zlb.dsgemode,'Enable','off');
                  end;
               else;
                  set(controls.learningtools.predictivedist.unconditional.original.zlb.dsgemode,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.annual.zlb.dsgemode,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.transformed.zlb.dsgemode,'Enable','off');
               end;
               if CheckConditioningData(DSGEModel)==1;
                  set(controls.learningtools.predictivedist.conditional.original.dsgemode,'Enable','on');
                  if max(DSGEModel.annual)>1;
                     set(controls.learningtools.predictivedist.conditional.annual.dsgemode,'Enable','on');
                  else;
                     set(controls.learningtools.predictivedist.conditional.annual.dsgemode,'Enable','off');
                  end;
                  if isempty(DSGEModel.YTransformation)==0;
                     set(controls.learningtools.predictivedist.conditional.transformed.dsgemode,'Enable','on');
                  else;
                     set(controls.learningtools.predictivedist.conditional.transformed.dsgemode,'Enable','off');
                  end;
                  %
                  if isempty(DSGEModel.ZLBPosition)==0;
                     set(controls.learningtools.predictivedist.conditional.original.zlb.dsgemode,'Enable','on');
                     if max(DSGEModel.annual)>1;
                        set(controls.learningtools.predictivedist.conditional.annual.zlb.dsgemode,'Enable','on');
                     else;
                        set(controls.learningtools.predictivedist.conditional.annual.zlb.dsgemode,'Enable','off');
                     end;
                     if isempty(DSGEModel.YTransformation)==0;
                        set(controls.learningtools.predictivedist.conditional.transformed.zlb.dsgemode,'Enable','on');
                     else;
                        set(controls.learningtools.predictivedist.conditional.transformed.zlb.dsgemode,'Enable','off');
                     end;
                  else;
                     set(controls.learningtools.predictivedist.conditional.original.zlb.dsgemode,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.annual.zlb.dsgemode,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.transformed.zlb.dsgemode,'Enable','off');
                  end;
                  %
                  % check if we have a file for the modesty statistic at the posterior mode
                  %
                  [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
                  NumPredPathsStr = get(controls.forecast.predpaths,'String');
                  NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
                  if DSGEModel.ShockControlMethod==1;
                     ShockMethod = 'Direct-';
                  elseif DSGEModel.ShockControlMethod==2;
                     ShockMethod = 'WaggonerZha-';
                  else;
                     ShockMethod = 'Subset-';
                  end;
                  ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-ModestyStatistics-AdaptiveLearning-' int2str(DSGEModel.FixedBeliefsForProj) '-' ShockMethod DSGEModel.NameOfModel '-' num2str(MaxPH,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-DSGEPosteriorMode.txt']);
                  if FileExist(ModestyFile)==1;
                     set(controls.learning.viewmenu.modesty.dsgemode,'Enable','on','UserData',ModestyFile);
                  else;
                     set(controls.learning.viewmenu.modesty.dsgemode,'Enable','off','UserData','');
                  end;
               else;
                  set(controls.learningtools.predictivedist.conditional.original.dsgemode,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.annual.dsgemode,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.transformed.dsgemode,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.original.zlb.dsgemode,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.annual.zlb.dsgemode,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.transformed.zlb.dsgemode,'Enable','off');
                  set(controls.learning.viewmenu.modesty.dsgemode,'Enable','off','UserData','');
               end;
            else;
               set(controls.learningtools.predictivedist.unconditional.original.dsgemode,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.annual.dsgemode,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.transformed.dsgemode,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.dsgemode,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.dsgemode,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.transformed.dsgemode,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.original.zlb.dsgemode,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.annual.zlb.dsgemode,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.transformed.zlb.dsgemode,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.zlb.dsgemode,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.zlb.dsgemode,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.transformed.zlb.dsgemode,'Enable','off');
               set(controls.learning.viewmenu.modesty.dsgemode,'Enable','off','UserData','');
            end;
         end;
         set(controls.learningtools.decompositions.obsvar.decomp.original.dsgemode,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.learningtools.decompositions.obsvar.decomp.annual.dsgemode,'Enable','on');
            set(controls.learningtools.irfs.annual.dsgemode,'Enable','on');
         else;
            set(controls.learningtools.decompositions.obsvar.decomp.annual.dsgemode,'Enable','off');
            set(controls.learningtools.irfs.annual.dsgemode,'Enable','off');
         end;
         set(controls.learningtools.decompositions.statevar.dsgemode,'Enable','on');
         set(controls.learningtools.irfs.original.dsgemode,'Enable','on');
         if sum(DSGEModel.levels)<DSGEModel.n;
            set(controls.learningtools.irfs.levels.dsgemode,'Enable','on');
         else;
            set(controls.learningtools.irfs.levels.dsgemode,'Enable','off');
         end;
      else;
         set(controls.learning.viewmenu.parametervalues.dsgemode,'Enable','off');
         set(controls.learning.viewmenu.structuralform.dsgemode,'Enable','off');
         set(controls.learning.viewmenu.beliefcoefficients.dsgemode,'Enable','off');
         set(controls.learning.viewmenu.steadystatespaceform.dsgemode,'Enable','off');
         set(controls.learning.viewmenu.postsample.laplace.dsgemode,'Enable','off');
         set(controls.learning.viewmenu.viewprior.dsgemode,'Enable','off');
         set(controls.learningtools.dsgeeigenvalues.dsgemode,'Enable','off');
         set(controls.learningtools.informationmatrix.frequencydomain.dsgemode,'Enable','off');
         set(controls.learningtools.informationmatrix.timedomain.dsgemode,'Enable','off');
         set(controls.learningtools.steadystatecorrelations.obsvar.timedomain.dsgemode,'Enable','off');
         set(controls.learningtools.steadystatecorrelations.statevar.timedomain.dsgemode,'Enable','off');
         set(controls.learningtools.statevariables.dsgemode,'Enable','off');
         set(controls.learningtools.stateshocks.dsgemode,'Enable','off');
         set(controls.learningtools.measurementerrors.dsgemode,'Enable','off');
         set(controls.learningtools.beliefcoefficients.dsgemode,'Enable','off');
         set(controls.learningtools.lawsofmotion.dsgemode,'Enable','off');
         set(controls.learningtools.persistence.dsgemode,'Enable','off');
         set(controls.learningtools.loglikelihood.dsgemode,'Enable','off');
         if isfield(controls.learningtools,'scenarios')==1;
            set(controls.learningtools.scenarios.ovs.original.dsgemode,'Enable','off');
            set(controls.learningtools.scenarios.ovs.annual.dsgemode,'Enable','off');
            set(controls.learningtools.scenarios.svs.original.dsgemode,'Enable','off');
            set(controls.learningtools.scenarios.svs.annual.dsgemode,'Enable','off');
         end;
         set(controls.learningtools.predictivedist.unconditional.original.dsgemode,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.dsgemode,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.transformed.dsgemode,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.dsgemode,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.dsgemode,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.transformed.dsgemode,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.zlb.dsgemode,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.zlb.dsgemode,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.transformed.zlb.dsgemode,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.zlb.dsgemode,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.zlb.dsgemode,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.transformed.zlb.dsgemode,'Enable','off');
         set(controls.learning.viewmenu.modesty.dsgemode,'Enable','off','UserData','');
         set(controls.learningtools.decompositions.obsvar.decomp.original.dsgemode,'Enable','off');
         set(controls.learningtools.decompositions.obsvar.decomp.annual.dsgemode,'Enable','off');
         set(controls.learningtools.decompositions.statevar.dsgemode,'Enable','off');
         set(controls.learningtools.irfs.original.dsgemode,'Enable','off');
         set(controls.learningtools.irfs.annual.dsgemode,'Enable','off');
         set(controls.learningtools.irfs.levels.dsgemode,'Enable','off');
      end;
      ALModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-AdaptiveLearning-' DSGEModel.NameOfModel '.mat']);
      if FileExist(ALModeFile)==1;
         set(controls.learning.options.importpriordata,'Enable','on');
         set(controls.learning.posteriorsamplingmenu,'Enable','on');
         set(controls.learning.viewmenu.parametervalues.postmode,'Enable','on');
         set(controls.learning.viewmenu.structuralform.postmode,'Enable','on');
         set(controls.learning.viewmenu.beliefcoefficients.postmode,'Enable','on');
         set(controls.learning.viewmenu.steadystatespaceform.postmode,'Enable','on');
         set(controls.learning.viewmenu.postsample.laplace.postmode,'Enable','on');
         set(controls.learning.viewmenu.iteratedparameters,'Enable','on');
         set(controls.learning.viewmenu.checkposterior,'Enable','on');
         set(controls.learning.viewmenu.threedeepostmode.original,'Enable','on');
         set(controls.learning.viewmenu.threedeepostmode.transformed,'Enable','on');
         set(controls.learning.viewmenu.viewlaplaceposterior,'Enable','on');
         set(controls.learning.viewmenu.viewprior.postmode,'Enable','on');
         set(controls.learningtools.dsgeeigenvalues.postmode,'Enable','on');
         set(controls.learningtools.informationmatrix.frequencydomain.postmode,'Enable','on');
         set(controls.learningtools.informationmatrix.timedomain.postmode,'Enable','on');
         set(controls.learningtools.steadystatecorrelations.obsvar.timedomain.postmode,'Enable','on');
         set(controls.learningtools.steadystatecorrelations.statevar.timedomain.postmode,'Enable','on');
         set(controls.learningtools.statevariables.postmode,'Enable','on');
         set(controls.learningtools.stateshocks.postmode,'Enable','on');
         set(controls.learningtools.measurementerrors.postmode,'Enable','on');
         set(controls.learningtools.beliefcoefficients.postmode,'Enable','on');
         set(controls.learningtools.lawsofmotion.postmode,'Enable','on');
         set(controls.learningtools.persistence.postmode,'Enable','on');
         set(controls.learningtools.loglikelihood.postmode,'Enable','on');
         if isfield(controls.learningtools,'scenarios')==1;
            if CheckScenarioData(DSGEModel)==1;
               set(controls.learningtools.scenarios.ovs.original.postmode,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.learningtools.scenarios.ovs.annual.postmode,'Enable','on');
               else;
                  set(controls.learningtools.scenarios.ovs.annual.postmode,'Enable','off');
               end;
            else;
               set(controls.learningtools.scenarios.ovs.original.postmode,'Enable','off');
               set(controls.learningtools.scenarios.ovs.annual.postmode,'Enable','off');
            end;
            if CheckStateScenarioData(DSGEModel)==1;
               set(controls.learningtools.scenarios.svs.original.postmode,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.learningtools.scenarios.svs.annual.postmode,'Enable','on');
               else;
                  set(controls.learningtools.scenarios.svs.annual.postmode,'Enable','off');
               end;
            else;
               set(controls.learningtools.scenarios.svs.original.postmode,'Enable','off');
               set(controls.learningtools.scenarios.svs.annual.postmode,'Enable','off');
            end;
         end;
         if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
            set(controls.learningtools.predictivedist.unconditional.original.postmode,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.postmode,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.transformed.postmode,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.postmode,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.postmode,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.transformed.postmode,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.original.zlb.postmode,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.zlb.postmode,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.transformed.zlb.postmode,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.zlb.postmode,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.zlb.postmode,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.transformed.zlb.postmode,'Enable','off');
            set(controls.learning.viewmenu.modesty.postmode,'Enable','off','UserData','');
         else;
            if exist('MaxFH')==0;
               MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
            end;
            if MaxFH>0;
               set(controls.learningtools.predictivedist.unconditional.original.postmode,'Enable','on');
               if max(DSGEModel.annual)>1;
                  set(controls.learningtools.predictivedist.unconditional.annual.postmode,'Enable','on');
               else;
                  set(controls.learningtools.predictivedist.unconditional.annual.postmode,'Enable','off');
               end;
               if isempty(DSGEModel.YTransformation)==0;
                  set(controls.learningtools.predictivedist.unconditional.transformed.postmode,'Enable','on');
               else;
                  set(controls.learningtools.predictivedist.unconditional.transformed.postmode,'Enable','off');
               end;
               if isempty(DSGEModel.ZLBPosition)==0;
                  set(controls.learningtools.predictivedist.unconditional.original.zlb.postmode,'Enable','on');
                  if max(DSGEModel.annual)>1;
                     set(controls.learningtools.predictivedist.unconditional.annual.zlb.postmode,'Enable','on');
                  else;
                     set(controls.learningtools.predictivedist.unconditional.annual.zlb.postmode,'Enable','off');
                  end;
                  if isempty(DSGEModel.YTransformation)==0;
                     set(controls.learningtools.predictivedist.unconditional.transformed.zlb.postmode,'Enable','on');
                  else;
                     set(controls.learningtools.predictivedist.unconditional.transformed.zlb.postmode,'Enable','off');
                  end;
               else;
                  set(controls.learningtools.predictivedist.unconditional.original.zlb.postmode,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.annual.zlb.postmode,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.transformed.zlb.postmode,'Enable','off');
               end;
               if CheckConditioningData(DSGEModel)==1;
                  set(controls.learningtools.predictivedist.conditional.original.postmode,'Enable','on');
                  if max(DSGEModel.annual)>1;
                     set(controls.learningtools.predictivedist.conditional.annual.postmode,'Enable','on');
                  else;
                     set(controls.learningtools.predictivedist.conditional.annual.postmode,'Enable','off');
                  end;
                  if isempty(DSGEModel.YTransformation)==0;
                     set(controls.learningtools.predictivedist.conditional.transformed.postmode,'Enable','on');
                  else;
                     set(controls.learningtools.predictivedist.conditional.transformed.postmode,'Enable','off');
                  end;
                  %
                  if isempty(DSGEModel.ZLBPosition)==0;
                     set(controls.learningtools.predictivedist.conditional.original.zlb.postmode,'Enable','on');
                     if max(DSGEModel.annual)>1;
                        set(controls.learningtools.predictivedist.conditional.annual.zlb.postmode,'Enable','on');
                     else;
                        set(controls.learningtools.predictivedist.conditional.annual.zlb.postmode,'Enable','off');
                     end;
                     if isempty(DSGEModel.YTransformation)==0;
                        set(controls.learningtools.predictivedist.conditional.transformed.zlb.postmode,'Enable','on');
                     else;
                        set(controls.learningtools.predictivedist.conditional.transformed.zlb.postmode,'Enable','off');
                     end;
                  else;
                     set(controls.learningtools.predictivedist.conditional.original.zlb.postmode,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.annual.zlb.postmode,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.transformed.zlb.postmode,'Enable','off');
                  end;
                  %
                  % check if we have a file for the modesty statistic at the posterior mode
                  %
                  [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
                  NumPredPathsStr = get(controls.forecast.predpaths,'String');
                  NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
                  if DSGEModel.ShockControlMethod==1;
                     ShockMethod = 'Direct-';
                  elseif DSGEModel.ShockControlMethod==2;
                     ShockMethod = 'WaggonerZha-';
                  else;
                     ShockMethod = 'Subset-';
                  end;
                  ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-ModestyStatistics-AdaptiveLearning-' int2str(DSGEModel.FixedBeliefsForProj) '-' ShockMethod DSGEModel.NameOfModel '-' num2str(MaxPH,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-PosteriorMode.txt']);
                  if FileExist(ModestyFile)==1;
                     set(controls.learning.viewmenu.modesty.postmode,'Enable','on','UserData',ModestyFile);
                  else;
                     set(controls.learning.viewmenu.modesty.postmode,'Enable','off','UserData','');
                  end;
               else;
                  set(controls.learningtools.predictivedist.conditional.original.postmode,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.annual.postmode,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.transformed.postmode,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.original.zlb.postmode,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.annual.zlb.postmode,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.transformed.zlb.postmode,'Enable','off');
                  set(controls.learning.viewmenu.modesty.postmode,'Enable','off','UserData','');
               end;
            else;
               set(controls.learningtools.predictivedist.unconditional.original.postmode,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.annual.postmode,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.transformed.postmode,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.postmode,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.postmode,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.transformed.postmode,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.original.zlb.postmode,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.annual.zlb.postmode,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.transformed.zlb.postmode,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.zlb.postmode,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.zlb.postmode,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.transformed.zlb.postmode,'Enable','off');
               set(controls.learning.viewmenu.modesty.postmode,'Enable','off','UserData','');
            end;
         end;
         set(controls.learningtools.decompositions.obsvar.decomp.original.postmode,'Enable','on');
         if max(DSGEModel.annual)>1;
            set(controls.learningtools.decompositions.obsvar.decomp.annual.postmode,'Enable','on');
            set(controls.learningtools.irfs.annual.postmode,'Enable','on');
         else;
            set(controls.learningtools.decompositions.obsvar.decomp.annual.postmode,'Enable','off');
            set(controls.learningtools.irfs.annual.postmode,'Enable','off');
         end;
         set(controls.learningtools.decompositions.statevar.postmode,'Enable','on');
         set(controls.learningtools.irfs.original.postmode,'Enable','on');
         if sum(DSGEModel.levels)<DSGEModel.n;
            set(controls.learningtools.irfs.levels.postmode,'Enable','on');
         else;
            set(controls.learningtools.irfs.levels.postmode,'Enable','off');
         end;
         if VerifyAdaptiveLearningDSGEPosteriorDraws(DSGEModel,1,controls)==1;
            set(controls.learning.viewmenu.postsample.rawplots.original,'Enable','on');
            set(controls.learning.viewmenu.postsample.rawplots.transformed,'Enable','on');
            set(controls.learning.viewmenu.postsample.rawplots.logpost,'Enable','on');
            if (DSGEModel.PosteriorSampler<=7)|(DSGEModel.PosteriorSampler==9);
               set(controls.learning.viewmenu.postsample.rawplots.weights,'Enable','off','Label','&Particle Weights...');
            elseif (DSGEModel.PosteriorSampler==8)|(DSGEModel.PosteriorSampler==10);
               set(controls.learning.viewmenu.postsample.rawplots.weights,'Enable','on');
               if DSGEModel.PosteriorSampler==8;
                  set(controls.learning.viewmenu.postsample.rawplots.weights,'Label','&Particle Weights...');
               else;
                  set(controls.learning.viewmenu.postsample.rawplots.weights,'Label','Im&portance Weights...');
               end;
            end;
            set(controls.learning.viewmenu.postsample.scatterplots.original,'Enable','on');
            set(controls.learning.viewmenu.postsample.scatterplots.transformed,'Enable','on');
            if DSGEModel.PosteriorSampler<=7;
               set(controls.learning.viewmenu.postsample.mhm,'Enable','on');
               set(controls.learning.viewmenu.postsample.swz,'Enable','on');
               if (DSGEModel.PosteriorSampler==1)|(DSGEModel.PosteriorSampler>=3);
                  set(controls.learning.viewmenu.postsample.chibjeliazkov,'Enable','on');
               elseif DSGEModel.PosteriorSampler==2;
                  set(controls.learning.viewmenu.postsample.chibjeliazkov,'Enable','off');
               end;
            else;
               set(controls.learning.viewmenu.postsample.mhm,'Enable','off');
               set(controls.learning.viewmenu.postsample.swz,'Enable','off');
               set(controls.learning.viewmenu.postsample.chibjeliazkov,'Enable','off');
            end;
            set(controls.learning.viewmenu.viewposterior.marginal,'Enable','on');
            set(controls.learning.viewmenu.viewposterior.bivariate,'Enable','on');
            set(controls.learning.viewmenu.viewposterior.correlations,'Enable','on');
            if (isempty(DSGEModel.PredictedX)==1)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
               set(controls.learningtools.predictivedist.unconditional.original.height.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.annual.height.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.original.crps.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.original.moments.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.original.pit.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.original.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.annual.crps.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.annual.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.transformed.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.original.zlb.height.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.original.zlb.crps.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.original.zlb.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.annual.zlb.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.unconditional.transformed.zlb.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.height.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.height.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.crps.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.crps.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.moments.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.pit.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.transformed.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.zlb.height.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.zlb.height.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.zlb.crps.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.original.zlb.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.annual.zlb.posterior,'Enable','off');
               set(controls.learningtools.predictivedist.conditional.transformed.zlb.posterior,'Enable','off');
               for i=1:10;
                  set(getfield(controls.learning.viewmenu.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
               end;
            else;
               if exist('MaxFH')==0;
                  MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
               end;
               if MaxFH>0;
                  set(controls.learningtools.predictivedist.unconditional.original.height.posterior,'Enable','on');
                  set(controls.learningtools.predictivedist.unconditional.original.crps.posterior,'Enable','on');
                  set(controls.learningtools.predictivedist.unconditional.original.moments.posterior,'Enable','on');
                  set(controls.learningtools.predictivedist.unconditional.original.pit.posterior,'Enable','on');
                  set(controls.learningtools.predictivedist.unconditional.original.zlb.height.posterior,'Enable','on');
                  set(controls.learningtools.predictivedist.unconditional.original.zlb.crps.posterior,'Enable','on');
                  set(controls.learningtools.predictivedist.unconditional.original.zlb.posterior,'Enable','on');
                  set(controls.learningtools.predictivedist.unconditional.original.posterior,'Enable','on');
                  if max(DSGEModel.annual)>1;
                     set(controls.learningtools.predictivedist.unconditional.annual.height.posterior,'Enable','on');
                     set(controls.learningtools.predictivedist.unconditional.annual.crps.posterior,'Enable','on');
                     set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.posterior,'Enable','on');
                     set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.posterior,'Enable','on');
                     set(controls.learningtools.predictivedist.unconditional.annual.zlb.posterior,'Enable','on');
                     set(controls.learningtools.predictivedist.unconditional.annual.posterior,'Enable','on');
                  else;
                     set(controls.learningtools.predictivedist.unconditional.annual.height.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.unconditional.annual.crps.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.unconditional.annual.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.unconditional.annual.zlb.posterior,'Enable','off');
                  end;
                  if isempty(DSGEModel.YTransformation)==0;
                     set(controls.learningtools.predictivedist.unconditional.transformed.zlb.posterior,'Enable','on');
                     set(controls.learningtools.predictivedist.unconditional.transformed.posterior,'Enable','on');
                  else;
                     set(controls.learningtools.predictivedist.unconditional.transformed.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.unconditional.transformed.zlb.posterior,'Enable','off');
                  end;
                  if CheckConditioningData(DSGEModel)==1;
                     set(controls.learningtools.predictivedist.conditional.original.height.posterior,'Enable','on');
                     set(controls.learningtools.predictivedist.conditional.original.crps.posterior,'Enable','on');
                     set(controls.learningtools.predictivedist.conditional.original.moments.posterior,'Enable','on');
                     set(controls.learningtools.predictivedist.conditional.original.pit.posterior,'Enable','on');
                     set(controls.learningtools.predictivedist.conditional.original.posterior,'Enable','on');
                     if max(DSGEModel.annual)>1;
                        set(controls.learningtools.predictivedist.conditional.annual.height.posterior,'Enable','on');
                        set(controls.learningtools.predictivedist.conditional.annual.crps.posterior,'Enable','on');
                        set(controls.learningtools.predictivedist.conditional.annual.posterior,'Enable','on');
                     else;
                        set(controls.learningtools.predictivedist.conditional.annual.height.posterior,'Enable','off');
                        set(controls.learningtools.predictivedist.conditional.annual.crps.posterior,'Enable','off');
                        set(controls.learningtools.predictivedist.conditional.annual.posterior,'Enable','off');
                     end;
                     if isempty(DSGEModel.YTransformation)==0;
                        set(controls.learningtools.predictivedist.conditional.transformed.posterior,'Enable','on');
                     else;
                        set(controls.learningtools.predictivedist.conditional.transformed.posterior,'Enable','off');
                     end;
                     if isempty(DSGEModel.ZLBPosition)==0;
                        set(controls.learningtools.predictivedist.conditional.original.zlb.height.posterior,'Enable','on');
                        set(controls.learningtools.predictivedist.conditional.original.zlb.crps.posterior,'Enable','on');
                        set(controls.learningtools.predictivedist.conditional.original.zlb.posterior,'Enable','on');
                        if max(DSGEModel.annual)>1;
                           set(controls.learningtools.predictivedist.conditional.annual.zlb.height.posterior,'Enable','on');
                           set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.posterior,'Enable','on');
                           set(controls.learningtools.predictivedist.conditional.annual.zlb.posterior,'Enable','on');
                        else;
                           set(controls.learningtools.predictivedist.conditional.annual.zlb.height.posterior,'Enable','off');
                           set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.posterior,'Enable','off');
                           set(controls.learningtools.predictivedist.conditional.annual.zlb.posterior,'Enable','off');
                        end;
                        if isempty(DSGEModel.YTransformation)==0;
                           set(controls.learningtools.predictivedist.conditional.transformed.zlb.posterior,'Enable','on');
                        else;
                           set(controls.learningtools.predictivedist.conditional.transformed.zlb.posterior,'Enable','off');
                        end;
                     else;
                        set(controls.learningtools.predictivedist.conditional.original.zlb.height.posterior,'Enable','off');
                        set(controls.learningtools.predictivedist.conditional.annual.zlb.height.posterior,'Enable','off');
                        set(controls.learningtools.predictivedist.conditional.original.zlb.crps.posterior,'Enable','off');
                        set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.posterior,'Enable','off');
                        set(controls.learningtools.predictivedist.conditional.original.zlb.posterior,'Enable','off');
                        set(controls.learningtools.predictivedist.conditional.annual.zlb.posterior,'Enable','off');
                        set(controls.learningtools.predictivedist.conditional.transformed.zlb.posterior,'Enable','off');
                     end;
                     %
                     % check if modesty results exists
                     %
                     [stat,files] = ModestyExist(DSGEModel,controls,'DSGE',1);
                     for i=1:10;
                        if stat(i)==1;
                           set(getfield(controls.learning.viewmenu.modesty,['chain' int2str(i)]),'Enable','on','UserData',StringTrim(files(i,:)));
                        else;
                           set(getfield(controls.learning.viewmenu.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
                        end;
                     end;
                  else;
                     set(controls.learningtools.predictivedist.conditional.original.height.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.annual.height.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.original.crps.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.annual.crps.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.original.moments.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.original.pit.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.original.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.annual.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.transformed.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.original.zlb.height.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.annual.zlb.height.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.original.zlb.crps.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.original.zlb.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.annual.zlb.posterior,'Enable','off');
                     set(controls.learningtools.predictivedist.conditional.transformed.zlb.posterior,'Enable','off');
                     for i=1:10;
                        set(getfield(controls.learning.viewmenu.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
                     end;
                  end;
               else;
                  set(controls.learningtools.predictivedist.unconditional.original.height.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.annual.height.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.original.crps.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.original.moments.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.original.pit.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.original.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.annual.crps.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.annual.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.transformed.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.original.zlb.height.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.original.zlb.crps.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.original.zlb.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.annual.zlb.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.unconditional.transformed.zlb.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.original.height.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.annual.height.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.original.crps.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.annual.crps.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.original.moments.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.original.pit.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.original.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.annual.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.transformed.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.original.zlb.height.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.annual.zlb.height.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.original.zlb.crps.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.original.zlb.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.annual.zlb.posterior,'Enable','off');
                  set(controls.learningtools.predictivedist.conditional.transformed.zlb.posterior,'Enable','off');
                  for i=1:10;
                     set(getfield(controls.learning.viewmenu.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
                  end;
               end;
            end;
         else;
            set(controls.learning.viewmenu.postsample.rawplots.original,'Enable','off');
            set(controls.learning.viewmenu.postsample.rawplots.transformed,'Enable','off');
            set(controls.learning.viewmenu.postsample.rawplots.logpost,'Enable','off');
            if DSGEModel.PosteriorSampler==10;
               set(controls.learning.viewmenu.postsample.rawplots.weights,'Enable','off','Label','Im&portance Weights...');
            else;
               set(controls.learning.viewmenu.postsample.rawplots.weights,'Enable','off','Label','&Particle Weights...');
            end;
            set(controls.learning.viewmenu.postsample.scatterplots.original,'Enable','off');
            set(controls.learning.viewmenu.postsample.scatterplots.transformed,'Enable','off');
            set(controls.learning.viewmenu.postsample.mhm,'Enable','off');
            set(controls.learning.viewmenu.postsample.swz,'Enable','off');
            set(controls.learning.viewmenu.postsample.chibjeliazkov,'Enable','off');
            set(controls.learning.viewmenu.viewposterior.marginal,'Enable','off');
            set(controls.learning.viewmenu.viewposterior.bivariate,'Enable','off');
            set(controls.learning.viewmenu.viewposterior.correlations,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.original.height.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.height.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.original.crps.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.original.moments.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.original.pit.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.original.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.crps.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.transformed.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.original.zlb.height.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.original.zlb.crps.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.original.zlb.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.annual.zlb.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.unconditional.transformed.zlb.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.height.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.height.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.crps.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.crps.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.moments.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.pit.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.transformed.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.zlb.height.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.zlb.height.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.zlb.crps.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.original.zlb.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.annual.zlb.posterior,'Enable','off');
            set(controls.learningtools.predictivedist.conditional.transformed.zlb.posterior,'Enable','off');
            for i=1:10;
               set(getfield(controls.learning.viewmenu.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
            end;
         end;
      else;
         set(controls.learning.options.importpriordata,'Enable','off');
         set(controls.learning.posteriorsamplingmenu,'Enable','off');
         set(controls.learning.viewmenu.parametervalues.postmode,'Enable','off');
         set(controls.learning.viewmenu.structuralform.postmode,'Enable','off');
         set(controls.learning.viewmenu.beliefcoefficients.postmode,'Enable','off');
         set(controls.learning.viewmenu.steadystatespaceform.postmode,'Enable','off');
         set(controls.learning.viewmenu.postsample.laplace.postmode,'Enable','off');
         set(controls.learning.viewmenu.iteratedparameters,'Enable','off');
         set(controls.learning.viewmenu.checkposterior,'Enable','off');
         set(controls.learning.viewmenu.threedeepostmode.original,'Enable','off');
         set(controls.learning.viewmenu.threedeepostmode.transformed,'Enable','off');
         set(controls.learning.viewmenu.viewlaplaceposterior,'Enable','off');
         set(controls.learning.viewmenu.viewprior.postmode,'Enable','off');
         set(controls.learning.viewmenu.postsample.rawplots.original,'Enable','off');
         set(controls.learning.viewmenu.postsample.rawplots.transformed,'Enable','off');
         set(controls.learning.viewmenu.postsample.rawplots.logpost,'Enable','off');
         if DSGEModel.PosteriorSampler==10;
            set(controls.learning.viewmenu.postsample.rawplots.weights,'Enable','off','Label','Im&portance Weights...');
         else;
            set(controls.learning.viewmenu.postsample.rawplots.weights,'Enable','off','Label','&Particle Weights...');
         end;
         set(controls.learning.viewmenu.postsample.scatterplots.original,'Enable','off');
         set(controls.learning.viewmenu.postsample.scatterplots.transformed,'Enable','off');
         set(controls.learning.viewmenu.postsample.mhm,'Enable','off');
         set(controls.learning.viewmenu.postsample.swz,'Enable','off');
         set(controls.learning.viewmenu.postsample.chibjeliazkov,'Enable','off');
         set(controls.learning.viewmenu.viewposterior.marginal,'Enable','off');
         set(controls.learning.viewmenu.viewposterior.bivariate,'Enable','off');
         set(controls.learning.viewmenu.viewposterior.correlations,'Enable','off');
         set(controls.learningtools.dsgeeigenvalues.postmode,'Enable','off');
         set(controls.learningtools.informationmatrix.frequencydomain.postmode,'Enable','off');
         set(controls.learningtools.informationmatrix.timedomain.postmode,'Enable','off');
         set(controls.learningtools.steadystatecorrelations.obsvar.timedomain.postmode,'Enable','off');
         set(controls.learningtools.steadystatecorrelations.statevar.timedomain.postmode,'Enable','off');
         set(controls.learningtools.statevariables.postmode,'Enable','off');
         set(controls.learningtools.stateshocks.postmode,'Enable','off');
         set(controls.learningtools.measurementerrors.postmode,'Enable','off');
         set(controls.learningtools.beliefcoefficients.postmode,'Enable','off');
         set(controls.learningtools.lawsofmotion.postmode,'Enable','off');
         set(controls.learningtools.persistence.postmode,'Enable','off');
         set(controls.learningtools.loglikelihood.postmode,'Enable','off');
         if isfield(controls.learningtools,'scenarios')==1;
            set(controls.learningtools.scenarios.ovs.original.postmode,'Enable','off');
            set(controls.learningtools.scenarios.ovs.annual.postmode,'Enable','off');
            set(controls.learningtools.scenarios.svs.original.postmode,'Enable','off');
            set(controls.learningtools.scenarios.svs.annual.postmode,'Enable','off');
         end;
         set(controls.learningtools.predictivedist.unconditional.original.height.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.height.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.crps.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.moments.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.pit.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.postmode,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.postmode,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.transformed.postmode,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.crps.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.transformed.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.zlb.height.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.zlb.crps.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.zlb.postmode,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.original.zlb.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.zlb.postmode,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.annual.zlb.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.transformed.zlb.postmode,'Enable','off');
         set(controls.learningtools.predictivedist.unconditional.transformed.zlb.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.postmode,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.postmode,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.transformed.postmode,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.zlb.postmode,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.zlb.postmode,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.transformed.zlb.postmode,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.height.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.height.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.crps.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.crps.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.moments.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.pit.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.transformed.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.zlb.height.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.zlb.height.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.zlb.crps.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.original.zlb.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.annual.zlb.posterior,'Enable','off');
         set(controls.learningtools.predictivedist.conditional.transformed.zlb.posterior,'Enable','off');
         set(controls.learning.viewmenu.modesty.postmode,'Enable','off','UserData','');
         for i=1:10;
            set(getfield(controls.learning.viewmenu.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
         end;
         set(controls.learningtools.decompositions.obsvar.decomp.original.postmode,'Enable','off');
         set(controls.learningtools.decompositions.obsvar.decomp.annual.postmode,'Enable','off');
         set(controls.learningtools.decompositions.statevar.postmode,'Enable','off');
         set(controls.learningtools.irfs.original.postmode,'Enable','off');
         set(controls.learningtools.irfs.annual.postmode,'Enable','off');
         set(controls.learningtools.irfs.levels.postmode,'Enable','off');
      end;
      ALModeTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeResults-AdaptiveLearning-' DSGEModel.NameOfModel '.txt']);
      if FileExist(ALModeTextFile)==1;
         set(controls.learning.viewmenu.postmode.results,'Enable','on','UserData',ALModeTextFile);
      else;
         set(controls.learning.viewmenu.postmode.results,'Enable','off','UserData','');
      end;
      ALModeSummaryTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeSummary-AdaptiveLearning-' DSGEModel.NameOfModel '.txt']);
      if FileExist(ALModeSummaryTextFile)==1;
         set(controls.learning.viewmenu.postmode.summary,'Enable','on','UserData',ALModeSummaryTextFile);
      else;
         set(controls.learning.viewmenu.postmode.summary,'Enable','off','UserData','');
      end;
      %
      % check if the post sample summary file exist
      %
      DrawsStr = get(controls.posterior.draws,'String');
      NumPostDraws = str2num(StringTrim(strrep(DrawsStr(DSGEModel.PosteriorDrawsValue,:),',','')));
      %
      ChainsStr = get(controls.posterior.chains,'String');
      NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
      %
      % number of tempering stages
      %
      TempStagesStr = get(controls.posterior.temperingstages,'String');
      TempStages = str2num(StringTrim(TempStagesStr(DSGEModel.TemperingStagesValue,:)));
      %
      for CurrChain=1:10;
         if DSGEModel.PosteriorSampler==1;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorSamplingSummary-AdaptiveLearning-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==2;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\SlicePosteriorSamplingSummary-AdaptiveLearning-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==3;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorSamplingSummary-t-AdaptiveLearning-' int2str(DSGEModel.StudenttDegFree) '-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==4;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorSamplingSummary-Fixed-AdaptiveLearning-' int2str(DSGEModel.FixedNumParamBlocks) '-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==5;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorSamplingSummary-Fixed-AdaptiveLearning-' int2str(DSGEModel.FixedNumParamBlocks) '-t-' int2str(DSGEModel.StudenttDegFree) '-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==6;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorSamplingSummary-Random-AdaptiveLearning-' int2str(DSGEModel.BlockSize(1)) '-' int2str(DSGEModel.BlockSize(2)) '-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==7;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorSamplingSummary-Random-AdaptiveLearning-' int2str(DSGEModel.BlockSize(1)) '-' int2str(DSGEModel.BlockSize(2)) '-t-' int2str(DSGEModel.StudenttDegFree) '-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==8;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\SMCPosteriorSamplingSummary-AdaptiveLearning-' DSGEModel.NameOfModel '-' int2str(TempStages) '.' int2str(DSGEModel.NumParamBlocks) '.' int2str(DSGEModel.ResamplingAlgorithm) '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==9;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\SMCPosteriorSamplingSummary-AdaptiveLearning-' DSGEModel.NameOfModel '-' int2str(DSGEModel.NumParamBlocks) '.' int2str(DSGEModel.ResamplingAlgorithm) '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         elseif DSGEModel.PosteriorSampler==10;
            PostSampleTextFile = FixFilePath([DSGEModel.OutputDirectory '\ISPosteriorSamplingSummary-AdaptiveLearning-' DSGEModel.NameOfModel '-' num2str(DSGEModel.InverseHessianEstimator,'%0.0f') '-' int2str(DSGEModel.ISMaxMixCompValue) '.' int2str(DSGEModel.ISInitialDF) '.' int2str(DSGEModel.ISWeightShareValue) '.' int2str(DSGEModel.ISAddedMixWeightValue) '.' int2str(DSGEModel.ISAddedDF) '-' num2str(CurrChain,'%0.0f') '.' num2str(NumChains,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         end;
         if FileExist(PostSampleTextFile)==1;
            set(getfield(controls.learning.viewmenu.postsamplesummary,['chain' int2str(CurrChain)]),'Enable','on','UserData',PostSampleTextFile);
         else;
            set(getfield(controls.learning.viewmenu.postsamplesummary,['chain' int2str(CurrChain)]),'Enable','off','UserData','');
         end;
      end;
   else;
      set(controls.learning.options.importpriordata,'Enable','off');
      set(controls.learning.saveinversehessian,'Enable','off');
      set(controls.learning.postmodemenu,'Enable','off');
      set(controls.learning.posteriorsamplingmenu,'Enable','off');
      set(controls.learning.priorsamplingmenu,'Enable','off');
      set(controls.learning.systempriormodemenu,'Enable','off');
      set(controls.learning.viewmenu.parent,'Enable','off');
      set(controls.learning.viewmenu.priorinformation,'Enable','off');
      set(controls.learning.viewmenu.parametervalues.initialvalues,'Enable','off');
      set(controls.learning.viewmenu.structuralform.initialvalues,'Enable','off');
      set(controls.learning.viewmenu.beliefcoefficients.initialvalues,'Enable','off');
      set(controls.learning.viewmenu.steadystatespaceform.initialvalues,'Enable','off');
      set(controls.learning.viewmenu.parametervalues.dsgemode,'Enable','off');
      set(controls.learning.viewmenu.structuralform.dsgemode,'Enable','off');
      set(controls.learning.viewmenu.beliefcoefficients.dsgemode,'Enable','off');
      set(controls.learning.viewmenu.steadystatespaceform.dsgemode,'Enable','off');
      set(controls.learning.viewmenu.parametervalues.postmode,'Enable','off');
      set(controls.learning.viewmenu.structuralform.postmode,'Enable','off');
      set(controls.learning.viewmenu.beliefcoefficients.postmode,'Enable','off');
      set(controls.learning.viewmenu.steadystatespaceform.postmode,'Enable','off');
      set(controls.learning.viewmenu.postmode.results,'Enable','off','UserData','');
      set(controls.learning.viewmenu.postmode.summary,'Enable','off','UserData','');
      for CurrChain=1:10;
         set(getfield(controls.learning.viewmenu.postsamplesummary,['chain' int2str(CurrChain)]),'Enable','off','UserData','');
      end;
      set(controls.learning.viewmenu.postsample.laplace.initialvalues,'Enable','off');
      set(controls.learning.viewmenu.postsample.laplace.dsgemode,'Enable','off');
      set(controls.learning.viewmenu.postsample.laplace.postmode,'Enable','off');
      set(controls.learning.viewmenu.iteratedparameters,'Enable','off');
      set(controls.learning.viewmenu.checkposterior,'Enable','off');
      set(controls.learning.viewmenu.threedeepostmode.original,'Enable','off');
      set(controls.learning.viewmenu.threedeepostmode.transformed,'Enable','off');
      set(controls.learning.viewmenu.viewlaplaceposterior,'Enable','off');
      set(controls.learning.viewmenu.viewprior.initialvalues,'Enable','off');
      set(controls.learning.viewmenu.viewprior.dsgemode,'Enable','off');
      set(controls.learning.viewmenu.viewprior.postmode,'Enable','off');
      set(controls.learning.viewmenu.postsample.rawplots.original,'Enable','off');
      set(controls.learning.viewmenu.postsample.rawplots.transformed,'Enable','off');
      set(controls.learning.viewmenu.postsample.rawplots.logpost,'Enable','off');
      if DSGEModel.PosteriorSampler==10;
         set(controls.learning.viewmenu.postsample.rawplots.weights,'Enable','off','Label','Im&portance Weights...');
      else;
         set(controls.learning.viewmenu.postsample.rawplots.weights,'Enable','off','Label','&Particle Weights...');
      end;
      set(controls.learning.viewmenu.postsample.scatterplots.original,'Enable','off');
      set(controls.learning.viewmenu.postsample.scatterplots.transformed,'Enable','off');
      set(controls.learning.viewmenu.postsample.mhm,'Enable','off');
      set(controls.learning.viewmenu.postsample.swz,'Enable','off');
      set(controls.learning.viewmenu.postsample.chibjeliazkov,'Enable','off');
      set(controls.learning.viewmenu.viewposterior.marginal,'Enable','off');
      set(controls.learning.viewmenu.viewposterior.bivariate,'Enable','off');
      set(controls.learning.viewmenu.viewposterior.correlations,'Enable','off');
      set(controls.learning.toolsmenu.parent,'Enable','off');
      set(controls.learningtools.dsgeeigenvalues.initialvalues,'Enable','off');
      set(controls.learningtools.dsgeeigenvalues.dsgemode,'Enable','off');
      set(controls.learningtools.dsgeeigenvalues.postmode,'Enable','off');
      set(controls.learningtools.montecarlofiltering,'Enable','off');
      set(controls.learningtools.informationmatrix.frequencydomain.initialvalues,'Enable','off');
      set(controls.learningtools.informationmatrix.frequencydomain.dsgemode,'Enable','off');
      set(controls.learningtools.informationmatrix.frequencydomain.postmode,'Enable','off');
      set(controls.learningtools.informationmatrix.timedomain.initialvalues,'Enable','off');
      set(controls.learningtools.informationmatrix.timedomain.dsgemode,'Enable','off');
      set(controls.learningtools.informationmatrix.timedomain.postmode,'Enable','off');
      set(controls.learningtools.steadystatecorrelations.obsvar.timedomain.initialvalues,'Enable','off');
      set(controls.learningtools.steadystatecorrelations.statevar.timedomain.initialvalues,'Enable','off');
      set(controls.learningtools.steadystatecorrelations.obsvar.timedomain.dsgemode,'Enable','off');
      set(controls.learningtools.steadystatecorrelations.statevar.timedomain.dsgemode,'Enable','off');
      set(controls.learningtools.steadystatecorrelations.obsvar.timedomain.postmode,'Enable','off');
      set(controls.learningtools.steadystatecorrelations.statevar.timedomain.postmode,'Enable','off');
      set(controls.learningtools.statevariables.initialvalues,'Enable','off');
      set(controls.learningtools.statevariables.dsgemode,'Enable','off');
      set(controls.learningtools.statevariables.postmode,'Enable','off');
      set(controls.learningtools.stateshocks.initialvalues,'Enable','off');
      set(controls.learningtools.stateshocks.dsgemode,'Enable','off');
      set(controls.learningtools.stateshocks.postmode,'Enable','off');
      set(controls.learningtools.measurementerrors.initialvalues,'Enable','off');
      set(controls.learningtools.measurementerrors.dsgemode,'Enable','off');
      set(controls.learningtools.measurementerrors.postmode,'Enable','off');
      set(controls.learningtools.beliefcoefficients.initialvalues,'Enable','off');
      set(controls.learningtools.beliefcoefficients.dsgemode,'Enable','off');
      set(controls.learningtools.beliefcoefficients.postmode,'Enable','off');
      set(controls.learningtools.lawsofmotion.initialvalues,'Enable','off');
      set(controls.learningtools.lawsofmotion.dsgemode,'Enable','off');
      set(controls.learningtools.lawsofmotion.postmode,'Enable','off');
      set(controls.learningtools.persistence.initialvalues,'Enable','off');
      set(controls.learningtools.persistence.dsgemode,'Enable','off');
      set(controls.learningtools.persistence.postmode,'Enable','off');
      set(controls.learningtools.loglikelihood.initialvalues,'Enable','off');
      set(controls.learningtools.loglikelihood.dsgemode,'Enable','off');
      set(controls.learningtools.loglikelihood.postmode,'Enable','off');
      if isfield(controls.learningtools,'scenarios')==1;
         set(controls.learningtools.scenarios.ovs.original.initialvalues,'Enable','off');
         set(controls.learningtools.scenarios.ovs.annual.initialvalues,'Enable','off');
         set(controls.learningtools.scenarios.ovs.original.dsgemode,'Enable','off');
         set(controls.learningtools.scenarios.ovs.annual.dsgemode,'Enable','off');
         set(controls.learningtools.scenarios.ovs.original.postmode,'Enable','off');
         set(controls.learningtools.scenarios.ovs.annual.postmode,'Enable','off');
         set(controls.learningtools.scenarios.svs.original.initialvalues,'Enable','off');
         set(controls.learningtools.scenarios.svs.annual.initialvalues,'Enable','off');
         set(controls.learningtools.scenarios.svs.original.dsgemode,'Enable','off');
         set(controls.learningtools.scenarios.svs.annual.dsgemode,'Enable','off');
         set(controls.learningtools.scenarios.svs.original.postmode,'Enable','off');
         set(controls.learningtools.scenarios.svs.annual.postmode,'Enable','off');
      end;
      set(controls.learningtools.predictivedist.unconditional.original.height.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.height.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.crps.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.moments.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.pit.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.initialvalues,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.initialvalues,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.transformed.initialvalues,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.zlb.initialvalues,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.zlb.initialvalues,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.transformed.zlb.initialvalues,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.dsgemode,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.dsgemode,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.transformed.dsgemode,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.zlb.dsgemode,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.zlb.dsgemode,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.transformed.zlb.dsgemode,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.postmode,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.postmode,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.transformed.postmode,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.crps.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.transformed.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.zlb.height.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.zlb.crps.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.zlb.postmode,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.original.zlb.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.zlb.postmode,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.annual.zlb.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.transformed.zlb.postmode,'Enable','off');
      set(controls.learningtools.predictivedist.unconditional.transformed.zlb.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.initialvalues,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.initialvalues,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.transformed.initialvalues,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.zlb.initialvalues,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.zlb.initialvalues,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.transformed.zlb.initialvalues,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.dsgemode,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.dsgemode,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.transformed.dsgemode,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.zlb.dsgemode,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.zlb.dsgemode,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.transformed.zlb.dsgemode,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.postmode,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.postmode,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.transformed.postmode,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.zlb.postmode,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.zlb.postmode,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.transformed.zlb.postmode,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.height.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.height.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.crps.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.crps.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.moments.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.pit.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.transformed.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.zlb.height.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.zlb.height.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.zlb.crps.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.original.zlb.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.annual.zlb.posterior,'Enable','off');
      set(controls.learningtools.predictivedist.conditional.transformed.zlb.posterior,'Enable','off');
      set(controls.learning.viewmenu.modesty.initialvalues,'Enable','off','UserData','');
      set(controls.learning.viewmenu.modesty.dsgemode,'Enable','off','UserData','');
      set(controls.learning.viewmenu.modesty.postmode,'Enable','off','UserData','');
      for i=1:10;
         set(getfield(controls.learning.viewmenu.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
      end;
      set(controls.learningtools.decompositions.obsvar.decomp.original.initialvalues,'Enable','off');
      set(controls.learningtools.decompositions.obsvar.decomp.annual.initialvalues,'Enable','off');
      set(controls.learningtools.decompositions.obsvar.decomp.original.dsgemode,'Enable','off');
      set(controls.learningtools.decompositions.obsvar.decomp.annual.dsgemode,'Enable','off');
      set(controls.learningtools.decompositions.obsvar.decomp.original.postmode,'Enable','off');
      set(controls.learningtools.decompositions.obsvar.decomp.annual.postmode,'Enable','off');
      set(controls.learningtools.decompositions.statevar.initialvalues,'Enable','off');
      set(controls.learningtools.decompositions.statevar.dsgemode,'Enable','off');
      set(controls.learningtools.decompositions.statevar.postmode,'Enable','off');
      set(controls.learningtools.irfs.original.initialvalues,'Enable','off');
      set(controls.learningtools.irfs.original.dsgemode,'Enable','off');
      set(controls.learningtools.irfs.original.postmode,'Enable','off');
      set(controls.learningtools.irfs.annual.initialvalues,'Enable','off');
      set(controls.learningtools.irfs.annual.dsgemode,'Enable','off');
      set(controls.learningtools.irfs.annual.postmode,'Enable','off');
      set(controls.learningtools.irfs.levels.initialvalues,'Enable','off');
      set(controls.learningtools.irfs.levels.dsgemode,'Enable','off');
      set(controls.learningtools.irfs.levels.postmode,'Enable','off');
   end;
else;
   if isfield(controls,'ovs')==1;
      set(controls.ovs.postmode,'Enable','off');
      set(controls.ovs.annpostmode,'Enable','off');
      set(controls.ovs.initialvalues,'Enable','off');
      set(controls.ovs.anninitialvalues,'Enable','off');
      set(controls.ovs.posterior,'Enable','off');
      set(controls.ovs.ann_posterior,'Enable','off');
      set(controls.ovs.viewscenariovars,'Enable','off');
      set(controls.ovs.setscenariovars,'Enable','off');
      if isfield(controls.ovs,'scenariodata')==1;
         set(controls.ovs.savescenariodata,'Enable','off');
         set(controls.ovs.editscenariodata,'Enable','off');
         set(controls.ovs.viewscenariodata,'Enable','off');
         set(controls.ovs.exportscenariodata,'Enable','off');
         set(controls.ovs.openscenariodata,'Enable','off');
      end;
      set(controls.ovs.setscenarioshocks,'Enable','off');
      set(controls.ovs.reorderscenarioshocks,'Enable','off');
   end;
   if isfield(controls,'svs')==1;
      set(controls.svs.initialvalues,'Enable','off');
      set(controls.svs.anninitialvalues,'Enable','off');
      set(controls.svs.postmode,'Enable','off');
      set(controls.svs.annpostmode,'Enable','off');
      set(controls.svs.posterior,'Enable','off');
      set(controls.svs.ann_posterior,'Enable','off');
      set(controls.tunedfilters.statevariables.initialvalues,'Enable','off');
      set(controls.tunedfilters.stateshocks.initialvalues,'Enable','off');
      set(controls.tunedfilters.measurement.initialvalues,'Enable','off');
      set(controls.tunedfilters.statevariables.postmode,'Enable','off');
      set(controls.tunedfilters.stateshocks.postmode,'Enable','off');
      set(controls.tunedfilters.measurement.postmode,'Enable','off');
      set(controls.tunedfilters.statevariables.posterior,'Enable','off');
      set(controls.tunedfilters.stateshocks.posterior,'Enable','off');
      set(controls.tunedfilters.measurement.posterior,'Enable','off');
      set(controls.svs.viewstatescenariovars,'Enable','off');
      set(controls.svs.setstatescenariovars,'Enable','off');
      set(controls.svs.setstatescenarioshocks,'Enable','off');
      set(controls.svs.reorderstatescenarioshocks,'Enable','off');
      set(controls.svs.stateconstraints,'Enable','off');
   end;
   if isfield(controls,'shockscenarios')==1;
      set(controls.shockscenarios.postmode,'Enable','off');
      set(controls.shockscenarios.annpostmode,'Enable','off');
      set(controls.shockscenarios.initialvalues,'Enable','off');
      set(controls.shockscenarios.anninitialvalues,'Enable','off');
      set(controls.shockscenarios.posterior,'Enable','off');
      set(controls.shockscenarios.annposterior,'Enable','off');
   end;
   set(controls.postmode,'Enable','off');
   set(controls.postmodemenu,'Enable','off');
   set(controls.dsgevarmargmodemenu,'Enable','off');
   set(controls.dsgevarjointmodemenu,'Enable','off');
   set(controls.dsgevarpostsamplingmenu,'Enable','off');
   set(controls.dsgevarview.varmodel.dsgemode,'Enable','off');
   set(controls.dsgevarview.eigenvalues.dsgemode,'Enable','off');
   set(controls.dsgevarview.sequentialmarglike.laplace.dsgemode,'Enable','off');
   set(controls.dsgevartools.simulatedata.dsgemode,'Enable','off');
   set(controls.dsgevartools.obscorr.timedomain.dsgemode,'Enable','off');
   set(controls.dsgevartools.obscorr.parameterchange.dsgemode,'Enable','off');
   set(controls.dsgevartools.shockcorr.dsgemode,'Enable','off');
   set(controls.dsgevartools.shocks.dsgemode,'Enable','off');
   set(controls.dsgevartools.loglikelihood.dsgemode,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.decomp.original.dsgemode,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.paths.original.dsgemode,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.decomp.annual.dsgemode,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.paths.annual.dsgemode,'Enable','off');
   set(controls.dsgevartools.decomposition.corrdecomp.dsgemode,'Enable','off');
   set(controls.dsgevartools.decomposition.spectraldecomp.dsgemode,'Enable','off');
   set(controls.dsgevartools.decomposition.fevd.original.dsgemode,'Enable','off');
   set(controls.dsgevartools.decomposition.fevd.levels.dsgemode,'Enable','off');
   set(controls.dsgevartools.irfunction.original.dsgemode,'Enable','off');
   set(controls.dsgevartools.irfunction.annual.dsgemode,'Enable','off');
   set(controls.dsgevartools.irfunction.levels.dsgemode,'Enable','off');
   if isfield(controls.dsgevartools,'obsvarscenario')==1;
      set(controls.dsgevartools.obsvarscenario.original.dsgemode,'Enable','off');
      set(controls.dsgevartools.obsvarscenario.annual.dsgemode,'Enable','off');
   end;
   set(controls.dsgevarvarpostsamplingmenu,'Enable','off');
   set(controls.dsgevarpriorsamplingmenu,'Enable','off');
   set(controls.dsgevarview.varmodel.initialvalues,'Enable','off');
   set(controls.dsgevarview.eigenvalues.initialvalues,'Enable','off');
   set(controls.dsgevarview.sequentialmarglike.laplace.initialvalues,'Enable','off');
   set(controls.dsgevarview.priordensity.varparameter,'Enable','off');
   set(controls.dsgevarview.priordensity.sigmaparameter,'Enable','off');
   set(controls.dsgevarview.priordensity.a0parameter,'Enable','off');
   set(controls.dsgevartools.simulatedata.initialvalues,'Enable','off');
   set(controls.dsgevartools.obscorr.frequencydomain.initialvalues,'Enable','off');
   set(controls.dsgevartools.obscorr.frequencydomain.prior,'Enable','off');
   set(controls.dsgevartools.obscorr.timedomain.initialvalues,'Enable','off');
   set(controls.dsgevartools.obscorr.parameterchange.initialvalues,'Enable','off');
   set(controls.dsgevartools.obscorr.timedomain.prior,'Enable','off');
   set(controls.dsgevartools.obscorr.parameterchange.prior,'Enable','off');
   set(controls.dsgevartools.condcorr.initialvalues,'Enable','off');
   set(controls.dsgevartools.condcorr.prior,'Enable','off');
   set(controls.dsgevartools.shockcorr.initialvalues,'Enable','off');
   set(controls.dsgevartools.shockcorr.prior,'Enable','off');
   set(controls.dsgevartools.shocks.initialvalues,'Enable','off');
   set(controls.dsgevartools.shocks.prior,'Enable','off');
   set(controls.dsgevartools.loglikelihood.initialvalues,'Enable','off');
   if isfield(controls.dsgevartools,'obsvarscenario')==1;
      set(controls.dsgevartools.obsvarscenario.original.initialvalues,'Enable','off');
      set(controls.dsgevartools.obsvarscenario.annual.initialvalues,'Enable','off');
      set(controls.dsgevartools.obsvarscenario.original.prior,'Enable','off');
      set(controls.dsgevartools.obsvarscenario.annual.prior,'Enable','off');
   end;
   set(controls.dsgevartools.forecast.unconditional.original.initialvalues,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.annual.initialvalues,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.transformed.initialvalues,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.original.height.initialvalues,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.annual.height.initialvalues,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.original.initialvalues,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.annual.initialvalues,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.transformed.initialvalues,'Enable','off');
   set(controls.dsgevarview.modesty.initialvalues,'Enable','off','UserData','');
   set(controls.dsgevartools.forecast.unconditional.original.prior,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.annual.prior,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.transformed.prior,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.original.height.prior,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.annual.height.prior,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.original.moments.prior,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.original.statpredvar.prior,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.original.prior,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.annual.prior,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.transformed.prior,'Enable','off');
   set(controls.dsgevarview.modesty.prior,'Enable','off','UserData','');
   set(controls.dsgevartools.decomposition.ovd.decomp.original.initialvalues,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.decomp.annual.initialvalues,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.paths.original.initialvalues,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.paths.annual.initialvalues,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.paths.original.prior,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.paths.annual.prior,'Enable','off');
   set(controls.dsgevartools.decomposition.corrdecomp.initialvalues,'Enable','off');
   set(controls.dsgevartools.decomposition.spectraldecomp.initialvalues,'Enable','off');
   set(controls.dsgevartools.decomposition.fevd.original.initialvalues,'Enable','off');
   set(controls.dsgevartools.decomposition.fevd.levels.initialvalues,'Enable','off');
   set(controls.dsgevartools.decomposition.fevd.original.prior,'Enable','off');
   set(controls.dsgevartools.decomposition.fevd.levels.prior,'Enable','off');
   set(controls.dsgevartools.irfunction.original.initialvalues,'Enable','off');
   set(controls.dsgevartools.irfunction.annual.initialvalues,'Enable','off');
   set(controls.dsgevartools.irfunction.levels.initialvalues,'Enable','off');
   set(controls.dsgevartools.irfunction.original.prior,'Enable','off');
   set(controls.dsgevartools.irfunction.annual.prior,'Enable','off');
   set(controls.dsgevartools.irfunction.levels.prior,'Enable','off');
   set(controls.dsgevarview.varmodel.margmode,'Enable','off');
   set(controls.dsgevarview.eigenvalues.margmode,'Enable','off');
   set(controls.dsgevarview.sequentialmarglike.laplace.margmode,'Enable','off');
   set(controls.dsgevarview.postmoderes.margmode,'Enable','off');
   set(controls.dsgevarview.postmodesum.margmode,'Enable','off');
   set(controls.dsgevarview.opterror.margmode,'Enable','off');
   set(controls.dsgevarview.compareparameters.margmode,'Enable','off')
   set(controls.dsgevarview.checkpostmode.margmode,'Enable','off');
   set(controls.dsgevarview.varmodel.jointmode,'Enable','off');
   set(controls.dsgevarview.eigenvalues.jointmode,'Enable','off');
   set(controls.dsgevarview.sequentialmarglike.laplace.jointmode,'Enable','off');
   set(controls.dsgevarview.postmoderes.jointmode,'Enable','off');
   set(controls.dsgevarview.postmodesum.jointmode,'Enable','off');
   set(controls.dsgevarview.opterror.jointmode,'Enable','off');
   set(controls.dsgevarview.posteriorsamplingsummary,'Enable','off');
   set(controls.dsgevarview.varposteriorsamplingsummary,'Enable','off');
   set(controls.dsgevarview.rawdraws.originalparameters,'Enable','off');
   set(controls.dsgevarview.rawdraws.transformedparameters,'Enable','off');
   set(controls.dsgevarview.rawdraws.logposterior,'Enable','off');
   set(controls.dsgevarview.rawdraws.weights,'Enable','off');
   if DSGEModel.PosteriorSampler==10;
      set(controls.dsgevarview.rawdraws.weights,'Label','Im&portance Weights...');
   else;
      set(controls.dsgevarview.rawdraws.weights,'Label','&Particle Weights...');
   end;
   set(controls.dsgevarview.scatterplots.originalparameters,'Enable','off');
   set(controls.dsgevarview.scatterplots.transformedparameters,'Enable','off');
   set(controls.dsgevarview.sequentialmarglike.mhm,'Enable','off');
   set(controls.dsgevarview.sequentialmarglike.swz,'Enable','off');
   set(controls.dsgevarview.sequentialmarglike.chibjeliazkov,'Enable','off');
   set(controls.dsgevarview.convergence.cusumplots.logposterior,'Enable','off');
   set(controls.dsgevarview.convergence.cusumplots.original,'Enable','off');
   set(controls.dsgevarview.convergence.cusumplots.transformed,'Enable','off');
   set(controls.dsgevarview.convergence.spmt.logposterior,'Enable','off');
   set(controls.dsgevarview.convergence.spmt.original,'Enable','off');
   set(controls.dsgevarview.convergence.spmt.transformed,'Enable','off');
   set(controls.dsgevarview.convergence.acceptancerate,'Enable','off');
   set(controls.dsgevarview.convergence.smcadaption,'Enable','off');
   set(controls.dsgevarview.convergence.manova,'Enable','off');
   set(controls.dsgevarview.convergence.posteriormean,'Enable','off');
   set(controls.dsgevarview.convergence.posteriormedian,'Enable','off');
   set(controls.dsgevarview.compareparameters.jointmode,'Enable','off');
   set(controls.dsgevarview.compareparameters.posterior,'Enable','off');
   set(controls.dsgevarview.checkpostmode.jointmode,'Enable','off');
   set(controls.dsgevarview.marglike.modifiedharmonic,'Enable','off');
   set(controls.dsgevarview.marglike.swzmodifiedharmonic,'Enable','off');
   set(controls.dsgevarview.marglike.chibjeliazkov,'Enable','off');
   set(controls.dsgevarview.marglike.smc,'Enable','off');
   set(controls.dsgevarview.viewlaplaceposterior.margmode,'Enable','off');
   set(controls.dsgevarview.viewlaplaceposterior.jointmode,'Enable','off');
   set(controls.dsgevarview.postdensity.dsgeparameter,'Enable','off');
   set(controls.dsgevarview.postdensity.bivariatedsgeparameter,'Enable','off');
   set(controls.dsgevarview.postdensity.varparameter,'Enable','off');
   set(controls.dsgevarview.postdensity.sigmaparameter,'Enable','off');
   set(controls.dsgevarview.postdensity.a0parameter,'Enable','off');
   set(controls.dsgevartools.simulatedata.margmode,'Enable','off');
   set(controls.dsgevartools.simulatedata.jointmode,'Enable','off');
   set(controls.dsgevartools.obscorr.frequencydomain.margmode,'Enable','off');
   set(controls.dsgevartools.obscorr.frequencydomain.jointmode,'Enable','off');
   set(controls.dsgevartools.obscorr.frequencydomain.posterior,'Enable','off');
   set(controls.dsgevartools.obscorr.timedomain.margmode,'Enable','off');
   set(controls.dsgevartools.obscorr.parameterchange.margmode,'Enable','off');
   set(controls.dsgevartools.obscorr.timedomain.jointmode,'Enable','off');
   set(controls.dsgevartools.obscorr.parameterchange.jointmode,'Enable','off');
   set(controls.dsgevartools.obscorr.timedomain.posterior,'Enable','off');
   set(controls.dsgevartools.obscorr.parameterchange.posterior,'Enable','off');
   set(controls.dsgevartools.condcorr.margmode,'Enable','off');
   set(controls.dsgevartools.condcorr.jointmode,'Enable','off');
   set(controls.dsgevartools.condcorr.posterior,'Enable','off');
   set(controls.dsgevartools.shockcorr.margmode,'Enable','off');
   set(controls.dsgevartools.shockcorr.jointmode,'Enable','off');
   set(controls.dsgevartools.shockcorr.posterior,'Enable','off');
   set(controls.dsgevartools.shocks.margmode,'Enable','off');
   set(controls.dsgevartools.shocks.jointmode,'Enable','off');
   set(controls.dsgevartools.shocks.posterior,'Enable','off');
   set(controls.dsgevartools.loglikelihood.margmode,'Enable','off');
   set(controls.dsgevartools.loglikelihood.jointmode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.original.margmode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.annual.margmode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.transformed.margmode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.original.height.margmode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.annual.height.margmode,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.original.margmode,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.annual.margmode,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.transformed.margmode,'Enable','off');
   set(controls.dsgevarview.modesty.margmode,'Enable','off','UserData','');
   set(controls.dsgevartools.forecast.unconditional.original.jointmode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.annual.jointmode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.transformed.jointmode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.original.height.jointmode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.annual.height.jointmode,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.original.jointmode,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.annual.jointmode,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.transformed.jointmode,'Enable','off');
   set(controls.dsgevarview.modesty.jointmode,'Enable','off','UserData','');
   set(controls.dsgevartools.forecast.unconditional.original.posterior,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.annual.posterior,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.transformed.posterior,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.original.predevent,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.annual.predevent,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.transformed.predevent,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.original.height.posterior,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.annual.height.posterior,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.original.moments.posterior,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.original.statpredvar.posterior,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.original.posterior,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.annual.posterior,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.transformed.posterior,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.original.predevent,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.annual.predevent,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.transformed.predevent,'Enable','off');
   for i=1:10;
      set(getfield(controls.dsgevarview.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
   end;
   set(controls.dsgevartools.decomposition.ovd.decomp.original.margmode,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.decomp.annual.margmode,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.decomp.original.jointmode,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.decomp.annual.jointmode,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.paths.original.margmode,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.paths.annual.margmode,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.paths.original.jointmode,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.paths.annual.jointmode,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.paths.original.posterior,'Enable','off');
   set(controls.dsgevartools.decomposition.ovd.paths.annual.posterior,'Enable','off');
   set(controls.dsgevartools.decomposition.corrdecomp.margmode,'Enable','off');
   set(controls.dsgevartools.decomposition.corrdecomp.jointmode,'Enable','off');
   set(controls.dsgevartools.decomposition.spectraldecomp.margmode,'Enable','off');
   set(controls.dsgevartools.decomposition.spectraldecomp.jointmode,'Enable','off');
   set(controls.dsgevartools.decomposition.fevd.original.margmode,'Enable','off');
   set(controls.dsgevartools.decomposition.fevd.levels.margmode,'Enable','off');
   set(controls.dsgevartools.decomposition.fevd.original.jointmode,'Enable','off');
   set(controls.dsgevartools.decomposition.fevd.levels.jointmode,'Enable','off');
   set(controls.dsgevartools.decomposition.fevd.original.posterior,'Enable','off');
   set(controls.dsgevartools.decomposition.fevd.levels.posterior,'Enable','off');
   set(controls.dsgevartools.irfunction.original.margmode,'Enable','off');
   set(controls.dsgevartools.irfunction.annual.margmode,'Enable','off');
   set(controls.dsgevartools.irfunction.levels.margmode,'Enable','off');
   set(controls.dsgevartools.irfunction.original.jointmode,'Enable','off');
   set(controls.dsgevartools.irfunction.annual.jointmode,'Enable','off');
   set(controls.dsgevartools.irfunction.levels.jointmode,'Enable','off');
   set(controls.dsgevartools.irfunction.original.posterior,'Enable','off');
   set(controls.dsgevartools.irfunction.annual.posterior,'Enable','off');
   set(controls.dsgevartools.irfunction.levels.posterior,'Enable','off');
   if isfield(controls.dsgevartools,'obsvarscenario')==1;
      set(controls.dsgevartools.obsvarscenario.original.margmode,'Enable','off');
      set(controls.dsgevartools.obsvarscenario.annual.margmode,'Enable','off');
      set(controls.dsgevartools.obsvarscenario.original.jointmode,'Enable','off');
      set(controls.dsgevartools.obsvarscenario.annual.jointmode,'Enable','off');
      set(controls.dsgevartools.obsvarscenario.original.posterior,'Enable','off');
      set(controls.dsgevartools.obsvarscenario.annual.posterior,'Enable','off');
   end;
   set(controls.dsgevarshocksmenu,'Enable','off');
   set(controls.priorsamplingmenu,'Enable','off');
   set(controls.priorsampling,'Enable','off');
   set(controls.montecarlofiltering,'Enable','off');
   set(controls.setconditionalvars,'Enable','off');
   set(controls.setconditionalshocks,'Enable','off');
   if isfield(controls,'setconditionalshocksmixed')==1;
      set(controls.setconditionalshocksmixed,'Enable','off');
   end;
   set(controls.reorderconditionalshocks,'Enable','off');
   set(controls.viewconditionalvars,'Enable','off');
   if isfield(controls,'viewstateconditionalvars')==1;
      set(controls.viewstateconditionalvars,'Enable','off');
      set(controls.setstateconditionalshocks,'Enable','off');
      set(controls.setstateconditionalvars,'Enable','off');
      set(controls.setstateconditionalshocksmixed,'Enable','off');
      set(controls.reorderstateconditionalshocks,'Enable','off');
   end;
   set(controls.configureshocks,'Enable','off');
   set(controls.configureshocksmenu,'Enable','off');
   set(controls.shockgroupmenu,'Enable','off');
   set(controls.shockgroup,'Enable','off');
   set(controls.initialstatevaluesmenu,'Enable','off');
   set(controls.unitrootstatemenu,'Enable','off');
   set(controls.modeinfo,'Enable','off','UserData','');
   set(controls.modesummary,'Enable','off','UserData','');
   set(controls.opterrorsummary,'Enable','off','UserData','');
   set(controls.postsample.laplace.parameterchange.initialvalues,'Enable','off');
   set(controls.postsample.laplaceinitval,'Enable','off');
   set(controls.dsgeeigenvalues.initialvalues,'Enable','off');
   set(controls.viewpriorvalue.initialvalues,'Enable','off');
   set(controls.dsgetovareigenvalues.initialvalues,'Enable','off');
   set(controls.informationmatrix.frequencydomain.initialvalues,'Enable','off');
   set(controls.informationmatrix.timedomain.initialvalues,'Enable','off');
   set(controls.statespaceinitialvalues,'Enable','off');
   set(controls.statespacesaveinitialvalues,'Enable','off');
   set(controls.parametervalues.initialvalues,'Enable','off');
   set(controls.properties.initialvalues,'Enable','off');
   set(controls.structuralforminitialvalues,'Enable','off');
   set(controls.saveinversehessian,'Enable','off');
   set(controls.obsvarcorrs.frequencydomain.initialvalues,'Enable','off');
   set(controls.obsvarcorrs.timedomain.initialvalues,'Enable','off');
   set(controls.obsvarcorrs.parameterchange.initialvalues,'Enable','off');
   set(controls.condcorrs.initialvalues,'Enable','off');
   set(controls.simulatedata.initialvalues,'Enable','off');
   set(controls.statevarcorrs.frequencydomain.initialvalues,'Enable','off');
   set(controls.statevarcorrs.timedomain.initialvalues,'Enable','off');
   set(controls.statevarcorrs.parameterchange.initialvalues,'Enable','off');
   set(controls.irfunctions.initialvalues,'Enable','off');
   set(controls.irfunctions.ann_initialvalues,'Enable','off');
   set(controls.irfunctions.permanentshock.initialvalues,'Enable','off');
   set(controls.irfunctions.parameterchange.initialvalues,'Enable','off');
   set(controls.hd.initialvalues,'Enable','off');
   set(controls.obsweights.decomp.states.initialvalues,'Enable','off');
   set(controls.obsweights.decomp.shocks.initialvalues,'Enable','off');
   set(controls.obsweights.weights.states.initialvalues,'Enable','off');
   set(controls.obsweights.weights.shocks.initialvalues,'Enable','off');
   set(controls.ovd.initialvalues,'Enable','off');
   set(controls.ovp.initialvalues,'Enable','off');
   set(controls.ovd.anninitialvalues,'Enable','off');
   set(controls.ovp.anninitialvalues,'Enable','off');
   set(controls.svd.initialvalues,'Enable','off');
   set(controls.corrdecomp.obsvar.initialvalues,'Enable','off');
   set(controls.corrdecomp.statevar.initialvalues,'Enable','off');
   set(controls.spectraldecomp.obsvar.initialvalues,'Enable','off');
   set(controls.spectraldecomp.statevar.initialvalues,'Enable','off');
   set(controls.fevd.initialvalues,'Enable','off');
   set(controls.fevd.lev_initialvalues,'Enable','off');
   set(controls.cvd.initialvalues,'Enable','off');
   set(controls.cvd.ann_initialvalues,'Enable','off');
   set(controls.cvd.lev_initialvalues,'Enable','off');
   set(controls.cvd.state.initialvalues,'Enable','off');
   set(controls.fevd.state.initialvalues,'Enable','off');
   set(controls.irfunctions.lev_initialvalues,'Enable','off');
   set(controls.statevariables.initialvalues,'Enable','off');
   set(controls.ps.initialvalues,'Enable','off');
   set(controls.ps.anninitialvalues,'Enable','off');
   set(controls.obsvar.initialvalues,'Enable','off');
   set(controls.stateshocks.initialvalues,'Enable','off');
   set(controls.measurementerror.initialvalues,'Enable','off');
   set(controls.loglikelihood.initialvalues,'Enable','off');
   set(controls.predict.unconditional_original_initialvalues,'Enable','off');
   set(controls.predict.conditional_original_initialvalues,'Enable','off');
   set(controls.predict.unconditional_transformed_initialvalues,'Enable','off');
   set(controls.predict.conditional_transformed_initialvalues,'Enable','off');
   set(controls.modesty.initialvalues,'Enable','off','UserData','');
   set(controls.predict.unconditional.original.zlb.initialvalues,'Enable','off');
   set(controls.predict.unconditional.annual.zlb.initialvalues,'Enable','off');
   set(controls.predict.unconditional.transformed.zlb.initialvalues,'Enable','off');
   set(controls.predict.conditional.original.zlb.initialvalues,'Enable','off');
   set(controls.predict.conditional.annual.zlb.initialvalues,'Enable','off');
   set(controls.predict.conditional.transformed.zlb.initialvalues,'Enable','off');
   set(controls.predict.unconditional.original.obsweightdecomp.initialvalues,'Enable','off');
   set(controls.predict.unconditional.annual.obsweightdecomp.initialvalues,'Enable','off');
   if isfield(controls.modesty,'state')==1;
      set(controls.modesty.state.initialvalues,'Enable','off','UserData','');
   end;
   set(controls.predict.unconditional.original.height.initialvalues,'Enable','off');
   set(controls.predict.unconditional.annual.height.initialvalues,'Enable','off');
   set(controls.predict.conditional_annual_initialvalues,'Enable','off');
   set(controls.predict.unconditional_annual_initialvalues,'Enable','off');
   set(controls.stateshockcorrs.initialvalues,'Enable','off');
   set(controls.measurementerrorcorrs.initialvalues,'Enable','off');
   set(controls.viewprior,'Enable','off');
   set(controls.viewbivariateprior,'Enable','off');
   set(controls.systempriormodemenu,'Enable','off');
   set(controls.systempriorcorrelations,'Enable','off');
   set(controls.irfunctions.postmode,'Enable','off');
   set(controls.irfunctions.permanentshock.postmode,'Enable','off');
   set(controls.irfunctions.parameterchange.postmode,'Enable','off');
   set(controls.predict.unconditional_original_postmode,'Enable','off');
   set(controls.predict.conditional_original_postmode,'Enable','off');
   set(controls.predict.unconditional_transformed_postmode,'Enable','off');
   set(controls.predict.conditional_transformed_postmode,'Enable','off');
   set(controls.modesty.postmode,'Enable','off','UserData','');
   set(controls.predict.unconditional.original.zlb.postmode,'Enable','off');
   set(controls.predict.unconditional.annual.zlb.postmode,'Enable','off');
   set(controls.predict.unconditional.transformed.zlb.postmode,'Enable','off');
   set(controls.predict.conditional.original.zlb.postmode,'Enable','off');
   set(controls.predict.conditional.annual.zlb.postmode,'Enable','off');
   set(controls.predict.conditional.transformed.zlb.postmode,'Enable','off');
   set(controls.predict.unconditional.original.obsweightdecomp.postmode,'Enable','off');
   set(controls.predict.unconditional.annual.obsweightdecomp.postmode,'Enable','off');
   if isfield(controls.modesty,'state')==1;
      set(controls.modesty.state.postmode,'Enable','off','UserData','');
   end;
   set(controls.predict.unconditional_annual_postmode,'Enable','off');
   set(controls.predict.conditional_annual_postmode,'Enable','off');
   set(controls.predict.unconditional.original.height.postmode,'Enable','off');
   set(controls.predict.unconditional.annual.height.postmode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.original.dsgemode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.annual.dsgemode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.transformed.dsgemode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.original.height.dsgemode,'Enable','off');
   set(controls.dsgevartools.forecast.unconditional.annual.height.dsgemode,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.original.dsgemode,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.annual.dsgemode,'Enable','off');
   set(controls.dsgevartools.forecast.conditional.transformed.dsgemode,'Enable','off');
   set(controls.dsgevarview.modesty.dsgemode,'Enable','off','UserData','');
   set(controls.irfunctions.ann_postmode,'Enable','off');
   set(controls.fevd.postmode,'Enable','off');
   set(controls.fevd.lev_postmode,'Enable','off');
   set(controls.cvd.postmode,'Enable','off');
   set(controls.cvd.ann_postmode,'Enable','off');
   set(controls.cvd.lev_postmode,'Enable','off');
   set(controls.cvd.state.postmode,'Enable','off');
   set(controls.fevd.state.postmode,'Enable','off');
   set(controls.irfunctions.lev_postmode,'Enable','off');
   set(controls.obsweights.decomp.states.postmode,'Enable','off');
   set(controls.obsweights.decomp.shocks.postmode,'Enable','off');
   set(controls.obsweights.weights.states.postmode,'Enable','off');
   set(controls.obsweights.weights.shocks.postmode,'Enable','off');
   set(controls.hd.postmode,'Enable','off');
   set(controls.ovd.postmode,'Enable','off');
   set(controls.ovp.postmode,'Enable','off');
   set(controls.ovd.annpostmode,'Enable','off');
   set(controls.ovp.annpostmode,'Enable','off');
   set(controls.svd.postmode,'Enable','off');
   set(controls.postsampling,'Enable','off');
   set(controls.postsamplingmenu,'Enable','off');
   set(controls.checkpostmode,'Enable','off');
   set(controls.ps.postmode,'Enable','off');
   set(controls.ps.annpostmode,'Enable','off');
   set(controls.threedeepostmode.transformed,'Enable','off');
   set(controls.threedeepostmode.original,'Enable','off');
   set(controls.iteratedparameters,'Enable','off');
   set(controls.statevariables.postmode,'Enable','off');
   set(controls.obsvar.postmode,'Enable','off');
   set(controls.stateshocks.postmode,'Enable','off');
   set(controls.measurementerror.postmode,'Enable','off');
   set(controls.loglikelihood.postmode,'Enable','off');
   set(controls.stateshockcorrs.postmode,'Enable','off');
   set(controls.measurementerrorcorrs.postmode,'Enable','off');
   set(controls.dsgeeigenvalues.postmode,'Enable','off');
   set(controls.postsample.laplace.parameterchange.postmode,'Enable','off');
   set(controls.postsample.laplacepostmode,'Enable','off');
   set(controls.viewlaplaceposterior,'Enable','off');
   set(controls.viewpriorvalue.postmode,'Enable','off');
   set(controls.dsgetovareigenvalues.postmode,'Enable','off');
   set(controls.informationmatrix.frequencydomain.postmode,'Enable','off');
   set(controls.informationmatrix.timedomain.postmode,'Enable','off');
   set(controls.simulatedata.postmode,'Enable','off');
   set(controls.statespacemode,'Enable','off');
   set(controls.statespacesavemode,'Enable','off');
   set(controls.parametervalues.postmode,'Enable','off');
   set(controls.properties.postmode,'Enable','off');
   set(controls.structuralformpostmode,'Enable','off');
   set(controls.obsvarcorrs.frequencydomain.postmode,'Enable','off');
   set(controls.dsgevartools.obscorr.frequencydomain.dsgemode,'Enable','off');
   set(controls.dsgevartools.condcorr.dsgemode,'Enable','off');
   set(controls.obsvarcorrs.timedomain.postmode,'Enable','off');
   set(controls.obsvarcorrs.parameterchange.postmode,'Enable','off');
   set(controls.condcorrs.postmode,'Enable','off');
   set(controls.statevarcorrs.frequencydomain.postmode,'Enable','off');
   set(controls.statevarcorrs.timedomain.postmode,'Enable','off');
   set(controls.statevarcorrs.parameterchange.postmode,'Enable','off');
   set(controls.corrdecomp.obsvar.postmode,'Enable','off');
   set(controls.corrdecomp.statevar.postmode,'Enable','off');
   set(controls.spectraldecomp.obsvar.postmode,'Enable','off');
   set(controls.spectraldecomp.statevar.postmode,'Enable','off');
   for CurrChain=1:10;
      set(getfield(controls.postsamplesummary,['chain' num2str(CurrChain,'%0.0f')]),'Enable','off','UserData','');
   end;
   set(controls.postsample.mhm,'Enable','off');
   set(controls.postsample.swz,'Enable','off');
   set(controls.postsample.chibjeliazkov,'Enable','off');
   set(controls.predict.unconditional_original_posterior,'Enable','off');
   set(controls.predict.unconditional_original_predevent,'Enable','off');
   set(controls.predict.unconditional_transformed_posterior,'Enable','off');
   set(controls.predict.unconditional_transformed_predevent,'Enable','off');
   set(controls.predict.unconditional.original.zlb.height.posterior,'Enable','off');
   set(controls.predict.unconditional.annual.zlb.height.posterior,'Enable','off');
   set(controls.predict.unconditional.original.zlb.crps.posterior,'Enable','off');
   set(controls.predict.unconditional.annual.zlb.crps.posterior,'Enable','off');
   set(controls.predict.unconditional.original.zlb.posterior,'Enable','off');
   set(controls.predict.unconditional.annual.zlb.posterior,'Enable','off');
   set(controls.predict.unconditional.transformed.zlb.posterior,'Enable','off');
   set(controls.predict.conditional.original.zlb.height.posterior,'Enable','off');
   set(controls.predict.conditional.annual.zlb.height.posterior,'Enable','off');
   set(controls.predict.conditional.original.zlb.crps.posterior,'Enable','off');
   set(controls.predict.conditional.annual.zlb.crps.posterior,'Enable','off');
   set(controls.predict.conditional.original.zlb.posterior,'Enable','off');
   set(controls.predict.conditional.annual.zlb.posterior,'Enable','off');
   set(controls.predict.conditional.transformed.zlb.posterior,'Enable','off');
   set(controls.predict.conditional_original_posterior,'Enable','off');
   set(controls.predict.conditional_original_predevent,'Enable','off');
   set(controls.predict.conditional_transformed_posterior,'Enable','off');
   set(controls.predict.conditional_transformed_predevent,'Enable','off');
   set(controls.predict.conditional.original.height.posterior,'Enable','off');
   set(controls.predict.conditional.annual.height.posterior,'Enable','off');
   set(controls.predict.conditional.original.crps.posterior,'Enable','off');
   set(controls.predict.conditional.annual.crps.posterior,'Enable','off');
   set(controls.predict.conditional.original.moments.posterior,'Enable','off');
   set(controls.predict.conditional.original.pit.posterior,'Enable','off');
   for i=1:10;
      set(getfield(controls.modesty,['chain' num2str(i,'%0.0f')]),'Enable','off','UserData','');
   end;
   if isfield(controls.modesty,'state')==1;
      for i=1:10;
         set(getfield(controls.modesty.state,['chain' num2str(i,'%0.0f')]),'Enable','off','UserData','');
      end;
   end;
   set(controls.predict.unconditional_annual_posterior,'Enable','off');
   set(controls.predict.unconditional_annual_predevent,'Enable','off');
   set(controls.predict.conditional_annual_posterior,'Enable','off');
   set(controls.predict.conditional_annual_predevent,'Enable','off');
   set(controls.predict.unconditional.original.height.posterior,'Enable','off');
   set(controls.predict.unconditional.annual.height.posterior,'Enable','off');
   set(controls.predict.unconditional.original.crps.posterior,'Enable','off');
   set(controls.predict.unconditional.annual.crps.posterior,'Enable','off');
   set(controls.predict.unconditional.original.moments.posterior,'Enable','off');
   set(controls.predict.unconditional.original.pit.posterior,'Enable','off');
   set(controls.predict.unconditional.original.variancedecomp.posterior,'Enable','off');
   set(controls.postsample.rawplots_original,'Enable','off');
   set(controls.postsample.scatterplots_original,'Enable','off');
   set(controls.postsample.rawplots_transformed,'Enable','off');
   set(controls.postsample.rawplots_logpost,'Enable','off');
   if DSGEModel.PosteriorSampler==10;
      set(controls.postsample.rawplots_weights,'Enable','off','Label','Im&portance Weights...');
   else;
      set(controls.postsample.rawplots_weights,'Enable','off','Label','&Particle Weights...');
   end;
   set(controls.postsample.scatterplots_transformed,'Enable','off');
   set(controls.hd.posterior,'Enable','off');
   set(controls.irfunctions.posterior,'Enable','off');
   set(controls.irfunctions.statevariables.posterior,'Enable','off');
   set(controls.ovd.posterior,'Enable','off');
   set(controls.ovp.posterior,'Enable','off');
   set(controls.obsvar.predchecks.posterior,'Enable','off');
   set(controls.obsvar.posterior,'Enable','off');
   set(controls.obsvarcorrs.frequencydomain.posterior,'Enable','off');
   set(controls.obsvarcorrs.timedomain.posterior,'Enable','off');
   set(controls.obsvarcorrs.parameterchange.posterior,'Enable','off');
   set(controls.condcorrs.posterior,'Enable','off');
   set(controls.statevariables.posterior,'Enable','off');
   set(controls.statevarcorrs.frequencydomain.posterior,'Enable','off');
   set(controls.statevarcorrs.timedomain.posterior,'Enable','off');
   set(controls.statevarcorrs.parameterchange.posterior,'Enable','off');
   set(controls.stateshocks.posterior,'Enable','off');
   set(controls.stateshockcorrs.posterior,'Enable','off');
   set(controls.measurementerror.posterior,'Enable','off');
   set(controls.measurementerrorcorrs.posterior,'Enable','off');
   set(controls.cvd.posterior,'Enable','off');
   set(controls.cvd.state.posterior,'Enable','off');
   set(controls.fevd.posterior,'Enable','off');
   set(controls.fevd.lev_posterior,'Enable','off');
   set(controls.fevd.state.posterior,'Enable','off');
   set(controls.estimateparamcovmat,'Enable','off');
   set(controls.irfunctions.ann_posterior,'Enable','off');
   set(controls.ovd.annposterior,'Enable','off');
   set(controls.ovp.annposterior,'Enable','off');
   set(controls.cvd.ann_posterior,'Enable','off');
   set(controls.irfunctions.lev_posterior,'Enable','off');
   set(controls.cvd.lev_posterior,'Enable','off');
   set(controls.postsample.cusumplots.logposterior,'Enable','off');
   set(controls.postsample.cusumplots.original,'Enable','off');
   set(controls.postsample.cusumplots.transformed,'Enable','off');
   set(controls.postsample.spmt.logposterior,'Enable','off');
   set(controls.postsample.spmt.original,'Enable','off');
   set(controls.postsample.spmt.transformed,'Enable','off');
   set(controls.postsample.acceptancerate,'Enable','off');
   set(controls.postsample.smcadaption,'Enable','off');
   set(controls.postsample.manova,'Enable','off');
   set(controls.postsample.mean,'Enable','off');
   set(controls.postsample.median,'Enable','off');
   set(controls.viewposterior,'Enable','off');
   set(controls.viewbivariateposterior,'Enable','off');
   set(controls.posteriorcorrelations,'Enable','off');
   set(controls.statespaceposteriordist,'Enable','off');
   set(controls.learning.setforwardvariables,'Enable','off');
   set(controls.learning.retoplm,'Enable','off');
   set(controls.learning.setbeliefpriorfile,'Enable','off');
   set(controls.learning.belief.parent,'Enable','off');
   set(controls.learning.belief.default,'Checked','on');
   set(controls.learning.belief.userdefined,'Checked','off');
   set(controls.learning.options.parent,'Enable','off');
   set(controls.learning.options.nosmoothedstatesforbeliefs,'Checked','off');
   set(controls.learning.options.importpriordata,'Enable','off');
   set(controls.learning.saveinversehessian,'Enable','off');
   set(controls.learning.postmodemenu,'Enable','off');
   set(controls.learning.posteriorsamplingmenu,'Enable','off');
   set(controls.learning.priorsamplingmenu,'Enable','off');
   set(controls.learning.systempriormodemenu,'Enable','off');
   set(controls.learning.viewmenu.parent,'Enable','off');
   set(controls.learning.viewmenu.priorinformation,'Enable','off');
   set(controls.learning.viewmenu.parametervalues.initialvalues,'Enable','off');
   set(controls.learning.viewmenu.structuralform.initialvalues,'Enable','off');
   set(controls.learning.viewmenu.beliefcoefficients.initialvalues,'Enable','off');
   set(controls.learning.viewmenu.steadystatespaceform.initialvalues,'Enable','off');
   set(controls.learning.viewmenu.parametervalues.dsgemode,'Enable','off');
   set(controls.learning.viewmenu.structuralform.dsgemode,'Enable','off');
   set(controls.learning.viewmenu.beliefcoefficients.dsgemode,'Enable','off');
   set(controls.learning.viewmenu.steadystatespaceform.dsgemode,'Enable','off');
   set(controls.learning.viewmenu.parametervalues.postmode,'Enable','off');
   set(controls.learning.viewmenu.structuralform.postmode,'Enable','off');
   set(controls.learning.viewmenu.beliefcoefficients.postmode,'Enable','off');
   set(controls.learning.viewmenu.steadystatespaceform.postmode,'Enable','off');
   set(controls.learning.viewmenu.postmode.results,'Enable','off','UserData','');
   set(controls.learning.viewmenu.postmode.summary,'Enable','off','UserData','');
   for CurrChain=1:10;
      set(getfield(controls.learning.viewmenu.postsamplesummary,['chain' int2str(CurrChain)]),'Enable','off','UserData','');
   end;
   set(controls.learning.viewmenu.postsample.laplace.initialvalues,'Enable','off');
   set(controls.learning.viewmenu.postsample.laplace.dsgemode,'Enable','off');
   set(controls.learning.viewmenu.postsample.laplace.postmode,'Enable','off');
   set(controls.learning.viewmenu.iteratedparameters,'Enable','off');
   set(controls.learning.viewmenu.checkposterior,'Enable','off');
   set(controls.learning.viewmenu.threedeepostmode.original,'Enable','off');
   set(controls.learning.viewmenu.threedeepostmode.transformed,'Enable','off');
   set(controls.learning.viewmenu.viewlaplaceposterior,'Enable','off');
   set(controls.learning.viewmenu.viewprior.initialvalues,'Enable','off');
   set(controls.learning.viewmenu.viewprior.dsgemode,'Enable','off');
   set(controls.learning.viewmenu.viewprior.postmode,'Enable','off');
   set(controls.learning.viewmenu.postsample.rawplots.original,'Enable','off');
   set(controls.learning.viewmenu.postsample.rawplots.transformed,'Enable','off');
   set(controls.learning.viewmenu.postsample.rawplots.logpost,'Enable','off');
   if DSGEModel.PosteriorSampler==10;
      set(controls.learning.viewmenu.postsample.rawplots.weights,'Enable','off','Label','Im&portance Weights...');
   else;
      set(controls.learning.viewmenu.postsample.rawplots.weights,'Enable','off','Label','&Particle Weights...');
   end;
   set(controls.learning.viewmenu.postsample.scatterplots.original,'Enable','off');
   set(controls.learning.viewmenu.postsample.scatterplots.transformed,'Enable','off');
   set(controls.learning.viewmenu.postsample.mhm,'Enable','off');
   set(controls.learning.viewmenu.postsample.swz,'Enable','off');
   set(controls.learning.viewmenu.postsample.chibjeliazkov,'Enable','off');
   set(controls.learning.viewmenu.viewposterior.marginal,'Enable','off');
   set(controls.learning.viewmenu.viewposterior.bivariate,'Enable','off');
   set(controls.learning.viewmenu.viewposterior.correlations,'Enable','off');
   set(controls.learning.toolsmenu.parent,'Enable','off');
   set(controls.learningtools.dsgeeigenvalues.initialvalues,'Enable','off');
   set(controls.learningtools.dsgeeigenvalues.dsgemode,'Enable','off');
   set(controls.learningtools.dsgeeigenvalues.postmode,'Enable','off');
   set(controls.learningtools.montecarlofiltering,'Enable','off');
   set(controls.learningtools.informationmatrix.frequencydomain.initialvalues,'Enable','off');
   set(controls.learningtools.informationmatrix.frequencydomain.dsgemode,'Enable','off');
   set(controls.learningtools.informationmatrix.frequencydomain.postmode,'Enable','off');
   set(controls.learningtools.informationmatrix.timedomain.initialvalues,'Enable','off');
   set(controls.learningtools.informationmatrix.timedomain.dsgemode,'Enable','off');
   set(controls.learningtools.informationmatrix.timedomain.postmode,'Enable','off');
   set(controls.learningtools.steadystatecorrelations.obsvar.timedomain.initialvalues,'Enable','off');
   set(controls.learningtools.steadystatecorrelations.statevar.timedomain.initialvalues,'Enable','off');
   set(controls.learningtools.steadystatecorrelations.obsvar.timedomain.dsgemode,'Enable','off');
   set(controls.learningtools.steadystatecorrelations.statevar.timedomain.dsgemode,'Enable','off');
   set(controls.learningtools.steadystatecorrelations.obsvar.timedomain.postmode,'Enable','off');
   set(controls.learningtools.steadystatecorrelations.statevar.timedomain.postmode,'Enable','off');
   set(controls.learningtools.statevariables.initialvalues,'Enable','off');
   set(controls.learningtools.statevariables.dsgemode,'Enable','off');
   set(controls.learningtools.statevariables.postmode,'Enable','off');
   set(controls.learningtools.stateshocks.initialvalues,'Enable','off');
   set(controls.learningtools.stateshocks.dsgemode,'Enable','off');
   set(controls.learningtools.stateshocks.postmode,'Enable','off');
   set(controls.learningtools.measurementerrors.initialvalues,'Enable','off');
   set(controls.learningtools.measurementerrors.dsgemode,'Enable','off');
   set(controls.learningtools.measurementerrors.postmode,'Enable','off');
   set(controls.learningtools.beliefcoefficients.initialvalues,'Enable','off');
   set(controls.learningtools.beliefcoefficients.dsgemode,'Enable','off');
   set(controls.learningtools.beliefcoefficients.postmode,'Enable','off');
   set(controls.learningtools.lawsofmotion.initialvalues,'Enable','off');
   set(controls.learningtools.lawsofmotion.dsgemode,'Enable','off');
   set(controls.learningtools.lawsofmotion.postmode,'Enable','off');
   set(controls.learningtools.persistence.initialvalues,'Enable','off');
   set(controls.learningtools.persistence.dsgemode,'Enable','off');
   set(controls.learningtools.persistence.postmode,'Enable','off');
   set(controls.learningtools.loglikelihood.initialvalues,'Enable','off');
   set(controls.learningtools.loglikelihood.dsgemode,'Enable','off');
   set(controls.learningtools.loglikelihood.postmode,'Enable','off');
   if isfield(controls.learningtools,'scenarios')==1;
      set(controls.learningtools.scenarios.ovs.original.initialvalues,'Enable','off');
      set(controls.learningtools.scenarios.ovs.annual.initialvalues,'Enable','off');
      set(controls.learningtools.scenarios.ovs.original.dsgemode,'Enable','off');
      set(controls.learningtools.scenarios.ovs.annual.dsgemode,'Enable','off');
      set(controls.learningtools.scenarios.ovs.original.postmode,'Enable','off');
      set(controls.learningtools.scenarios.ovs.annual.postmode,'Enable','off');
      set(controls.learningtools.scenarios.svs.original.initialvalues,'Enable','off');
      set(controls.learningtools.scenarios.svs.annual.initialvalues,'Enable','off');
      set(controls.learningtools.scenarios.svs.original.dsgemode,'Enable','off');
      set(controls.learningtools.scenarios.svs.annual.dsgemode,'Enable','off');
      set(controls.learningtools.scenarios.svs.original.postmode,'Enable','off');
      set(controls.learningtools.scenarios.svs.annual.postmode,'Enable','off');
   end;
   set(controls.learningtools.predictivedist.unconditional.original.height.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.height.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.crps.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.moments.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.pit.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.initialvalues,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.initialvalues,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.transformed.initialvalues,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.zlb.initialvalues,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.zlb.initialvalues,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.transformed.zlb.initialvalues,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.dsgemode,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.dsgemode,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.transformed.dsgemode,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.zlb.dsgemode,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.zlb.dsgemode,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.transformed.zlb.dsgemode,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.postmode,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.postmode,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.transformed.postmode,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.crps.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.transformed.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.zlb.height.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.zlb.crps.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.zlb.postmode,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.original.zlb.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.zlb.height.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.zlb.crps.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.zlb.postmode,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.annual.zlb.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.transformed.zlb.postmode,'Enable','off');
   set(controls.learningtools.predictivedist.unconditional.transformed.zlb.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.initialvalues,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.initialvalues,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.transformed.initialvalues,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.zlb.initialvalues,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.zlb.initialvalues,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.transformed.zlb.initialvalues,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.dsgemode,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.dsgemode,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.transformed.dsgemode,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.zlb.dsgemode,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.zlb.dsgemode,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.transformed.zlb.dsgemode,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.postmode,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.postmode,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.transformed.postmode,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.zlb.postmode,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.zlb.postmode,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.transformed.zlb.postmode,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.height.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.height.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.crps.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.crps.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.moments.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.pit.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.transformed.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.zlb.height.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.zlb.height.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.zlb.crps.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.zlb.crps.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.original.zlb.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.annual.zlb.posterior,'Enable','off');
   set(controls.learningtools.predictivedist.conditional.transformed.zlb.posterior,'Enable','off');
   set(controls.learning.viewmenu.modesty.initialvalues,'Enable','off','UserData','');
   set(controls.learning.viewmenu.modesty.dsgemode,'Enable','off','UserData','');
   set(controls.learning.viewmenu.modesty.postmode,'Enable','off','UserData','');
   for i=1:10;
      set(getfield(controls.learning.viewmenu.modesty,['chain' int2str(i)]),'Enable','off','UserData','');
   end;
   set(controls.learningtools.decompositions.obsvar.decomp.original.initialvalues,'Enable','off');
   set(controls.learningtools.decompositions.obsvar.decomp.annual.initialvalues,'Enable','off');
   set(controls.learningtools.decompositions.obsvar.decomp.original.dsgemode,'Enable','off');
   set(controls.learningtools.decompositions.obsvar.decomp.annual.dsgemode,'Enable','off');
   set(controls.learningtools.decompositions.obsvar.decomp.original.postmode,'Enable','off');
   set(controls.learningtools.decompositions.obsvar.decomp.annual.postmode,'Enable','off');
   set(controls.learningtools.decompositions.statevar.initialvalues,'Enable','off');
   set(controls.learningtools.decompositions.statevar.dsgemode,'Enable','off');
   set(controls.learningtools.decompositions.statevar.postmode,'Enable','off');
   set(controls.learningtools.irfs.original.initialvalues,'Enable','off');
   set(controls.learningtools.irfs.original.dsgemode,'Enable','off');
   set(controls.learningtools.irfs.original.postmode,'Enable','off');
   set(controls.learningtools.irfs.annual.initialvalues,'Enable','off');
   set(controls.learningtools.irfs.annual.dsgemode,'Enable','off');
   set(controls.learningtools.irfs.annual.postmode,'Enable','off');
   set(controls.learningtools.irfs.levels.initialvalues,'Enable','off');
   set(controls.learningtools.irfs.levels.dsgemode,'Enable','off');
   set(controls.learningtools.irfs.levels.postmode,'Enable','off');
end;
if FileExist(DSGEModel.DataConstructionFile)==1;
   set(controls.viewdata,'Enable','on');
   set(controls.predict.actuals,'Enable','on');
   set(controls.obsvargroupsmenu,'Enable','on');
   if max(DSGEModel.annual)>1;
      set(controls.viewannualdata,'Enable','on');
   else;
      set(controls.viewannualdata,'Enable','off');
   end;
   if isempty(DSGEModel.YTransformation)==0;
      set(controls.viewtransdata,'Enable','on');
   else;
      set(controls.viewtransdata,'Enable','off');
   end;
   %
   % check if file with steady state prior parameters exists
   %
   if VerifySteadyStatePrior(DSGEModel.SteadyStatePriorFile,DSGEModel.BVARY,DSGEModel.BVARX)==1;
      if exist('MaxFH')==0;
         MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
      end;
      if exist('MaxPH')==0
         [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
      end;
      if exist('NumPredPaths')==0;
         NumPredPathsStr = get(controls.forecast.predpaths,'String');
         NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
      end;
      DrawsStr = get(controls.posterior.draws,'String');
      NumDraws = str2num(StringTrim(strrep(DrawsStr(DSGEModel.PosteriorDrawsValue,:),',','')));
      BurninStr = get(controls.posterior.burnin,'String');
      NumBurnin = str2num(strrep(StringTrim(BurninStr(DSGEModel.BurnInValue,:)),',',''));
      NumDraws = max(NumDraws-NumBurnin,0);
      PostDrawsUsageStr = get(controls.posterior.postdrawsusage,'String');
      NumDraws = min(str2num(strrep(StringTrim(PostDrawsUsageStr(DSGEModel.PostDrawsUsageValue,:)),',','')),NumDraws);
      set(controls.bvarmodemenu,'Enable','on');
      set(controls.bvarpriordensitypsi,'Enable','on');
      if (DSGEModel.PriorType==1)|((DSGEModel.PriorType==2)&(DSGEModel.OmegaPriorType==2));
         set(controls.bvarpriordensitypi,'Enable','on');
      else;
         set(controls.bvarpriordensitypi,'Enable','off');
      end;
      if DSGEModel.OmegaPriorType==2;
         set(controls.bvarpriordensityomega,'Enable','on');
      else;
         set(controls.bvarpriordensityomega,'Enable','off');
      end;
      DrawsStr = get(controls.posterior.draws,'String');
      NumPostDraws = str2num(StringTrim(strrep(DrawsStr(DSGEModel.PosteriorDrawsValue,:),',','')));
      ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-BVAR-' DSGEModel.NameOfModel '-' num2str(DSGEModel.PriorType,'%0.0f') '.' num2str(DSGEModel.OmegaPriorType,'%0.0f') '.mat']);
      if (FileExist(ModeFile)==1)&(MaxFH>0);
         %
         % Enable a few menu's of interest
         %
         if (isempty(DSGEModel.PredictedX)==1)&(isempty(DSGEModel.BVARX)==0)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
            set(controls.bvarpredict.unconditional.original.postmode,'Enable','off');
            set(controls.bvarpredict.unconditional.annual.postmode,'Enable','off');
            set(controls.bvarpredict.conditional.original.postmode,'Enable','off');
            set(controls.bvarpredict.conditional.annual.postmode,'Enable','off');
            set(controls.bvarmodesty.postmode,'Enable','off','UserData','');
         else;
            set(controls.bvarpredict.unconditional.original.postmode,'Enable','on');
            if max(DSGEModel.annual(DSGEModel.BVARY))>1;
               set(controls.bvarpredict.unconditional.annual.postmode,'Enable','on');
            else;
               set(controls.bvarpredict.unconditional.annual.postmode,'Enable','off');
            end;
            if (CheckConditioningData(DSGEModel)==1)&(rank(DSGEModel.K1(DSGEModel.BVARY,:))==size(DSGEModel.K1(DSGEModel.BVARY,:),2));
               set(controls.bvarpredict.conditional.original.postmode,'Enable','on');
               if max(DSGEModel.annual(DSGEModel.BVARY))>1;
                  set(controls.bvarpredict.conditional.annual.postmode,'Enable','on');
               else;
                  set(controls.bvarpredict.conditional.annual.postmode,'Enable','off');
               end;
               ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\BVAR-ModestyStatistics-' int2str(DSGEModel.PriorType) '.' int2str(DSGEModel.OmegaPriorType) '-' int2str(DSGEModel.BVARLags) '-' DSGEModel.NameOfModel '-' int2str(MaxPH) '.' int2str(NumPredPaths) '.txt']);
               if FileExist(ModestyFile)==1;
                  set(controls.bvarmodesty.postmode,'Enable','on','UserData',ModestyFile);
               else;
                  set(controls.bvarmodesty.postmode,'Enable','off','UserData','');
               end;
            else;
               set(controls.bvarpredict.conditional.original.postmode,'Enable','off');
               set(controls.bvarpredict.conditional.annual.postmode,'Enable','off');
               set(controls.bvarmodesty.postmode,'Enable','off','UserData','');
            end;
         end;
%         set(controls.bvarforecast.postmode,'Enable','on');
%         if max(DSGEModel.annual(DSGEModel.BVARY))>1;
%            set(controls.bvarforecast.annpostmode,'Enable','on');
%         else;
%            set(controls.bvarforecast.annpostmode,'Enable','off');
%         end;
         ModeTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeBVAR-' DSGEModel.NameOfModel '-' num2str(DSGEModel.PriorType,'%0.0f') '.' num2str(DSGEModel.OmegaPriorType,'%0.0f') '.txt']);
         if FileExist(ModeTextFile)==1;
            set(controls.bvarmoderesultsmenu,'Enable','on');
         else;
            set(controls.bvarmoderesultsmenu,'Enable','off');
         end;
         set(controls.gibbssamplingmenu,'Enable','on');
         set(controls.bvareigenvalues,'Enable','on');
         GibbsTextFile = FixFilePath([DSGEModel.OutputDirectory '\BVAR-GibbsSummary-' DSGEModel.NameOfModel '-' num2str(DSGEModel.PriorType,'%0.0f') '.' num2str(DSGEModel.OmegaPriorType,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
         if FileExist(GibbsTextFile)==1;
            set(controls.bvargibbsresultsmenu,'Enable','on');
            if length(DSGEModel.BVARX)>0;
               set(controls.bvarrawdrawspsi,'Enable','on');
               set(controls.bvarpostdensitypsi,'Enable','on');
               set(controls.bvarpsimeanconvergence,'Enable','on');
               set(controls.bvarpsimedianconvergence,'Enable','on');
               if (isempty(DSGEModel.PredictedX)==1)&(isempty(DSGEModel.BVARX)==0)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
                  set(controls.bvarpredict.unconditional.original.posterior,'Enable','off');
                  set(controls.bvarpredict.unconditional.annual.posterior,'Enable','off');
                  set(controls.bvarpredict.unconditional.original.predevent,'Enable','off');
                  set(controls.bvarpredict.unconditional.annual.predevent,'Enable','off');
                  set(controls.bvarpredict.conditional.original.posterior,'Enable','off');
                  set(controls.bvarpredict.conditional.annual.posterior,'Enable','off');
                  set(controls.bvarpredict.conditional.original.predevent,'Enable','off');
                  set(controls.bvarpredict.conditional.annual.predevent,'Enable','off');
                  set(controls.bvarmodesty.posterior,'Enable','off','UserData','');
               else;
                  set(controls.bvarpredict.unconditional.original.posterior,'Enable','on');
                  set(controls.bvarpredict.unconditional.original.predevent,'Enable','on');
                  if max(DSGEModel.annual(DSGEModel.BVARY))>1;
                     set(controls.bvarpredict.unconditional.annual.posterior,'Enable','on');
                     set(controls.bvarpredict.unconditional.annual.predevent,'Enable','on');
                  else;
                     set(controls.bvarpredict.unconditional.annual.posterior,'Enable','off');
                     set(controls.bvarpredict.unconditional.annual.predevent,'Enable','off');
                  end;
                  if (CheckConditioningData(DSGEModel)==1)&(rank(DSGEModel.K1(DSGEModel.BVARY,:))==size(DSGEModel.K1(DSGEModel.BVARY,:),2));
                     set(controls.bvarpredict.conditional.original.posterior,'Enable','on');
                     set(controls.bvarpredict.conditional.original.predevent,'Enable','on');
                     if max(DSGEModel.annual(DSGEModel.BVARY))>1;
                        set(controls.bvarpredict.conditional.annual.posterior,'Enable','on');
                        set(controls.bvarpredict.conditional.annual.predevent,'Enable','on');
                     else;
                        set(controls.bvarpredict.conditional.annual.posterior,'Enable','off');
                        set(controls.bvarpredict.conditional.annual.predevent,'Enable','off');
                     end;
                     ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\BVAR-ModestyStatistics-' int2str(DSGEModel.PriorType) '.' int2str(DSGEModel.OmegaPriorType) '-' int2str(DSGEModel.BVARLags) '-' DSGEModel.NameOfModel '-' int2str(MaxPH) '.' int2str(NumDraws) '.' int2str(NumPredPaths) '.txt']);
                     if FileExist(ModestyFile)==1;
                        set(controls.bvarmodesty.posterior,'Enable','on','UserData',ModestyFile);
                     else;
                        set(controls.bvarmodesty.posterior,'Enable','off','UserData','');
                     end;
                  else;
                     set(controls.bvarpredict.conditional.original.posterior,'Enable','off');
                     set(controls.bvarpredict.conditional.annual.posterior,'Enable','off');
                     set(controls.bvarpredict.conditional.original.predevent,'Enable','off');
                     set(controls.bvarpredict.conditional.annual.predevent,'Enable','off');
                     set(controls.bvarmodesty.posterior,'Enable','off','UserData','');
                  end;
               end;
            else;
               set(controls.bvarrawdrawspsi,'Enable','off');
               set(controls.bvarpostdensitypsi,'Enable','off');
               set(controls.bvarpsimeanconvergence,'Enable','off');
               set(controls.bvarpsimedianconvergence,'Enable','off');
               set(controls.bvarpredict.unconditional.original.posterior,'Enable','off');
               set(controls.bvarpredict.unconditional.annual.posterior,'Enable','off');
               set(controls.bvarpredict.unconditional.original.predevent,'Enable','off');
               set(controls.bvarpredict.unconditional.annual.predevent,'Enable','off');
               set(controls.bvarpredict.conditional.original.posterior,'Enable','off');
               set(controls.bvarpredict.conditional.annual.posterior,'Enable','off');
               set(controls.bvarpredict.conditional.original.predevent,'Enable','off');
               set(controls.bvarpredict.conditional.annual.predevent,'Enable','off');
               set(controls.bvarmodesty.posterior,'Enable','off','UserData','');
            end;
            set(controls.bvarrawdrawsomega,'Enable','on');
            set(controls.bvaromegameanconvergence,'Enable','on');
            set(controls.bvaromegamedianconvergence,'Enable','on');
            set(controls.bvarpostdensityomega,'Enable','on');
            set(controls.bvarrawdrawspi,'Enable','on');
            set(controls.bvarpimeanconvergence,'Enable','on');
            set(controls.bvarpimedianconvergence,'Enable','on');
            set(controls.bvarpostdensitypi,'Enable','on');
            set(controls.bvarmarglike,'Enable','on');
         else;
            set(controls.bvargibbsresultsmenu,'Enable','off');
            set(controls.bvarrawdrawspsi,'Enable','off');
            set(controls.bvarpredict.unconditional.original.posterior,'Enable','off');
            set(controls.bvarpredict.unconditional.annual.posterior,'Enable','off');
            set(controls.bvarpredict.unconditional.original.predevent,'Enable','off');
            set(controls.bvarpredict.unconditional.annual.predevent,'Enable','off');
            set(controls.bvarpredict.conditional.original.posterior,'Enable','off');
            set(controls.bvarpredict.conditional.annual.posterior,'Enable','off');
            set(controls.bvarpredict.conditional.original.predevent,'Enable','off');
            set(controls.bvarpredict.conditional.annual.predevent,'Enable','off');
            set(controls.bvarmodesty.posterior,'Enable','off','UserData','');
            set(controls.bvarpostdensitypsi,'Enable','off');
            set(controls.bvarpsimeanconvergence,'Enable','off');
            set(controls.bvarpsimedianconvergence,'Enable','off');
            set(controls.bvarrawdrawsomega,'Enable','off');
            set(controls.bvaromegameanconvergence,'Enable','off');
            set(controls.bvaromegamedianconvergence,'Enable','off');
            set(controls.bvarpostdensityomega,'Enable','off');
            set(controls.bvarrawdrawspi,'Enable','off');
            set(controls.bvarpimeanconvergence,'Enable','off');
            set(controls.bvarpimedianconvergence,'Enable','off');
            set(controls.bvarpostdensitypi,'Enable','off');
            set(controls.bvarmarglike,'Enable','off');
         end;
      else;
         if FileExist(ModeFile)==1;
            if (isempty(DSGEModel.PredictedX)==1)&(isempty(DSGEModel.BVARX)==0)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
               set(controls.bvarpredict.unconditional.original.postmode,'Enable','off');
               set(controls.bvarpredict.unconditional.annual.postmode,'Enable','off');
               set(controls.bvarpredict.conditional.original.postmode,'Enable','off');
               set(controls.bvarpredict.conditional.annual.postmode,'Enable','off');
               set(controls.bvarmodesty.postmode,'Enable','off','UserData','');
            else;
               set(controls.bvarpredict.unconditional.original.postmode,'Enable','on');
               if max(DSGEModel.annual(DSGEModel.BVARY))>1;
                  set(controls.bvarpredict.unconditional.annual.postmode,'Enable','on');
               else;
                  set(controls.bvarpredict.unconditional.annual.postmode,'Enable','off');
               end;
               if (CheckConditioningData(DSGEModel)==1)&(rank(DSGEModel.K1(DSGEModel.BVARY,:))==size(DSGEModel.K1(DSGEModel.BVARY,:),2));
                  set(controls.bvarpredict.conditional.original.postmode,'Enable','on');
                  if max(DSGEModel.annual(DSGEModel.BVARY))>1;
                     set(controls.bvarpredict.conditional.annual.postmode,'Enable','on');
                  else;
                     set(controls.bvarpredict.conditional.annual.postmode,'Enable','off');
                  end;
                  ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\BVAR-ModestyStatistics-' int2str(DSGEModel.PriorType) '.' int2str(DSGEModel.OmegaPriorType) '-' int2str(DSGEModel.BVARLags) '-' DSGEModel.NameOfModel '-' int2str(MaxPH) '.' int2str(NumPredPaths) '.txt']);
                  if FileExist(ModestyFile)==1;
                     set(controls.bvarmodesty.postmode,'Enable','on','UserData',ModestyFile);
                  else;
                     set(controls.bvarmodesty.postmode,'Enable','off','UserData','');
                  end;
               else;
                  set(controls.bvarpredict.conditional.original.postmode,'Enable','off');
                  set(controls.bvarpredict.conditional.annual.postmode,'Enable','off');
                  set(controls.bvarmodesty.postmode,'Enable','off','UserData','');
               end;
            end;
            set(controls.gibbssamplingmenu,'Enable','on');
            set(controls.bvareigenvalues,'Enable','on');
            GibbsTextFile = FixFilePath([DSGEModel.OutputDirectory '\BVAR-GibbsSummary-' DSGEModel.NameOfModel '-' num2str(DSGEModel.PriorType,'%0.0f') '.' num2str(DSGEModel.OmegaPriorType,'%0.0f') '-' num2str(NumPostDraws,'%0.0f') '.txt']);
            if FileExist(GibbsTextFile)==1;
               set(controls.bvargibbsresultsmenu,'Enable','on');
               if length(DSGEModel.BVARX)>0;
                  set(controls.bvarrawdrawspsi,'Enable','on');
                  set(controls.bvarpostdensitypsi,'Enable','on');
                  set(controls.bvarpsimeanconvergence,'Enable','on');
                  set(controls.bvarpsimedianconvergence,'Enable','on');
                  if (isempty(DSGEModel.PredictedX)==1)&(isempty(DSGEModel.BVARX)==0)&(strcmp(DSGEModel.SubEndYear,DSGEModel.EndYear)==1)&(strcmp(DSGEModel.SubEndPeriod,DSGEModel.EndPeriod)==1);
                     set(controls.bvarpredict.unconditional.original.posterior,'Enable','off');
                     set(controls.bvarpredict.unconditional.annual.posterior,'Enable','off');
                     set(controls.bvarpredict.unconditional.original.predevent,'Enable','off');
                     set(controls.bvarpredict.unconditional.annual.predevent,'Enable','off');
                     set(controls.bvarpredict.conditional.original.posterior,'Enable','off');
                     set(controls.bvarpredict.conditional.annual.posterior,'Enable','off');
                     set(controls.bvarpredict.conditional.original.predevent,'Enable','off');
                     set(controls.bvarpredict.conditional.annual.predevent,'Enable','off');
                     set(controls.bvarmodesty.posterior,'Enable','off','UserData','');
                  else;
                     set(controls.bvarpredict.unconditional.original.posterior,'Enable','on');
                     set(controls.bvarpredict.unconditional.original.predevent,'Enable','on');
                     if max(DSGEModel.annual(DSGEModel.BVARY))>1;
                        set(controls.bvarpredict.unconditional.annual.posterior,'Enable','on');
                        set(controls.bvarpredict.unconditional.annual.predevent,'Enable','on');
                     else;
                        set(controls.bvarpredict.unconditional.annual.posterior,'Enable','off');
                        set(controls.bvarpredict.unconditional.annual.predevent,'Enable','off');
                     end;
                     if (CheckConditioningData(DSGEModel)==1)&(rank(DSGEModel.K1(DSGEModel.BVARY,:))==size(DSGEModel.K1(DSGEModel.BVARY,:),2));
                        set(controls.bvarpredict.conditional.original.posterior,'Enable','on');
                        set(controls.bvarpredict.conditional.original.predevent,'Enable','on');
                        if max(DSGEModel.annual(DSGEModel.BVARY))>1;
                           set(controls.bvarpredict.conditional.annual.posterior,'Enable','on');
                           set(controls.bvarpredict.conditional.annual.predevent,'Enable','on');
                        else;
                           set(controls.bvarpredict.conditional.annual.posterior,'Enable','off');
                           set(controls.bvarpredict.conditional.annual.predevent,'Enable','off');
                        end;
                        ModestyFile = FixFilePath([DSGEModel.OutputDirectory '\BVAR-ModestyStatistics-' int2str(DSGEModel.PriorType) '.' int2str(DSGEModel.OmegaPriorType) '-' int2str(DSGEModel.BVARLags) '-' DSGEModel.NameOfModel '-' int2str(MaxPH) '.' int2str(NumDraws) '.' int2str(NumPredPaths) '.txt']);
                        if FileExist(ModestyFile)==1;
                           set(controls.bvarmodesty.posterior,'Enable','on','UserData',ModestyFile);
                        else;
                           set(controls.bvarmodesty.posterior,'Enable','off','UserData','');
                        end;
                     else;
                        set(controls.bvarpredict.conditional.original.posterior,'Enable','off');
                        set(controls.bvarpredict.conditional.annual.posterior,'Enable','off');
                        set(controls.bvarpredict.conditional.original.predevent,'Enable','off');
                        set(controls.bvarpredict.conditional.annual.predevent,'Enable','off');
                        set(controls.bvarmodesty.posterior,'Enable','off','UserData','');
                     end;
                  end;
               else;
                  set(controls.bvarrawdrawspsi,'Enable','off');
                  set(controls.bvarpredict.unconditional.original.posterior,'Enable','off');
                  set(controls.bvarpredict.unconditional.annual.posterior,'Enable','off');
                  set(controls.bvarpredict.unconditional.original.predevent,'Enable','off');
                  set(controls.bvarpredict.unconditional.annual.predevent,'Enable','off');
                  set(controls.bvarpredict.conditional.original.posterior,'Enable','off');
                  set(controls.bvarpredict.conditional.annual.posterior,'Enable','off');
                  set(controls.bvarpredict.conditional.original.predevent,'Enable','off');
                  set(controls.bvarpredict.conditional.annual.predevent,'Enable','off');
                  set(controls.bvarmodesty.posterior,'Enable','off','UserData','');
                  set(controls.bvarpostdensitypsi,'Enable','off');
                  set(controls.bvarpsimeanconvergence,'Enable','off');
                  set(controls.bvarpsimedianconvergence,'Enable','off');
               end;
               set(controls.bvarrawdrawsomega,'Enable','on');
               set(controls.bvaromegameanconvergence,'Enable','on');
               set(controls.bvaromegamedianconvergence,'Enable','on');
               set(controls.bvarpostdensityomega,'Enable','on');
               set(controls.bvarrawdrawspi,'Enable','on');
               set(controls.bvarpimeanconvergence,'Enable','on');
               set(controls.bvarpimedianconvergence,'Enable','on');
               set(controls.bvarpostdensitypi,'Enable','on');
               set(controls.bvarmarglike,'Enable','on');
            else;
               set(controls.bvargibbsresultsmenu,'Enable','off');
               set(controls.bvarrawdrawspsi,'Enable','off');
               set(controls.bvarpredict.unconditional.original.posterior,'Enable','off');
               set(controls.bvarpredict.unconditional.annual.posterior,'Enable','off');
               set(controls.bvarpredict.unconditional.original.predevent,'Enable','off');
               set(controls.bvarpredict.unconditional.annual.predevent,'Enable','off');
               set(controls.bvarpredict.conditional.original.posterior,'Enable','off');
               set(controls.bvarpredict.conditional.annual.posterior,'Enable','off');
               set(controls.bvarpredict.conditional.original.predevent,'Enable','off');
               set(controls.bvarpredict.conditional.annual.predevent,'Enable','off');
               set(controls.bvarmodesty.posterior,'Enable','off','UserData','');
               set(controls.bvarpostdensitypsi,'Enable','off');
               set(controls.bvarpsimeanconvergence,'Enable','off');
               set(controls.bvarpsimedianconvergence,'Enable','off');
               set(controls.bvarrawdrawsomega,'Enable','off');
               set(controls.bvaromegameanconvergence,'Enable','off');
               set(controls.bvaromegamedianconvergence,'Enable','off');
               set(controls.bvarpostdensityomega,'Enable','off');
               set(controls.bvarrawdrawspi,'Enable','off');
               set(controls.bvarpimeanconvergence,'Enable','off');
               set(controls.bvarpimedianconvergence,'Enable','off');
               set(controls.bvarpostdensitypi,'Enable','off');
               set(controls.bvarmarglike,'Enable','off');
            end;
         else;
            set(controls.gibbssamplingmenu,'Enable','off');
            set(controls.bvareigenvalues,'Enable','off');
            set(controls.bvargibbsresultsmenu,'Enable','off');
            set(controls.bvarrawdrawspsi,'Enable','off');
            set(controls.bvarpredict.unconditional.original.posterior,'Enable','off');
            set(controls.bvarpredict.unconditional.annual.posterior,'Enable','off');
            set(controls.bvarpredict.unconditional.original.predevent,'Enable','off');
            set(controls.bvarpredict.unconditional.annual.predevent,'Enable','off');
            set(controls.bvarpredict.conditional.original.posterior,'Enable','off');
            set(controls.bvarpredict.conditional.annual.posterior,'Enable','off');
            set(controls.bvarpredict.conditional.original.predevent,'Enable','off');
            set(controls.bvarpredict.conditional.annual.predevent,'Enable','off');
            set(controls.bvarmodesty.posterior,'Enable','off','UserData','');
            set(controls.bvarpostdensitypsi,'Enable','off');
            set(controls.bvarpsimeanconvergence,'Enable','off');
            set(controls.bvarpsimedianconvergence,'Enable','off');
            set(controls.bvarrawdrawsomega,'Enable','off');
            set(controls.bvaromegameanconvergence,'Enable','off');
            set(controls.bvaromegamedianconvergence,'Enable','off');
            set(controls.bvarpostdensityomega,'Enable','off');
            set(controls.bvarrawdrawspi,'Enable','off');
            set(controls.bvarpimeanconvergence,'Enable','off');
            set(controls.bvarpimedianconvergence,'Enable','off');
            set(controls.bvarpostdensitypi,'Enable','off');
            set(controls.bvarmarglike,'Enable','off');
            set(controls.bvarpredict.unconditional.original.postmode,'Enable','off');
            set(controls.bvarpredict.unconditional.annual.postmode,'Enable','off');
            set(controls.bvarpredict.conditional.original.postmode,'Enable','off');
            set(controls.bvarpredict.conditional.annual.postmode,'Enable','off');
            set(controls.bvarmodesty.postmode,'Enable','off','UserData','');
         end;
%         set(controls.bvarforecast.postmode,'Enable','off');
%         set(controls.bvarforecast.annpostmode,'Enable','off');
         ModeTextFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeBVAR-' DSGEModel.NameOfModel '-' num2str(DSGEModel.PriorType,'%0.0f') '.' num2str(DSGEModel.OmegaPriorType,'%0.0f') '.txt']);
         if FileExist(ModeTextFile)==1;
            set(controls.bvarmoderesultsmenu,'Enable','on');
         else;
            set(controls.bvarmoderesultsmenu,'Enable','off');
         end;
      end;
   else;
      set(controls.gibbssamplingmenu,'Enable','off');
      set(controls.bvareigenvalues,'Enable','off');
      set(controls.bvargibbsresultsmenu,'Enable','off');
      set(controls.bvarrawdrawspsi,'Enable','off');
      set(controls.bvarpredict.unconditional.original.posterior,'Enable','off');
      set(controls.bvarpredict.unconditional.annual.posterior,'Enable','off');
      set(controls.bvarpredict.unconditional.original.predevent,'Enable','off');
      set(controls.bvarpredict.unconditional.annual.predevent,'Enable','off');
      set(controls.bvarpredict.conditional.original.posterior,'Enable','off');
      set(controls.bvarpredict.conditional.annual.posterior,'Enable','off');
      set(controls.bvarpredict.conditional.original.predevent,'Enable','off');
      set(controls.bvarpredict.conditional.annual.predevent,'Enable','off');
      set(controls.bvarmodesty.posterior,'Enable','off','UserData','');
      set(controls.bvarpostdensitypsi,'Enable','off');
      set(controls.bvarpsimeanconvergence,'Enable','off');
      set(controls.bvarpsimedianconvergence,'Enable','off');
      set(controls.bvarrawdrawsomega,'Enable','off');
      set(controls.bvaromegameanconvergence,'Enable','off');
      set(controls.bvaromegamedianconvergence,'Enable','off');
      set(controls.bvarpostdensityomega,'Enable','off');
      set(controls.bvarrawdrawspi,'Enable','off');
      set(controls.bvarpimeanconvergence,'Enable','off');
      set(controls.bvarpimedianconvergence,'Enable','off');
      set(controls.bvarpostdensitypi,'Enable','off');
      set(controls.bvarmarglike,'Enable','off');
      set(controls.bvarmodemenu,'Enable','off');
      set(controls.bvarpriordensitypsi,'Enable','off');
      set(controls.bvarpriordensitypi,'Enable','off');
      set(controls.bvarpriordensityomega,'Enable','off');
%      set(controls.bvarforecast.postmode,'Enable','off');
%      set(controls.bvarforecast.annpostmode,'Enable','off');
      set(controls.bvarpredict.unconditional.original.postmode,'Enable','off');
      set(controls.bvarpredict.unconditional.annual.postmode,'Enable','off');
      set(controls.bvarpredict.conditional.original.postmode,'Enable','off');
      set(controls.bvarpredict.conditional.annual.postmode,'Enable','off');
      set(controls.bvarmodesty.postmode,'Enable','off','UserData','');
      set(controls.bvarmoderesultsmenu,'Enable','off');
   end;
else;
   set(controls.viewdata,'Enable','off');
   set(controls.predict.actuals,'Enable','off');
   set(controls.obsvargroupsmenu,'Enable','off');
   set(controls.viewannualdata,'Enable','off');
   set(controls.viewtransdata,'Enable','off');
   set(controls.gibbssamplingmenu,'Enable','off');
   set(controls.bvareigenvalues,'Enable','off');
   set(controls.bvargibbsresultsmenu,'Enable','off');
   set(controls.bvarrawdrawspsi,'Enable','off');
   set(controls.bvarpredict.unconditional.original.posterior,'Enable','off');
   set(controls.bvarpredict.unconditional.annual.posterior,'Enable','off');
   set(controls.bvarpredict.unconditional.original.predevent,'Enable','off');
   set(controls.bvarpredict.unconditional.annual.predevent,'Enable','off');
   set(controls.bvarpredict.conditional.original.posterior,'Enable','off');
   set(controls.bvarpredict.conditional.annual.posterior,'Enable','off');
   set(controls.bvarpredict.conditional.original.predevent,'Enable','off');
   set(controls.bvarpredict.conditional.annual.predevent,'Enable','off');
   set(controls.bvarmodesty.posterior,'Enable','off','UserData','');
   set(controls.bvarpostdensitypsi,'Enable','off');
   set(controls.bvarpsimeanconvergence,'Enable','off');
   set(controls.bvarpsimedianconvergence,'Enable','off');
   set(controls.bvarrawdrawsomega,'Enable','off');
   set(controls.bvaromegameanconvergence,'Enable','off');
   set(controls.bvaromegamedianconvergence,'Enable','off');
   set(controls.bvarpostdensityomega,'Enable','off');
   set(controls.bvarrawdrawspi,'Enable','off');
   set(controls.bvarpimeanconvergence,'Enable','off');
   set(controls.bvarpimedianconvergence,'Enable','off');
   set(controls.bvarpostdensitypi,'Enable','off');
   set(controls.bvarmarglike,'Enable','off');
   set(controls.bvarmodemenu,'Enable','off');
   set(controls.bvarpriordensitypsi,'Enable','off');
   set(controls.bvarpriordensitypi,'Enable','off');
   set(controls.bvarpriordensityomega,'Enable','off');
%   set(controls.bvarforecast.postmode,'Enable','off');
%   set(controls.bvarforecast.annpostmode,'Enable','off');
   set(controls.bvarpredict.unconditional.original.postmode,'Enable','off');
   set(controls.bvarpredict.unconditional.annual.postmode,'Enable','off');
   set(controls.bvarpredict.conditional.original.postmode,'Enable','off');
   set(controls.bvarpredict.conditional.annual.postmode,'Enable','off');
   set(controls.bvarmodesty.postmode,'Enable','off','UserData','');
   set(controls.bvarmoderesultsmenu,'Enable','off');
end;
if FileExist(DSGEModel.PriorFile)==1;
   set(controls.priorinfo,'Enable','on');
else;
   set(controls.priorinfo,'Enable','off');
end;
%
VerifyStateCondControls(DSGEModel,controls);
%
if FileExist(FixFilePath([pwd '\tmp\AiMErrorData.mat']))==1;
   delete(FixFilePath([pwd '\tmp\AiMErrorData.mat']));
end;

%
% end of YADAEnableControls.m
%
