function DecompToolsMenuFunctions(selector,maingui)
% DecompToolsMenuFunctions: switch function for running decomposition functions on the tools menu.
%
% USAGE:
%
%       DecompToolsMenuFunctions(selector,maingui)
%
% REQUIRED INPUT: selector (string) that determines which sub-function should be applied.
%
% OPTIONAL INPUT: maingui (handle) to the YADA GUI.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2025 European Central Bank.
%
%                       First version: May 10, 2010.
%                        This version: January 9, 2025.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 11-05-2010: Updated the documentation.
%
% * 08-07-2010: Changed headers on About dialogs when "mcode" or "kalmanstatus" reports problems.
%
% * 05-08-2010: Added code that allows the observed variable decompositions to be performed with
%               constrained filters for posterior mode values.
%
% * 06-08-2010: Added code that allows the observed variable decompositions to be performed with
%               constrained filters for initial values, as well as code for state variable
%               decompositions at posterior mode and initial values.
%
% * 17-12-2010: The function now supports the Klein and Sims DSGE model solvers.
%
% * 05-01-2011: Updated the documentation.
%
% * 11-01-2011: Made sure that "ModeFile" supports unix and mac paths.
%
% * 12-01-2011: Added support for unix and mac paths.
%
% * 17-01-2011: Started work on the correlation decompositions.
%
% * 18-01-2011: Finished the code on correlation decompositions for the observed and state
%               variables of the DSGE model.
%
% * 19-01-2011: Updated the documentation.
%
% * 02-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 30-08-2013: Began work on using the exact variance decompositions where state variable uncertainty
%               is NOT decomposed into its sources.
%
% * 02-09-2013: Continued work on the exact variance decompositions.
%
% * 16-09-2013: Took into account that the forecast error variance decompositions for the original data
%               now also produces long-run decompositions.
%
% * 28-01-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 18-03-2015: Switched to the new IsHandle function.
%
% * 02-09-2015: Fixed the information displayed when the kalmanstatus is -1.
%
% * 27-01-2016: Remember Shoah.
%
% * 21-03-2017: Updated the documentation.
%
% * 03-05-2017: Added selectors for state variable conditional variance decompositions.
%
% * 04-05-2017: Finished coding the posterior mode and initial values cases for the cvd's of state variables.
%               Began work on the posterior draws option.
%
% * 05-05-2017: Finished the posterior and prior draws options of the conditional variance decompositions for
%               the state variables.
%
% * 23-08-2017: Took into account that LoadDSGEPosteriorDraws now provides the output variable "Weights".
%
% * 25-08-2017: Took into account that "HFEDDistribution", "DSGEObsVarDecompDistribution",
%               "DSGEVarDecDistribution", "DSGECVDDistribution", and "DSGEStateCVDDistribution"
%               now require the "Weights" input variable.
%
% * 15-09-2017: Updated the documentation.
%
% * 13-12-2017: Made sure that a subset of prior draws can be used when the model includes a system prior.
%
% * 15-12-2017: Began work on adding variance decompositions for state variables.
%
% * 19-12-2017: Took into account that DSGEVarianceDecompostion has been renamed DSGEVarianceDecomposition,
%               and that DSGECondVarianceDecompostion is now called DSGECondVarianceDecomposition.
%
% * 20-12-2017: Added the initial values case for variance decompositions for state variables. Began work
%               on the posterior draws case.
%
% * 21-12-2017: Finished the posterior draws case.
%
% * 05-01-2018: Updated the documentation.
%
% * 01-08-2018: The function supports user written model solver function.
%
% * 15-08-2018: Took into account the new error handling via the function YADALastError.
%
% * 29-08-2018: Updated the documentation.
%
% * 25-10-2018: Made sure that the name of the prior draws file reflects using a system prior.
%
% * 23-01-2019: Updated the documentation.
%
% * 27-02-2019: The function now calls "DSGEObservationWeightsThetaDiffuse" for the observation weight
%               calculations when using diffuse initialization of the state variables.
%
% * 10-01-2020: Updated the documentation.
%
% * 09-12-2020: Increased the size of the About dialog for ErrorStr.
%
% * 26-01-2021: Updated the documentation.
%
% * 05-03-2021: The state variable decomposition results can now be directly stored to file.
%
% * 08-03-2021: The observed variable decompositions at initial values and at posterior mode values
%               can now be saved to file.
%
% * 06-01-2022: Updated the documentation.
%
% * 05-01-2023: Updated the documentation.
%
% * 24-01-2023: Added driver support for the observed variable decomposition
%               when using a regular Kalman filter/smoother and the constrainted
%               filter.
%
% * 25-01-2023: Added driver support for the observed variable decompositions
%               when using the regular Kalman filter/smoother and annualized
%               data.
%
% * 06-02-2023: Added driver support for the correlation and spectral decompositions
%               of the observed and the state variables at the posterior mode values.
%               Driver support was also added for the conditional variance decompositions
%               at posterior mode for the original data, the annualized data and the
%               levels data.
%
% * 10-02-2023: Added driver support for the observation weight decompositions of the
%               state variables and of the structural shocks at the posterior mode values.
%
% * 21-02-2023: Added the "maingui" input variable.
%
% * 03-07-2023: Corrected text describing the dimension of the correlation decomposition output.
%
% * 11-12-2023: Began work on the observed variable decompositions using prior and posterior draws.
%
% * 12-12-2023: Continued work on the observed variable decompositions using prior and posterior draws.
%
% * 13-12-2023: Finished the observed variable decompositions using prior and posterior draws.
%
% * 18-01-2024: Updated the documentation.
%
% * 28-02-2024: The observed variable decomposition at the initial values and the posterior mode values
%               can now save the annualized data when this case is executed.
%
% * 15-03-2024: Changed the lower vertical position of the TextGUI function from 32 pixels to 50.
%
% * 09-01-2025: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% collect some inportant data structures
%
if nargin==1;
   maingui = findobj('Type','figure','Tag','YADA');
end;
controls = get(maingui,'UserData');
CurrINI = get(controls.filemenu,'UserData');
DSGEModel = get(controls.open,'UserData');
OrigDSGEModel = get(controls.openmenu,'UserData');
if MatlabNumber<7;
   lasterr = '';
end;
%
switch selector
   case 'HFEDecompInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view graphs of the forecast error decompositions before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Forecast Error Decompositions - Initial Values',450,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
%               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
               %
               % Try to calculate state variables. First, however, the code needs to check if a unique convergent
               % solution exists.
               %
               [StateVarStructure,mcode,kalmanstatus] = CalculateDSGEStateVariables(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,0,0,'');
               if (mcode==1)&(kalmanstatus==0);
                  %
                  % we're OK
                  %
                  if strcmp(lower(DSGEModel.DataFrequency(1,1)),'q')==1;
                     FreqStr = 'quarter';
                     DefaultOption = 4;
                  elseif strcmp(lower(DSGEModel.DataFrequency(1,1)),'m')==1;
                     FreqStr = 'month';
                     DefaultOption = 12;
                  else;
                     FreqStr = 'year';
                     DefaultOption = 1;
                  end;
                  %
                  % select horizon for historical decomposition
                  %
                  SelectionOptions = ['1 ' FreqStr];
                  for i=2:max(20,floor(DSGEModel.T/4));
                     SelectionOptions = strvcat(SelectionOptions,[num2str(i) ' ' FreqStr 's']);
                  end;
                  %
                  [action,SelectedOption] = SelectionDlg(SelectionOptions,DefaultOption,'Select forecast horizon','Forecast Horizon Selection','Forecast Error Decompositions - Initial Values','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     %
                     % Now determine the horizon
                     %
                     ForecastHorizon = strrep(SelectionOptions(SelectedOption,:),FreqStr,'');
                     ForecastHorizon = str2num(StringTrim(strrep(ForecastHorizon,'s','')));
                     %
                     % compute the historical decomposition.
                     %
                     HistDecompStructure = DSGEHistDecompFcn(StateVarStructure.Y,StateVarStructure.X,StateVarStructure.A,StateVarStructure.H,StateVarStructure.F,StateVarStructure.B0,StateVarStructure.Ksitt,StateVarStructure.KsitT,StateVarStructure.etatT,StateVarStructure.wthT,ForecastHorizon);
                     if isempty(HistDecompStructure)==0;
                        HistDecompStructure.R = StateVarStructure.R;
                        HistDecompStructure.ForecastHorizon = ForecastHorizon;
                        HistDecompStructure.FreqStr = strcat(upper(FreqStr(1,1)),FreqStr(1,2:length(FreqStr)));
                        HistDecompDLG('init',CurrINI,DSGEModel,HistDecompStructure,'Initial Values');
                     end;
                  end;
               elseif (mcode==1)&(kalmanstatus~=0);
                  if kalmanstatus==1;
                     txt = 'The state variables are not stationary at the initial values.';
                  else;
                     txt = 'The covariance matrix of the forecast of the observed variables in period t conditional on data until t-1 is not positive definite for some time period t. This implies that the log-likelihood value is a NaN (or a complex number) in Matlab.';
                  end;
                  About(txt,'information','Forecast Error Decompositions - Initial Values',200,500,CurrINI);
               elseif mcode~=1;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Forecast Error Decompositions - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'HFEDecompPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,'Forecast Error Decompositions - Prior Distribution',500,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the posterior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection','Forecast Error Decompositions - Prior Distribution','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            %
            % select the forecast horizon
            %
            if strcmp(lower(DSGEModel.DataFrequency(1,1)),'q')==1;
               FreqStr = 'quarter';
               DefaultOption = 4;
            elseif strcmp(lower(DSGEModel.DataFrequency(1,1)),'m')==1;
               FreqStr = 'month';
               DefaultOption = 12;
            else;
               FreqStr = 'year';
               DefaultOption = 1;
            end;
            %
            % select horizon for historical decomposition
            %
            SelectionOptions = ['1 ' FreqStr];
            for i=2:max(20,floor(DSGEModel.T/4));
               SelectionOptions = strvcat(SelectionOptions,[num2str(i) ' ' FreqStr 's']);
            end;
            %
            [action,SelectedOption] = SelectionDlg(SelectionOptions,DefaultOption,'Select forecast horizon','Forecast Horizon Selection','Forecast Error Decompositions - Prior Distribution','','',CurrINI);
            if strcmp(lower(action),'ok')==1;
               %
               % Now determine the horizon
               %
               ForecastHorizon = strrep(SelectionOptions(SelectedOption,:),FreqStr,'');
               ForecastHorizon = str2num(StringTrim(strrep(ForecastHorizon,'s','')));
               %
               % First we check if the calculations have already been performed
               %
               if HFEDExist(DSGEModel,ForecastHorizon,NumPriorDraws,NumPriorDraws,1,0)==1;
                  txt = 'YADA has located results for the historical forecast error decompositions on disk. Would you like to use these results?';
                  answer = Query(txt,'question',150,'Forecast Error Decompositions - Prior Distribution',450,'no',CurrINI);
               else;
                  answer = 'No';
               end;
               if strcmp(lower(answer),'yes')==1;
                  DoneCalc = 1;
               else;
                  %
                  % compute the historical forecast error decoimpositions for the posterior draws
                  %
                  DoneCalc = DSGEForecastErrorDecomposition(theta,thetaDraws',thetaPositions,ModelParameters,DSGEModel,CurrINI,ForecastHorizon,NumPriorDraws,1,0);
               end;
               %
               % check if we should show any results
               %
               if DoneCalc==1;
                  %
                  % compute the distribution
                  %
                  HistDecompStructure = HFEDDistribution(DSGEModel,CurrINI,ForecastHorizon,NumPriorDraws,NumPriorDraws,1,0,[]);
                  %
                  % ask if the user wants to save the results to disk
                  %
                  txt = 'Would you like to save the historical forecast error decompositions to file?';
                  answer = Query(txt,'question',140,'Save - Forecast Error Decompositions',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     OldHistDecompStructure = HistDecompStructure;
                     HistDecompStructure = rmfield(HistDecompStructure,{'R' 'KeepVar'});
                     YNames = DSGEModel.VariableNames;
                     ShockNames = DSGEModel.StateShockNames(OldHistDecompStructure.KeepVar,:);
                     file = FixFilePath([DSGEModel.OutputDirectory '\HistForecastErrorDecompPriorDist-' int2str(ForecastHorizon) '-' num2str(NumPriorDraws,'%0.0f') '.mat']);
                     save(file,'YNames','ShockNames','HistDecompStructure');
                     %
                     % create a matlab file to read the data
                     %
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\HFEDPriorDist' int2str(ForecastHorizon) num2str(NumPriorDraws,'%0.0f') '.m']);
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                     fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                     fprintf(fid,'YNames = DataStructure.YNames;\n');
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                     fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                     fprintf(fid,'%%\n%% structure with fields epstth holding the forecast errors,\n%% with share wthT due to the measurement error, KsiErr due\n%% to the state error, and etathT due to the economic shocks.\n%% In addition, the structure has fields ForecastHorizon, and\n%% Quantiles with the percentile data.\n%%\n');
                     fprintf(fid,'HistDecompStructure = DataStructure.HistDecompStructure;\n');
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     txt = ['The historical forecast error decomposition data have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), and HistDecompStructure (a structure with posterior mean and quantile data for the decomposition). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                     About(txt,'information','Forecast Error Decompositions - Prior Distribution',200,500,CurrINI);
                     HistDecompStructure = OldHistDecompStructure;
                  end;
                  HistDecompStructure.FreqStr = strcat(upper(FreqStr(1,1)),FreqStr(1,2:length(FreqStr)));
                  %
                  % display the results
                  %
                  HistDecompDLG('init',CurrINI,DSGEModel,HistDecompStructure,'Prior Distribution');
               else;
                  DSGEModel = OldDSGEModel;
               end;
            else;
               DSGEModel = OldDSGEModel;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'HFEDecompPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%            else;
%               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            if strcmp(lower(DSGEModel.DataFrequency(1,1)),'q')==1;
               FreqStr = 'quarter';
               DefaultOption = 4;
            elseif strcmp(lower(DSGEModel.DataFrequency(1,1)),'m')==1;
               FreqStr = 'month';
               DefaultOption = 12;
            else;
               FreqStr = 'year';
               DefaultOption = 1;
            end;
            %
            % select horizon for historical decomposition
            %
            SelectionOptions = ['1 ' FreqStr];
            for i=2:max(20,floor(DSGEModel.T/4));
               SelectionOptions = strvcat(SelectionOptions,[num2str(i) ' ' FreqStr 's']);
            end;
            %
            [action,SelectedOption] = SelectionDlg(SelectionOptions,DefaultOption,'Select forecast horizon','Forecast Horizon Selection','Forecast Error Decompositions - Posterior Mode','','',CurrINI);
            if strcmp(lower(action),'ok')==1;
               %
               % Now determine the horizon
               %
               ForecastHorizon = strrep(SelectionOptions(SelectedOption,:),FreqStr,'');
               ForecastHorizon = str2num(StringTrim(strrep(ForecastHorizon,'s','')));
               %
               % calculate all the state variables, shocks, etc
               %
               StateVarStructure = CalculateDSGEStateVariables(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,0,0,'');
               %
               % compute the historical decomposition.
               %
               HistDecompStructure = DSGEHistDecompFcn(StateVarStructure.Y,StateVarStructure.X,StateVarStructure.A,StateVarStructure.H,StateVarStructure.F,StateVarStructure.B0,StateVarStructure.Ksitt,StateVarStructure.KsitT,StateVarStructure.etatT,StateVarStructure.wthT,ForecastHorizon);
               if isempty(HistDecompStructure)==0;
                  HistDecompStructure.R = StateVarStructure.R;
                  HistDecompStructure.ForecastHorizon = ForecastHorizon;
                  HistDecompStructure.FreqStr = strcat(upper(FreqStr(1,1)),FreqStr(1,2:length(FreqStr)));
                  HistDecompDLG('init',CurrINI,DSGEModel,HistDecompStructure,'Posterior Mode');
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'HFEDecompPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%               FirstPeriod = ModeData.DSGEModel.FirstPeriod;
%               LastPeriod = ModeData.DSGEModel.LastPeriod;
%            else;
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Forecast Error Decomposition','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            %
            %
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  NumDraws = length(LogPost);
                  clear('PostSample','LogPost','AcceptedDraws');
                  drawnow;
                  %
                  % select which posterior draws to use
                  %
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumDraws,:);
                  NumDraws = NumDraws-NumBurnin;
                  %
                  % check which draws we should use
                  %
                  if DSGEModel.PosteriorSampler<=7;
                     UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                     if length(UseDraws)<NumDraws;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        UsedDraws = length(UseDraws);
                     else;
                        UsedDraws = NumDraws;
                     end;
                  else;
                     UsedDraws = NumDraws;
                  end;
                  %
                  % select the forecast horizon
                  %
                  if strcmp(lower(DSGEModel.DataFrequency(1,1)),'q')==1;
                     FreqStr = 'quarter';
                     DefaultOption = 4;
                  elseif strcmp(lower(DSGEModel.DataFrequency(1,1)),'m')==1;
                     FreqStr = 'month';
                     DefaultOption = 12;
                  else;
                     FreqStr = 'year';
                     DefaultOption = 1;
                  end;
                  %
                  % select horizon for historical decomposition
                  %
                  SelectionOptions = ['1 ' FreqStr];
                  for i=2:max(20,floor(DSGEModel.T/4));
                     SelectionOptions = strvcat(SelectionOptions,[num2str(i) ' ' FreqStr 's']);
                  end;
                  %
                  [action,SelectedOption] = SelectionDlg(SelectionOptions,DefaultOption,'Select forecast horizon','Forecast Horizon Selection','Forecast Error Decompositions - Distribution','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     %
                     % Now determine the horizon
                     %
                     ForecastHorizon = strrep(SelectionOptions(SelectedOption,:),FreqStr,'');
                     ForecastHorizon = str2num(StringTrim(strrep(ForecastHorizon,'s','')));
                     %
                     % First we check if the calculations have already been performed
                     %
                     if HFEDExist(DSGEModel,ForecastHorizon,UsedDraws,NumDraws,CurrChain,1)==1;
                        txt = 'YADA has located results for the historical forecast error decompositions on disk. Would you like to use these results?';
                        answer = Query(txt,'question',150,'Forecast Error Decompositions - Distribution',450,'no',CurrINI);
                     else;
                        answer = 'No';
                     end;
                     if strcmp(lower(answer),'yes')==1;
                        DoneCalc = 1;
                     else;
                        %
                        % compute the historical forecast error decoimpositions for the posterior draws
                        %
                        DoneCalc = DSGEForecastErrorDecomposition(theta,thetaPostSample,thetaPositions,ModelParameters,DSGEModel,CurrINI,ForecastHorizon,NumDraws,CurrChain,1);
                     end;
                     %
                     % clear the posterior draws
                     %
                     clear('thetaPostSample');
                     %
                     % check if we should show any results
                     %
                     if DoneCalc==1;
                        %
                        % compute the distribution
                        %
                        HistDecompStructure = HFEDDistribution(DSGEModel,CurrINI,ForecastHorizon,UsedDraws,NumDraws,CurrChain,1,Weights);
                        %
                        % ask if the user wants to save the results to disk
                        %
                        txt = 'Would you like to save the historical forecast error decompositions to file?';
                        answer = Query(txt,'question',140,'Save - Forecast Error Decompositions',500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           OldHistDecompStructure = HistDecompStructure;
                           HistDecompStructure = rmfield(HistDecompStructure,{'R' 'KeepVar'});
                           YNames = DSGEModel.VariableNames;
                           ShockNames = DSGEModel.StateShockNames(OldHistDecompStructure.KeepVar,:);
                           file = FixFilePath([DSGEModel.OutputDirectory '\HistForecastErrorDecompDist-' int2str(ForecastHorizon) '-' int2str(CurrChain) '-' int2str(UsedDraws) '-' int2str(NumDraws) '.mat']);
                           save(file,'YNames','ShockNames','HistDecompStructure');
                           %
                           % create a matlab file to read the data
                           %
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\HFEDDist' int2str(ForecastHorizon) int2str(CurrChain) int2str(UsedDraws) int2str(NumDraws) '.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                           fprintf(fid,'YNames = DataStructure.YNames;\n');
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                           fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                           fprintf(fid,'%%\n%% structure with fields epstth holding the forecast errors,\n%% with share wthT due to the measurement error, KsiErr due\n%% to the state error, and etathT due to the economic shocks.\n%% In addition, the structure has fields ForecastHorizon, and\n%% Quantiles with the percentile data.\n%%\n');
                           fprintf(fid,'HistDecompStructure = DataStructure.HistDecompStructure;\n');
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                           txt = ['The historical forecast error decomposition data have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), and HistDecompStructure (a structure with posterior mean and quantile data for the decomposition). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                           About(txt,'information','Forecast Error Decompositions - Distribution',200,500,CurrINI);
                           HistDecompStructure = OldHistDecompStructure;
                        end;
                        HistDecompStructure.FreqStr = strcat(upper(FreqStr(1,1)),FreqStr(1,2:length(FreqStr)));
                        %
                        % display the results
                        %
                        HistDecompDLG('init',CurrINI,DSGEModel,HistDecompStructure,'Posterior Distribution');
                     end;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ObsWeightDecompInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view graphs of the observation weight decompositions before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Observation Weight Decompositions - Initial Values',450,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
               if gcbo==controls.obsweights.decomp.states.initialvalues;
                  VarStr = 'State Variables';
                  VarType = 1;
               else;
                  VarStr = 'Shocks';
                  VarType = 2;
               end;
               if MatlabNumber>=8.0;
                  try;
                     if DSGEModel.UseDoublingAlgorithm<=3;
                        [StateDecomp,mcode,kalmanstatus] = DSGEObservationWeightsTheta(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                     else;
                        [StateDecomp,mcode,kalmanstatus] = DSGEObservationWeightsThetaDiffuse(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                     end;
                  catch ME;
                     WaitHandle = findobj('Type','figure','Tag','WaitDLG');
                     if (isempty(WaitHandle)==0)&(IsHandle(WaitHandle)==1);
                        WaitControls = get(WaitHandle,'UserData');
                        set(WaitControls.text,'UserData','done');
                        delete(WaitHandle);
                        drawnow;
                        pause(0.02);
                     end;
                     StateDecomp = [];
                     mcode = 1;
                     kalmanstatus = 0;
                     txt = 'There was an error running the observation weight function. The most likely reason is that matlab ran out of memory.';
                     if isempty(YADALastError(ME))==0;
                        txt = [txt ' YADA caught the following message: ' YADALastError(ME)];
                     end;
                     About(txt,'information','Observation Weight Decompositions - Initial Values',400,500,CurrINI);
                  end;
               else;
                  try;
                     if DSGEModel.UseDoublingAlgorithm<=3;
                        [StateDecomp,mcode,kalmanstatus] = DSGEObservationWeightsTheta(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                     else;
                        [StateDecomp,mcode,kalmanstatus] = DSGEObservationWeightsThetaDiffuse(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                     end;
                  catch;
                     WaitHandle = findobj('Type','figure','Tag','WaitDLG');
                     if (isempty(WaitHandle)==0)&(IsHandle(WaitHandle)==1);
                        WaitControls = get(WaitHandle,'UserData');
                        set(WaitControls.text,'UserData','done');
                        delete(WaitHandle);
                        drawnow;
                        pause(0.02);
                     end;
                     StateDecomp = [];
                     mcode = 1;
                     kalmanstatus = 0;
                     txt = 'There was an error running the observation weight function. The most likely reason is that matlab ran out of memory.';
                     if isempty(YADALastError)==0;
                        txt = [txt ' YADA caught the following message: ' YADALastError];
                     end;
                     About(txt,'information','Observation Weight Decompositions - Initial Values',400,500,CurrINI);
                  end;
               end;
               if (mcode==1)&(kalmanstatus==0);
                  if isempty(StateDecomp)==0;
                     %
                     % save the results to disk
                     %
                     txt = ['Would you like to save the observation weight decompositions of the ' lower(VarStr) ' at initial values to disk?'];
                     answer = Query(txt,'question',200,'Save - Observation Weight Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        if VarType==1;
                           StateForecastDecomp = StateDecomp.StateForecastDecomp;
                           StateUpdateDecomp = StateDecomp.StateUpdateDecomp;
                           StateSmoothDecomp = StateDecomp.StateSmoothDecomp;
                           Ksitt1 = StateDecomp.Ksitt1;
                           Ksitt = StateDecomp.Ksitt;
                           KsitT = StateDecomp.KsitT;
                           YNames = DSGEModel.VariableNames;
                           StateVariableNames = StateDecomp.VariableNames;
                           DateVector = StateDecomp.DateVector;
                           %
                           file = FixFilePath([DSGEModel.OutputDirectory '\StateVariableObsDecomp-InitialValues.mat']);
                           save(file,'StateForecastDecomp','StateUpdateDecomp','StateSmoothDecomp','Ksitt1','Ksitt','KsitT','YNames','StateVariableNames','DateVector');
                           %
                           % create the script file
                           %
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\SVObsDecInitVal.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% string matrix with names of the observed variables\n%%\n');
                           fprintf(fid,'YNames = DataStructure.YNames;\n');
                           fprintf(fid,'%%\n%% string matrix with names of the state variables\n%%\n');
                           fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                           fprintf(fid,'%%\n%% decompositions of the forecast estimates of the state variables into observed\n%% variables and the initial values of the state variables\n%%\n');
                           fprintf(fid,'StateForecastDecomp = DataStructure.StateForecastDecomp;\n');
                           fprintf(fid,'%%\n%% decompositions of the update estimates of the state variables into observed\n%% variables and the initial values of the state variables\n%%\n');
                           fprintf(fid,'StateUpdateDecomp = DataStructure.StateUpdateDecomp;\n');
                           fprintf(fid,'%%\n%% decompositions of the smooth estimates of the state variables into observed\n%% variables and the initial values of the state variables\n%%\n');
                           fprintf(fid,'StateSmoothDecomp = DataStructure.StateSmoothDecomp;\n');
                           fprintf(fid,'%%\n%% forecast estimates of the state variables\n%%\n');
                           fprintf(fid,'Ksitt1 = DataStructure.Ksitt1;\n');
                           fprintf(fid,'%%\n%% update estimates of the state variables\n%%\n');
                           fprintf(fid,'Ksitt = DataStructure.Ksitt;\n');
                           fprintf(fid,'%%\n%% smooth estimates of the state variables\n%%\n');
                           fprintf(fid,'KsitT = DataStructure.KsitT;\n');
                           fprintf(fid,'%%\n%% vector with numeric dates\n%%\n');
                           fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                           %
                           txt = ['The observation weight decompositions of the state variables at initial values have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 9 entries: YNames (string matrix with the names of the observed variables), StateVariableNames (string matrix with the state variable names), StateForecastDecomp (3D matrix with the decompositions for the forecast estimates of the state variables into the observed variables and the initial condition of the state variables), StateUpdateDecomp (3D matrix with the decompositions for the update estimates of the state variables into the observed variables and the initial condition of the state variables), StateSmoothDecomp (3D matrix with the decompositions for the smooth estimates of the state variables into the observed variables and the initial condition of the state variables), Ksitt1 (forecast estimates of the state variables), Ksitt (update estimates of the state variables), KsitT (smooth estimates of the state variables), and DateVector (vector with dates for the variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                           About(txt,'information','Observation Weight Decompositions - Initial Values',400,500,CurrINI);
                        else;
                           ShockUpdateDecomp = StateDecomp.ShockUpdateDecomp;
                           ShockSmoothDecomp = StateDecomp.ShockSmoothDecomp;
                           etatt = StateDecomp.etatt;
                           etatT = StateDecomp.etatT;
                           YNames = DSGEModel.VariableNames;
                           ShockNames = StateDecomp.VariableNames;
                           DateVector = StateDecomp.DateVector;
                           %
                           file = FixFilePath([DSGEModel.OutputDirectory '\ShockObsDecomp-InitialValues.mat']);
                           save(file,'ShockUpdateDecomp','ShockSmoothDecomp','etatt','etatT','YNames','ShockNames','DateVector');
                           %
                           % create the script file
                           %
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\SObsDecInitVal.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% string matrix with names of the observed variables\n%%\n');
                           fprintf(fid,'YNames = DataStructure.YNames;\n');
                           fprintf(fid,'%%\n%% string matrix with names of the shocks\n%%\n');
                           fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                           fprintf(fid,'%%\n%% decompositions of the update estimates of the shocks into observed\n%% variables and the initial values of the state variables\n%%\n');
                           fprintf(fid,'ShockUpdateDecomp = DataStructure.ShockUpdateDecomp;\n');
                           fprintf(fid,'%%\n%% decompositions of the smooth estimates of the shocks into observed\n%% variables and the initial values of the state variables\n%%\n');
                           fprintf(fid,'ShockSmoothDecomp = DataStructure.ShockSmoothDecomp;\n');
                           fprintf(fid,'%%\n%% update estimates of the shocks\n%%\n');
                           fprintf(fid,'etatt = DataStructure.etatt;\n');
                           fprintf(fid,'%%\n%% smooth estimates of the shock\n%%\n');
                           fprintf(fid,'etatT = DataStructure.etatT;\n');
                           fprintf(fid,'%%\n%% vector with numeric dates\n%%\n');
                           fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                           %
                           txt = ['The observation weight decompositions of the shocks at initial values have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 7 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the shock names), ShockUpdateDecomp (3D matrix with the decompositions for the update estimates of the shocks into the observed variables and the initial condition of the state variables), ShockSmoothDecomp (3D matrix with the decompositions for the smooth estimates of the shocks into the observed variables and the initial condition of the state variables), etatt (update estimates of the shocks), etatT (smooth estimates of the shocks), and DateVector (vector with dates for the variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                           About(txt,'information','Observation Weight Decompositions - Initial Values',400,500,CurrINI);
                        end;
                     end;
                     %
                     % we can now display the results
                     %
                     ObsWeightDecompDLG('init',StateDecomp,VarStr,'Initial Values',DSGEModel,CurrINI);
                  end;
               elseif (mcode==1)&(kalmanstatus~=0);
                  if kalmanstatus==1;
                     txt = 'The state variables are not stationary at the initial values.';
                  else;
                     txt = 'The covariance matrix of the forecast of the observed variables in period t conditional on data until t-1 is not positive definite for some time period t. This implies that the log-likelihood value is a NaN (or a complex number) in Matlab.';
                  end;
                  About(txt,'information','Observation Weight Decompositions - Initial Values',200,500,CurrINI);
               elseif mcode~=1;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Observation Weight Decompositions - Initial Values',200,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ObsWeightDecompPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            %
            if DSGEModel.RunDriver==0;
               if gcbo==controls.obsweights.decomp.states.postmode;
                  VarStr = 'State Variables';
                  VarType = 1;
               elseif gcbo==controls.obsweights.decomp.shocks.postmode;
                  VarStr = 'Shocks';
                  VarType = 2;
               end;
            else;
               if strcmp(lower(DSGEModel.answers{1}),'state')==1;
                  VarStr = 'State Variables';
                  VarType = 1;
               else;
                  VarStr = 'Shocks';
                  VarType = 2;
               end;
            end;
            %
            % compute the decompositions
            %
            if MatlabNumber>=8.0;
               try;
                  if DSGEModel.UseDoublingAlgorithm<=3;
                     StateDecomp = DSGEObservationWeightsTheta(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                  else;
                     StateDecomp = DSGEObservationWeightsThetaDiffuse(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                  end;
               catch ME;
                  WaitHandle = findobj('Type','figure','Tag','WaitDLG');
                  if (isempty(WaitHandle)==0)&(IsHandle(WaitHandle)==1);
                     WaitControls = get(WaitHandle,'UserData');
                     set(WaitControls.text,'UserData','done');
                     delete(WaitHandle);
                     drawnow;
                     pause(0.02);
                  end;
                  StateDecomp = [];
                  if DSGEModel.RunDriver==0;
                     txt = 'There was an error running the observation weight function. The most likely reason is that matlab ran out of memory.';
                     if isempty(YADALastError(ME))==0;
                        txt = [txt ' YADA caught the following message: ' YADALastError(ME)];
                     end;
                     About(txt,'information','Observation Weight Decompositions - Posterior Mode',400,500,CurrINI);
                  else;
                     SetLogText(strvcat('There was an error running the obs. weight function.','The most likely reason is not enough memory.',' '));
                  end;
               end;
            else;
               try;
                  if DSGEModel.UseDoublingAlgorithm<=3;
                     StateDecomp = DSGEObservationWeightsTheta(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                  else;
                     StateDecomp = DSGEObservationWeightsThetaDiffuse(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                  end;
               catch;
                  WaitHandle = findobj('Type','figure','Tag','WaitDLG');
                  if (isempty(WaitHandle)==0)&(IsHandle(WaitHandle)==1);
                     WaitControls = get(WaitHandle,'UserData');
                     set(WaitControls.text,'UserData','done');
                     delete(WaitHandle);
                     drawnow;
                     pause(0.02);
                  end;
                  StateDecomp = [];
                  if DSGEModel.RunDriver==0;
                     txt = 'There was an error running the observation weight function. The most likely reason is that matlab ran out of memory.';
                     if isempty(YADALastError)==0;
                        txt = [txt ' YADA caught the following message: ' YADALastError];
                     end;
                     About(txt,'information','Observation Weight Decompositions - Posterior Mode',400,500,CurrINI);
                  else;
                     SetLogText(strvcat('There was an error running the obs. weight function.','The most likely reason is not enough memory.',' '));
                  end;
               end;
            end;
            if isempty(StateDecomp)==0;
               %
               % save the results to disk
               %
               if DSGEModel.RunDriver==0;
                  txt = ['Would you like to save the observation weight decompositions of the ' lower(VarStr) ' at posterior mode to disk?'];
                  answer = Query(txt,'question',200,'Save - Observation Weight Decompositions',500,'no',CurrINI);
               else;
                  answer = DSGEModel.answers{2};
               end;
               if strcmp(lower(answer),'yes')==1;
                  if DSGEModel.RunDriver==1;
                     SetLogText(strvcat('* Saving results to: ',['     ' DSGEModel.OutputDirectory]));
                  end;
                  if VarType==1;
                     StateForecastDecomp = StateDecomp.StateForecastDecomp;
                     StateUpdateDecomp = StateDecomp.StateUpdateDecomp;
                     StateSmoothDecomp = StateDecomp.StateSmoothDecomp;
                     Ksitt1 = StateDecomp.Ksitt1;
                     Ksitt = StateDecomp.Ksitt;
                     KsitT = StateDecomp.KsitT;
                     YNames = DSGEModel.VariableNames;
                     StateVariableNames = StateDecomp.VariableNames;
                     DateVector = StateDecomp.DateVector;
                     %
                     file = FixFilePath([DSGEModel.OutputDirectory '\StateVariableObsDecomp-PostMode.mat']);
                     save(file,'StateForecastDecomp','StateUpdateDecomp','StateSmoothDecomp','Ksitt1','Ksitt','KsitT','YNames','StateVariableNames','DateVector');
                     %
                     % create the script file
                     %
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\SVObsDecPostMode.m']);
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                     fprintf(fid,'%%\n%% string matrix with names of the observed variables\n%%\n');
                     fprintf(fid,'YNames = DataStructure.YNames;\n');
                     fprintf(fid,'%%\n%% string matrix with names of the state variables\n%%\n');
                     fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                     fprintf(fid,'%%\n%% decompositions of the forecast estimates of the state variables into observed\n%% variables and the initial values of the state variables\n%%\n');
                     fprintf(fid,'StateForecastDecomp = DataStructure.StateForecastDecomp;\n');
                     fprintf(fid,'%%\n%% decompositions of the update estimates of the state variables into observed\n%% variables and the initial values of the state variables\n%%\n');
                     fprintf(fid,'StateUpdateDecomp = DataStructure.StateUpdateDecomp;\n');
                     fprintf(fid,'%%\n%% decompositions of the smooth estimates of the state variables into observed\n%% variables and the initial values of the state variables\n%%\n');
                     fprintf(fid,'StateSmoothDecomp = DataStructure.StateSmoothDecomp;\n');
                     fprintf(fid,'%%\n%% forecast estimates of the state variables\n%%\n');
                     fprintf(fid,'Ksitt1 = DataStructure.Ksitt1;\n');
                     fprintf(fid,'%%\n%% update estimates of the state variables\n%%\n');
                     fprintf(fid,'Ksitt = DataStructure.Ksitt;\n');
                     fprintf(fid,'%%\n%% smooth estimates of the state variables\n%%\n');
                     fprintf(fid,'KsitT = DataStructure.KsitT;\n');
                     fprintf(fid,'%%\n%% vector with numeric dates\n%%\n');
                     fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     %
                     if DSGEModel.RunDriver==0;
                        txt = ['The observation weight decompositions of the state variables at posterior mode have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 9 entries: YNames (string matrix with the names of the observed variables), StateVariableNames (string matrix with the state variable names), StateForecastDecomp (3D matrix with the decompositions for the forecast estimates of the state variables into the observed variables and the initial condition of the state variables), StateUpdateDecomp (3D matrix with the decompositions for the update estimates of the state variables into the observed variables and the initial condition of the state variables), StateSmoothDecomp (3D matrix with the decompositions for the smooth estimates of the state variables into the observed variables and the initial condition of the state variables), Ksitt1 (forecast estimates of the state variables), Ksitt (update estimates of the state variables), KsitT (smooth estimates of the state variables), and DateVector (vector with dates for the variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Observation Weight Decompositions - Posterior Mode',400,500,CurrINI);
                     end;
                  else;
                     ShockUpdateDecomp = StateDecomp.ShockUpdateDecomp;
                     ShockSmoothDecomp = StateDecomp.ShockSmoothDecomp;
                     etatt = StateDecomp.etatt;
                     etatT = StateDecomp.etatT;
                     YNames = DSGEModel.VariableNames;
                     ShockNames = StateDecomp.VariableNames;
                     DateVector = StateDecomp.DateVector;
                     %
                     file = FixFilePath([DSGEModel.OutputDirectory '\ShockObsDecomp-PostMode.mat']);
                     save(file,'ShockUpdateDecomp','ShockSmoothDecomp','etatt','etatT','YNames','ShockNames','DateVector');
                     %
                     % create the script file
                     %
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\SObsDecPostMode.m']);
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                     fprintf(fid,'%%\n%% string matrix with names of the observed variables\n%%\n');
                     fprintf(fid,'YNames = DataStructure.YNames;\n');
                     fprintf(fid,'%%\n%% string matrix with names of the shocks\n%%\n');
                     fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                     fprintf(fid,'%%\n%% decompositions of the update estimates of the shocks into observed\n%% variables and the initial values of the state variables\n%%\n');
                     fprintf(fid,'ShockUpdateDecomp = DataStructure.ShockUpdateDecomp;\n');
                     fprintf(fid,'%%\n%% decompositions of the smooth estimates of the shocks into observed\n%% variables and the initial values of the state variables\n%%\n');
                     fprintf(fid,'ShockSmoothDecomp = DataStructure.ShockSmoothDecomp;\n');
                     fprintf(fid,'%%\n%% update estimates of the shocks\n%%\n');
                     fprintf(fid,'etatt = DataStructure.etatt;\n');
                     fprintf(fid,'%%\n%% smooth estimates of the shock\n%%\n');
                     fprintf(fid,'etatT = DataStructure.etatT;\n');
                     fprintf(fid,'%%\n%% vector with numeric dates\n%%\n');
                     fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     %
                     if DSGEModel.RunDriver==0;
                        txt = ['The observation weight decompositions of the shocks at posterior mode have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 7 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the shock names), ShockUpdateDecomp (3D matrix with the decompositions for the update estimates of the shocks into the observed variables and the initial condition of the state variables), ShockSmoothDecomp (3D matrix with the decompositions for the smooth estimates of the shocks into the observed variables and the initial condition of the state variables), etatt (update estimates of the shocks), etatT (smooth estimates of the shocks), and DateVector (vector with dates for the variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Observation Weight Decompositions - Posterior Mode',400,500,CurrINI);
                     end;
                  end;
               end;
               %
               % we can now display the results
               %
               if DSGEModel.RunDriver==0;
                  ObsWeightDecompDLG('init',StateDecomp,VarStr,'Posterior Mode',DSGEModel,CurrINI);
               else;
                  SetLogText(strvcat('* Finished calculations.',' '));
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ObsWeightInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view graphs of the observation weight decompositions before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Observation Weight Decompositions - Initial Values',450,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
               if gcbo==controls.obsweights.weights.states.initialvalues;
                  VarStr = 'State Variables';
                  VarType = 3;
               else;
                  VarStr = 'Shocks';
                  VarType = 4;
               end;
               if MatlabNumber>=8.0;
                  try;
                     if DSGEModel.UseDoublingAlgorithm<=3;
                        [StateDecomp,mcode,kalmanstatus] = DSGEObservationWeightsTheta(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                     else;
                        [StateDecomp,mcode,kalmanstatus] = DSGEObservationWeightsThetaDiffuse(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                     end;
                  catch ME;
                     WaitHandle = findobj('Type','figure','Tag','WaitDLG');
                     if (isempty(WaitHandle)==0)&(IsHandle(WaitHandle)==1);
                        WaitControls = get(WaitHandle,'UserData');
                        set(WaitControls.text,'UserData','done');
                        delete(WaitHandle);
                        drawnow;
                        pause(0.02);
                     end;
                     StateDecomp = [];
                     mcode = 1;
                     kalmanstatus = 0;
                     txt = 'There was an error running the observation weight function. The most likely reason is that matlab ran out of memory.';
                     if isempty(YADALastError(ME))==0;
                        txt = [txt ' YADA caught the following message: ' YADALastError(ME)];
                     end;
                     About(txt,'information','Observation Weights - Initial Values',400,500,CurrINI);
                  end;
               else;
                  try;
                     if DSGEModel.UseDoublingAlgorithm<=3;
                        [StateDecomp,mcode,kalmanstatus] = DSGEObservationWeightsTheta(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                     else;
                        [StateDecomp,mcode,kalmanstatus] = DSGEObservationWeightsThetaDiffuse(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                     end;
                  catch;
                     WaitHandle = findobj('Type','figure','Tag','WaitDLG');
                     if (isempty(WaitHandle)==0)&(IsHandle(WaitHandle)==1);
                        WaitControls = get(WaitHandle,'UserData');
                        set(WaitControls.text,'UserData','done');
                        delete(WaitHandle);
                        drawnow;
                        pause(0.02);
                     end;
                     StateDecomp = [];
                     mcode = 1;
                     kalmanstatus = 0;
                     txt = 'There was an error running the observation weight function. The most likely reason is that matlab ran out of memory.';
                     if isempty(YADALastError)==0;
                        txt = [txt ' YADA caught the following message: ' YADALastError];
                     end;
                     About(txt,'information','Observation Weights - Initial Values',400,500,CurrINI);
                  end;
               end;
               if (mcode==1)&(kalmanstatus==0);
                  if isempty(StateDecomp)==0;
                     %
                     % save the results to disk
                     %
                     txt = ['Would you like to save the observation weights of the ' lower(VarStr) ' at initial values to disk?'];
                     answer = Query(txt,'question',200,'Save - Observation Weights',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        if VarType==3;
                           StateForecastWeights = StateDecomp.StateForecastWeights;
                           StateUpdateWeights = StateDecomp.StateUpdateWeights;
                           StateSmoothWeights = StateDecomp.StateSmoothWeights;
                           StateForecastInitCondWeights = StateDecomp.StateForecastInitCondWeights;
                           StateUpdateInitCondWeights = StateDecomp.StateUpdateInitCondWeights;
                           StateSmoothInitCondWeights = StateDecomp.StateSmoothInitCondWeights;
                           YStdDev = StateDecomp.StdDev;
                           StateStdDev = StateDecomp.StateStdDev;
                           YNames = DSGEModel.VariableNames;
                           StateVariableNames = StateDecomp.VariableNames;
                           DateVector = StateDecomp.DateVector;
                           %
                           file = FixFilePath([DSGEModel.OutputDirectory '\StateVariableObsWeights-InitialValues.mat']);
                           save(file,'StateForecastWeights','StateUpdateWeights','StateSmoothWeights','StateForecastInitCondWeights','StateUpdateInitCondWeights','StateSmoothInitCondWeights','YStdDev','StateStdDev','YNames','StateVariableNames','DateVector');
                           %
                           % create the script file
                           %
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\SVObsWeightsInitVal.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% string matrix with names of the observed variables\n%%\n');
                           fprintf(fid,'YNames = DataStructure.YNames;\n');
                           fprintf(fid,'%%\n%% string matrix with names of the state variables\n%%\n');
                           fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                           fprintf(fid,'%%\n%% TxT cell array of rxn matrices with weights on observations\n%% for the forecasted state variables.\n%% Rows in cell array give time period for state variables and columns for observed variables.\n%%\n');
                           fprintf(fid,'StateForecastWeights = DataStructure.StateForecastWeights;\n');
                           fprintf(fid,'%%\n%% TxT cell array of rxn matrices with weights on observations\n%% for the updated state variables.\n%% Rows in cell array give time period for state variables and columns for observed variables.\n%%\n');
                           fprintf(fid,'StateUpdateWeights = DataStructure.StateUpdateWeights;\n');
                           fprintf(fid,'%%\n%% TxT cell array of rxn matrices with weights on observations\n%% for the smoothed state variables.\n%% Rows in cell array give time period for state variables and columns for observed variables.\n%%\n');
                           fprintf(fid,'StateSmoothWeights = DataStructure.StateSmoothWeights;\n');
                           fprintf(fid,'%%\n%% T cell array of rxr matrices with weights on initial conditions\n%% for the forecasted state variables.\n%%\n');
                           fprintf(fid,'StateForecastInitCondWeights = DataStructure.StateForecastInitCondWeights;\n');
                           fprintf(fid,'%%\n%% T cell array of rxr matrices with weights on initial conditions\n%% for the updated state variables.\n%%\n');
                           fprintf(fid,'StateUpdateInitCondWeights = DataStructure.StateUpdateInitCondWeights;\n');
                           fprintf(fid,'%%\n%% T cell array of rxr matrices with weights on initial conditions\n%% for the smoothed state variables.\n%%\n');
                           fprintf(fid,'StateSmoothInitCondWeights = DataStructure.StateSmoothInitCondWeights;\n');
                           if isempty(YStdDev)==0;
                              fprintf(fid,'%%\n%% Standard deviations of observed variables\n%%\n');
                              fprintf(fid,'YStdDev = DataStructure.YStdDev;\n');
                              fprintf(fid,'%%\n%% Standard deviations of state variables\n%%\n');
                              fprintf(fid,'StateStdDev = DataStructure.StateStdDev;\n');
                              NumEntries = 11;
                              StrEntries = 'YStdDev (matrix with standard deviations of the observed variables), StateStdDev (vector with standard deviations of the state variables),';
                           else;
                              NumEntries = 9;
                              StrEntries = '';
                           end;
                           fprintf(fid,'%%\n%% vector with numeric dates\n%%\n');
                           fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                           %
                           txt = ['The observation weights of the state variables at initial values have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' int2str(NumEntries) ' entries: YNames (string matrix with the names of the observed variables), StateVariableNames (string matrix with the state variable names), StateForecastWeights (TxT cell array of rxn matrices with weights on observed variables for the forecasted state variables), StateUpdateWeights (TxT cell array of rxn matrices with weights on observed variables for the updated state variables), StateSmoothWeights (TxT cell array of rxn matrices with weights on observed variables for the smoothed state variables), StateForecastInitCondWeights (T cell array of rxr matrices with weights on initial conditions for the forecasted state variables), StateUpdateInitCondWeights (T cell array of rxr matrices with weights on initial conditions for the updated state variables), StateSmoothInitCondWeights (T cell array of rxr matrices with weights on initial conditions for the smoothed state variables),' StrEntries ' and DateVector (vector with dates for the variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                           About(txt,'information','Observation Weights - Initial Values',500,600,CurrINI);
                        else;
                           ShockUpdateWeights = StateDecomp.ShockUpdateWeights;
                           ShockSmoothWeights = StateDecomp.ShockSmoothWeights;
                           ShockUpdateInitCondWeights = StateDecomp.ShockUpdateInitCondWeights;
                           ShockSmoothInitCondWeights = StateDecomp.ShockSmoothInitCondWeights;
                           YStdDev = StateDecomp.StdDev;
                           StateStdDev = StateDecomp.StateStdDev;
                           YNames = DSGEModel.VariableNames;
                           ShockNames = StateDecomp.VariableNames;
                           StateVariableNames = DSGEModel.StateVariableNames;
                           DateVector = StateDecomp.DateVector;
                           %
                           file = FixFilePath([DSGEModel.OutputDirectory '\ShockObsWeights-InitialValues.mat']);
                           save(file,'ShockUpdateWeights','ShockSmoothWeights','ShockUpdateInitCondWeights','ShockSmoothInitCondWeights','YStdDev','StateStdDev','YNames','ShockNames','StateVariableNames','DateVector');
                           %
                           % create the script file
                           %
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\SObsWeightsInitVal.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% string matrix with names of the n observed variables\n%%\n');
                           fprintf(fid,'YNames = DataStructure.YNames;\n');
                           fprintf(fid,'%%\n%% string matrix with names of the q shocks\n%%\n');
                           fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                           fprintf(fid,'%%\n%% string matrix with names of the r state variables\n%%\n');
                           fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                           fprintf(fid,'%%\n%% TxT cell array of qxn matrices with weights on observations\n%% for the updated shocks.\n%% Rows in cell array give time period for shocks and columns for observed variables.\n%%\n');
                           fprintf(fid,'ShockUpdateWeights = DataStructure.ShockUpdateWeights;\n');
                           fprintf(fid,'%%\n%% TxT cell array of qxn matrices with weights on observations\n%% for the smoothed shocks.\n%% Rows in cell array give time period for shocks and columns for observed variables.\n%%\n');
                           fprintf(fid,'ShockSmoothWeights = DataStructure.ShockSmoothWeights;\n');
                           fprintf(fid,'%%\n%% T cell array of qxr matrices with weights on initial conditions.\n%%\n');
                           fprintf(fid,'ShockUpdateInitCondWeights = DataStructure.ShockUpdateInitCondWeights;\n');
                           fprintf(fid,'%%\n%% T cell array of qxr matrices with weights on initial conditions.\n%%\n');
                           fprintf(fid,'ShockSmoothInitCondWeights = DataStructure.ShockSmoothInitCondWeights;\n');
                           if isempty(YStdDev)==0;
                              fprintf(fid,'%%\n%% Standard deviations of observed variables\n%%\n');
                              fprintf(fid,'YStdDev = DataStructure.YStdDev;\n');
                              fprintf(fid,'%%\n%% Standard deviations of state variables\n%%\n');
                              fprintf(fid,'StateStdDev = DataStructure.StateStdDev;\n');
                              NumEntries = 10;
                              StrEntries = 'YStdDev (matrix with standard deviations of the observed variables), StateStdDev (vector with standard deviations of the state variables),';
                           else;
                              NumEntries = 8;
                              StrEntries = '';
                           end;
                           fprintf(fid,'%%\n%% vector with numeric dates\n%%\n');
                           fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                           %
                           txt = ['The observation weights of the shocks at initial values have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' int2str(NumEntries) ' entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the shocks), StateVariableNames (string matrix with the state variable names), ShockUpdateWeights (TxT cell array of qxn matrices with weights on observed variables for the updated shocks), ShockSmoothWeights (TxT cell array of qxn matrices with weights on observed variables for the smoothed shocks), ShockUpdateInitCondWeights (T cell array of qxr matrices with weights on initial conditions for the updated shocks), ShockSmoothInitCondWeights (T cell array of qxr matrices with weights on initial conditions for the smoothed shockss),' StrEntries ' and DateVector (vector with dates for the variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                           About(txt,'information','Observation Weights - Initial Values',500,600,CurrINI);
                        end;
                     end;
                     %
                     % we can now display the results
                     %
                     ObsWeightsDLG('init',StateDecomp,VarStr,'Initial Values',DSGEModel,CurrINI);
                  end;
               elseif (mcode==1)&(kalmanstatus~=0);
                  if kalmanstatus==1;
                     txt = 'The state variables are not stationary at the initial values.';
                  else;
                     txt = 'The covariance matrix of the forecast of the observed variables in period t conditional on data until t-1 is not positive definite for some time period t. This implies that the log-likelihood value is a NaN (or a complex number) in Matlab.';
                  end;
                  About(txt,'information','Observation Weights - Initial Values',200,500,CurrINI);
               elseif mcode~=1;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Observation Weights - Initial Values',200,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ObsWeightPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            %
            if gcbo==controls.obsweights.weights.states.postmode;
               VarStr = 'State Variables';
               VarType = 3;
            else;
               VarStr = 'Shocks';
               VarType = 4;
            end;
            %
            % compute the decompositions
            %
            if MatlabNumber>=8.0;
               try;
                  if DSGEModel.UseDoublingAlgorithm<=3;
                     StateDecomp = DSGEObservationWeightsTheta(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                  else;
                     StateDecomp = DSGEObservationWeightsThetaDiffuse(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                  end;
               catch ME;
                  WaitHandle = findobj('Type','figure','Tag','WaitDLG');
                  if (isempty(WaitHandle)==0)&(IsHandle(WaitHandle)==1);
                     WaitControls = get(WaitHandle,'UserData');
                     set(WaitControls.text,'UserData','done');
                     delete(WaitHandle);
                     drawnow;
                     pause(0.02);
                  end;
                  StateDecomp = [];
                  txt = 'There was an error running the observation weight function. The most likely reason is that matlab ran out of memory.';
                  if isempty(YADALastError(ME))==0;
                     txt = [txt ' YADA caught the following message: ' YADALastError(ME)];
                  end;
                  About(txt,'information','Observation Weights - Posterior Mode',400,500,CurrINI);
               end;
            else;
               try;
                  if DSGEModel.UseDoublingAlgorithm<=3;
                     StateDecomp = DSGEObservationWeightsTheta(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                  else;
                     StateDecomp = DSGEObservationWeightsThetaDiffuse(theta,thetaPositions,ModelParameters,VarType,DSGEModel,CurrINI);
                  end;
               catch;
                  WaitHandle = findobj('Type','figure','Tag','WaitDLG');
                  if (isempty(WaitHandle)==0)&(IsHandle(WaitHandle)==1);
                     WaitControls = get(WaitHandle,'UserData');
                     set(WaitControls.text,'UserData','done');
                     delete(WaitHandle);
                     drawnow;
                     pause(0.02);
                  end;
                  StateDecomp = [];
                  txt = 'There was an error running the observation weight function. The most likely reason is that matlab ran out of memory.';
                  if isempty(YADALastError)==0;
                     txt = [txt ' YADA caught the following message: ' YADALastError];
                  end;
                  About(txt,'information','Observation Weights - Posterior Mode',400,500,CurrINI);
               end;
            end;
            if isempty(StateDecomp)==0;
               %
               % save the results to disk
               %
               txt = ['Would you like to save the observation weights of the ' lower(VarStr) ' at posterior mode to disk?'];
               answer = Query(txt,'question',200,'Save - Observation Weights',500,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  if VarType==3;
                     StateForecastWeights = StateDecomp.StateForecastWeights;
                     StateUpdateWeights = StateDecomp.StateUpdateWeights;
                     StateSmoothWeights = StateDecomp.StateSmoothWeights;
                     StateForecastInitCondWeights = StateDecomp.StateForecastInitCondWeights;
                     StateUpdateInitCondWeights = StateDecomp.StateUpdateInitCondWeights;
                     StateSmoothInitCondWeights = StateDecomp.StateSmoothInitCondWeights;
                     YStdDev = StateDecomp.StdDev;
                     StateStdDev = StateDecomp.StateStdDev;
                     YNames = DSGEModel.VariableNames;
                     StateVariableNames = StateDecomp.VariableNames;
                     DateVector = StateDecomp.DateVector;
                     %
                     file = FixFilePath([DSGEModel.OutputDirectory '\StateVariableObsWeights-PostMode.mat']);
                     save(file,'StateForecastWeights','StateUpdateWeights','StateSmoothWeights','StateForecastInitCondWeights','StateUpdateInitCondWeights','StateSmoothInitCondWeights','YStdDev','StateStdDev','YNames','StateVariableNames','DateVector');
                     %
                     % create the script file
                     %
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\SVObsWeightsPostMode.m']);
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                     fprintf(fid,'%%\n%% string matrix with names of the observed variables\n%%\n');
                     fprintf(fid,'YNames = DataStructure.YNames;\n');
                     fprintf(fid,'%%\n%% string matrix with names of the state variables\n%%\n');
                     fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                     fprintf(fid,'%%\n%% TxT cell array of rxn matrices with weights on observations\n%% for the forecasted state variables.\n%% Rows in cell array give time period for state variables and columns for observed variables.\n%%\n');
                     fprintf(fid,'StateForecastWeights = DataStructure.StateForecastWeights;\n');
                     fprintf(fid,'%%\n%% TxT cell array of rxn matrices with weights on observations\n%% for the updated state variables.\n%% Rows in cell array give time period for state variables and columns for observed variables.\n%%\n');
                     fprintf(fid,'StateUpdateWeights = DataStructure.StateUpdateWeights;\n');
                     fprintf(fid,'%%\n%% TxT cell array of rxn matrices with weights on observations\n%% for the smoothed state variables.\n%% Rows in cell array give time period for state variables and columns for observed variables.\n%%\n');
                     fprintf(fid,'StateSmoothWeights = DataStructure.StateSmoothWeights;\n');
                     fprintf(fid,'%%\n%% T cell array of rxr matrices with weights on initial conditions\n%% for the forecasted state variables.\n%%\n');
                     fprintf(fid,'StateForecastInitCondWeights = DataStructure.StateForecastInitCondWeights;\n');
                     fprintf(fid,'%%\n%% T cell array of rxr matrices with weights on initial conditions\n%% for the updated state variables.\n%%\n');
                     fprintf(fid,'StateUpdateInitCondWeights = DataStructure.StateUpdateInitCondWeights;\n');
                     fprintf(fid,'%%\n%% T cell array of rxr matrices with weights on initial conditions\n%% for the smoothed state variables.\n%%\n');
                     fprintf(fid,'StateSmoothInitCondWeights = DataStructure.StateSmoothInitCondWeights;\n');
                     if isempty(YStdDev)==0;
                        fprintf(fid,'%%\n%% Standard deviations of observed variables\n%%\n');
                        fprintf(fid,'YStdDev = DataStructure.YStdDev;\n');
                        fprintf(fid,'%%\n%% Standard deviations of state variables\n%%\n');
                        fprintf(fid,'StateStdDev = DataStructure.StateStdDev;\n');
                        NumEntries = 11;
                        StrEntries = 'YStdDev (matrix with standard deviations of the observed variables), StateStdDev (vector with standard deviations of the state variables),';
                     else;
                        NumEntries = 9;
                        StrEntries = '';
                     end;
                     fprintf(fid,'%%\n%% vector with numeric dates\n%%\n');
                     fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     %
                     txt = ['The observation weights of the state variables at posterior mode have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' int2str(NumEntries) ' entries: YNames (string matrix with the names of the observed variables), StateVariableNames (string matrix with the state variable names), StateForecastWeights (TxT cell array of rxn matrices with weights on observed variables for the forecasted state variables), StateUpdateWeights (TxT cell array of rxn matrices with weights on observed variables for the updated state variables), StateSmoothWeights (TxT cell array of rxn matrices with weights on observed variables for the smoothed state variables), StateForecastInitCondWeights (T cell array of rxr matrices with weights on initial conditions for the forecasted state variables), StateUpdateInitCondWeights (T cell array of rxr matrices with weights on initial conditions for the updated state variables), StateSmoothInitCondWeights (T cell array of rxr matrices with weights on initial conditions for the smoothed state variables),' StrEntries ' and DateVector (vector with dates for the variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                     About(txt,'information','Observation Weights - Posterior Mode',500,600,CurrINI);
                  else;
                     ShockUpdateWeights = StateDecomp.ShockUpdateWeights;
                     ShockSmoothWeights = StateDecomp.ShockSmoothWeights;
                     ShockUpdateInitCondWeights = StateDecomp.ShockUpdateInitCondWeights;
                     ShockSmoothInitCondWeights = StateDecomp.ShockSmoothInitCondWeights;
                     YStdDev = StateDecomp.StdDev;
                     StateStdDev = StateDecomp.StateStdDev;
                     YNames = DSGEModel.VariableNames;
                     ShockNames = StateDecomp.VariableNames;
                     StateVariableNames = DSGEModel.StateVariableNames;
                     DateVector = StateDecomp.DateVector;
                     %
                     file = FixFilePath([DSGEModel.OutputDirectory '\ShockObsWeights-PostMode.mat']);
                     save(file,'ShockUpdateWeights','ShockSmoothWeights','ShockUpdateInitCondWeights','ShockSmoothInitCondWeights','YStdDev','StateStdDev','YNames','ShockNames','StateVariableNames','DateVector');
                     %
                     % create the script file
                     %
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\SObsWeightsPostMode.m']);
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                     fprintf(fid,'%%\n%% string matrix with names of the n observed variables\n%%\n');
                     fprintf(fid,'YNames = DataStructure.YNames;\n');
                     fprintf(fid,'%%\n%% string matrix with names of the q shocks\n%%\n');
                     fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                     fprintf(fid,'%%\n%% string matrix with names of the r state variables\n%%\n');
                     fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                     fprintf(fid,'%%\n%% TxT cell array of qxn matrices with weights on observations\n%% for the updated shocks.\n%% Rows in cell array give time period for shocks and columns for observed variables.\n%%\n');
                     fprintf(fid,'ShockUpdateWeights = DataStructure.ShockUpdateWeights;\n');
                     fprintf(fid,'%%\n%% TxT cell array of qxn matrices with weights on observations\n%% for the smoothed shocks.\n%% Rows in cell array give time period for shocks and columns for observed variables.\n%%\n');
                     fprintf(fid,'ShockSmoothWeights = DataStructure.ShockSmoothWeights;\n');
                     fprintf(fid,'%%\n%% T cell array of qxr matrices with weights on initial conditions.\n%%\n');
                     fprintf(fid,'ShockUpdateInitCondWeights = DataStructure.ShockUpdateInitCondWeights;\n');
                     fprintf(fid,'%%\n%% T cell array of qxr matrices with weights on initial conditions.\n%%\n');
                     fprintf(fid,'ShockSmoothInitCondWeights = DataStructure.ShockSmoothInitCondWeights;\n');
                     if isempty(YStdDev)==0;
                        fprintf(fid,'%%\n%% Standard deviations of observed variables\n%%\n');
                        fprintf(fid,'YStdDev = DataStructure.YStdDev;\n');
                        fprintf(fid,'%%\n%% Standard deviations of state variables\n%%\n');
                        fprintf(fid,'StateStdDev = DataStructure.StateStdDev;\n');
                        NumEntries = 10;
                        StrEntries = 'YStdDev (matrix with standard deviations of the observed variables), StateStdDev (vector with standard deviations of the state variables),';
                     else;
                        NumEntries = 8;
                        StrEntries = '';
                     end;
                     fprintf(fid,'%%\n%% vector with numeric dates\n%%\n');
                     fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     %
                     txt = ['The observation weights of the shocks at posterior mode have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' int2str(NumEntries) ' entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the shocks), StateVariableNames (string matrix with the state variable names), ShockUpdateWeights (TxT cell array of qxn matrices with weights on observed variables for the updated shocks), ShockSmoothWeights (TxT cell array of qxn matrices with weights on observed variables for the smoothed shocks), ShockUpdateInitCondWeights (T cell array of qxr matrices with weights on initial conditions for the updated shocks), ShockSmoothInitCondWeights (T cell array of qxr matrices with weights on initial conditions for the smoothed shockss),' StrEntries ' and DateVector (vector with dates for the variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                     About(txt,'information','Observation Weights - Posterior Mode',500,600,CurrINI);
                  end;
               end;
               %
               % we can now display the results
               %
               ObsWeightsDLG('init',StateDecomp,VarStr,'Posterior Mode',DSGEModel,CurrINI);
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ObsVarDecompInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view graphs of the observed variables decompositions before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Observed Variables Decomposition - Initial Values',450,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
%               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
               %
               % Try to calculate state variables. First, however, the code needs to check if a unique convergent
               % solution exists.
               %
               if (isfield(controls,'svs')==1)&(CheckStateScenarioData(DSGEModel)==1);
                  txt = 'Would you like to estimate structural shocks using a constrained Kalman filter routine instead of the standard Kalman filter?';
                  answer = Query(txt,'question',200,'Observed Variable Decomposition - Initial Values',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     ConEst = 1;
                  else;
                     ConEst = 0;
                  end;
               else;
                  ConEst = 0;
               end;
               if ConEst==0;
                  [StateVarStructure,mcode,kalmanstatus] = CalculateDSGEStateVariables(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,1,0,'');
               else;
                  [StateVarStructure,mcode,kalmanstatus] = ConstrainedObsVarDecomp(theta,thetaPositions,ModelParameters,'Initial Values',DSGEModel,CurrINI);
               end;
               if (mcode==1)&(kalmanstatus==0);
                  %
                  % we're OK
                  %
                  if isempty(StateVarStructure)==0;
                     if gcbo==controls.ovd.initialvalues;
                        AnnualStr = 'Original';
                        IsOriginal = 1;
                     else;
                        AnnualStr = 'Annualized';
                        IsOriginal = 0;
                     end;
                     %
                     % save data to disk
                     %
                     txt = ['Would you like to save the decompositions of the ' lower(AnnualStr) ' observed and state variables at initial values to file?'];
                     answer = Query(txt,'question',140,'Save - Observed Variable Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        StateVariableNames = DSGEModel.StateVariableNames;
                        ShockNames = DSGEModel.StateShockNames;
                        YNames = DSGEModel.VariableNames;
                        if ConEst==0;
                           if IsOriginal==1;
                              MatFile = FixFilePath([DSGEModel.OutputDirectory '\ObservedVariableDecompositions-InitialValues.mat']);
                              mfile = FixFilePath([DSGEModel.OutputDirectory '\OVDInitVal.m']);
                           else;
                              MatFile = FixFilePath([DSGEModel.OutputDirectory '\ObservedVariableDecompositions-Annualized-InitialValues.mat']);
                              mfile = FixFilePath([DSGEModel.OutputDirectory '\OVDAnnInitVal.m']);
                           end;
                        else;
                           if IsOriginal==1;
                              MatFile = FixFilePath([DSGEModel.OutputDirectory '\ConstObservedVariableDecompositions-InitialValues.mat']);
                              mfile = FixFilePath([DSGEModel.OutputDirectory '\ConOVDInitVal.m']);
                           else;
                              MatFile = FixFilePath([DSGEModel.OutputDirectory '\ConstObservedVariableDecompositions-Annualized-InitialValues.mat']);
                              mfile = FixFilePath([DSGEModel.OutputDirectory '\ConOVDAnnInitVal.m']);
                           end;
                        end;
                        DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency);
                        if length(DateVector)>length(StateVarStructure.Y);
                           DateVector = DateVector(1,length(DateVector)-length(StateVarStructure.Y)+1:length(DateVector));
                        end;
                        if IsOriginal==1;
                           KsitT = StateVarStructure.KsitT;
                           Y = StateVarStructure.Y;
                           A = StateVarStructure.A;
                           X = StateVarStructure.X;
                           if isempty(X)==0;
                              AX = A'*X;
                           else;
                              AX = zeros(size(Y));
                           end;
                           KeepShocks = StateVarStructure.KeepVar;
                           YDecomp = StateVarStructure.etaDecomp;
                           KsiDecomp = StateVarStructure.XietaDecomp;
                           YInit = StateVarStructure.XiInit;
                           KsiInit = StateVarStructure.XietaInit;
                           wtT = StateVarStructure.wthT;
                           if isempty(wtT)==1;
                              wtT = zeros(size(Y));
                           end;
                        else;
                           %
                           % annualize
                           %
                           Y = Annualize(StateVarStructure.Y,DSGEModel.annual,DSGEModel.annualscale);
                           YInit = Annualize(StateVarStructure.XiInit,DSGEModel.annual,DSGEModel.annualscale);
                           if isempty(StateVarStructure.wthT)==0;
                              wtT = Annualize(StateVarStructure.wthT,DSGEModel.annual,DSGEModel.annualscale);
                           else;
                              wtT = zeros(size(Y));
                           end;
                           if isempty(StateVarStructure.X)==0;
                              X = StateVarStructure.X;
                              A = StateVarStructure.A;
                              AX = Annualize(A'*X,DSGEModel.annual,DSGEModel.annualscale);
                           else;
                              AX = zeros(size(Y));
                           end;
                           q = size(StateVarStructure.etaDecomp,3);
                           YDecomp = zeros(DSGEModel.n,size(Y,2),q);
                           for i=1:q;
                              YDecomp(:,:,i) = Annualize(StateVarStructure.etaDecomp(:,:,i),DSGEModel.annual,DSGEModel.annualscale);
                           end;
                           FirstPos = size(StateVarStructure.Y,2)-size(Y,2)+1;
                           LastPos = size(StateVarStructure.Y,2);
                           KsitT = StateVarStructure.KsitT(:,FirstPos:LastPos);
                           KsiDecomp = StateVarStructure.XietaDecomp(:,FirstPos:LastPos,:);
                           KsiInit = StateVarStructure.XietaInit(:,FirstPos:LastPos);
                           DateVector = DateVector(FirstPos:LastPos);
                           KeepShocks = StateVarStructure.KeepVar;
                        end;
                        ShockNames = ShockNames(KeepShocks,:);
                        save(MatFile,'Y','AX','KsitT','wtT','YInit','YDecomp','KsiInit','KsiDecomp','YNames','StateVariableNames','ShockNames','DateVector');
                        %
                        % write to an m-file
                        %
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(MatFile) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(MatFile));
                        fprintf(fid,'%%\n%% nxT matrix with the data on the observed variables\n%%\n');
                        fprintf(fid,'Y = DataStructure.Y;\n');
                        fprintf(fid,'%%\n%% nxT matrix with steady-state values in measurement equation\n%%\n');
                        fprintf(fid,'AX = DataStructure.AX;\n');
                        fprintf(fid,'%%\n%% nxT matrix with smoothed estimates of measurement errors\n%%\n');
                        fprintf(fid,'wtT = DataStructure.wtT;\n');
                        fprintf(fid,'%%\n%% rxT matrix with smooth estimates of state variables\n%%\n');
                        fprintf(fid,'KsitT = DataStructure.KsitT;\n');
                        fprintf(fid,'%%\n%% nxT matrix with impact of initial state variables on obs variable decomp\n%%\n');
                        fprintf(fid,'YInit = DataStructure.YInit;\n');
                        fprintf(fid,'%%\n%% nxTxq matrix with the obs variable decomposition into the q shocks\n%%\n');
                        fprintf(fid,'YDecomp = DataStructure.YDecomp;\n');
                        fprintf(fid,'%%\n%% rxT matrix with the impact of initial state variables on state variable decomp\n%%\n');
                        fprintf(fid,'KsiInit = DataStructure.KsiInit;\n');
                        fprintf(fid,'%%\n%% rxTxq matrix with the state variable decompositon into the q shocks\n%%\n');
                        fprintf(fid,'KsiDecomp = DataStructure.KsiDecomp;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                        fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the structural shocks\n%%\n');
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% vector with dates\n%%\n');
                        fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The observed variable decomposition data have been saved to the file "' GetFilename(MatFile) '" in the directory "' GetPath(MatFile) '". The file contains 12 entries: Y (matrix with the observed variables); AX (matrix with steady-states for the observed variables); wtT (smooth estmates of the measurement errors); KsitT (smooth estimates of the state variables); YInit (matrix with the impact of initial states on observed variable decomposition); YDecomp (matrix with the observed variable decomposition for shocks); KsiInit (matrix with the impact of initial states on state variable decomposition); KsiDecomp (matrix with the state variable decomposition for shocks); YNames (matrix with the names of the observed variables); StateVariableNames (matrix with the state variable decomposition for shocks); ShockNames (matrix with names for the shocks); and DateVector (vector with dates). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Observed Variable Decomposition - Initial Values',500,600,CurrINI);
                     end;
                     %
                     % select scatter plots or regular decomposition bar plots
                     %
                     txt = ['Would you like to produce scatter plots of the decompositions for the ' lower(AnnualStr) ' data instead of time series based bar charts?'];
                     answer = Query(txt,'question',200,'Observed Variable Decomposition - Initial Values',500,'no',CurrINI);
                     %
                     if strcmp(lower(answer),'no')==1;
                        ObsVarDecompDLG('init',StateVarStructure,'Initial Values',AnnualStr,CurrINI,DSGEModel);
                     else;
                        ScatterDecompDLG('init',StateVarStructure,'Initial Values',AnnualStr,CurrINI,DSGEModel);
                     end;
                  end;
               elseif (mcode==1)&(kalmanstatus~=0);
                  if kalmanstatus==1;
                     txt = 'The state variables are not stationary at the initial values.';
                  else;
                     txt = 'The covariance matrix of the forecast of the observed variables in period t conditional on data until t-1 is not positive definite for some time period t. This implies that the log-likelihood value is a NaN (or a complex number) in Matlab.';
                  end;
                  About(txt,'information','Observed Variables Decomposition - Initial Values',200,500,CurrINI);
               elseif mcode~=1;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Observed Variables Decomposition - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ObsVarPathInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view graphs of the observed variables decompositions before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Observed Variables Decomposition at Initial Values',450,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
%               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
               %
               % Try to calculate state variables. First, however, the code needs to check if a unique convergent
               % solution exists.
               %
               [StateVarStructure,mcode,kalmanstatus] = CalculateDSGEStateVariables(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,1,0,'');
               if (mcode==1)&(kalmanstatus==0);
                  %
                  % we're OK
                  %
                  if isempty(StateVarStructure)==0;
                     if gcbo==controls.ovp.initialvalues;
                        AnnualStr = 'Original';
                     else;
                        AnnualStr = 'Annualized';
                     end;
                     %
                     % ask if we should look at shock groups rather than individual shocks
                     %
                     ShockType = 0;
                     if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                        txt = 'Would you like to view plots of observed variable decomposition paths for shock groups instead of for the individual shocks?';
                        answer = Query(txt,'question',140,'Observed Variable Decomposition Paths - Initial Values',500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           etaDecomp = zeros(size(StateVarStructure.etaDecomp,1),size(StateVarStructure.etaDecomp,2),max(DSGEModel.ShockGroups));
                           for i=1:max(DSGEModel.ShockGroups);
                              Ind = (DSGEModel.ShockGroups==i).*(1:length(DSGEModel.ShockGroups));
                              Ind = Ind(Ind>0);
                              DecompTmp = StateVarStructure.etaDecomp(:,:,Ind);
                              if length(size(DecompTmp))==3;
                                 DecompTmp = sum(DecompTmp,3);
                              end;
                              etaDecomp(:,:,i) = DecompTmp;
                           end;
                           StateVarStructure.etaDecomp = etaDecomp;
                           ShockNames = DSGEModel.ShockGroupNames;
                           for i=1:max(DSGEModel.ShockGroups);
                              ShockNames(i,:) = strrep(ShockNames(i,:),'_',' ');
                           end;
                           ShockType = 1;
                        else;
                           ShockNames = DSGEModel.StateShockNames(StateVarStructure.KeepVar,:);
                        end;
                     else;
                        ShockNames = DSGEModel.StateShockNames(StateVarStructure.KeepVar,:);
                     end;
                     %
                     % get the terms
                     %
                     DecompShocks = StateVarStructure.etaDecomp;
                     DecompInitState = StateVarStructure.XiInit;
                     if isempty(DSGEModel.X)==0;
                        DecompSteadyState = StateVarStructure.A'*StateVarStructure.X;
                     else;
                        DecompSteadyState = zeros(size(DecompInitState));
                     end;
                     if isempty(StateVarStructure.wthT)==0;
                        DecompMeasureError = StateVarStructure.wthT;
                     else;
                        DecompMeasureError = zeros(size(DecompInitState));
                     end;
                     Y = StateVarStructure.Y;
                     %
                     % check if we should annualize
                     %
                     if strcmp(lower(AnnualStr),'annualized')==1;
                        Y = Annualize(Y,DSGEModel.annual,DSGEModel.annualscale);
                        DecompInitState = Annualize(DecompInitState,DSGEModel.annual,DSGEModel.annualscale);
                        DecompSteadyState = Annualize(DecompSteadyState,DSGEModel.annual,DSGEModel.annualscale);
                        DecompMeasureError = Annualize(DecompMeasureError,DSGEModel.annual,DSGEModel.annualscale);
                        DecompShocksTmp = zeros(size(Y,1),size(Y,2),size(DecompShocks,3));
                        for i=1:size(DecompShocks,3);
                           DecompShocksTmp(:,:,i) = Annualize(DecompShocks(:,:,i),DSGEModel.annual,DSGEModel.annualscale);
                        end;
                        DecompShocks = DecompShocksTmp;
                     end;
                     DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency);
                     %
                     % Make sure that DateVector is not longer than the number of periods for the shocks
                     %
                     if length(DateVector)>size(Y,2);
                        DateVector = DateVector(1,length(DateVector)-size(Y,2)+1:length(DateVector));
                     end;
                     %
                     % ask if we should save the data to file
                     %
                     txt = 'Would you like to save the observed variable decomposition paths at initial values to disk?';
                     answer = Query(txt,'question',140,'Save - Observed Variable decomposition Paths',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        if ShockType==0;
                           file = FixFilePath([DSGEModel.OutputDirectory '\ObsVarDecompPath-' AnnualStr '-Groups-InitialValues.mat']);
                        else;
                           file = FixFilePath([DSGEModel.OutputDirectory '\ObsVarDecompPath-' AnnualStr '-InitialValues.mat']);
                        end;
                        YNames = DSGEModel.VariableNames;
                        save(file,'YNames','ShockNames','Y','DecompInitState','DecompSteadyState','DecompMeasureError','DecompShocks','DateVector');
                        %
                        % create a matlab file to read the data
                        %
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\OVP' AnnualStr 'InitVal.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        if ShockType==0;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                           GroupStr = '';
                        else;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                           GroupStr = ' group';
                        end;
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% matrix with data on the observed variables\n%%\n');
                        fprintf(fid,'Y = DataStructure.Y;\n');
                        fprintf(fid,'%%\n%% matrix with estimates of the initial state term\n%%\n');
                        fprintf(fid,'DecompInitState = DataStructure.DecompInitState;\n');
                        fprintf(fid,'%%\n%% matrix with estimates of the steady-state term\n%%\n');
                        fprintf(fid,'DecompSteadyState = DataStructure.DecompSteadyState;\n');
                        fprintf(fid,'%%\n%% matrix with estimates of the measurement error term\n%%\n');
                        fprintf(fid,'DecompMeasureError = DataStructure.DecompMeasureError;\n');
                        fprintf(fid,'%%\n%% 3D matrix with estimates of the shock%s terms\n%%\n',GroupStr);
                        fprintf(fid,'DecompShocks = DataStructure.DecompShocks;\n');
                        fprintf(fid,'%%\n%% vector with numeric dates for the observed variables\n%%\n');
                        fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The observed variable decomposition paths at initial values have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 8 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the shock' GroupStr ' names), Y (matrix with the data on the observed variables), DecompInitState (matrix with estimates of the initial state term), DecompSteadyState (matrix with estimates of the steady-state term), DecompMeasureError (matrix with estimates of the measurement error term), DecompShocks (3D matrix with estimates of the shock' GroupStr ' terms), DateVector (vector with dates for the observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Observed Variable Decomposition Paths - Initial Values',400,500,CurrINI);
                     end;
                     %
                     % display the results
                     %
                     ObsVarDecompPathDLG('init',Y,DecompInitState,DecompSteadyState,DecompMeasureError,DecompShocks,[],DateVector,ShockNames,ShockType,'Initial Values',AnnualStr,CurrINI,DSGEModel);
                  end;
               elseif (mcode==1)&(kalmanstatus~=0);
                  if kalmanstatus==1;
                     txt = 'The state variables are not stationary at the initial values.';
                  else;
                     txt = 'The covariance matrix of the forecast of the observed variables in period t conditional on data until t-1 is not positive definite for some time period t. This implies that the log-likelihood value is a NaN (or a complex number) in Matlab.';
                  end;
                  About(txt,'information','Observed Variable Decomposition Paths - Initial Values',200,500,CurrINI);
               elseif mcode~=1;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Observed Variable Decomposition Paths - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ObsVarDecompPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % are we using annualized data or the original
         %
         if gcbo==controls.ovd.prior;
            AnnualizeData = 0;
            QueryHead = 'Observed Variable Decomposition For Prior - Original Data';
            VarType = 'Original';
         else;
            AnnualizeData = 1;
            QueryHead = 'Observed Variable Decomposition For Prior - Annualized Data';
            VarType = 'Annualized';
         end;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,QueryHead,550,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the posterior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection',QueryHead,'','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            %
            % First we check if the calculations have already been performed
            %
            if OVPExist(DSGEModel,AnnualizeData,NumPriorDraws,NumPriorDraws,1,0)==1;
               txt = 'YADA has located results for the observed variable decompositions on disk. Would you like to use these results?';
               answer = Query(txt,'question',150,QueryHead,550,'no',CurrINI);
            else;
               answer = 'No';
            end;
            if strcmp(lower(answer),'yes')==1;
               DoneCalc = 1;
            else;
               %
               % compute the observed variable decomposition paths for all the posterior draws
               %
               DoneCalc = DSGEObsVarDecomposition(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,AnnualizeData,NumPriorDraws,1,0);
            end;
            %
            if DoneCalc==1;
               ShockType = 0;
               if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                  txt = 'Would you like to view plots of observed variable decompositions for shock groups instead of for the individual shocks?';
                  answer = Query(txt,'question',200,QueryHead,550,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     ShockType = 1;
                  end;
               end;
               %
               % compute the distributional details
               %
               OVDPs = DSGEObsVarDecompDistribution(DSGEModel,CurrINI,AnnualizeData,ShockType,NumPriorDraws,NumPriorDraws,1,0,[]);
               %
               % ask if we should save results to disk
               %
               txt = 'Would you like to save the observed variable decompositions to file?';
               answer = Query(txt,'question',140,'Save - Observed Variable Decompositions',500,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  YNames = DSGEModel.VariableNames;
                  DateVector = OVDPs.DateVector;
                  Y = OVDPs.Y;
                  DecompInitState = OVDPs.DecompInitState;
                  DecompSteadyState = OVDPs.DecompSteadyState;
                  DecompMeasureError = OVDPs.DecompMeasureError;
                  DecompShocks = OVDPs.DecompShocks;
                  DecompMedianInitState = OVDPs.DecompMedianInitState;
                  DecompMedianSteadyState = OVDPs.DecompMedianSteadyState;
                  DecompMedianMeasureError = OVDPs.DecompMedianMeasureError;
                  DecompMedianShocks = OVDPs.DecompMedianShocks;
                  ShockNames = OVDPs.ShockNames;
                  if ShockType==1;
                     file = FixFilePath([DSGEModel.OutputDirectory '\ObsVarDecompPriorDist-' VarType '-Group-' int2str(NumPriorDraws) '.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\OVDPriorDist' VarType 'Group' int2str(NumPriorDraws) '.m']);
                  else;
                     file = FixFilePath([DSGEModel.OutputDirectory '\ObsVarDecompPriorDist-' VarType '-' int2str(NumPriorDraws) '.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\OVDPriorDist' VarType int2str(NumPriorDraws) '.m']);
                  end;
                  save(file,'YNames','ShockNames','Y','DecompInitState','DecompSteadyState','DecompMeasureError','DecompShocks','DecompMedianInitState','DecompMedianSteadyState','DecompMedianMeasureError','DecompMedianShocks','DateVector');
                  %
                  % create a matlab file to read the data
                  %
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  if ShockType==0;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                     GroupStr = '';
                  else;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                     GroupStr = ' group';
                  end;
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% matrix with data on the observed variables\n%%\n');
                  fprintf(fid,'Y = DataStructure.Y;\n');
                  fprintf(fid,'%%\n%% matrix with prior mean estimates of the initial state term\n%%\n');
                  fprintf(fid,'DecompInitState = DataStructure.DecompInitState;\n');
                  fprintf(fid,'%%\n%% matrix with prior mean estimates of the steady-state term\n%%\n');
                  fprintf(fid,'DecompSteadyState = DataStructure.DecompSteadyState;\n');
                  fprintf(fid,'%%\n%% matrix with prior mean estimates of the measurement error term\n%%\n');
                  fprintf(fid,'DecompMeasureError = DataStructure.DecompMeasureError;\n');
                  fprintf(fid,'%%\n%% 3D matrix with prior mean estimates of the shock%s terms\n%%\n',GroupStr);
                  fprintf(fid,'DecompShocks = DataStructure.DecompShocks;\n');
                  fprintf(fid,'%%\n%% matrix with prior median estimates of the initial state term\n%%\n');
                  fprintf(fid,'DecompMedianInitState = DataStructure.DecompMedianInitState;\n');
                  fprintf(fid,'%%\n%% matrix with prior median estimates of the steady-state term\n%%\n');
                  fprintf(fid,'DecompMedianSteadyState = DataStructure.DecompMedianSteadyState;\n');
                  fprintf(fid,'%%\n%% matrix with prior median estimates of the measurement error term\n%%\n');
                  fprintf(fid,'DecompMedianMeasureError = DataStructure.DecompMedianMeasureError;\n');
                  fprintf(fid,'%%\n%% 3D matrix with prior median estimates of the shock%s terms\n%%\n',GroupStr);
                  fprintf(fid,'DecompMedianShocks = DataStructure.DecompMedianShocks;\n');
                  fprintf(fid,'%%\n%% vector with numeric dates for the observed variables\n%%\n');
                  fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  txt = ['The observed variable decompositions data have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 12 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the shock' GroupStr ' names), Y (matrix with the data on the observed variables), DecompInitState (matrix with prior mean estimates of the initial state term), DecompSteadyState (matrix with prior mean estimates of the steady-state term), DecompMeasureError (matrix with prior mean estimates of the measurement error term), DecompShocks (3D matrix with prior mean estimates of the shock' GroupStr ' terms), DecompMedianInitState (matrix with prior median estimates of the initial state term), DecompMedianSteadyState (matrix with prior median estimates of the steady-state term), DecompMedianMeasureError (matrix with prior median estimates of the measurement error term), DecompMedianShocks (3D matrix with prior median estimates of the shock' GroupStr ' terms), DateVector (vector with dates for the observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                  About(txt,'information',QueryHead,500,600,CurrINI);
               end;
               %
               % plotting decision
               %
               txt = ['Would you like to produce scatter plots of the decompositions for the ' lower(VarType) ' data instead of time series based bar charts?'];
               answer = Query(txt,'question',200,'Observed Variable Decomposition - Prior Distribution',600,'no',CurrINI);
               %
               % now display the results
               %
               if strcmp(lower(answer),'no')==1;
                  ObsVarDecompDistDLG('init',OVDPs,'Prior',VarType,ShockType,CurrINI,DSGEModel);
               else;
                  ScatterDecompDistDLG('init',OVDPs,'Prior',VarType,ShockType,CurrINI,DSGEModel);
               end;
            else;
               DSGEModel = OldDSGEModel;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ObsVarPathPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % are we using annualized data or the original
         %
         if gcbo==controls.ovp.prior;
            AnnualizeData = 0;
            QueryHead = 'Observed Variable Decomposition Paths For Prior - Original Data';
            VarType = 'Original';
         else;
            AnnualizeData = 1;
            QueryHead = 'Observed Variable Decomposition Paths For Prior - Annualized Data';
            VarType = 'Annualized';
         end;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,QueryHead,550,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the posterior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection',QueryHead,'','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            %
            % First we check if the calculations have already been performed
            %
            if OVPExist(DSGEModel,AnnualizeData,NumPriorDraws,NumPriorDraws,1,0)==1;
               txt = 'YADA has located results for the observed variable decomposition paths on disk. Would you like to use these results?';
               answer = Query(txt,'question',150,QueryHead,550,'no',CurrINI);
            else;
               answer = 'No';
            end;
            if strcmp(lower(answer),'yes')==1;
               DoneCalc = 1;
            else;
               %
               % compute the observed variable decomposition paths for all the posterior draws
               %
               DoneCalc = DSGEObsVarDecomposition(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,AnnualizeData,NumPriorDraws,1,0);
            end;
            %
            if DoneCalc==1;
               ShockType = 0;
               if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                  txt = 'Would you like to view plots of observed variable decomposition paths for shock groups instead of for the individual shocks?';
                  answer = Query(txt,'question',200,QueryHead,550,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     ShockType = 1;
                  end;
               end;
               %
               % compute the distributional details
               %
               OVDPs = DSGEObsVarDecompDistribution(DSGEModel,CurrINI,AnnualizeData,ShockType,NumPriorDraws,NumPriorDraws,1,0,[]);
               %
               % ask if we should save results to disk
               %
               txt = 'Would you like to save the observed variable decomposition paths to file?';
               answer = Query(txt,'question',140,'Save - Observed Variable Decomposition Paths',500,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  YNames = DSGEModel.VariableNames;
                  DateVector = OVDPs.DateVector;
                  Y = OVDPs.Y;
                  DecompInitState = OVDPs.DecompInitState;
                  DecompSteadyState = OVDPs.DecompSteadyState;
                  DecompMeasureError = OVDPs.DecompMeasureError;
                  DecompShocks = OVDPs.DecompShocks;
                  ShockNames = OVDPs.ShockNames;
                  Quantiles = OVDPs.Quantiles;
                  if ShockType==1;
                     file = FixFilePath([DSGEModel.OutputDirectory '\ObsVarDecompPathPriorDist-' VarType '-Group-' int2str(NumPriorDraws) '.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\OVDPPriorDist' VarType 'Group' int2str(NumPriorDraws) '.m']);
                  else;
                     file = FixFilePath([DSGEModel.OutputDirectory '\ObsVarDecompPathPriorDist-' VarType '-' int2str(NumPriorDraws) '.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\OVDPPriorDist' VarType int2str(NumPriorDraws) '.m']);
                  end;
                  save(file,'YNames','ShockNames','Y','DecompInitState','DecompSteadyState','DecompMeasureError','DecompShocks','Quantiles','DateVector');
                  %
                  % create a matlab file to read the data
                  %
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  if ShockType==0;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                     GroupStr = '';
                  else;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                     GroupStr = ' group';
                  end;
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% matrix with data on the observed variables\n%%\n');
                  fprintf(fid,'Y = DataStructure.Y;\n');
                  fprintf(fid,'%%\n%% matrix with estimates of the initial state term\n%%\n');
                  fprintf(fid,'DecompInitState = DataStructure.DecompInitState;\n');
                  fprintf(fid,'%%\n%% matrix with estimates of the steady-state term\n%%\n');
                  fprintf(fid,'DecompSteadyState = DataStructure.DecompSteadyState;\n');
                  fprintf(fid,'%%\n%% matrix with estimates of the measurement error term\n%%\n');
                  fprintf(fid,'DecompMeasureError = DataStructure.DecompMeasureError;\n');
                  fprintf(fid,'%%\n%% 3D matrix with estimates of the shock%s terms\n%%\n',GroupStr);
                  fprintf(fid,'DecompShocks = DataStructure.DecompShocks;\n');
                  fprintf(fid,'%%\n%% structure with quantile data\n%%\n');
                  fprintf(fid,'Quantiles = DataStructure.Quantiles;\n');
                  fprintf(fid,'%%\n%% vector with numeric dates for the observed variables\n%%\n');
                  fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  txt = ['The observed variable decomposition paths data have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 9 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the shock' GroupStr ' names), Y (matrix with the data on the observed variables), DecompInitState (matrix with estimates of the initial state term), DecompSteadyState (matrix with estimates of the steady-state term), DecompMeasureError (matrix with estimates of the measurement error term), DecompShocks (3D matrix with estimates of the shock' GroupStr ' terms), Quantiles (structure with quantile data on the decomposition of the observed variables for the sum of the initial state, the steady-state, the measurement error, and shock' GroupStr ' terms), DateVector (vector with dates for the observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                  About(txt,'information',QueryHead,400,550,CurrINI);
               end;
               %
               % display the results
               %
               ObsVarDecompPathDLG('init',OVDPs.Y,OVDPs.DecompInitState,OVDPs.DecompSteadyState,OVDPs.DecompMeasureError,OVDPs.DecompShocks,OVDPs.Quantiles,OVDPs.DateVector,OVDPs.ShockNames,ShockType,'Prior Distribution',VarType,CurrINI,DSGEModel);
            else;
               DSGEModel = OldDSGEModel;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ObsVarDecompPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%            else;
%               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            %
            % we can now calculate the state shocks
            %
            
            if (isfield(controls,'svs')==1)&(CheckStateScenarioData(DSGEModel)==1);
               if DSGEModel.RunDriver==0;
                  txt = 'Would you like to estimate structural shocks using a constrained Kalman filter routine instead of the standard Kalman filter?';
                  answer = Query(txt,'question',200,'Observed Variable Decomposition - Posterior Mode',500,'no',CurrINI);
               else;
                  answer = DSGEModel.answers{1};
               end;
               if strcmp(lower(answer),'yes')==1;
                  ConEst = 1;
               else;
                  ConEst = 0;
               end;
            else;
               ConEst = 0;
            end;
            if ConEst==0;
               StateVarStructure = CalculateDSGEStateVariables(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,1,0,'');
            else;
               StateVarStructure = ConstrainedObsVarDecomp(theta,thetaPositions,ModelParameters,'Posterior Mode',DSGEModel,CurrINI);
            end;
            if isempty(StateVarStructure)==0;
               if DSGEModel.RunDriver==0;
                  if gcbo==controls.ovd.postmode;
                     IsOriginal = 1;
                     AnnualStr = 'Original';
                  else;
                     IsOriginal = 0;
                     AnnualStr = 'Annualized';
                  end;
               else;
                  if strcmp(lower(DSGEModel.answers{2}),'original')==1;
                     IsOriginal = 1;
                     AnnualStr = 'Original';
                  else;
                     IsOriginal = 0;
                     AnnualStr = 'Annualized';
                  end;
               end;
               %
               % save data to disk
               %
               if DSGEModel.RunDriver==0;
                  txt = ['Would you like to save the decompositions of the ' lower(AnnualStr) ' observed and state variables at posterior mode to file?'];
                  answer = Query(txt,'question',140,'Save - Observed Variable Decompositions',500,'no',CurrINI);
               else;
                  answer = DSGEModel.answers{3};
               end;
               if strcmp(lower(answer),'yes')==1;
                  if DSGEModel.RunDriver==1;
                     SetLogText(strvcat('* Saving results to: ',['     ' DSGEModel.OutputDirectory]));
                  end;
                  StateVariableNames = DSGEModel.StateVariableNames;
                  ShockNames = DSGEModel.StateShockNames;
                  YNames = DSGEModel.VariableNames;
                  if ConEst==0;
                     if IsOriginal==1;
                        MatFile = FixFilePath([DSGEModel.OutputDirectory '\ObservedVariableDecompositions-PostMode.mat']);
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\OVDPostMode.m']);
                     else;
                        MatFile = FixFilePath([DSGEModel.OutputDirectory '\ObservedVariableDecompositions-Annualized-PostMode.mat']);
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\OVDAnnPostMode.m']);
                     end;
                  else;
                     if IsOriginal==1;
                        MatFile = FixFilePath([DSGEModel.OutputDirectory '\ConstObservedVariableDecompositions-PostMode.mat']);
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\ConOVDPostMode.m']);
                     else;
                        MatFile = FixFilePath([DSGEModel.OutputDirectory '\ConstObservedVariableDecompositions-Annualized-PostMode.mat']);
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\ConOVDAnnPostMode.m']);
                     end;
                  end;
                  DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency);
                  if length(DateVector)>length(StateVarStructure.Y);
                     DateVector = DateVector(1,length(DateVector)-length(StateVarStructure.Y)+1:length(DateVector));
                  end;
                  if IsOriginal==1;
                     KsitT = StateVarStructure.KsitT;
                     Y = StateVarStructure.Y;
                     A = StateVarStructure.A;
                     X = StateVarStructure.X;
                     if isempty(X)==0;
                        AX = A'*X;
                     else;
                        AX = zeros(size(Y));
                     end;
                     KeepShocks = StateVarStructure.KeepVar;
                     YDecomp = StateVarStructure.etaDecomp;
                     KsiDecomp = StateVarStructure.XietaDecomp;
                     YInit = StateVarStructure.XiInit;
                     KsiInit = StateVarStructure.XietaInit;
                     wtT = StateVarStructure.wthT;
                     if isempty(wtT)==1;
                        wtT = zeros(size(Y));
                     end;
                  else;
                     %
                     % annualize
                     %
                     Y = Annualize(StateVarStructure.Y,DSGEModel.annual,DSGEModel.annualscale);
                     YInit = Annualize(StateVarStructure.XiInit,DSGEModel.annual,DSGEModel.annualscale);
                     if isempty(StateVarStructure.wthT)==0;
                        wtT = Annualize(StateVarStructure.wthT,DSGEModel.annual,DSGEModel.annualscale);
                     else;
                        wtT = zeros(size(Y));
                     end;
                     if isempty(StateVarStructure.X)==0;
                        X = StateVarStructure.X;
                        A = StateVarStructure.A;
                        AX = Annualize(A'*X,DSGEModel.annual,DSGEModel.annualscale);
                     else;
                        AX = zeros(size(Y));
                     end;
                     q = size(StateVarStructure.etaDecomp,3);
                     YDecomp = zeros(DSGEModel.n,size(Y,2),q);
                     for i=1:q;
                        YDecomp(:,:,i) = Annualize(StateVarStructure.etaDecomp(:,:,i),DSGEModel.annual,DSGEModel.annualscale);
                     end;
                     FirstPos = size(StateVarStructure.Y,2)-size(Y,2)+1;
                     LastPos = size(StateVarStructure.Y,2);
                     KsitT = StateVarStructure.KsitT(:,FirstPos:LastPos);
                     KsiDecomp = StateVarStructure.XietaDecomp(:,FirstPos:LastPos,:);
                     KsiInit = StateVarStructure.XietaInit(:,FirstPos:LastPos);
                     DateVector = DateVector(FirstPos:LastPos);
                     KeepShocks = StateVarStructure.KeepVar;
                  end;
                  ShockNames = ShockNames(KeepShocks,:);
                  save(MatFile,'Y','AX','KsitT','wtT','YInit','YDecomp','KsiInit','KsiDecomp','YNames','StateVariableNames','ShockNames','DateVector');
                  %
                  % write to an m-file
                  %
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(MatFile) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(MatFile));
                  fprintf(fid,'%%\n%% nxT matrix with the data on the observed variables\n%%\n');
                  fprintf(fid,'Y = DataStructure.Y;\n');
                  fprintf(fid,'%%\n%% nxT matrix with steady-state values in measurement equation\n%%\n');
                  fprintf(fid,'AX = DataStructure.AX;\n');
                  fprintf(fid,'%%\n%% nxT matrix with smoothed estimates of measurement errors\n%%\n');
                  fprintf(fid,'wtT = DataStructure.wtT;\n');
                  fprintf(fid,'%%\n%% rxT matrix with smooth estimates of state variables\n%%\n');
                  fprintf(fid,'KsitT = DataStructure.KsitT;\n');
                  fprintf(fid,'%%\n%% nxT matrix with impact of initial state variables on obs variable decomp\n%%\n');
                  fprintf(fid,'YInit = DataStructure.YInit;\n');
                  fprintf(fid,'%%\n%% nxTxq matrix with the obs variable decomposition into the q shocks\n%%\n');
                  fprintf(fid,'YDecomp = DataStructure.YDecomp;\n');
                  fprintf(fid,'%%\n%% rxT matrix with the impact of initial state variables on state variable decomp\n%%\n');
                  fprintf(fid,'KsiInit = DataStructure.KsiInit;\n');
                  fprintf(fid,'%%\n%% rxTxq matrix with the state variable decompositon into the q shocks\n%%\n');
                  fprintf(fid,'KsiDecomp = DataStructure.KsiDecomp;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                  fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the structural shocks\n%%\n');
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% vector with dates\n%%\n');
                  fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  if DSGEModel.RunDriver==0;
                     txt = ['The observed variable decomposition data have been saved to the file "' GetFilename(MatFile) '" in the directory "' GetPath(MatFile) '". The file contains 12 entries: Y (matrix with the observed variables); AX (matrix with steady-states for the observed variables); wtT (smooth estmates of the measurement errors); KsitT (smooth estimates of the state variables); YInit (matrix with the impact of initial states on observed variable decomposition); YDecomp (matrix with the observed variable decomposition for shocks); KsiInit (matrix with the impact of initial states on state variable decomposition); KsiDecomp (matrix with the state variable decomposition for shocks); YNames (matrix with the names of the observed variables); StateVariableNames (matrix with the state variable decomposition for shocks); ShockNames (matrix with names for the shocks); and DateVector (vector with dates). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                     About(txt,'information','Observed Variable Decomposition - Posterior Mode',500,600,CurrINI);
                  end;
               end;
               %
               if DSGEModel.RunDriver==0;
                  txt = ['Would you like to produce scatter plots of the decompositions for the ' lower(AnnualStr) ' data instead of time series based bar charts?'];
                  answer = Query(txt,'question',200,'Observed Variable Decomposition - Posterior Mode',500,'no',CurrINI);
                  %
                  % we can now send the data for graphing
                  %
                  if strcmp(lower(answer),'no')==1;
                     ObsVarDecompDLG('init',StateVarStructure,'Posterior Mode',AnnualStr,CurrINI,DSGEModel);
                  else;
                     ScatterDecompDLG('init',StateVarStructure,'Posterior Mode',AnnualStr,CurrINI,DSGEModel);
                  end;
               else;
                  SetLogText(strvcat('* Finished calculations.',' '));
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ObsVarPathPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%            else;
%               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            %
            % we can now calculate the state shocks
            %
            StateVarStructure = CalculateDSGEStateVariables(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,1,0,'');
            if isempty(StateVarStructure)==0;
               if gcbo==controls.ovp.postmode;
                  AnnualStr = 'Original';
               else;
                  AnnualStr = 'Annualized';
               end;
               %
               % ask if we should look at shock groups rather than individual shocks
               %
               ShockType = 0;
               if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                  txt = 'Would you like to view plots of observed variable decomposition paths for shock groups instead of for the individual shocks?';
                  answer = Query(txt,'question',140,'Observed Variable Decomposition Paths - Posterior Mode',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     etaDecomp = zeros(size(StateVarStructure.etaDecomp,1),size(StateVarStructure.etaDecomp,2),max(DSGEModel.ShockGroups));
                     for i=1:max(DSGEModel.ShockGroups);
                        Ind = (DSGEModel.ShockGroups==i).*(1:length(DSGEModel.ShockGroups));
                        Ind = Ind(Ind>0);
                        DecompTmp = StateVarStructure.etaDecomp(:,:,Ind);
                        if length(size(DecompTmp))==3;
                           DecompTmp = sum(DecompTmp,3);
                        end;
                        etaDecomp(:,:,i) = DecompTmp;
                     end;
                     StateVarStructure.etaDecomp = etaDecomp;
                     ShockNames = DSGEModel.ShockGroupNames;
                     for i=1:max(DSGEModel.ShockGroups);
                        ShockNames(i,:) = strrep(ShockNames(i,:),'_',' ');
                     end;
                     ShockType = 1;
                  else;
                     ShockNames = DSGEModel.StateShockNames(StateVarStructure.KeepVar,:);
                  end;
               else;
                  ShockNames = DSGEModel.StateShockNames(StateVarStructure.KeepVar,:);
               end;
               %
               % get the terms
               %
               DecompShocks = StateVarStructure.etaDecomp;
               DecompInitState = StateVarStructure.XiInit;
               if isempty(DSGEModel.X)==0;
                  DecompSteadyState = StateVarStructure.A'*StateVarStructure.X;
               else;
                  DecompSteadyState = zeros(size(DecompInitState));
               end;
               if isempty(StateVarStructure.wthT)==0;
                  DecompMeasureError = StateVarStructure.wthT;
               else;
                  DecompMeasureError = zeros(size(DecompInitState));
               end;
               Y = StateVarStructure.Y;
               %
               % check if we should annualize
               %
               if strcmp(lower(AnnualStr),'annualized')==1;
                  Y = Annualize(Y,DSGEModel.annual,DSGEModel.annualscale);
                  DecompInitState = Annualize(DecompInitState,DSGEModel.annual,DSGEModel.annualscale);
                  DecompSteadyState = Annualize(DecompSteadyState,DSGEModel.annual,DSGEModel.annualscale);
                  DecompMeasureError = Annualize(DecompMeasureError,DSGEModel.annual,DSGEModel.annualscale);
                  DecompShocksTmp = zeros(size(Y,1),size(Y,2),size(DecompShocks,3));
                  for i=1:size(DecompShocks,3);
                     DecompShocksTmp(:,:,i) = Annualize(DecompShocks(:,:,i),DSGEModel.annual,DSGEModel.annualscale);
                  end;
                  DecompShocks = DecompShocksTmp;
               end;
               DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency);
               %
               % Make sure that DateVector is not longer than the number of periods for the shocks
               %
               if length(DateVector)>size(Y,2);
                  DateVector = DateVector(1,length(DateVector)-size(Y,2)+1:length(DateVector));
               end;
               %
               % ask if we should save the data to file
               %
               txt = 'Would you like to save the observed variable decomposition paths at posterior mode to disk?';
               answer = Query(txt,'question',140,'Save - Observed Variable decomposition Paths',500,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  if ShockType==0;
                     file = FixFilePath([DSGEModel.OutputDirectory '\ObsVarDecompPath-' AnnualStr '-Groups-PosteriorMode.mat']);
                  else;
                     file = FixFilePath([DSGEModel.OutputDirectory '\ObsVarDecompPath-' AnnualStr '-PosteriorMode.mat']);
                  end;
                  YNames = DSGEModel.VariableNames;
                  save(file,'YNames','ShockNames','Y','DecompInitState','DecompSteadyState','DecompMeasureError','DecompShocks','DateVector');
                  %
                  % create a matlab file to read the data
                  %
                  mfile = FixFilePath([DSGEModel.OutputDirectory '\OVP' AnnualStr 'PostMode.m']);
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  if ShockType==0;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                     GroupStr = '';
                  else;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                     GroupStr = ' group';
                  end;
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% matrix with data on the observed variables\n%%\n');
                  fprintf(fid,'Y = DataStructure.Y;\n');
                  fprintf(fid,'%%\n%% matrix with estimates of the initial state term\n%%\n');
                  fprintf(fid,'DecompInitState = DataStructure.DecompInitState;\n');
                  fprintf(fid,'%%\n%% matrix with estimates of the steady-state term\n%%\n');
                  fprintf(fid,'DecompSteadyState = DataStructure.DecompSteadyState;\n');
                  fprintf(fid,'%%\n%% matrix with estimates of the measurement error term\n%%\n');
                  fprintf(fid,'DecompMeasureError = DataStructure.DecompMeasureError;\n');
                  fprintf(fid,'%%\n%% 3D matrix with estimates of the shock%s terms\n%%\n',GroupStr);
                  fprintf(fid,'DecompShocks = DataStructure.DecompShocks;\n');
                  fprintf(fid,'%%\n%% vector with numeric dates for the observed variables\n%%\n');
                  fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  txt = ['The observed variable decomposition paths at posterior mode have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 8 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the shock' GroupStr ' names), Y (matrix with the data on the observed variables), DecompInitState (matrix with estimates of the initial state term), DecompSteadyState (matrix with estimates of the steady-state term), DecompMeasureError (matrix with estimates of the measurement error term), DecompShocks (3D matrix with estimates of the shock' GroupStr ' terms), DateVector (vector with dates for the observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                  About(txt,'information','Observed Variable Decomposition Paths - Posterior Mode',400,500,CurrINI);
               end;
               %
               % display the results
               %
               ObsVarDecompPathDLG('init',Y,DecompInitState,DecompSteadyState,DecompMeasureError,DecompShocks,[],DateVector,ShockNames,ShockType,'Posterior Mode',AnnualStr,CurrINI,DSGEModel);
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ObsVarDecompPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            theta = ModeData.thetaMode;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Observed Variable Decompositions','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            %
            %
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  NumDraws = length(LogPost);
                  clear('PostSample','LogPost','AcceptedDraws');
                  drawnow;
                  %
                  % select which posterior draws to use
                  %
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumDraws,:);
                  NumDraws = NumDraws-NumBurnin;
                  %
                  % check which draws we should use
                  %
                  if DSGEModel.PosteriorSampler<=7;
                     UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                     if length(UseDraws)<NumDraws;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        UsedDraws = length(UseDraws);
                     else;
                        UsedDraws = NumDraws;
                     end;
                  else;
                     UsedDraws = NumDraws;
                  end;
                  %
                  % are we using annualized data or the original
                  %
                  if gcbo==controls.ovd.posterior;
                     AnnualizeData = 0;
                     QueryHead = 'Observed Variable Decomposition - Original Data';
                     VarType = 'Original';
                  else;
                     AnnualizeData = 1;
                     QueryHead = 'Observed Variable Decomposition - Annualized Data';
                     VarType = 'Annualized';
                  end;
                  %
                  % First we check if the calculations have already been performed
                  %
                  if OVPExist(DSGEModel,AnnualizeData,UsedDraws,NumDraws,CurrChain,1)==1;
                     txt = 'YADA has located results for the observed variable decompositions on disk. Would you like to use these results?';
                     answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                  else;
                     %
                     % compute the observed variable decomposition paths for all the posterior draws
                     %
                     DoneCalc = DSGEObsVarDecomposition(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,AnnualizeData,NumDraws,CurrChain,1);
                  end;
                  %
                  % clear everything
                  %
                  clear('thetaPostSample');
                  %
                  if DoneCalc==1;
                     ShockType = 0;
                     if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                        txt = 'Would you like to view plots of observed variable decompositions for shock groups instead of for the individual shocks?';
                        answer = Query(txt,'question',200,QueryHead,500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           ShockType = 1;
                        end;
                     end;
                     %
                     % compute the distributional details
                     %
                     OVDPs = DSGEObsVarDecompDistribution(DSGEModel,CurrINI,AnnualizeData,ShockType,UsedDraws,NumDraws,CurrChain,1,Weights);
                     %
                     % ask if we should save results to disk
                     %
                     txt = 'Would you like to save the observed variable decompositions to file?';
                     answer = Query(txt,'question',140,'Save - Observed Variable Decomposition',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        YNames = DSGEModel.VariableNames;
                        DateVector = OVDPs.DateVector;
                        Y = OVDPs.Y;
                        DecompInitState = OVDPs.DecompInitState;
                        DecompSteadyState = OVDPs.DecompSteadyState;
                        DecompMeasureError = OVDPs.DecompMeasureError;
                        DecompShocks = OVDPs.DecompShocks;
                        DecompMedianInitState = OVDPs.DecompMedianInitState;
                        DecompMedianSteadyState = OVDPs.DecompMedianSteadyState;
                        DecompMedianMeasureError = OVDPs.DecompMedianMeasureError;
                        DecompMedianShocks = OVDPs.DecompMedianShocks;
                        ShockNames = OVDPs.ShockNames;
                        if ShockType==1;
                           file = FixFilePath([DSGEModel.OutputDirectory '\ObsVarDecompDist-' VarType '-Group-' int2str(CurrChain) '-' int2str(UsedDraws) '-' int2str(NumDraws) '.mat']);
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\OVDDist' VarType 'Group' int2str(CurrChain) int2str(UsedDraws) int2str(NumDraws) '.m']);
                        else;
                           file = FixFilePath([DSGEModel.OutputDirectory '\ObsVarDecompDist-' VarType '-' int2str(CurrChain) '-' int2str(UsedDraws) '-' int2str(NumDraws) '.mat']);
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\OVDDist' VarType int2str(CurrChain) int2str(UsedDraws) int2str(NumDraws) '.m']);
                        end;
                        save(file,'YNames','ShockNames','Y','DecompInitState','DecompSteadyState','DecompMeasureError','DecompShocks','DecompMedianInitState','DecompMedianSteadyState','DecompMedianMeasureError','DecompMedianShocks','DateVector');
                        %
                        % create a matlab file to read the data
                        %
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        if ShockType==0;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                           GroupStr = '';
                        else;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                           GroupStr = ' group';
                        end;
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% matrix with data on the observed variables\n%%\n');
                        fprintf(fid,'Y = DataStructure.Y;\n');
                        fprintf(fid,'%%\n%% matrix with posterior mean estimates of the initial state term\n%%\n');
                        fprintf(fid,'DecompInitState = DataStructure.DecompInitState;\n');
                        fprintf(fid,'%%\n%% matrix with posterior mean estimates of the steady-state term\n%%\n');
                        fprintf(fid,'DecompSteadyState = DataStructure.DecompSteadyState;\n');
                        fprintf(fid,'%%\n%% matrix with posterior mean estimates of the measurement error term\n%%\n');
                        fprintf(fid,'DecompMeasureError = DataStructure.DecompMeasureError;\n');
                        fprintf(fid,'%%\n%% 3D matrix with posterior mean estimates of the shock%s terms\n%%\n',GroupStr);
                        fprintf(fid,'DecompShocks = DataStructure.DecompShocks;\n');
                        fprintf(fid,'%%\n%% matrix with posterior median estimates of the initial state term\n%%\n');
                        fprintf(fid,'DecompMedianInitState = DataStructure.DecompMedianInitState;\n');
                        fprintf(fid,'%%\n%% matrix with posterior median estimates of the steady-state term\n%%\n');
                        fprintf(fid,'DecompMedianSteadyState = DataStructure.DecompMedianSteadyState;\n');
                        fprintf(fid,'%%\n%% matrix with posterior median estimates of the measurement error term\n%%\n');
                        fprintf(fid,'DecompMedianMeasureError = DataStructure.DecompMedianMeasureError;\n');
                        fprintf(fid,'%%\n%% 3D matrix with posterior median estimates of the shock%s terms\n%%\n',GroupStr);
                        fprintf(fid,'DecompMedianShocks = DataStructure.DecompMedianShocks;\n');
                        fprintf(fid,'%%\n%% vector with numeric dates for the observed variables\n%%\n');
                        fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The observed variable decompositions data have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 12 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the shock' GroupStr ' names), Y (matrix with the data on the observed variables), DecompInitState (matrix with posterior mean estimates of the initial state term), DecompSteadyState (matrix with posterior mean estimates of the steady-state term), DecompMeasureError (matrix with posterior mean estimates of the measurement error term), DecompShocks (3D matrix with posterior mean estimates of the shock' GroupStr ' terms), DecompMedianInitState (matrix with posterior median estimates of the initial state term), DecompMedianSteadyState (matrix with posterior median estimates of the steady-state term), DecompMedianMeasureError (matrix with posterior median estimates of the measurement error term), DecompMedianShocks (3D matrix with posterior median estimates of the shock' GroupStr ' terms), DateVector (vector with dates for the observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information',QueryHead,500,600,CurrINI);
                     end;
                     %
                     % plotting decision
                     %
                     txt = ['Would you like to produce scatter plots of the decompositions for the ' lower(VarType) ' data instead of time series based bar charts?'];
                     answer = Query(txt,'question',200,'Observed Variable Decomposition - Posterior Distribution',600,'no',CurrINI);
                     %
                     % now display the results
                     %
                     if strcmp(lower(answer),'no')==1;
                        ObsVarDecompDistDLG('init',OVDPs,'Posterior',VarType,ShockType,CurrINI,DSGEModel);
                     else;
                        ScatterDecompDistDLG('init',OVDPs,'Posterior',VarType,ShockType,CurrINI,DSGEModel);
                     end;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ObsVarPathPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            theta = ModeData.thetaMode;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Observed Variable Decomposition Paths','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            %
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  NumDraws = length(LogPost);
                  clear('PostSample','LogPost','AcceptedDraws');
                  drawnow;
                  %
                  % select which posterior draws to use
                  %
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumDraws,:);
                  NumDraws = NumDraws-NumBurnin;
                  %
                  % check which draws we should use
                  %
                  if DSGEModel.PosteriorSampler<=7;
                     UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                     if length(UseDraws)<NumDraws;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        UsedDraws = length(UseDraws);
                     else;
                        UsedDraws = NumDraws;
                     end;
                  else;
                     UsedDraws = NumDraws;
                  end;
                  %
                  % are we using annualized data or the original
                  %
                  if gcbo==controls.ovp.posterior;
                     AnnualizeData = 0;
                     QueryHead = 'Observed Variable Decomposition Paths - Original Data';
                     VarType = 'Original';
                  else;
                     AnnualizeData = 1;
                     QueryHead = 'Observed Variable Decomposition Paths - Annualized Data';
                     VarType = 'Annualized';
                  end;
                  %
                  % First we check if the calculations have already been performed
                  %
                  if OVPExist(DSGEModel,AnnualizeData,UsedDraws,NumDraws,CurrChain,1)==1;
                     txt = 'YADA has located results for the observed variable decomposition paths on disk. Would you like to use these results?';
                     answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                  else;
                     %
                     % compute the observed variable decomposition paths for all the posterior draws
                     %
                     DoneCalc = DSGEObsVarDecomposition(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,AnnualizeData,NumDraws,CurrChain,1);
                  end;
                  %
                  % clear everything
                  %
                  clear('thetaPostSample');
                  %
                  if DoneCalc==1;
                     ShockType = 0;
                     if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                        txt = 'Would you like to view plots of observed variable decomposition paths for shock groups instead of for the individual shocks?';
                        answer = Query(txt,'question',200,QueryHead,500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           ShockType = 1;
                        end;
                     end;
                     %
                     % compute the distributional details
                     %
                     OVDPs = DSGEObsVarDecompDistribution(DSGEModel,CurrINI,AnnualizeData,ShockType,UsedDraws,NumDraws,CurrChain,1,Weights);
                     %
                     % ask if we should save results to disk
                     %
                     txt = 'Would you like to save the observed variable decomposition paths to file?';
                     answer = Query(txt,'question',140,'Save - Observed Variable Decomposition Paths',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        YNames = DSGEModel.VariableNames;
                        DateVector = OVDPs.DateVector;
                        Y = OVDPs.Y;
                        DecompInitState = OVDPs.DecompInitState;
                        DecompSteadyState = OVDPs.DecompSteadyState;
                        DecompMeasureError = OVDPs.DecompMeasureError;
                        DecompShocks = OVDPs.DecompShocks;
                        ShockNames = OVDPs.ShockNames;
                        Quantiles = OVDPs.Quantiles;
                        if ShockType==1;
                           file = FixFilePath([DSGEModel.OutputDirectory '\ObsVarDecompPathDist-' VarType '-Group-' int2str(CurrChain) '-' int2str(UsedDraws) '-' int2str(NumDraws) '.mat']);
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\OVDPDist' VarType 'Group' int2str(CurrChain) int2str(UsedDraws) int2str(NumDraws) '.m']);
                        else;
                           file = FixFilePath([DSGEModel.OutputDirectory '\ObsVarDecompPathDist-' VarType '-' int2str(CurrChain) '-' int2str(UsedDraws) '-' int2str(NumDraws) '.mat']);
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\OVDPDist' VarType int2str(CurrChain) int2str(UsedDraws) int2str(NumDraws) '.m']);
                        end;
                        save(file,'YNames','ShockNames','Y','DecompInitState','DecompSteadyState','DecompMeasureError','DecompShocks','Quantiles','DateVector');
                        %
                        % create a matlab file to read the data
                        %
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        if ShockType==0;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                           GroupStr = '';
                        else;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                           GroupStr = ' group';
                        end;
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% matrix with data on the observed variables\n%%\n');
                        fprintf(fid,'Y = DataStructure.Y;\n');
                        fprintf(fid,'%%\n%% matrix with estimates of the initial state term\n%%\n');
                        fprintf(fid,'DecompInitState = DataStructure.DecompInitState;\n');
                        fprintf(fid,'%%\n%% matrix with estimates of the steady-state term\n%%\n');
                        fprintf(fid,'DecompSteadyState = DataStructure.DecompSteadyState;\n');
                        fprintf(fid,'%%\n%% matrix with estimates of the measurement error term\n%%\n');
                        fprintf(fid,'DecompMeasureError = DataStructure.DecompMeasureError;\n');
                        fprintf(fid,'%%\n%% 3D matrix with estimates of the shock%s terms\n%%\n',GroupStr);
                        fprintf(fid,'DecompShocks = DataStructure.DecompShocks;\n');
                        fprintf(fid,'%%\n%% structure with quantile data\n%%\n');
                        fprintf(fid,'Quantiles = DataStructure.Quantiles;\n');
                        fprintf(fid,'%%\n%% vector with numeric dates for the observed variables\n%%\n');
                        fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The observed variable decomposition paths data have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 9 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the shock' GroupStr ' names), Y (matrix with the data on the observed variables), DecompInitState (matrix with estimates of the initial state term), DecompSteadyState (matrix with estimates of the steady-state term), DecompMeasureError (matrix with estimates of the measurement error term), DecompShocks (3D matrix with estimates of the shock' GroupStr ' terms), Quantiles (structure with quantile data on the decomposition of the observed variables for the sum of the initial state, the steady-state, the measurement error, and shock' GroupStr ' terms), DateVector (vector with dates for the observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information',QueryHead,400,500,CurrINI);
                     end;
                     %
                     % display the results
                     %
                     ObsVarDecompPathDLG('init',OVDPs.Y,OVDPs.DecompInitState,OVDPs.DecompSteadyState,OVDPs.DecompMeasureError,OVDPs.DecompShocks,OVDPs.Quantiles,OVDPs.DateVector,OVDPs.ShockNames,ShockType,'Posterior Distribution',VarType,CurrINI,DSGEModel);
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'StateVarDecompInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view graphs of the state variables decompositions before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'State Variable Decomposition - Initial Values',500,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
%               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
               %
               % Try to calculate state variables. First, however, the code needs to check if a unique convergent
               % solution exists.
               %
               if (isfield(controls,'svs')==1)&(CheckStateScenarioData(DSGEModel)==1);
                  txt = 'Would you like to estimate structural shocks using a constrained Kalman filter routine instead of the standard Kalman filter?';
                  answer = Query(txt,'question',200,'State Variable Decomposition - Initial Values',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     ConEst = 1;
                  else;
                     ConEst = 0;
                  end;
               else;
                  ConEst = 0;
               end;
               if ConEst==0;
                  [StateVarStructure,mcode,kalmanstatus] = CalculateDSGEStateVariables(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,1,0,'');
               else;
                  [StateVarStructure,mcode,kalmanstatus] = ConstrainedObsVarDecomp(theta,thetaPositions,ModelParameters,'Initial Values',DSGEModel,CurrINI);
               end;
               if (mcode==1)&(kalmanstatus==0);
                  %
                  % check if we should save the results
                  %
                  txt = ['Would you like to save the decompositions of the state variables at initial values to file?'];
                  answer = Query(txt,'question',140,'Save - State Variable Decompositions',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     StateVariableNames = DSGEModel.StateVariableNames;
                     ShockNames = DSGEModel.StateShockNames;
                     YNames = DSGEModel.VariableNames;
                     if ConEst==0;
                        MatFile = FixFilePath([DSGEModel.OutputDirectory '\StateVariableDecompositions-InitialValues.mat']);
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\SVDInitVal.m']);
                     else;
                        MatFile = FixFilePath([DSGEModel.OutputDirectory '\ConstStateVariableDecompositions-InitialValues.mat']);
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\ConSVDInitVal.m']);
                     end;
                     DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency);
                     if length(DateVector)>length(StateVarStructure.Y);
                        DateVector = DateVector(1,length(DateVector)-length(StateVarStructure.Y)+1:length(DateVector));
                     end;
                     KsitT = StateVarStructure.KsitT;
                     Y = StateVarStructure.Y;
                     A = StateVarStructure.A;
                     X = StateVarStructure.X;
                     KeepShocks = StateVarStructure.KeepVar;
                     YDecomp = StateVarStructure.etaDecomp;
                     KsiDecomp = StateVarStructure.XietaDecomp;
                     YInit = StateVarStructure.XiInit;
                     KsiInit = StateVarStructure.XietaInit;
                     wtT = StateVarStructure.wthT;
                     ShockNames = ShockNames(KeepShocks,:);
                     save(MatFile,'Y','A','X','KsitT','wtT','YInit','YDecomp','KsiInit','KsiDecomp','YNames','StateVariableNames','ShockNames','DateVector');
                     %
                     % write to an m-file
                     %
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(MatFile) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(MatFile));
                     fprintf(fid,'%%\n%% nxT matrix with the data on the observed variables\n%%\n');
                     fprintf(fid,'Y = DataStructure.Y;\n');
                     fprintf(fid,'%%\n%% kxn matrix on deterministic variables in measurement equation\n%%\n');
                     fprintf(fid,'A = DataStructure.A;\n');
                     fprintf(fid,'%%\n%% kxT matrix with the data on the deterministic variables\n%%\n');
                     fprintf(fid,'X = DataStructure.X;\n');
                     fprintf(fid,'%%\n%% nxT matrix with smoothed estimates of measurement errors\n%%\n');
                     fprintf(fid,'wtT = DataStructure.wtT;\n');
                     fprintf(fid,'%%\n%% rxT matrix with smooth estimates of state variables\n%%\n');
                     fprintf(fid,'KsitT = DataStructure.KsitT;\n');
                     fprintf(fid,'%%\n%% nxT matrix with impact of initial state variables on obs variable decomp\n%%\n');
                     fprintf(fid,'YInit = DataStructure.YInit;\n');
                     fprintf(fid,'%%\n%% nxTxq matrix with the obs variable decomposition into the q shocks\n%%\n');
                     fprintf(fid,'YDecomp = DataStructure.YDecomp;\n');
                     fprintf(fid,'%%\n%% rxT matrix with the impact of initial state variables on state variable decomp\n%%\n');
                     fprintf(fid,'KsiInit = DataStructure.KsiInit;\n');
                     fprintf(fid,'%%\n%% rxTxq matrix with the state variable decompositon into the q shocks\n%%\n');
                     fprintf(fid,'KsiDecomp = DataStructure.KsiDecomp;\n');
                     fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                     fprintf(fid,'YNames = DataStructure.YNames;\n');
                     fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                     fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                     fprintf(fid,'%%\n%% string matrix with the names of the structural shocks\n%%\n');
                     fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                     fprintf(fid,'%%\n%% vector with dates\n%%\n');
                     fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     txt = ['The state variable decomposition data for the initial values have been saved to the file "' GetFilename(MatFile) '" in the directory "' GetPath(MatFile) '". The file contains 13 entries: Y (matrix with the observed variables); A (matrix with coefficients on the deterministic variables); X (matrix with the deterministic variables); wtT (smooth estmates of any measurement errors); KsitT (smooth estimates of the state variables); YInit (matrix with the impact of initial states on observed variable decomposition); YDecomp (matrix with the observed variable decomposition for shocks); KsiInit (matrix with the impact of initial states on state variable decomposition); KsiDecomp (); YNames (); StateVariableNames (matrix with the state variable decomposition for shocks); ShockNames (matrix with names for the shocks); and DateVector (vector with dates). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                     About(txt,'information','State Variable Decomposition - Initial Values',500,600,CurrINI);
                  end;
                  %
                  % we're OK
                  %
                  if isempty(StateVarStructure)==0;
                     StateVarDecompDLG('init',StateVarStructure,'Initial Values',CurrINI,DSGEModel);
                  end;
               elseif (mcode==1)&(kalmanstatus~=0);
                  if kalmanstatus==1;
                     txt = 'The state variables are not stationary at the initial values.';
                  else;
                     txt = 'The covariance matrix of the forecast of the observed variables in period t conditional on data until t-1 is not positive definite for some time period t. This implies that the log-likelihood value is a NaN (or a complex number) in Matlab.';
                  end;
                  About(txt,'information','State Variable Decomposition - Initial Values',200,500,CurrINI);
               elseif mcode~=1;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','State Variable Decomposition - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'StateVarDecompPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%            else;
%               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            %
            % we can now calculate the state shocks
            %
            if (isfield(controls,'svs')==1)&(CheckStateScenarioData(DSGEModel)==1);
               txt = 'Would you like to estimate structural shocks using a constrained Kalman filter routine instead of the standard Kalman filter?';
               answer = Query(txt,'question',200,'State Variable Decomposition - Posterior Mode',500,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  ConEst = 1;
               else;
                  ConEst = 0;
               end;
            else;
               ConEst = 0;
            end;
            if ConEst==0;
               StateVarStructure = CalculateDSGEStateVariables(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,1,0,'');
            else;
               StateVarStructure = ConstrainedObsVarDecomp(theta,thetaPositions,ModelParameters,'Posterior Mode',DSGEModel,CurrINI);
            end;
            if isempty(StateVarStructure)==0;
               %
               txt = ['Would you like to save the decompositions of the state variables at posterior mode to file?'];
               answer = Query(txt,'question',140,'Save - State Variable Decompositions',500,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  StateVariableNames = DSGEModel.StateVariableNames;
                  ShockNames = DSGEModel.StateShockNames;
                  YNames = DSGEModel.VariableNames;
                  if ConEst==0;
                     MatFile = FixFilePath([DSGEModel.OutputDirectory '\StateVariableDecompositions-PostMode.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\SVDPostMode.m']);
                  else;
                     MatFile = FixFilePath([DSGEModel.OutputDirectory '\ConstStateVariableDecompositions-PostMode.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\ConSVDPostMode.m']);
                  end;
                  DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency);
                  if length(DateVector)>length(StateVarStructure.Y);
                     DateVector = DateVector(1,length(DateVector)-length(StateVarStructure.Y)+1:length(DateVector));
                  end;
                  KsitT = StateVarStructure.KsitT;
                  Y = StateVarStructure.Y;
                  A = StateVarStructure.A;
                  X = StateVarStructure.X;
                  KeepShocks = StateVarStructure.KeepVar;
                  YDecomp = StateVarStructure.etaDecomp;
                  KsiDecomp = StateVarStructure.XietaDecomp;
                  YInit = StateVarStructure.XiInit;
                  KsiInit = StateVarStructure.XietaInit;
                  wtT = StateVarStructure.wthT;
                  ShockNames = ShockNames(KeepShocks,:);
                  save(MatFile,'Y','A','X','KsitT','wtT','YInit','YDecomp','KsiInit','KsiDecomp','YNames','StateVariableNames','ShockNames','DateVector');
                  %
                  % write to an m-file
                  %
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(MatFile) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(MatFile));
                  fprintf(fid,'%%\n%% nxT matrix with the data on the observed variables\n%%\n');
                  fprintf(fid,'Y = DataStructure.Y;\n');
                  fprintf(fid,'%%\n%% kxn matrix on deterministic variables in measurement equation\n%%\n');
                  fprintf(fid,'A = DataStructure.A;\n');
                  fprintf(fid,'%%\n%% kxT matrix with the data on the deterministic variables\n%%\n');
                  fprintf(fid,'X = DataStructure.X;\n');
                  fprintf(fid,'%%\n%% nxT matrix with smoothed estimates of measurement errors\n%%\n');
                  fprintf(fid,'wtT = DataStructure.wtT;\n');
                  fprintf(fid,'%%\n%% rxT matrix with smooth estimates of state variables\n%%\n');
                  fprintf(fid,'KsitT = DataStructure.KsitT;\n');
                  fprintf(fid,'%%\n%% nxT matrix with impact of initial state variables on obs variable decomp\n%%\n');
                  fprintf(fid,'YInit = DataStructure.YInit;\n');
                  fprintf(fid,'%%\n%% nxTxq matrix with the obs variable decomposition into the q shocks\n%%\n');
                  fprintf(fid,'YDecomp = DataStructure.YDecomp;\n');
                  fprintf(fid,'%%\n%% rxT matrix with the impact of initial state variables on state variable decomp\n%%\n');
                  fprintf(fid,'KsiInit = DataStructure.KsiInit;\n');
                  fprintf(fid,'%%\n%% rxTxq matrix with the state variable decompositon into the q shocks\n%%\n');
                  fprintf(fid,'KsiDecomp = DataStructure.KsiDecomp;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                  fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the structural shocks\n%%\n');
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% vector with dates\n%%\n');
                  fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  txt = ['The state variable decomposition data have been saved to the file "' GetFilename(MatFile) '" in the directory "' GetPath(MatFile) '". The file contains 13 entries: Y (matrix with the observed variables); A (matrix with coefficients on the deterministic variables); X (matrix with the deterministic variables); wtT (smooth estmates of any measurement errors); KsitT (smooth estimates of the state variables); YInit (matrix with the impact of initial states on observed variable decomposition); YDecomp (matrix with the observed variable decomposition for shocks); KsiInit (matrix with the impact of initial states on state variable decomposition); KsiDecomp (); YNames (); StateVariableNames (matrix with the state variable decomposition for shocks); ShockNames (matrix with names for the shocks); and DateVector (vector with dates). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                  About(txt,'information','State Variable Decomposition - Posterior Mode',500,600,CurrINI);
               end;
               %
               % we can now send the data for graphing
               %
               StateVarDecompDLG('init',StateVarStructure,'Posterior Mode',CurrINI,DSGEModel);
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'CorrDecompInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view graphs of the correlation decompositions before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Correlation Decompositions - Initial Values',450,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
               %
               % check if we are concerned with observed variables or state variables
               %
               if gcbo==controls.corrdecomp.obsvar.initialvalues;
                  VarStr = 'Observed Variables';
                  VarType = 1;
                  VariableNames = DSGEModel.VariableNames;
               else;
                  VarStr = 'State Variables';
                  VarType = 2;
                  VariableNames = DSGEModel.StateVariableNames;
               end;
               %
               % compute the decompositions
               %
               [CorrDec,mcode] = DSGECorrelationDecompTheta(theta,thetaPositions,ModelParameters,VarStr,DSGEModel,CurrINI);
               if mcode==1;
                  if isempty(CorrDec)==0;
                     %
                     % save the results to disk
                     %
                     txt = ['Would you like to save the correlation decompositions of the ' lower(VarStr) ' at initial values to disk?'];
                     answer = Query(txt,'question',200,'Save - Correlation Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        if VarType==1;
                           YDecomp = CorrDec.Y;
                           YNames = DSGEModel.VariableNames;
                           ShockNames = CorrDec.ShockNames;
                           AutoCovHorizon = CorrDec.AutoCovHorizon;
                           R = CorrDec.R;
                           file = FixFilePath([DSGEModel.OutputDirectory '\CorrDec-ObsVar-InitialValues.mat']);
                           save(file,'YDecomp','YNames','ShockNames','AutoCovHorizon','R');
                           %
                           % create the script file
                           %
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\CorrDecOVarInitVal.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% string matrix with names of the n observed variables\n%%\n');
                           fprintf(fid,'YNames = DataStructure.YNames;\n');
                           fprintf(fid,'%%\n%% string matrix with names of the q shocks\n%%\n');
                           fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                           fprintf(fid,'%%\n%% 3D [(n(n+1)/2)x(2h+1)x(q+1)] matrix with correlation decompositions of the observed variables\n%%\n');
                           fprintf(fid,'YDecomp = DataStructure.YDecomp;\n');
                           fprintf(fid,'%%\n%% length of the autocovariance horizon (h)\n%%\n');
                           fprintf(fid,'AutoCovHorizon = DataStructure.AutoCovHorizon;\n');
                           fprintf(fid,'%%\n%% nxn population covariance matrix of the observed variables due to the measurement errors\n%%\n');
                           fprintf(fid,'R = DataStructure.R;\n');
                           %
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                           %
                           txt = ['The correlation decompositions of the observed variables at initial values have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 5 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the shocks), YDecomp (an nx(2h+1)x(q+1) matrix with the correlation decompositions of the observed variables for autocovariance horizons -h until h of the q shocks and the measurement error), AutoCovHorizon (integer with the length of the autocovariance horizon, i.e. h), and R (covariance matrix of the measurement errors). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                           About(txt,'information','Correlation Decompositions - Initial Values',500,600,CurrINI);
                           drawnow;
                           pause(0.02);
                        else;
                           StateDecomp = CorrDec.Xi;
                           StateVariableNames = DSGEModel.StateVariableNames;
                           ShockNames = CorrDec.ShockNames;
                           AutoCovHorizon = CorrDec.AutoCovHorizon;
                           file = FixFilePath([DSGEModel.OutputDirectory '\CorrDec-StateVar-InitialValues.mat']);
                           save(file,'StateDecomp','StateVariableNames','ShockNames','AutoCovHorizon');
                           %
                           % create the script file
                           %
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\CorrDecSVarInitVal.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% string matrix with names of the r state variables\n%%\n');
                           fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                           fprintf(fid,'%%\n%% string matrix with names of the q shocks\n%%\n');
                           fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                           fprintf(fid,'%%\n%% 3D [(r(r+1)/2)x(2h+1)xq] matrix with correlation decompositions of the state variables\n%%\n');
                           fprintf(fid,'StateDecomp = DataStructure.StateDecomp;\n');
                           fprintf(fid,'%%\n%% length of the autocovariance horizon (h)\n%%\n');
                           fprintf(fid,'AutoCovHorizon = DataStructure.AutoCovHorizon;\n');
                           %
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                           %
                           txt = ['The correlation decompositions of the state variables at initial values have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 4 entries: StateVariableNames (string matrix with the names of the state variables), ShockNames (string matrix with the names of the shocks), StateDecomp (an rx(2h+1)xq matrix with the correlation decompositions of the state variables for autocovariance horizons -h until h of the q shocks), and AutoCovHorizon (integer with the length of the autocovariance horizon, i.e. h). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                           About(txt,'information','Correlation Decompositions - Initial Values',500,600,CurrINI);
                           drawnow;
                           pause(0.02);
                        end;
                     end;
                     %
                     % display the results
                     %
                     CorrelationDecompositionDLG('init',CorrDec,VariableNames,VarStr,'DSGE','Initial Values',DSGEModel,CurrINI);
                  end;
               else;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Correlation Decompositions - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'CorrDecompPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            %
            % check if we are concerned with observed variables or state variables
            %
            if gcbo==controls.corrdecomp.obsvar.postmode;
               VarStr = 'Observed Variables';
               VarType = 1;
               VariableNames = DSGEModel.VariableNames;
            elseif gcbo==controls.corrdecomp.statevar.postmode;
               VarStr = 'State Variables';
               VarType = 2;
               VariableNames = DSGEModel.StateVariableNames;
            elseif DSGEModel.RunDriver==1;
               if strcmp(lower(DSGEModel.answers{1}),'obs')==1;
                  VarStr = 'Observed Variables';
                  VarType = 1;
                  VariableNames = DSGEModel.VariableNames;
               else;
                  VarStr = 'State Variables';
                  VarType = 2;
                  VariableNames = DSGEModel.StateVariableNames;
               end;
            end;
            %
            % compute the decompositions
            %
            CorrDec = DSGECorrelationDecompTheta(theta,thetaPositions,ModelParameters,VarStr,DSGEModel,CurrINI);
            if isempty(CorrDec)==0;
               %
               % save the results to disk
               %
               if DSGEModel.RunDriver==0;
                  txt = ['Would you like to save the correlation decompositions of the ' lower(VarStr) ' at posterior mode to disk?'];
                  answer = Query(txt,'question',200,'Save - Correlation Decompositions',500,'no',CurrINI);
               else;
                  answer = DSGEModel.answers{2};
               end;
               if strcmp(lower(answer),'yes')==1;
                  if VarType==1;
                     if DSGEModel.RunDriver==1;
                        SetLogText(strvcat('* Saving results to: ',['     ' DSGEModel.OutputDirectory]));
                     end;
                     YDecomp = CorrDec.Y;
                     YNames = DSGEModel.VariableNames;
                     ShockNames = CorrDec.ShockNames;
                     AutoCovHorizon = CorrDec.AutoCovHorizon;
                     R = CorrDec.R;
                     file = FixFilePath([DSGEModel.OutputDirectory '\CorrDec-ObsVar-PostMode.mat']);
                     save(file,'YDecomp','YNames','ShockNames','AutoCovHorizon','R');
                     %
                     % create the script file
                     %
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\CorrDecOVarPostMode.m']);
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                     fprintf(fid,'%%\n%% string matrix with names of the n observed variables\n%%\n');
                     fprintf(fid,'YNames = DataStructure.YNames;\n');
                     fprintf(fid,'%%\n%% string matrix with names of the q shocks\n%%\n');
                     fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                     fprintf(fid,'%%\n%% 3D [(n(n+1)/2)x(2h+1)x(q+1)] matrix with correlation decompositions of the observed variables\n%%\n');
                     fprintf(fid,'YDecomp = DataStructure.YDecomp;\n');
                     fprintf(fid,'%%\n%% length of the autocovariance horizon (h)\n%%\n');
                     fprintf(fid,'AutoCovHorizon = DataStructure.AutoCovHorizon;\n');
                     fprintf(fid,'%%\n%% nxn population covariance matrix of the observed variables due to the measurement errors\n%%\n');
                     fprintf(fid,'R = DataStructure.R;\n');
                     %
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     %
                     if DSGEModel.RunDriver==0;
                        txt = ['The correlation decompositions of the observed variables at posterior mode have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 5 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the shocks), YDecomp (an nx(2h+1)x(q+1) matrix with the correlation decompositions of the observed variables for autocovariance horizons -h until h of the q shocks and the measurement error), AutoCovHorizon (integer with the length of the autocovariance horizon, i.e. h), and R (covariance matrix of the measurement errors). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Correlation Decompositions - Posterior Mode',500,600,CurrINI);
                        drawnow;
                        pause(0.02);
                     end;
                  else;
                     if DSGEModel.RunDriver==1;
                        SetLogText(strvcat('* Saving results to: ',['     ' DSGEModel.OutputDirectory]));
                     end;
                     StateDecomp = CorrDec.Xi;
                     StateVariableNames = DSGEModel.StateVariableNames;
                     ShockNames = CorrDec.ShockNames;
                     AutoCovHorizon = CorrDec.AutoCovHorizon;
                     file = FixFilePath([DSGEModel.OutputDirectory '\CorrDec-StateVar-PostMode.mat']);
                     save(file,'StateDecomp','StateVariableNames','ShockNames','AutoCovHorizon');
                     %
                     % create the script file
                     %
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\CorrDecSVarPostMode.m']);
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                     fprintf(fid,'%%\n%% string matrix with names of the r state variables\n%%\n');
                     fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                     fprintf(fid,'%%\n%% string matrix with names of the q shocks\n%%\n');
                     fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                     fprintf(fid,'%%\n%% 3D [(r(r+1)/2)x(2h+1)xq] matrix with correlation decompositions of the state variables\n%%\n');
                     fprintf(fid,'StateDecomp = DataStructure.StateDecomp;\n');
                     fprintf(fid,'%%\n%% length of the autocovariance horizon (h)\n%%\n');
                     fprintf(fid,'AutoCovHorizon = DataStructure.AutoCovHorizon;\n');
                     %
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     %
                     if DSGEModel.RunDriver==0;
                        txt = ['The correlation decompositions of the state variables at posterior mode have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 4 entries: StateVariableNames (string matrix with the names of the state variables), ShockNames (string matrix with the names of the shocks), StateDecomp (an rx(2h+1)xq matrix with the correlation decompositions of the state variables for autocovariance horizons -h until h of the q shocks), and AutoCovHorizon (integer with the length of the autocovariance horizon, i.e. h). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Correlation Decompositions - Posterior Mode',500,600,CurrINI);
                        drawnow;
                        pause(0.02);
                     end;
                  end;
               end;
               %
               % display the results
               %
               if DSGEModel.RunDriver==0;
                  CorrelationDecompositionDLG('init',CorrDec,VariableNames,VarStr,'DSGE','Posterior Mode',DSGEModel,CurrINI);
               else;
                  SetLogText(strvcat('* Finished calculations.',' '));
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'SpectralDecompInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view graphs of the spectral decompositions before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Spectral Decompositions - Initial Values',450,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
               %
               % check if we are concerned with observed variables or state variables
               %
               if gcbo==controls.spectraldecomp.obsvar.initialvalues;
                  VarStr = 'Observed Variables';
                  VarType = 1;
               else;
                  VarStr = 'State Variables';
                  VarType = 2;
               end;
               %
               % compute the decompositions
               %
               [SpecDec,mcode,kalmanstatus] = DSGESpectralDecompTheta(theta,thetaPositions,ModelParameters,VarStr,DSGEModel,CurrINI);
               if (mcode==1)&(kalmanstatus==0);
                  if isempty(SpecDec)==0;
                     %
                     % save the results to disk
                     %
                     txt = ['Would you like to save the spectral decompositions of the ' lower(VarStr) ' at initial values to disk?'];
                     answer = Query(txt,'question',200,'Save - Spectral Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        if VarType==1;
                           YDecomp = SpecDec.Y;
                           YStateDecomp = SpecDec.States;
                           YShockDecomp = SpecDec.Shocks;
                           MeasureErrorDecomp = SpecDec.MeasureError;
                           Frequencies = SpecDec.Frequencies;
                           YNames = DSGEModel.VariableNames;
                           ShockNames = SpecDec.ShockNames;
                           SigmaY = SpecDec.SigmaY;
                           SigmaXi = SpecDec.SigmaXi;
                           R = SpecDec.R;
                           if isfield(SpecDec,'AnnualY')==1;
                              ComputeAnnual = 1;
                              AnnualYDecomp = SpecDec.AnnualY;
                              AnnualYStateDecomp = SpecDec.AnnualYStates;
                              AnnualYShockDecomp = SpecDec.AnnualYShocks;
                              AnnualMeasureErrorDecomp = SpecDec.AnnualMeasureError;
                           else;
                              ComputeAnnual = 0;
                           end;
                           %
                           file = FixFilePath([DSGEModel.OutputDirectory '\SpecDec-ObsVar-InitialValues.mat']);
                           if ComputeAnnual==1;
                              save(file,'Frequencies','YDecomp','MeasureErrorDecomp','YStateDecomp','YShockDecomp','AnnualYDecomp','AnnualMeasureErrorDecomp','AnnualYStateDecomp','AnnualYShockDecomp','SigmaY','SigmaXi','R','YNames','ShockNames');
                           else;
                              save(file,'Frequencies','YDecomp','MeasureErrorDecomp','YStateDecomp','YShockDecomp','SigmaY','SigmaXi','R','YNames','ShockNames');
                           end;
                           %
                           % create the script file
                           %
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\SpDecOVarInitVal.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% string matrix with names of the n observed variables\n%%\n');
                           fprintf(fid,'YNames = DataStructure.YNames;\n');
                           fprintf(fid,'%%\n%% string matrix with names of the q shocks\n%%\n');
                           fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                           fprintf(fid,'%%\n%% f dimensional vector with individual frequencies\n%%\n');
                           fprintf(fid,'Frequencies = DataStructure.Frequencies;\n');
                           fprintf(fid,'%%\n%% f dimensional cell array with nxn matrices of the\n%% population spectrum of the observed variables\n%%\n');
                           fprintf(fid,'YDecomp = DataStructure.YDecomp;\n');
                           fprintf(fid,'%%\n%% nxn matrix with the constant population spectrum of the measurement errors\n%%\n');
                           fprintf(fid,'MeasureErrorDecomp = DataStructure.MeasureErrorDecomp;\n');
                           fprintf(fid,'%%\n%% f dimensional cell array with nxn matrices of the\n%% population spectrum of the observed variables for\n%% the state variables\n%%\n');
                           fprintf(fid,'YStateDecomp = DataStructure.YStateDecomp;\n');
                           fprintf(fid,'%%\n%% qxf dimensional cell array with nxn matrices of the\n%% population spectrum of the observed variables for\n%% individual shocks\n%%\n');
                           fprintf(fid,'YShockDecomp = DataStructure.YShockDecomp;\n');
                           if ComputeAnnual==1;
                              fprintf(fid,'%%\n%% f dimensional cell array with nxn matrices of the\n%% annualized population spectrum of the observed variables\n%%\n');
                              fprintf(fid,'AnnualYDecomp = DataStructure.AnnualYDecomp;\n');
                              fprintf(fid,'%%\n%% f dimensional cell array with nxn matrices of the\n%% annualized population spectrum of the measurement errors\n%%\n');
                              fprintf(fid,'AnnualMeasureErrorDecomp = DataStructure.AnnualMeasureErrorDecomp;\n');
                              fprintf(fid,'%%\n%% f dimensional cell array with nxn matrices of the\n%% annualized population spectrum of the observed variables based on the state variables\n%%\n');
                              fprintf(fid,'AnnualYStateDecomp = DataStructure.AnnualYStateDecomp;\n');
                              fprintf(fid,'%%\n%% qxf dimensional cell array with nxn matrices of the\n%% annualized population spectrum of the observed variables for\n%% individual shocks\n%%\n');
                              fprintf(fid,'AnnualYShockDecomp = DataStructure.AnnualYShockDecomp;\n');
                              NumEntries = 14;
                              AddText = ' AnnualYDecomp (an f dimenional cell array with nxn matrices of the annualized population spectrum of the observed variables at frequencies 0 until pi), AnnualMeasureDecomp (an f dimenional cell array with nxn matrices of the annualized population spectrum of the measurement errors at frequencies 0 until pi), AnnualYStateDecomp(an f dimenional cell array with nxn matrices of the annualized population spectrum at frequencies 0 until pi of the observed variables based on the state variables), AnnualYShockDecomp (a qxf dimenional cell array with nxn matrices of the annualized population spectrum at frequencies 0 until pi of the observed variables for each individual shock),';
                           else;
                              NumEntries = 10;
                              AddText = '';
                           end;
                           fprintf(fid,'%%\n%% nxn population covariance matrix of the observed variables\n%%\n');
                           fprintf(fid,'SigmaY = DataStructure.SigmaY;\n');
                           fprintf(fid,'%%\n%% nxn population covariance matrix of the observed variables due to the state variables\n%%\n');
                           fprintf(fid,'SigmaXi = DataStructure.SigmaXi;\n');
                           fprintf(fid,'%%\n%% nxn population covariance matrix of the observed variables due to the measurement errors\n%%\n');
                           fprintf(fid,'R = DataStructure.R;\n');
                           %
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                           %
                           txt = ['The spectral decompositions of the observed variables at initial values have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' int2str(NumEntries) ' entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the shocks), Frequencies (an f dimensional vector with the individual frequencies for the spectral decomposition), YDecomp (an f dimenional cell array with nxn matrices of the population spectrum of the observed variables at frequencies 0 until pi), MeasureDecomp (an nxn matrix with the constant population spectrum at frequencies 0 until pi of the measurement errors), YStateDecomp(an f dimenional cell array with nxn matrices of the population spectrum at frequencies 0 until pi of the observed variables for the state variables), YShockDecomp (a qxf dimenional cell array with nxn matrices of the population spectrum at frequencies 0 until pi of the observed variables for each individual shock),' AddText ' SigmaY (population covariance matrix of the observed variables), R (population covariance matrix of the observed variables due to the measurement errors), and SigmaXi (population covariance matrix of the observed variables due to the state variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                           About(txt,'information','Spectral Decompositions - Initial Values',500,600,CurrINI);
                           drawnow;
                           pause(0.02);
                        else;
                           StateDecomp = SpecDec.States;
                           ShockDecomp = SpecDec.Shocks;
                           Frequencies = SpecDec.Frequencies;
                           StateVariableNames = DSGEModel.StateVariableNames;
                           ShockNames = SpecDec.ShockNames;
                           SigmaXi = SpecDec.SigmaXi;
                           %
                           file = FixFilePath([DSGEModel.OutputDirectory '\SpecDec-StateVar-InitialValues.mat']);
                           save(file,'Frequencies','StateDecomp','ShockDecomp','SigmaXi','StateVariableNames','ShockNames');
                           %
                           % create the script file
                           %
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\SpDecSVarInitVal.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% string matrix with names of the q shocks\n%%\n');
                           fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                           fprintf(fid,'%%\n%% string matrix with names of the r state variables\n%%\n');
                           fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                           fprintf(fid,'%%\n%% f dimensional vector with individual frequencies\n%%\n');
                           fprintf(fid,'Frequencies = DataStructure.Frequencies;\n');
                           fprintf(fid,'%%\n%% f dimensional cell array with rxr matrices of the\n%% population spectrum of the state variables\n%%\n');
                           fprintf(fid,'StateDecomp = DataStructure.StateDecomp;\n');
                           fprintf(fid,'%%\n%% qxf dimensional cell array with rxr matrices of the\n%% population spectrum of the state variables for\n%% individual shocks\n%%\n');
                           fprintf(fid,'ShockDecomp = DataStructure.ShockDecomp;\n');
                           fprintf(fid,'%%\n%% rxr population covariance matrix of the state variables\n%%\n');
                           fprintf(fid,'SigmaXi = DataStructure.SigmaXi;\n');
                           %
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                           %
                           txt = ['The spectral decompositions of the state variables at initial values have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 6 entries: ShockNames (string matrix with the names of the shocks), StateVariableNames (string matrix with the state variable names), Frequencies (an f dimensional vector with the individual frequencies for the spectral decomposition), StateDecomp(an f dimenional cell array with rxr matrices of the population spectrum at frequencies 0 until pi of the state variables), ShockDecomp (a qxf dimenional cell array with rxr matrices of the population spectrum at frequencies 0 until pi of the state variables for each individual shock), and SigmaXi (population covariance matrix of the state variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                           About(txt,'information','Spectral Decompositions - Initial Values',500,600,CurrINI);
                        end;
                     end;
                     %
                     % display the results
                     %
                     SpectralDecompDLG('init',SpecDec,VarStr,'Initial Values',DSGEModel,CurrINI);
                  end;
               elseif (mcode==1)&(kalmanstatus~=0);
                  if kalmanstatus==1;
                     txt = 'The state variables are not stationary at the initial values.';
                  else;
                     txt = 'The covariance matrix of the forecast of the observed variables in period t conditional on data until t-1 is not positive definite for some time period t. This implies that the log-likelihood value is a NaN (or a complex number) in Matlab.';
                  end;
                  About(txt,'information','Spectral Decompositions - Initial Values',200,500,CurrINI);
               elseif mcode~=1;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Spectral Decompositions - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'SpectralDecompPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            %
            % check if we are concerned with observed variables or state variables
            %
            if gcbo==controls.spectraldecomp.obsvar.postmode;
               VarStr = 'Observed Variables';
               VarType = 1;
            elseif gcbo==controls.spectraldecomp.statevar.postmode;
               VarStr = 'State Variables';
               VarType = 2;
            elseif DSGEModel.RunDriver==1;
               if strcmp(lower(DSGEModel.answers{1}),'obs')==1;
                  VarStr = 'Observed Variables';
                  VarType = 1;
               else;
                  VarStr = 'State Variables';
                  VarType = 2;
               end;
            end;
            %
            % compute the decompositions
            %
            SpecDec = DSGESpectralDecompTheta(theta,thetaPositions,ModelParameters,VarStr,DSGEModel,CurrINI);
            if isempty(SpecDec)==0;
               %
               % save the results to disk
               %
               if DSGEModel.RunDriver==0;
                  txt = ['Would you like to save the spectral decompositions of the ' lower(VarStr) ' at posterior mode to disk?'];
                  answer = Query(txt,'question',200,'Save - Spectral Decompositions',500,'no',CurrINI);
               else;
                  answer = DSGEModel.answers{2};
               end;
               if strcmp(lower(answer),'yes')==1;
                  if DSGEModel.RunDriver==1;
                     SetLogText(strvcat('* Saving results to: ',['     ' DSGEModel.OutputDirectory]));
                  end;
                  if VarType==1;
                     YDecomp = SpecDec.Y;
                     YStateDecomp = SpecDec.States;
                     YShockDecomp = SpecDec.Shocks;
                     MeasureErrorDecomp = SpecDec.MeasureError;
                     Frequencies = SpecDec.Frequencies;
                     YNames = DSGEModel.VariableNames;
                     ShockNames = SpecDec.ShockNames;
                     SigmaY = SpecDec.SigmaY;
                     SigmaXi = SpecDec.SigmaXi;
                     R = SpecDec.R;
                     if isfield(SpecDec,'AnnualY')==1;
                        ComputeAnnual = 1;
                        AnnualYDecomp = SpecDec.AnnualY;
                        AnnualYStateDecomp = SpecDec.AnnualYStates;
                        AnnualYShockDecomp = SpecDec.AnnualYShocks;
                        AnnualMeasureErrorDecomp = SpecDec.AnnualMeasureError;
                     else;
                        ComputeAnnual = 0;
                     end;
                     %
                     file = FixFilePath([DSGEModel.OutputDirectory '\SpecDec-ObsVar-PostMode.mat']);
                     if ComputeAnnual==1;
                        save(file,'Frequencies','YDecomp','MeasureErrorDecomp','YStateDecomp','YShockDecomp','AnnualYDecomp','AnnualMeasureErrorDecomp','AnnualYStateDecomp','AnnualYShockDecomp','SigmaY','SigmaXi','R','YNames','ShockNames');
                     else;
                        save(file,'Frequencies','YDecomp','MeasureErrorDecomp','YStateDecomp','YShockDecomp','SigmaY','SigmaXi','R','YNames','ShockNames');
                     end;
                     %
                     % create the script file
                     %
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\SpDecOVarPostMode.m']);
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                     fprintf(fid,'%%\n%% string matrix with names of the n observed variables\n%%\n');
                     fprintf(fid,'YNames = DataStructure.YNames;\n');
                     fprintf(fid,'%%\n%% string matrix with names of the q shocks\n%%\n');
                     fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                     fprintf(fid,'%%\n%% f dimensional vector with individual frequencies\n%%\n');
                     fprintf(fid,'Frequencies = DataStructure.Frequencies;\n');
                     fprintf(fid,'%%\n%% f dimensional cell array with nxn matrices of the\n%% population spectrum of the observed variables\n%%\n');
                     fprintf(fid,'YDecomp = DataStructure.YDecomp;\n');
                     fprintf(fid,'%%\n%% nxn matrix with the constant population spectrum of the measurement errors\n%%\n');
                     fprintf(fid,'MeasureErrorDecomp = DataStructure.MeasureErrorDecomp;\n');
                     fprintf(fid,'%%\n%% f dimensional cell array with nxn matrices of the\n%% population spectrum of the observed variables for\n%% the state variables\n%%\n');
                     fprintf(fid,'YStateDecomp = DataStructure.YStateDecomp;\n');
                     fprintf(fid,'%%\n%% qxf dimensional cell array with nxn matrices of the\n%% population spectrum of the observed variables for\n%% individual shocks\n%%\n');
                     fprintf(fid,'YShockDecomp = DataStructure.YShockDecomp;\n');
                     if ComputeAnnual==1;
                        fprintf(fid,'%%\n%% f dimensional cell array with nxn matrices of the\n%% annualized population spectrum of the observed variables\n%%\n');
                        fprintf(fid,'AnnualYDecomp = DataStructure.AnnualYDecomp;\n');
                        fprintf(fid,'%%\n%% f dimensional cell array with nxn matrices of the\n%% annualized population spectrum of the measurement errors\n%%\n');
                        fprintf(fid,'AnnualMeasureErrorDecomp = DataStructure.AnnualMeasureErrorDecomp;\n');
                        fprintf(fid,'%%\n%% f dimensional cell array with nxn matrices of the\n%% annualized population spectrum of the observed variables based on the state variables\n%%\n');
                        fprintf(fid,'AnnualYStateDecomp = DataStructure.AnnualYStateDecomp;\n');
                        fprintf(fid,'%%\n%% qxf dimensional cell array with nxn matrices of the\n%% annualized population spectrum of the observed variables for\n%% individual shocks\n%%\n');
                        fprintf(fid,'AnnualYShockDecomp = DataStructure.AnnualYShockDecomp;\n');
                        NumEntries = 14;
                        AddText = ' AnnualYDecomp (an f dimenional cell array with nxn matrices of the annualized population spectrum of the observed variables at frequencies 0 until pi), AnnualMeasureDecomp (an f dimenional cell array with nxn matrices of the annualized population spectrum of the measurement errors at frequencies 0 until pi), AnnualYStateDecomp(an f dimenional cell array with nxn matrices of the annualized population spectrum at frequencies 0 until pi of the observed variables based on the state variables), AnnualYShockDecomp (a qxf dimenional cell array with nxn matrices of the annualized population spectrum at frequencies 0 until pi of the observed variables for each individual shock),';
                     else;
                        NumEntries = 10;
                        AddText = '';
                     end;
                     fprintf(fid,'%%\n%% nxn population covariance matrix of the observed variables\n%%\n');
                     fprintf(fid,'SigmaY = DataStructure.SigmaY;\n');
                     fprintf(fid,'%%\n%% nxn population covariance matrix of the observed variables due to the state variables\n%%\n');
                     fprintf(fid,'SigmaXi = DataStructure.SigmaXi;\n');
                     fprintf(fid,'%%\n%% nxn population covariance matrix of the observed variables due to the measurement errors\n%%\n');
                     fprintf(fid,'R = DataStructure.R;\n');
                     %
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     %
                     if DSGEModel.RunDriver==0;
                        txt = ['The spectral decompositions of the observed variables at posterior mode have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' int2str(NumEntries) ' entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the shocks), Frequencies (an f dimensional vector with the individual frequencies for the spectral decomposition), YDecomp (an f dimenional cell array with nxn matrices of the population spectrum of the observed variables at frequencies 0 until pi), MeasureDecomp (an nxn matrix with the constant population spectrum at frequencies 0 until pi of the measurement errors), YStateDecomp(an f dimenional cell array with nxn matrices of the population spectrum at frequencies 0 until pi of the observed variables for the state variables), YShockDecomp (a qxf dimenional cell array with nxn matrices of the population spectrum at frequencies 0 until pi of the observed variables for each individual shock),' AddText ' SigmaY (population covariance matrix of the observed variables), R (population covariance matrix of the observed variables due to the measurement errors), and SigmaXi (population covariance matrix of the observed variables due to the state variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Spectral Decompositions - Posterior Mode',500,600,CurrINI);
                        drawnow;
                        pause(0.02);
                     end;
                  else;
                     StateDecomp = SpecDec.States;
                     ShockDecomp = SpecDec.Shocks;
                     Frequencies = SpecDec.Frequencies;
                     StateVariableNames = DSGEModel.StateVariableNames;
                     ShockNames = SpecDec.ShockNames;
                     SigmaXi = SpecDec.SigmaXi;
                     %
                     file = FixFilePath([DSGEModel.OutputDirectory '\SpecDec-StateVar-PostMode.mat']);
                     save(file,'Frequencies','StateDecomp','ShockDecomp','SigmaXi','StateVariableNames','ShockNames');
                     %
                     % create the script file
                     %
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\SpDecSVarPostMode.m']);
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                     fprintf(fid,'%%\n%% string matrix with names of the q shocks\n%%\n');
                     fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                     fprintf(fid,'%%\n%% string matrix with names of the r state variables\n%%\n');
                     fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                     fprintf(fid,'%%\n%% f dimensional vector with individual frequencies\n%%\n');
                     fprintf(fid,'Frequencies = DataStructure.Frequencies;\n');
                     fprintf(fid,'%%\n%% f dimensional cell array with rxr matrices of the\n%% population spectrum of the state variables\n%%\n');
                     fprintf(fid,'StateDecomp = DataStructure.StateDecomp;\n');
                     fprintf(fid,'%%\n%% qxf dimensional cell array with rxr matrices of the\n%% population spectrum of the state variables for\n%% individual shocks\n%%\n');
                     fprintf(fid,'ShockDecomp = DataStructure.ShockDecomp;\n');
                     fprintf(fid,'%%\n%% rxr population covariance matrix of the state variables\n%%\n');
                     fprintf(fid,'SigmaXi = DataStructure.SigmaXi;\n');
                     %
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     %
                     if DSGEModel.RunDriver==0;
                        txt = ['The spectral decompositions of the state variables at posterior mode have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 6 entries: ShockNames (string matrix with the names of the shocks), StateVariableNames (string matrix with the state variable names), Frequencies (an f dimensional vector with the individual frequencies for the spectral decomposition), StateDecomp(an f dimenional cell array with rxr matrices of the population spectrum at frequencies 0 until pi of the state variables), ShockDecomp (a qxf dimenional cell array with rxr matrices of the population spectrum at frequencies 0 until pi of the state variables for each individual shock), and SigmaXi (population covariance matrix of the state variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Spectral Decompositions - Posterior Mode',500,600,CurrINI);
                        drawnow;
                        pause(0.02);
                     end;
                  end;
               end;
               %
               % display the results
               %
               if DSGEModel.RunDriver==0;
                  SpectralDecompDLG('init',SpecDec,VarStr,'Posterior Mode',DSGEModel,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'FEVDInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view the forecast error variance decompositions before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Variance Decompositions - Initial Values',450,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
               %
               % Try to calculate impulse responses. First, however, the code needs to check if a unique convergent
               % solution exists.
               %
               [FEVDs,LRVD,UniquenessCheck,ConvValue,mcode] = DSGEVarianceDecomposition(theta,thetaPositions,ModelParameters,0,DSGEModel,CurrINI);
               %
               % If status~=1, the model doesn't have a unique convergent solutions
               %
               if mcode==1;
                  %
                  % Display the results - if any
                  %
                  if (isempty(FEVDs)==0)&(length(size(FEVDs))==3);
                     %
                     % ask if we should save to disk
                     %
                     txt = 'Would you like to save the variance decompositions at initial values to file?';
                     answer = Query(txt,'question',140,'Save - Variance Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        file = FixFilePath([DSGEModel.OutputDirectory '\VarianceDecompositions-InitialValues.mat']);
                        YNames = DSGEModel.VariableNames;
                        ShockNames = DSGEModel.StateShockNames;
                        save(file,'FEVDs','LRVD','YNames','ShockNames');
                        %
                        % create a matlab file to read the data
                        %
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\VDInitVal.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% a 3D matrix of dimension nx(2+q)xh with the variance decompositions\n%% for the n observed variables into the share of state variable uncertainty,\n%% the share of measurement error uncertainty, and the q economic shocks,\n%% and the h forecast horizons\n%%\n');
                        fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                        fprintf(fid,'%%\n%% a nx(1+q) matrix with the long-run variance decompositions for the\n%% n observed variables into the measurement errors,\n%% and the q economic shocks.\n%%\n');
                        fprintf(fid,'LRVD = DataStructure.LRVD;');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The variance decompositions have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 4 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), FEVDs (a 3D matrix of dimension nx(2+q)xh with the variance decompositions for the n observed variables), and LRVD (a nx(1+q) matrix with the long-run variance decompositions for the n observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Variance Decompositions - Initial Values',200,500,CurrINI);
                     end;
                     %
                     % ask if we should look at shock groups
                     %
                     PrintGroups = 0;
                     if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                        txt = 'Would you like to view results of the variance decompositions for shock groups instead of for the individual shocks?';
                        answer = Query(txt,'question',140,'Variance Decompositions - Initial Values',500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups)+2,size(FEVDs,3));
                           IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                           IMatrixSR = [eye(2) zeros(2,size(IMatrix,2));zeros(size(IMatrix,1),2) IMatrix];
                           for i=1:size(FEVDs,3);
                              FEVD(:,:,i) = FEVDs(:,:,i)*IMatrixSR;
                           end;
                           FEVDs = FEVD;
                           PrintGroups = 1;
                        end;
                     end;
                     %
                     % print the results to file
                     %
                     PrintVarianceDecompositions(DSGEModel,FEVDs,LRVD,UniquenessCheck,PrintGroups,0,CurrINI,'initial');
                     if PrintGroups==0;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\InitialValueFEVDs-' DSGEModel.NameOfModel '.txt']);
                     else;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\InitialValueFEVDs-ShockGroups-' DSGEModel.NameOfModel '.txt']);
                     end;
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Initial Parameter Values',50,CurrINI,1,1);
                     end;
                  end;
               else;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Variance Decompositions - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'FEVDLevelsInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view the forecast error variance decompositions for the levels before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Variance Decompositions - Initial Values',450,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
               %
               % Try to calculate impulse responses. First, however, the code needs to check if a unique convergent
               % solution exists.
               %
               [FEVDs,LRVD,UniquenessCheck,ConvValue,mcode] = DSGEVarianceDecomposition(theta,thetaPositions,ModelParameters,1,DSGEModel,CurrINI);
               %
               % If status~=1, the model doesn't have a unique convergent solutions
               %
               if mcode==1;
                  %
                  % Display the results - if any
                  %
                  if (isempty(FEVDs)==0)&(length(size(FEVDs))==3);
                     %
                     % ask if we should save to disk
                     %
                     txt = 'Would you like to save the variance decompositions for the levels at initial values to file?';
                     answer = Query(txt,'question',140,'Save - Variance Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        file = FixFilePath([DSGEModel.OutputDirectory '\VarianceDecompositions-Levels-InitialValues.mat']);
                        YNames = DSGEModel.VariableNames;
                        ShockNames = DSGEModel.StateShockNames;
                        save(file,'FEVDs','LRVD','YNames','ShockNames');
                        %
                        % create a matlab file to read the data
                        %
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\VDLInitVal.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% a 3D matrix of dimension nx(2+q)xh with the variance decompositions\n%% for the n observed variables into the share of state variable uncertainty,\n%% the share of measurement error uncertainty, and the q economic shocks,\n%% and the h forecast horizons\n%%\n');
                        fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                        fprintf(fid,'%%\n%% a nx(1+q) matrix with the long-run variance decompositions for the\n%% n observed variables into the measurement errors,\n%% and the q economic shocks.\n%%\n');
                        fprintf(fid,'LRVD = DataStructure.LRVD;');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The variance decompositions for the levels have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 4 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), FEVDs (a 3D matrix of dimension nx(2+q)xh with the variance decompositions for the n observed variables), and LRVD (a nx(1+q) matrix with the long-run variance decompositions for the n observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Variance Decompositions - Initial Values',200,500,CurrINI);
                     end;
                     %
                     % ask if we should look at shock groups
                     %
                     PrintGroups = 0;
                     if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                        txt = 'Would you like to view results of the variance decompositions of the levels for shock groups instead of for the individual shocks?';
                        answer = Query(txt,'question',140,'Variance Decompositions - Initial Values',500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups)+2,size(FEVDs,3));
                           IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                           IMatrixSR = [eye(2) zeros(2,size(IMatrix,2));zeros(size(IMatrix,1),2) IMatrix];
                           IMatrixLR = [1 zeros(1,size(IMatrix,2));zeros(size(IMatrix,1),1) IMatrix];
                           for i=1:size(FEVDs,3);
                              FEVD(:,:,i) = FEVDs(:,:,i)*IMatrixSR;
                           end;
                           LRVD = LRVD*IMatrixLR;
                           FEVDs = FEVD;
                           PrintGroups = 1;
                        end;
                     end;
                     %
                     % print the results to file
                     %
                     PrintVarianceDecompositions(DSGEModel,FEVDs,LRVD,UniquenessCheck,PrintGroups,1,CurrINI,'initial');
                     if PrintGroups==0;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\InitialValueFEVDs-Levels-' DSGEModel.NameOfModel '.txt']);
                     else;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\InitialValueFEVDs-ShockGroups-Levels-' DSGEModel.NameOfModel '.txt']);
                     end;
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Levels Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Initial Parameter Values',50,CurrINI,1,1);
                     end;
                  end;
               else;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Variance Decompositions - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'FEVDPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check which function to run
         %
         if gcbo==controls.fevd.prior;
            LevelsData = 0;
            QueryHead = 'Variance Decompositions For Prior - Original Data';
            VarType = 'Original';
         else;
            LevelsData = 1;
            QueryHead = 'Variance Decompositions For Prior - Levels Data';
            VarType = 'Levels';
         end;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,QueryHead,550,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the posterior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection',QueryHead,'','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            %
            % First we check if the calculations have already been performed
            %
            if VarDecExist(DSGEModel,LevelsData,NumPriorDraws,NumPriorDraws,1,0)==1;
               txt = ['YADA has located results for the forecast error variance decompositions for the ' lower(VarType) ' data on disk. Would you like to use these results?'];
               answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
            else;
               answer = 'No';
            end;
            RunTimeStr = '';
            if strcmp(lower(answer),'yes')==1;
               DoneCalc = 1;
            else;
               %
               % compute the variance decompositions for all the posterior draws
               %
               StartTime = clock;
               DoneCalc = DSGEFEVD(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,LevelsData,NumPriorDraws,1,0);
               EndTime = clock;
               VarDecRunTime = etime(EndTime,StartTime);
               RunTimeStr = ['The variance decomposition calculations using ' int2str(NumPriorDraws) ' prior draws have finished after ' SecondsToHoursStr(VarDecRunTime) ' (hrs:min:sec). '];
            end;
            if DoneCalc==1;
               %
               % ask if we should look at shock groups
               %
               PrintGroups = 0;
               if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                  txt = [RunTimeStr 'Would you like to view results of the forecast error variance decompositions for shock groups instead of for the individual shocks?'];
                  answer = Query(txt,'question',150,QueryHead,500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     PrintGroups = 1;
                  end;
               end;
               %
               % compute the distribution for the conditional variance decompositions
               %
               VDs = DSGEVarDecDistribution(DSGEModel,CurrINI,LevelsData,PrintGroups,NumPriorDraws,NumPriorDraws,1,0,[]);
               %
               % ask if we should save results to disk
               %
               txt = 'Would you like to save the forecast error variance decompositions to file?';
               answer = Query(txt,'question',140,'Save - Variance Decompositions',500,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  YNames = DSGEModel.VariableNames;
                  if PrintGroups==0;
                     ShockNames = DSGEModel.StateShockNames;
                  else;
                     ShockNames = char(zeros(size(DSGEModel.ShockGroupNames)));
                     for i=1:size(DSGEModel.ShockGroupNames,1);
                        ShockNames(i,:) = strrep(DSGEModel.ShockGroupNames(i,:),'_',' ');
                     end;
                  end;
                  if PrintGroups==0;
                     file = FixFilePath([DSGEModel.OutputDirectory '\VarianceDecompositionPriorDist-' VarType '-' int2str(NumPriorDraws) '.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\VDPriorDist' VarType int2str(NumPriorDraws) '.m']);
                  else;
                     file = FixFilePath([DSGEModel.OutputDirectory '\VarianceDecompositionPriorDist-ShockGroup-' VarType '-' int2str(NumPriorDraws) '.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\VDPriorDistShockGroup' VarType int2str(NumPriorDraws) '.m']);
                  end;
                  save(file,'YNames','ShockNames','VDs');
                  %
                  % create a matlab file to read the data
                  %
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  if PrintGroups==0;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                     GroupStr = 'shocks';
                  else;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                     GroupStr = 'shock groups';
                  end;
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% structure with fields FEVD containing the posterior mean\n%% variance decomposition, LRVD the long-run variance\n%% decomposition, Econ containing the joint impact of all\n%% economic shocks, EconLR with the joint impact of all\n%% economic shocks in the long run, and the vector field\n%% Quantiles with subfields FEVD, LRVD, Econ, EconLR, and\n%% percent holding quantile data and quantile percent.\n%%\n');
                  fprintf(fid,'VDs = DataStructure.VDs;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  txt = ['The forecast error variance decomposition data has been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), and VDs (a structure with prior mean and quantile data for the variance decompositions). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                  About(txt,'information',QueryHead,200,500,CurrINI);
               end;
               %
               % display the results
               %
               PrintFEVD(DSGEModel,CurrINI,VDs,PrintGroups,VarType,NumPriorDraws,NumPriorDraws,1,0);
               if PrintGroups==0;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PriorDist-VD-' VarType '-' DSGEModel.NameOfModel '-' num2str(NumPriorDraws,'%0.0f') '.txt']);
               else;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PriorDist-VD-ShockGroups-' VarType '-' DSGEModel.NameOfModel '-' num2str(NumPriorDraws,'%0.0f') '.txt']);
               end;
               if FileExist(ResFile)==1;
                  TextGUI(ResFile,['Variance Decompositions For Prior - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],['Prior Distribution - ' VarType ' Data'],50,CurrINI,1,1);
               end;
            else;
               DSGEModel = OldDSGEModel;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'FEVDPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            %
            % we can now compute the forecast error variance decompositions up to a given horizon
            %
            [FEVDs,LRVD,UniquenessCheck,ConvValue] = DSGEVarianceDecomposition(theta,thetaPositions,ModelParameters,0,DSGEModel,CurrINI);
            if (isempty(FEVDs)==0)&(length(size(FEVDs))==3);
               %
               % ask if we should save to disk
               %
               txt = 'Would you like to save the variance decompositions at posterior mode to file?';
               answer = Query(txt,'question',140,'Save - Variance Decompositions',500,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  file = FixFilePath([DSGEModel.OutputDirectory '\VarianceDecompositions-PosteriorMode.mat']);
                  YNames = DSGEModel.VariableNames;
                  ShockNames = DSGEModel.StateShockNames;
                  save(file,'FEVDs','LRVD','YNames','ShockNames');
                  %
                  % create a matlab file to read the data
                  %
                  mfile = FixFilePath([DSGEModel.OutputDirectory '\VDPostMode.m']);
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% a 3D matrix of dimension nx(2+q)xh with the variance decompositions\n%% for the n observed variables into the share of state variable uncertainty,\n%% the share of measurement error uncertainty, and the q economic shocks,\n%% and the h forecast horizons\n%%\n');
                  fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                  fprintf(fid,'%%\n%% a nx(1+q) matrix with the long-run variance decompositions for the\n%% n observed variables into the measurement errors,\n%% and the q economic shocks.\n%%\n');
                  fprintf(fid,'LRVD = DataStructure.LRVD;');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  txt = ['The variance decompositions have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 4 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), FEVDs (a 3D matrix of dimension nx(2+q)xh with the variance decompositions for the n observed variables), and LRVD (a nx(1+q) matrix with the long-run variance decompositions for the n observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                  About(txt,'information','Variance Decompositions - Posterior Mode',200,500,CurrINI);
               end;
               %
               % ask if we should look at shock groups
               %
               PrintGroups = 0;
               if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                  txt = 'Would you like to view results of the variance decompositions for shock groups instead of for the individual shocks?';
                  answer = Query(txt,'question',140,'Variance Decompositions - Posterior Mode',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups)+2,size(FEVDs,3));
                     IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                     IMatrixSR = [eye(2) zeros(2,size(IMatrix,2));zeros(size(IMatrix,1),2) IMatrix];
                     for i=1:size(FEVDs,3);
                        FEVD(:,:,i) = FEVDs(:,:,i)*IMatrixSR;
                     end;
                     FEVDs = FEVD;
                     PrintGroups = 1;
                  end;
               end;
               %
               % print the results to file
               %
               PrintVarianceDecompositions(DSGEModel,FEVDs,LRVD,UniquenessCheck,PrintGroups,0,CurrINI,'posterior mode');
               if PrintGroups==0;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeFEVDs-' DSGEModel.NameOfModel '.txt']);
               else;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeFEVDs-ShockGroups-' DSGEModel.NameOfModel '.txt']);
               end;
               if FileExist(ResFile)==1;
                  TextGUI(ResFile,['Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Mode Parameter Values',50,CurrINI,1,1);
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'FEVDLevelsPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            %
            % we can now compute the forecast error variance decompositions up to a given horizon
            %
            [FEVDs,LRVD,UniquenessCheck,ConvValue] = DSGEVarianceDecomposition(theta,thetaPositions,ModelParameters,1,DSGEModel,CurrINI);
            if (isempty(FEVDs)==0)&(length(size(FEVDs))==3);
               %
               % ask if we should save to disk
               %
               txt = 'Would you like to save the variance decompositions for the levels at posterior mode to file?';
               answer = Query(txt,'question',140,'Save - Variance Decompositions',500,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  file = FixFilePath([DSGEModel.OutputDirectory '\VarianceDecompositions-Levels-PosteriorMode.mat']);
                  YNames = DSGEModel.VariableNames;
                  ShockNames = DSGEModel.StateShockNames;
                  save(file,'FEVDs','LRVD','YNames','ShockNames');
                  %
                  % create a matlab file to read the data
                  %
                  mfile = FixFilePath([DSGEModel.OutputDirectory '\VDLPostMode.m']);
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% a 3D matrix of dimension nx(2+q)xh with the variance decompositions\n%% for the n observed variables into the share of state variable uncertainty,\n%% the share of measurement error uncertainty, and the q economic shocks,\n%% and the h forecast horizons\n%%\n');
                  fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                  fprintf(fid,'%%\n%% a nx(1+q) matrix with the long-run variance decompositions for the\n%% n observed variables into the measurement errors,\n%% and the q economic shocks.\n%%\n');
                  fprintf(fid,'LRVD = DataStructure.LRVD;');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  txt = ['The variance decompositions for the levels have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 4 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), FEVDs (a 3D matrix of dimension nx(2+q)xh with the variance decompositions for the n observed variables), and LRVD (a nx(1+q) matrix with the long-run variance decompositions for the n observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                  About(txt,'information','Variance Decompositions - Posterior Mode',200,500,CurrINI);
               end;
               %
               % ask if we should look at shock groups
               %
               PrintGroups = 0;
               if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                  txt = 'Would you like to view results of the variance decompositions of the levels for shock groups instead of for the individual shocks?';
                  answer = Query(txt,'question',140,'Variance Decompositions - Posterior Mode',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups)+2,size(FEVDs,3));
                     IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                     IMatrixSR = [eye(2) zeros(2,size(IMatrix,2));zeros(size(IMatrix,1),2) IMatrix];
                     IMatrixLR = [1 zeros(1,size(IMatrix,2));zeros(size(IMatrix,1),1) IMatrix];
                     for i=1:size(FEVDs,3);
                        FEVD(:,:,i) = FEVDs(:,:,i)*IMatrixSR;
                     end;
                     LRVD = LRVD*IMatrixLR;
                     FEVDs = FEVD;
                     PrintGroups = 1;
                  end;
               end;
               %
               % print the results to file
               %
               PrintVarianceDecompositions(DSGEModel,FEVDs,LRVD,UniquenessCheck,PrintGroups,1,CurrINI,'posterior mode');
               if PrintGroups==0;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeFEVDs-Levels-' DSGEModel.NameOfModel '.txt']);
               else;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeFEVDs-ShockGroups-Levels-' DSGEModel.NameOfModel '.txt']);
               end;
               if FileExist(ResFile)==1;
                  TextGUI(ResFile,['Levels Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Mode Parameter Values',50,CurrINI,1,1);
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'FEVDPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            theta = ModeData.thetaMode;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%               FirstPeriod = ModeData.DSGEModel.FirstPeriod;
%               LastPeriod = ModeData.DSGEModel.LastPeriod;
%            else;
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Variance Decompositions','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  NumDraws = length(LogPost);
                  clear('PostSample','LogPost','AcceptedDraws');
                  drawnow;
                  %
                  % select which posterior draws to use
                  %
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumDraws,:);
                  NumDraws = NumDraws-NumBurnin;
                  %
                  % check which draws we should use
                  %
                  if DSGEModel.PosteriorSampler<=7;
                     UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                     if length(UseDraws)<NumDraws;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        UsedDraws = length(UseDraws);
                     else;
                        UsedDraws = NumDraws;
                     end;
                  else;
                     UsedDraws = NumDraws;
                  end;
                  %
                  % check which function to run
                  %
                  if gcbo==controls.fevd.posterior;
                     LevelsData = 0;
                     QueryHead = 'Variance Decompositions - Original Data';
                     VarType = 'Original';
                  else;
                     LevelsData = 1;
                     QueryHead = 'Variance Decompositions - Levels Data';
                     VarType = 'Levels';
                  end;
                  %
                  % First we check if the calculations have already been performed
                  %
                  if VarDecExist(DSGEModel,LevelsData,UsedDraws,NumDraws,CurrChain,1)==1;
                     txt = ['YADA has located results for the forecast error variance decompositions for the ' lower(VarType) ' data on disk. Would you like to use these results?'];
                     answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  RunTimeStr = '';
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                  else;
                     %
                     % compute the variance decompositions for all the posterior draws
                     %
                     StartTime = clock;
                     DoneCalc = DSGEFEVD(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,LevelsData,NumDraws,CurrChain,1);
                     EndTime = clock;
                     VarDecRunTime = etime(EndTime,StartTime);
                     RunTimeStr = ['The variance decomposition calculations using ' int2str(UsedDraws) ' posterior draws have finished after ' SecondsToHoursStr(VarDecRunTime) ' (hrs:min:sec). '];
                  end;
                  if DoneCalc==1;
                     %
                     % ask if we should look at shock groups
                     %
                     PrintGroups = 0;
                     if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                        txt = [RunTimeStr 'Would you like to view results of the forecast error variance decompositions for shock groups instead of for the individual shocks?'];
                        answer = Query(txt,'question',150,QueryHead,500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           PrintGroups = 1;
                        end;
                     end;
                     %
                     % compute the distribution for the conditional variance decompositions
                     %
                     VDs = DSGEVarDecDistribution(DSGEModel,CurrINI,LevelsData,PrintGroups,UsedDraws,NumDraws,CurrChain,1,Weights);
                     %
                     % ask if we should save results to disk
                     %
                     txt = 'Would you like to save the forecast error variance decompositions to file?';
                     answer = Query(txt,'question',140,'Save - Variance Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        YNames = DSGEModel.VariableNames;
                        if PrintGroups==0;
                           ShockNames = DSGEModel.StateShockNames;
                        else;
                           ShockNames = char(zeros(size(DSGEModel.ShockGroupNames)));
                           for i=1:size(DSGEModel.ShockGroupNames,1);
                              ShockNames(i,:) = strrep(DSGEModel.ShockGroupNames(i,:),'_',' ');
                           end;
                        end;
                        if PrintGroups==0;
                           file = FixFilePath([DSGEModel.OutputDirectory '\VarianceDecompositionDist-' VarType '-' int2str(CurrChain) '-' int2str(UsedDraws) '-' int2str(NumDraws) '.mat']);
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\VDDist' VarType int2str(CurrChain) int2str(UsedDraws) int2str(NumDraws) '.m']);
                        else;
                           file = FixFilePath([DSGEModel.OutputDirectory '\VarianceDecompositionDist-ShockGroup-' VarType '-' int2str(CurrChain) '-' int2str(UsedDraws) '-' int2str(NumDraws) '.mat']);
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\VDDistShockGroup' VarType int2str(CurrChain) int2str(UsedDraws) int2str(NumDraws) '.m']);
                        end;
                        save(file,'YNames','ShockNames','VDs');
                        %
                        % create a matlab file to read the data
                        %
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        if PrintGroups==0;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                        else;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                        end;
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% structure with fields FEVD containing the posterior mean\n%% variance decomposition, LRVD the long-run variance\n%% decomposition, Econ containing the joint impact of all\n%% economic shocks, EconLR with the joint impact of all\n%% economic shocks in the long run, and the vector field\n%% Quantiles with subfields FEVD, LRVD, Econ, EconLR, and\n%% percent holding quantile data and quantile percent.\n%%\n');
                        fprintf(fid,'VDs = DataStructure.VDs;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The forecast error variance decomposition data has been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), and VDs (a structure with posterior mean and quantile data for the variance decompositions). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information',QueryHead,200,500,CurrINI);
                     end;
                     %
                     % display the results
                     %
                     PrintFEVD(DSGEModel,CurrINI,VDs,PrintGroups,VarType,UsedDraws,NumDraws,CurrChain,1);
                     if PrintGroups==0;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorDist-VD-' VarType '-' num2str(CurrChain,'%0.0f') '-' DSGEModel.NameOfModel '-' num2str(UsedDraws,'%0.0f') '.' num2str(NumDraws,'%0.0f') '.txt']);
                     else;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorDist-VD-ShockGroups-' VarType '-' num2str(CurrChain,'%0.0f') '-' DSGEModel.NameOfModel '-' num2str(UsedDraws,'%0.0f') '.' num2str(NumDraws,'%0.0f') '.txt']);
                     end;
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],['Posterior Distribution - ' VarType ' Data'],50,CurrINI,1,1);
                     end;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'CondVDInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view the conditional variance decompositions before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Conditional Variance Decompositions - Initial Values',500,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
               %
               % Try to calculate impulse responses. First, however, the code needs to check if a unique convergent
               % solution exists.
               %
               [FEVDs,ConvValue,mcode] = DSGECondVarianceDecomposition(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,0);
               %
               % If status~=1, the model doesn't have a unique convergent solutions
               %
               if mcode==1;
                  %
                  % Display the results - if any
                  %
                  if (isempty(FEVDs)==0)&(length(size(FEVDs))==3);
                     %
                     % ask if we should save to disk
                     %
                     txt = 'Would you like to save the conditional variance decompositions for the original data at initial values to file?';
                     answer = Query(txt,'question',140,'Save - Conditional Variance Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        file = FixFilePath([DSGEModel.OutputDirectory '\CondVarianceDecompositions-InitialValues-Original.mat']);
                        YNames = DSGEModel.VariableNames;
                        ShockNames = DSGEModel.StateShockNames;
                        save(file,'FEVDs','YNames','ShockNames');
                        %
                        % create a matlab file to read the data
                        %
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDInitValOriginal.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% a 3D matrix of dimension nxqxh with the conditional variance decompositions\n%% for the n observed variables, the q economic shocks, and the h forecast horizons\n%%\n');
                        fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The conditional variance decompositions for the original data have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), and FEVDs (a 3D matrix of dimension nxqxh with the variance decompositions for the n observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Conditional Variance Decompositions - Initial Values',200,500,CurrINI);
                     end;
                     %
                     % ask if we should look at shock groups
                     %
                     PrintGroups = 0;
                     if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                        txt = 'Would you like to view results of the conditional variance decompositions for shock groups instead of for the individual shocks?';
                        answer = Query(txt,'question',140,'Conditional Variance Decompositions - Initial Values',500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups),size(FEVDs,3));
                           IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                           for i=1:size(FEVDs,3);
                              FEVD(:,:,i) = FEVDs(:,:,i)*IMatrix;
                           end;
                           FEVDs = FEVD;
                           PrintGroups = 1;
                        end;
                     end;
                     %
                     % we can now present the results
                     %
                     PrintCondVarianceDecompositions(DSGEModel,FEVDs,ConvValue,PrintGroups,CurrINI,'initial','');
                     if PrintGroups==0;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\InitialValueCFEVDs-' DSGEModel.NameOfModel '.txt']);
                     else;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\InitialValueCFEVDs-ShockGroups-' DSGEModel.NameOfModel '.txt']);
                     end;
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Conditional Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Initial Parameter Values',50,CurrINI,1,1);
                     end;
                  end;
               else;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Conditional Variance Decompositions - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'CondVDAnnualInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view the annualized conditional variance decompositions before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Conditional Variance Decompositions - Initial Values',500,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
               %
               % Try to calculate impulse responses. First, however, the code needs to check if a unique convergent
               % solution exists.
               %
               [FEVDs,ConvValue,mcode] = DSGECondVarianceDecomposition(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,2);
               %
               % If status~=1, the model doesn't have a unique convergent solutions
               %
               if mcode==1;
                  %
                  % Display the results - if any
                  %
                  if (isempty(FEVDs)==0)&(length(size(FEVDs))==3);
                     %
                     % ask if we should save to disk
                     %
                     txt = 'Would you like to save the conditional variance decompositions for the annualized data at initial values to file?';
                     answer = Query(txt,'question',140,'Save - Conditional Variance Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        file = FixFilePath([DSGEModel.OutputDirectory '\CondVarianceDecompositions-InitialValues-Annual.mat']);
                        YNames = DSGEModel.VariableNames;
                        ShockNames = DSGEModel.StateShockNames;
                        save(file,'FEVDs','YNames','ShockNames');
                        %
                        % create a matlab file to read the data
                        %
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDInitValAnnual.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% a 3D matrix of dimension nxqxh with the conditional variance decompositions\n%% for the n observed variables, the q economic shocks, and the h forecast horizons\n%%\n');
                        fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The conditional variance decompositions for the annualized data have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), and FEVDs (a 3D matrix of dimension nxqxh with the variance decompositions for the n observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Conditional Variance Decompositions - Initial Values',200,500,CurrINI);
                     end;
                     %
                     % ask if we should look at shock groups
                     %
                     PrintGroups = 0;
                     if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                        txt = 'Would you like to view results of the conditional variance decompositions for shock groups instead of for the individual shocks?';
                        answer = Query(txt,'question',140,'Conditional Variance Decompositions - Initial Values',500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups),size(FEVDs,3));
                           IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                           for i=1:size(FEVDs,3);
                              FEVD(:,:,i) = FEVDs(:,:,i)*IMatrix;
                           end;
                           FEVDs = FEVD;
                           PrintGroups = 1;
                        end;
                     end;
                     %
                     % print the results to file
                     %
                     PrintCondVarianceDecompositions(DSGEModel,FEVDs,ConvValue,PrintGroups,CurrINI,'initial','Annualized');
                     if PrintGroups==0;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\InitialValueCFEVDs-Annualized-' DSGEModel.NameOfModel '.txt']);
                     else;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\InitialValueCFEVDs-ShockGroups-Annualized-' DSGEModel.NameOfModel '.txt']);
                     end;
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Conditional Annualized Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Initial Parameter Values',50,CurrINI,1,1);
                     end;
                  end;
               else;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Conditional Variance Decompositions - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'CondVDLevelsInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view the levels conditional variance decompositions before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Conditional Variance Decompositions - Initial Values',500,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
               %
               % Try to calculate impulse responses. First, however, the code needs to check if a unique convergent
               % solution exists.
               %
               [FEVDs,ConvValue,mcode] = DSGECondVarianceDecomposition(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,1);
               %
               % If status~=1, the model doesn't have a unique convergent solutions
               %
               if mcode==1;
                  %
                  % Display the results - if any
                  %
                  if (isempty(FEVDs)==0)&(length(size(FEVDs))==3);
                     %
                     % ask if we should save to disk
                     %
                     txt = 'Would you like to save the conditional variance decompositions for the levels data at initial values to file?';
                     answer = Query(txt,'question',140,'Save - Conditional Variance Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        file = FixFilePath([DSGEModel.OutputDirectory '\CondVarianceDecompositions-InitialValues-Levels.mat']);
                        YNames = DSGEModel.VariableNames;
                        ShockNames = DSGEModel.StateShockNames;
                        save(file,'FEVDs','YNames','ShockNames');
                        %
                        % create a matlab file to read the data
                        %
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDInitValLevels.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% a 3D matrix of dimension nxqxh with the conditional variance decompositions\n%% for the n observed variables, the q economic shocks, and the h forecast horizons\n%%\n');
                        fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The conditional variance decompositions for the levels data have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), and FEVDs (a 3D matrix of dimension nxqxh with the variance decompositions for the n observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Conditional Variance Decompositions - Initial Values',200,500,CurrINI);
                     end;
                     %
                     % ask if we should look at shock groups
                     %
                     PrintGroups = 0;
                     if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                        txt = 'Would you like to view results of the conditional variance decompositions for shock groups instead of for the individual shocks?';
                        answer = Query(txt,'question',140,'Conditional Variance Decompositions - Initial Values',500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups),size(FEVDs,3));
                           IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                           for i=1:size(FEVDs,3);
                              FEVD(:,:,i) = FEVDs(:,:,i)*IMatrix;
                           end;
                           FEVDs = FEVD;
                           PrintGroups = 1;
                        end;
                     end;
                     %
                     % print the results to file
                     %
                     PrintCondVarianceDecompositions(DSGEModel,FEVDs,ConvValue,PrintGroups,CurrINI,'initial','Levels');
                     if PrintGroups==0;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\InitialValueCFEVDs-Levels-' DSGEModel.NameOfModel '.txt']);
                     else;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\InitialValueCFEVDs-ShockGroups-Levels-' DSGEModel.NameOfModel '.txt']);
                     end;
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Conditional Levels Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Initial Parameter Values',50,CurrINI,1,1);
                     end;
                  end;
               else;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Conditional Variance Decompositions - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'CondVDPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % are we using annualized data, levels, or the original
         %
         if gcbo==controls.cvd.prior;
            AnnualizeData = 0;
            LevelsData = 0;
            QueryHead = 'Conditional Variance Decompositions For Prior - Original Data';
            VarType = 'Original';
         elseif gcbo==controls.cvd.lev_prior;
            AnnualizeData = 0;
            LevelsData = 1;
            QueryHead = 'Conditional Variance Decompositions For Prior - Levels Data';
            VarType = 'Levels';
         else;
            AnnualizeData = 1;
            LevelsData = 0;
            QueryHead = 'Conditional Variance Decompositions For Prior - Annualized Data';
            VarType = 'Annualized';
         end;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,QueryHead,550,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the posterior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection',QueryHead,'','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            %
            % First we check if the calculations have already been performed
            %
            if CVDExist(DSGEModel,AnnualizeData,LevelsData,NumPriorDraws,NumPriorDraws,1,0)==1;
               txt = 'YADA has located results for the conditional variance decompositions on disk. Would you like to use these results?';
               answer = Query(txt,'question',150,QueryHead,550,'no',CurrINI);
            else;
               answer = 'No';
            end;
            if strcmp(lower(answer),'yes')==1;
               DoneCalc = 1;
            else;
               %
               % compute the conditional variance decompositions for all the prior draws
               %
               DoneCalc = DSGEConditionalFEVD(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,AnnualizeData,LevelsData,NumPriorDraws,1,0);
            end;
            %
            % check if we should show any results
            %
            if DoneCalc==1;
               %
               % ask if we should look at shock groups
               %
               PrintGroups = 0;
               if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                  txt = 'Would you like to view results of the conditional variance decompositions for shock groups instead of for the individual shocks?';
                  answer = Query(txt,'question',140,QueryHead,550,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     PrintGroups = 1;
                  end;
               end;
               %
               % compute the distribution for the conditional variance decompositions
               %
               CVDs = DSGECVDDistribution(DSGEModel,CurrINI,AnnualizeData,LevelsData,PrintGroups,NumPriorDraws,NumPriorDraws,1,0,[]);
               %
               % ask if we should save results to disk
               %
               txt = 'Would you like to save the conditional forecast error variance decompositions to file?';
               answer = Query(txt,'question',140,'Save - Conditional Variance Decompositions',500,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  YNames = DSGEModel.VariableNames;
                  if PrintGroups==0;
                     ShockNames = DSGEModel.StateShockNames;
                  else;
                     ShockNames = char(zeros(size(DSGEModel.ShockGroupNames)));
                     for i=1:size(DSGEModel.ShockGroupNames,1);
                        ShockNames(i,:) = strrep(DSGEModel.ShockGroupNames(i,:),'_',' ');
                     end;
                  end;
                  if PrintGroups==0;
                     file = FixFilePath([DSGEModel.OutputDirectory '\ConditionalVarianceDecompositionPriorDist-' VarType '-' int2str(NumPriorDraws) '.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDPriorDist' VarType int2str(NumPriorDraws) '.m']);
                  else;
                     file = FixFilePath([DSGEModel.OutputDirectory '\ConditionalVarianceDecompositionPriorDist-ShockGroup-' VarType '-' int2str(NumPriorDraws) '.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDPriorDistShockGroup' VarType int2str(NumPriorDraws) '.m']);
                  end;
                  save(file,'YNames','ShockNames','CVDs');
                  %
                  % create a matlab file to read the data
                  %
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  if PrintGroups==0;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                  else;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                  end;
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% structure with fields FEVD containing the prior mean\n%% conditional variance decomposition and the vector field\n%% Quantiles with subfields FEVD and percent holding quantile\n%% data and quantile percent.\n%%\n');
                  fprintf(fid,'CVDs = DataStructure.CVDs;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  txt = ['The forecast error variance decomposition data has been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), and CVDs (a structure with prior mean and quantile data for the conditional variance decompositions). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                  About(txt,'information',QueryHead,200,550,CurrINI);
               end;
               %
               % display the results
               %
               PrintConditionalCVD(DSGEModel,CurrINI,CVDs,PrintGroups,VarType,NumPriorDraws,NumPriorDraws,1,0);
               if PrintGroups==0;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PriorDist-CVD-' VarType '-' DSGEModel.NameOfModel '-' num2str(NumPriorDraws,'%0.0f') '.txt']);
               else;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PriorDist-CVD-ShockGroups-' VarType '-' DSGEModel.NameOfModel '-' num2str(NumPriorDraws,'%0.0f') '.txt']);
               end;
               if FileExist(ResFile)==1;
                  TextGUI(ResFile,['Conditional Variance Decompositions For Prior - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],['Prior Distribution - ' VarType ' Data'],50,CurrINI,1,1);
               end;
            else;
               DSGEModel = OldDSGEModel;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'CondVDPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            %
            % we can now compute the conditional forecast error variance decompositions up to a given horizon
            %
            [FEVDs,ConvValue] = DSGECondVarianceDecomposition(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,0);
            if (isempty(FEVDs)==0)&(length(size(FEVDs))==3);
               %
               % ask if we should save to disk
               %
               if DSGEModel.RunDriver==0;
                  txt = 'Would you like to save the conditional variance decompositions for the original data at posterior mode to file?';
                  answer = Query(txt,'question',140,'Save - Conditional Variance Decompositions',500,'no',CurrINI);
               else;
                  answer = DSGEModel.answers{1};
               end;
               if strcmp(lower(answer),'yes')==1;
                  if DSGEModel.RunDriver==1;
                     SetLogText(strvcat('* Saving results to: ',['     ' DSGEModel.OutputDirectory]));
                  end;
                  file = FixFilePath([DSGEModel.OutputDirectory '\CondVarianceDecompositions-PosteriorMode-Original.mat']);
                  YNames = DSGEModel.VariableNames;
                  ShockNames = DSGEModel.StateShockNames;
                  save(file,'FEVDs','YNames','ShockNames');
                  %
                  % create a matlab file to read the data
                  %
                  mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDPostModeOriginal.m']);
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% a 3D matrix of dimension nxqxh with the conditional variance decompositions\n%% for the n observed variables, the q economic shocks, and the h forecast horizons\n%%\n');
                  fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  if DSGEModel.RunDriver==0;
                     txt = ['The conditional variance decompositions for the original data have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), and FEVDs (a 3D matrix of dimension nxqxh with the variance decompositions for the n observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                     About(txt,'information','Conditional Variance Decompositions - Posterior Mode',200,500,CurrINI);
                  end;
               end;
               %
               % ask if we should look at shock groups
               %
               PrintGroups = 0;
               if DSGEModel.RunDriver==0;
                  if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                     txt = 'Would you like to view results of the conditional variance decompositions for shock groups instead of for the individual shocks?';
                     answer = Query(txt,'question',140,'Conditional Variance Decompositions - Posterior Mode',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups),size(FEVDs,3));
                        IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                        for i=1:size(FEVDs,3);
                           FEVD(:,:,i) = FEVDs(:,:,i)*IMatrix;
                        end;
                        FEVDs = FEVD;
                        PrintGroups = 1;
                     end;
                  end;
               else;
                  if strcmp(lower(DSGEModel.answers{2}),'yes')==1;
                     PrintGroups = 1;
                  end;
               end;
               %
               % we can now print the results to file
               %
               PrintCondVarianceDecompositions(DSGEModel,FEVDs,ConvValue,PrintGroups,CurrINI,'posterior mode','');
               if DSGEModel.RunDriver==0;
                  if PrintGroups==0;
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeCFEVDs-' DSGEModel.NameOfModel '.txt']);
                  else;
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeCFEVDs-ShockGroups-' DSGEModel.NameOfModel '.txt']);
                  end;
                  if FileExist(ResFile)==1;
                     TextGUI(ResFile,['Conditional Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Mode Parameter Values',50,CurrINI,1,1);
                  end;
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'CondVDAnnualPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            %
            % we can now compute the conditional forecast error variance decompositions up to a given horizon
            %
            [FEVDs,ConvValue] = DSGECondVarianceDecomposition(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,2);
            if (isempty(FEVDs)==0)&(length(size(FEVDs))==3);
               %
               % ask if we should save to disk
               %
               if DSGEModel.RunDriver==0;
                  txt = 'Would you like to save the conditional variance decompositions for the annualized data at posterior mode to file?';
                  answer = Query(txt,'question',140,'Save - Conditional Variance Decompositions',500,'no',CurrINI);
               else;
                  answer = DSGEModel.answers{1};
               end;
               if strcmp(lower(answer),'yes')==1;
                  if DSGEModel.RunDriver==1;
                     SetLogText(strvcat('* Saving results to: ',['     ' DSGEModel.OutputDirectory]));
                  end;
                  file = FixFilePath([DSGEModel.OutputDirectory '\CondVarianceDecompositions-PosteriorMode-Annual.mat']);
                  YNames = DSGEModel.VariableNames;
                  ShockNames = DSGEModel.StateShockNames;
                  save(file,'FEVDs','YNames','ShockNames');
                  %
                  % create a matlab file to read the data
                  %
                  mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDPostModeAnnual.m']);
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% a 3D matrix of dimension nxqxh with the conditional variance decompositions\n%% for the n observed variables, the q economic shocks, and the h forecast horizons\n%%\n');
                  fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  if DSGEModel.RunDriver==0;
                     txt = ['The conditional variance decompositions for the annualized data have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), and FEVDs (a 3D matrix of dimension nxqxh with the variance decompositions for the n observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                     About(txt,'information','Conditional Variance Decompositions - Posterior Mode',200,500,CurrINI);
                  end;
               end;
               %
               % ask if we should look at shock groups
               %
               PrintGroups = 0;
               if DSGEModel.RunDriver==0;
                  if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                     txt = 'Would you like to view results of the conditional variance decompositions for shock groups instead of for the individual shocks?';
                     answer = Query(txt,'question',140,'Conditional Variance Decompositions - Posterior Mode',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups),size(FEVDs,3));
                        IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                        for i=1:size(FEVDs,3);
                           FEVD(:,:,i) = FEVDs(:,:,i)*IMatrix;
                        end;
                        FEVDs = FEVD;
                        PrintGroups = 1;
                     end;
                  end;
               else;
                  if strcmp(lower(DSGEModel.answers{2}),'yes')==1;
                     PrintGroups = 1;
                  end;
               end;
               %
               % print the results to file
               %
               PrintCondVarianceDecompositions(DSGEModel,FEVDs,ConvValue,PrintGroups,CurrINI,'posterior mode','Annualized');
               if DSGEModel.RunDriver==0;
                  if PrintGroups==0;
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeCFEVDs-Annualized-' DSGEModel.NameOfModel '.txt']);
                  else;
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeCFEVDs-ShockGroups-Annualized-' DSGEModel.NameOfModel '.txt']);
                  end;
                  if FileExist(ResFile)==1;
                     TextGUI(ResFile,['Conditional Annualized Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Mode Parameter Values',50,CurrINI,1,1);
                  end;
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'CondVDLevelsPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            %
            % we can now compute the conditional forecast error variance decompositions up to a given horizon
            %
            [FEVDs,ConvValue] = DSGECondVarianceDecomposition(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,1);
            if (isempty(FEVDs)==0)&(length(size(FEVDs))==3);
               %
               % ask if we should save to disk
               %
               if DSGEModel.RunDriver==0;
                  txt = 'Would you like to save the conditional variance decompositions for the levels data at posterior mode to file?';
                  answer = Query(txt,'question',140,'Save - Conditional Variance Decompositions',500,'no',CurrINI);
               else;
                  answer = DSGEModel.answers{1};
               end;
               if strcmp(lower(answer),'yes')==1;
                  if DSGEModel.RunDriver==1;
                     SetLogText(strvcat('* Saving results to: ',['     ' DSGEModel.OutputDirectory]));
                  end;
                  file = FixFilePath([DSGEModel.OutputDirectory '\CondVarianceDecompositions-PosteriorMode-Levels.mat']);
                  YNames = DSGEModel.VariableNames;
                  ShockNames = DSGEModel.StateShockNames;
                  save(file,'FEVDs','YNames','ShockNames');
                  %
                  % create a matlab file to read the data
                  %
                  mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDPostModeLevels.m']);
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% a 3D matrix of dimension nxqxh with the conditional variance decompositions\n%% for the n observed variables, the q economic shocks, and the h forecast horizons\n%%\n');
                  fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  if DSGEModel.RunDriver==0;
                     txt = ['The conditional variance decompositions for the levels data have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), and FEVDs (a 3D matrix of dimension nxqxh with the variance decompositions for the n observed variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                     About(txt,'information','Conditional Variance Decompositions - Posterior Mode',200,500,CurrINI);
                  end;
               end;
               %
               % ask if we should look at shock groups
               %
               PrintGroups = 0;
               if DSGEModel.RunDriver==0;
                  if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                     txt = 'Would you like to view results of the conditional variance decompositions for shock groups instead of for the individual shocks?';
                     answer = Query(txt,'question',140,'Conditional Variance Decompositions - Posterior Mode',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups),size(FEVDs,3));
                        IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                        for i=1:size(FEVDs,3);
                           FEVD(:,:,i) = FEVDs(:,:,i)*IMatrix;
                        end;
                        FEVDs = FEVD;
                        PrintGroups = 1;
                     end;
                  end;
               else;
                  if strcmp(lower(DSGEModel.answers{2}),'yes')==1;
                     PrintGroups = 1;
                  end;
               end;
               %
               % print the results to file
               %
               PrintCondVarianceDecompositions(DSGEModel,FEVDs,ConvValue,PrintGroups,CurrINI,'posterior mode','Levels');
               if DSGEModel.RunDriver==0;
                  if PrintGroups==0;
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeCFEVDs-Levels-' DSGEModel.NameOfModel '.txt']);
                  else;
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeCFEVDs-ShockGroups-Levels-' DSGEModel.NameOfModel '.txt']);
                  end;
                  if FileExist(ResFile)==1;
                     TextGUI(ResFile,['Conditional Levels Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Mode Parameter Values',50,CurrINI,1,1);
                  end;
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'CondVDPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            theta = ModeData.thetaMode;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%               FirstPeriod = ModeData.DSGEModel.FirstPeriod;
%               LastPeriod = ModeData.DSGEModel.LastPeriod;
%            else;
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Conditional Variance Decompositions','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  NumDraws = length(LogPost);
                  clear('PostSample','LogPost','AcceptedDraws');
                  drawnow;
                  %
                  % select which posterior draws to use
                  %
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumDraws,:);
                  NumDraws = NumDraws-NumBurnin;
                  %
                  % check which draws we should use
                  %
                  if DSGEModel.PosteriorSampler<=7;
                     UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                     if length(UseDraws)<NumDraws;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        UsedDraws = length(UseDraws);
                     else;
                        UsedDraws = NumDraws;
                     end;
                  else;
                     UsedDraws = NumDraws;
                  end;
                  %
                  % are we using annualized data, levels, or the original
                  %
                  if gcbo==controls.cvd.posterior;
                     AnnualizeData = 0;
                     LevelsData = 0;
                     QueryHead = 'Conditional Variance Decompositions - Original Data';
                     VarType = 'Original';
                  elseif gcbo==controls.cvd.lev_posterior;
                     AnnualizeData = 0;
                     LevelsData = 1;
                     QueryHead = 'Conditional Variance Decompositions - Levels Data';
                     VarType = 'Levels';
                  else;
                     AnnualizeData = 1;
                     LevelsData = 0;
                     QueryHead = 'Conditional Variance Decompositions - Annualized Data';
                     VarType = 'Annualized';
                  end;
                  %
                  % First we check if the calculations have already been performed
                  %
                  if CVDExist(DSGEModel,AnnualizeData,LevelsData,UsedDraws,NumDraws,CurrChain,1)==1;
                     txt = 'YADA has located results for the conditional variance decompositions on disk. Would you like to use these results?';
                     answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                  else;
                     %
                     % compute the conditional variance decompositions for all the posterior draws
                     %
                     DoneCalc = DSGEConditionalFEVD(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,AnnualizeData,LevelsData,NumDraws,CurrChain,1);
                  end;
                  %
                  % check if we should show any results
                  %
                  if DoneCalc==1;
                     %
                     % ask if we should look at shock groups
                     %
                     PrintGroups = 0;
                     if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                        txt = 'Would you like to view results of the conditional variance decompositions for shock groups instead of for the individual shocks?';
                        answer = Query(txt,'question',140,QueryHead,500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           PrintGroups = 1;
                        end;
                     end;
                     %
                     % compute the distribution for the conditional variance decompositions
                     %
                     CVDs = DSGECVDDistribution(DSGEModel,CurrINI,AnnualizeData,LevelsData,PrintGroups,UsedDraws,NumDraws,CurrChain,1,Weights);
                     %
                     % ask if we should save results to disk
                     %
                     txt = 'Would you like to save the conditional forecast error variance decompositions to file?';
                     answer = Query(txt,'question',140,'Save - Conditional Variance Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        YNames = DSGEModel.VariableNames;
                        if PrintGroups==0;
                           ShockNames = DSGEModel.StateShockNames;
                        else;
                           ShockNames = char(zeros(size(DSGEModel.ShockGroupNames)));
                           for i=1:size(DSGEModel.ShockGroupNames,1);
                              ShockNames(i,:) = strrep(DSGEModel.ShockGroupNames(i,:),'_',' ');
                           end;
                        end;
                        if PrintGroups==0;
                           file = FixFilePath([DSGEModel.OutputDirectory '\ConditionalVarianceDecompositionDist-' VarType '-' int2str(CurrChain) '-' int2str(UsedDraws) '-' int2str(NumDraws) '.mat']);
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDDist' VarType int2str(CurrChain) int2str(UsedDraws) int2str(NumDraws) '.m']);
                        else;
                           file = FixFilePath([DSGEModel.OutputDirectory '\ConditionalVarianceDecompositionDist-ShockGroup-' VarType '-' int2str(CurrChain) '-' int2str(UsedDraws) '-' int2str(NumDraws) '.mat']);
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDDistShockGroup' VarType int2str(CurrChain) int2str(UsedDraws) int2str(NumDraws) '.m']);
                        end;
                        save(file,'YNames','ShockNames','CVDs');
                        %
                        % create a matlab file to read the data
                        %
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        if PrintGroups==0;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                        else;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                        end;
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% structure with fields FEVD containing the posterior mean\n%% conditional variance decomposition and the vector field\n%% Quantiles with subfields FEVD and percent holding quantile\n%% data and quantile percent.\n%%\n');
                        fprintf(fid,'CVDs = DataStructure.CVDs;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The forecast error variance decomposition data has been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: YNames (string matrix with the names of the observed variables), ShockNames (string matrix with the names of the economic shocks), and CVDs (a structure with posterior mean and quantile data for the conditional variance decompositions). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information',QueryHead,200,500,CurrINI);
                     end;
                     %
                     % display the results
                     %
                     PrintConditionalCVD(DSGEModel,CurrINI,CVDs,PrintGroups,VarType,UsedDraws,NumDraws,CurrChain,1);
                     if PrintGroups==0;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorDist-CVD-' VarType '-' num2str(CurrChain,'%0.0f') '-' DSGEModel.NameOfModel '-' num2str(UsedDraws,'%0.0f') '.' num2str(NumDraws,'%0.0f') '.txt']);
                     else;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorDist-CVD-ShockGroups-' VarType '-' num2str(CurrChain,'%0.0f') '-' DSGEModel.NameOfModel '-' num2str(UsedDraws,'%0.0f') '.' num2str(NumDraws,'%0.0f') '.txt']);
                     end;
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Conditional Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],['Posterior Distribution - ' VarType ' Data'],50,CurrINI,1,1);
                     end;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'VDStateInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view the variance decompositions for the state variables at the initial values before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Variance Decompositions - Initial Values',500,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            if InitStatus==1;
               %
               % Try to calculate conditional variance decompositions. First, check if there's a unique
               % convergent solution
               %
               [FEVDs,LRVD,UniquenessCheck,mcode] = DSGEStateVarianceDecomposition(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI);
               %
               % if mcode is not 1, then a unique convergent solution doesn't exist
               %
               if mcode==1;
                  %
                  % ask if we should save to disk
                  %
                  txt = 'Would you like to save the variance decompositions for the state variables at initial values to file?';
                  answer = Query(txt,'question',140,'Save - Variance Decompositions',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     file = FixFilePath([DSGEModel.OutputDirectory '\StateVarianceDecompositions-InitialValues.mat']);
                     StateVariableNames = DSGEModel.StateVariableNames;
                     ShockNames = DSGEModel.StateShockNames;
                     save(file,'FEVDs','LRVD','StateVariableNames','ShockNames');
                     %
                     % create a matlab file to read the data
                     %
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\VDStateInitVal.m']);
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                     fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                     fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                     fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                     fprintf(fid,'%%\n%% a 3D matrix of dimension rx(1q)xh with the variance decompositions\n%% for the r state variables into the share of state variable uncertainty\n%% and the q economic shocks for the h forecast horizons\n%%\n');
                     fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                     fprintf(fid,'%%\n%% a rxq matrix with the long-run variance decompositions for the\n%% r state variables into the q economic shocks.\n%%\n');
                     fprintf(fid,'LRVD = DataStructure.LRVD;');
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     txt = ['The variance decompositions for the state variables have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 4 entries: StateVariableNames (string matrix with the names of the state variables), ShockNames (string matrix with the names of the economic shocks), FEVDs (a 3D matrix of dimension rx(1+q)xh with the variance decompositions for the r state variables), and LRVD (a rxq matrix with the long-run variance decompositions for the r state variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                     About(txt,'information','Variance Decompositions - Initial Values',200,500,CurrINI);
                  end;
                  %
                  % ask if we should look at shock groups
                  %
                  PrintGroups = 0;
                  if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                     txt = 'Would you like to view results of the variance decompositions for shock groups instead of for the individual shocks?';
                     answer = Query(txt,'question',140,'Variance Decompositions - Initial Values',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups)+1,size(FEVDs,3));
                        IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                        IMatrixSR = [1 zeros(1,size(IMatrix,2));zeros(size(IMatrix,1),1) IMatrix];
                        for i=1:size(FEVDs,3);
                           FEVD(:,:,i) = FEVDs(:,:,i)*IMatrixSR;
                        end;
                        FEVDs = FEVD;
                        LRVD = LRVD*IMatrix;
                        PrintGroups = 1;
                     end;
                  end;
                  %
                  % print the results to file
                  %
                  if PrintGroups==0;
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\InitialValueStateVDs-' DSGEModel.NameOfModel '.txt']);
                  else;
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\InitialValueStateVDs-ShockGroups-' DSGEModel.NameOfModel '.txt']);
                  end;
                  PrintStateVarianceDecompositions(ResFile,DSGEModel,FEVDs,LRVD,UniquenessCheck,PrintGroups,CurrINI,'initial');
                  if FileExist(ResFile)==1;
                     TextGUI(ResFile,['Variance Decompositions For State Variables - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Initial Parameter Values',50,CurrINI,1,1);
                  end;
               else;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Variance Decompositions - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'VDStatePriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,'Variance Decomposition - State Variables',550,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         %
         if InitStatus==1;
            %
            % load the data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the posterior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection','Variance Decomposition - State Variables','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            %
            % First we check if the calculations have already been performed
            %
            if StateVarDecExist(DSGEModel,NumPriorDraws,NumPriorDraws,1,0)==1;
               txt = 'YADA has located posterior draws results for the forecast error variance decompositions for the state variables data on disk. Would you like to use these results?';
               answer = Query(txt,'question',150,'Variance Decompositions - State Variables',450,'no',CurrINI);
            else;
               answer = 'No';
            end;
            RunTimeStr = '';
            if strcmp(lower(answer),'yes')==1;
               DoneCalc = 1;
            else;
               %
               % compute the variance decompositions for all the posterior draws
               %
               StartTime = clock;
               DoneCalc = DSGEStateFEVD(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,NumPriorDraws,1,0);
               EndTime = clock;
               VarDecRunTime = etime(EndTime,StartTime);
               RunTimeStr = ['The variance decomposition calculations using ' int2str(NumPriorDraws) ' prior draws have finished after ' SecondsToHoursStr(VarDecRunTime) ' (hrs:min:sec). '];
            end;
            if DoneCalc==1;
               %
               % ask if we should look at shock groups
               %
               PrintGroups = 0;
               if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                  txt = [RunTimeStr 'Would you like to view results of the forecast error variance decompositions for shock groups instead of for the individual shocks?'];
                  answer = Query(txt,'question',150,'Variance Decompositions - State Variables',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     PrintGroups = 1;
                  end;
               end;
               %
               % compute the distribution for the variance decompositions
               %
               VDs = DSGEStateVarDecDistribution(DSGEModel,CurrINI,PrintGroups,NumPriorDraws,NumPriorDraws,1,0,[]);
               %
               % ask if we should save results to disk
               %
               txt = 'Would you like to save the forecast error variance decompositions for the state variables to file?';
               answer = Query(txt,'question',140,'Save - Variance Decompositions',500,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  StateVariableNames = DSGEModel.StateVariableNames;
                  if PrintGroups==0;
                     ShockNames = DSGEModel.StateShockNames;
                  else;
                     ShockNames = char(zeros(size(DSGEModel.ShockGroupNames)));
                     for i=1:size(DSGEModel.ShockGroupNames,1);
                        ShockNames(i,:) = strrep(DSGEModel.ShockGroupNames(i,:),'_',' ');
                     end;
                  end;
                  if PrintGroups==0;
                     file = FixFilePath([DSGEModel.OutputDirectory '\StateVarianceDecompositionPriorDist-' int2str(NumPriorDraws) '.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\StateVDPriorDist' int2str(NumPriorDraws) '.m']);
                  else;
                     file = FixFilePath([DSGEModel.OutputDirectory '\StateVarianceDecompositionPriorDist-ShockGroup-' int2str(NumPriorDraws) '.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\StateVDPriorDistShockGroup' int2str(NumPriorDraws) '.m']);
                  end;
                  save(file,'StateVariableNames','ShockNames','VDs');
                  %
                  % create a matlab file to read the data
                  %
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                  fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                  if PrintGroups==0;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                     GroupStr = 'shocks';
                  else;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                     GroupStr = 'shock groups';
                  end;
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% structure with fields FEVD containing the posterior mean\n%% variance decomposition, LRVD the long-run variance\n%% decomposition, Econ containing the joint impact of all\n%% economic shocks, EconLR with the joint impact of all\n%% economic shocks in the long run, and the vector field\n%% Quantiles with subfields FEVD, LRVD, Econ, EconLR, and\n%% percent holding quantile data and quantile percent.\n%%\n');
                  fprintf(fid,'VDs = DataStructure.VDs;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  txt = ['The forecast error variance decomposition for the state variables based on prior draws has been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: StateVariableNames (string matrix with the names of the state variables), ShockNames (string matrix with the names of the economic shocks), and VDs (a structure with prior mean and quantile data for the variance decompositions). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                  About(txt,'information','Variance Decompositions - State Variables',200,500,CurrINI);
               end;
               %
               % display the results
               %
               if PrintGroups==0;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PriorDist-StateVD-' DSGEModel.NameOfModel '-' num2str(NumPriorDraws,'%0.0f') '.txt']);
               else;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PriorDist-StateVD-ShockGroups-' DSGEModel.NameOfModel '-' num2str(NumPriorDraws,'%0.0f') '.txt']);
               end;
               PrintStateFEVD(ResFile,DSGEModel,CurrINI,VDs,PrintGroups,NumPriorDraws,NumPriorDraws,1,0);
               if FileExist(ResFile)==1;
                  TextGUI(ResFile,['Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Prior Distribution - State Variables',50,CurrINI,1,1);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'VDStatePostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            %
            % we can now compute the forecast error variance decompositions up to a given horizon
            %
            [FEVDs,LRVD,UniquenessCheck] = DSGEStateVarianceDecomposition(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI);
            if (isempty(FEVDs)==0)&(length(size(FEVDs))==3);
               %
               % ask if we should save to disk
               %
               txt = 'Would you like to save the variance decompositions for the state variables at posterior mode to file?';
               answer = Query(txt,'question',140,'Save - Variance Decompositions',500,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  file = FixFilePath([DSGEModel.OutputDirectory '\StateVarianceDecompositions-PosteriorMode.mat']);
                  StateVariableNames = DSGEModel.StateVariableNames;
                  ShockNames = DSGEModel.StateShockNames;
                  save(file,'FEVDs','LRVD','StateVariableNames','ShockNames');
                  %
                  % create a matlab file to read the data
                  %
                  mfile = FixFilePath([DSGEModel.OutputDirectory '\VDStatePostMode.m']);
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                  fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% a 3D matrix of dimension rx(1q)xh with the variance decompositions\n%% for the r state variables into the share of state variable uncertainty\n%% and the q economic shocks for the h forecast horizons\n%%\n');
                  fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                  fprintf(fid,'%%\n%% a rxq matrix with the long-run variance decompositions for the\n%% r state variables into the q economic shocks.\n%%\n');
                  fprintf(fid,'LRVD = DataStructure.LRVD;');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  txt = ['The variance decompositions for the state variables have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 4 entries: StateVariableNames (string matrix with the names of the state variables), ShockNames (string matrix with the names of the economic shocks), FEVDs (a 3D matrix of dimension rx(1+q)xh with the variance decompositions for the r state variables), and LRVD (a rxq matrix with the long-run variance decompositions for the r state variables). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                  About(txt,'information','Variance Decompositions - Posterior Mode',200,500,CurrINI);
               end;
               %
               % ask if we should look at shock groups
               %
               PrintGroups = 0;
               if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                  txt = 'Would you like to view results of the variance decompositions for shock groups instead of for the individual shocks?';
                  answer = Query(txt,'question',140,'Variance Decompositions - Posterior Mode',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups)+1,size(FEVDs,3));
                     IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                     IMatrixSR = [1 zeros(1,size(IMatrix,2));zeros(size(IMatrix,1),1) IMatrix];
                     for i=1:size(FEVDs,3);
                        FEVD(:,:,i) = FEVDs(:,:,i)*IMatrixSR;
                     end;
                     FEVDs = FEVD;
                     LRVD = LRVD*IMatrix;
                     PrintGroups = 1;
                  end;
               end;
               %
               % print the results to file
               %
               if PrintGroups==0;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeStateVDs-' DSGEModel.NameOfModel '.txt']);
               else;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorModeStateVDs-ShockGroups-' DSGEModel.NameOfModel '.txt']);
               end;
               PrintStateVarianceDecompositions(ResFile,DSGEModel,FEVDs,LRVD,UniquenessCheck,PrintGroups,CurrINI,'posterior mode');
               if FileExist(ResFile)==1;
                  TextGUI(ResFile,['Variance Decompositions For State Variables - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Mode Parameter Values',50,CurrINI,1,1);
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'VDStatePosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            theta = ModeData.thetaMode;
            [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Variance Decompositions','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  NumDraws = length(LogPost);
                  clear('PostSample','LogPost','AcceptedDraws');
                  drawnow;
                  %
                  % select which posterior draws to use
                  %
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumDraws,:);
                  NumDraws = NumDraws-NumBurnin;
                  %
                  % check which draws we should use
                  %
                  if DSGEModel.PosteriorSampler<=7;
                     UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                     if length(UseDraws)<NumDraws;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        UsedDraws = length(UseDraws);
                     else;
                        UsedDraws = NumDraws;
                     end;
                  else;
                     UsedDraws = NumDraws;
                  end;
                  %
                  % check which function to run
                  %
                  if StateVarDecExist(DSGEModel,UsedDraws,NumDraws,CurrChain,1)==1;
                     txt = 'YADA has located posterior draws results for the forecast error variance decompositions for the state variables data on disk. Would you like to use these results?';
                     answer = Query(txt,'question',150,'Variance Decompositions - State Variables',450,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  RunTimeStr = '';
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                  else;
                     %
                     % compute the variance decompositions for all the posterior draws
                     %
                     StartTime = clock;
                     DoneCalc = DSGEStateFEVD(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,NumDraws,CurrChain,1);
                     EndTime = clock;
                     VarDecRunTime = etime(EndTime,StartTime);
                     RunTimeStr = ['The variance decomposition calculations using ' int2str(UsedDraws) ' posterior draws have finished after ' SecondsToHoursStr(VarDecRunTime) ' (hrs:min:sec). '];
                  end;
                  if DoneCalc==1;
                     %
                     % ask if we should look at shock groups
                     %
                     PrintGroups = 0;
                     if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                        txt = [RunTimeStr 'Would you like to view results of the forecast error variance decompositions for shock groups instead of for the individual shocks?'];
                        answer = Query(txt,'question',150,'Variance Decompositions - State Variables',500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           PrintGroups = 1;
                        end;
                     end;
                     %
                     % compute the distribution for the variance decompositions
                     %
                     VDs = DSGEStateVarDecDistribution(DSGEModel,CurrINI,PrintGroups,UsedDraws,NumDraws,CurrChain,1,Weights);
                     %
                     % ask if we should save results to disk
                     %
                     txt = 'Would you like to save the forecast error variance decompositions for the state variables to file?';
                     answer = Query(txt,'question',140,'Save - Variance Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        StateVariableNames = DSGEModel.StateVariableNames;
                        if PrintGroups==0;
                           ShockNames = DSGEModel.StateShockNames;
                        else;
                           ShockNames = char(zeros(size(DSGEModel.ShockGroupNames)));
                           for i=1:size(DSGEModel.ShockGroupNames,1);
                              ShockNames(i,:) = strrep(DSGEModel.ShockGroupNames(i,:),'_',' ');
                           end;
                        end;
                        if PrintGroups==0;
                           file = FixFilePath([DSGEModel.OutputDirectory '\StateVarianceDecompositionDist-' int2str(CurrChain) '-' int2str(UsedDraws) '-' int2str(NumDraws) '.mat']);
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\StateVDDist' int2str(CurrChain) int2str(UsedDraws) int2str(NumDraws) '.m']);
                        else;
                           file = FixFilePath([DSGEModel.OutputDirectory '\StateVarianceDecompositionDist-ShockGroup-' int2str(CurrChain) '-' int2str(UsedDraws) '-' int2str(NumDraws) '.mat']);
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\StateVDDistShockGroup' int2str(CurrChain) int2str(UsedDraws) int2str(NumDraws) '.m']);
                        end;
                        save(file,'StateVariableNames','ShockNames','VDs');
                        %
                        % create a matlab file to read the data
                        %
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                        fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                        if PrintGroups==0;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                        else;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                        end;
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% structure with fields FEVD containing the posterior mean\n%% variance decomposition, LRVD the long-run variance\n%% decomposition, Econ containing the joint impact of all\n%% economic shocks, EconLR with the joint impact of all\n%% economic shocks in the long run, and the vector field\n%% Quantiles with subfields FEVD, LRVD, Econ, EconLR, and\n%% percent holding quantile data and quantile percent.\n%%\n');
                        fprintf(fid,'VDs = DataStructure.VDs;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The forecast error variance decomposition for the state variables has been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: StateVariableNames (string matrix with the names of the state variables), ShockNames (string matrix with the names of the economic shocks), and VDs (a structure with posterior mean and quantile data for the variance decompositions). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Variance Decompositions - State Variables',200,500,CurrINI);
                     end;
                     %
                     % display the results
                     %
                     if PrintGroups==0;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorDist-StateVD-' num2str(CurrChain,'%0.0f') '-' DSGEModel.NameOfModel '-' num2str(UsedDraws,'%0.0f') '.' num2str(NumDraws,'%0.0f') '.txt']);
                     else;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorDist-StateVD-ShockGroups-' num2str(CurrChain,'%0.0f') '-' DSGEModel.NameOfModel '-' num2str(UsedDraws,'%0.0f') '.' num2str(NumDraws,'%0.0f') '.txt']);
                     end;
                     PrintStateFEVD(ResFile,DSGEModel,CurrINI,VDs,PrintGroups,UsedDraws,NumDraws,CurrChain,1);
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution - State Variables',50,CurrINI,1,1);
                     end;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'CondVDStateInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view the conditional variance decompositions for the state variables at the initial values before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Conditional Variance Decompositions - Initial Values',500,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
               %
               % Try to calculate conditional variance decompositions. First, check if there's a unique
               % convergent solution
               %
               [FEVDs,mcode] = DSGEStateCondVarianceDecompostion(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI);
               %
               % if mcode is not 1, then a unique convergent solution doesn't exist
               %
               if mcode==1;
                  %
                  % display the results if any
                  %
                  if (isempty(FEVDs)==0)&(length(size(FEVDs))==3);
                     %
                     % ask if we should save to disk
                     %
                     txt = 'Would you like to save the conditional variance decompositions for the state variables at the initial values to file?';
                     answer = Query(txt,'question',140,'Save - Conditional Variance Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        file = FixFilePath([DSGEModel.OutputDirectory '\CondVarianceDecompositionsState-InitialValues.mat']);
                        StateVariableNames = DSGEModel.StateVariableNames;
                        ShockNames = DSGEModel.StateShockNames;
                        save(file,'FEVDs','StateVariableNames','ShockNames');
                        %
                        % create a matlab file to read the data
                        %
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDStateInitVal.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                        fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% a 3D matrix of dimension nxqxh with the conditional variance decompositions\n%% for the r observed variables, the q economic shocks, and the h+1 forecast horizons\n%%\n');
                        fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The conditional variance decompositions for the state variables have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: StateVariableNames (string matrix with the names of the state variables), ShockNames (string matrix with the names of the economic shocks), and FEVDs (a 3D matrix of dimension rxqx(h+1) with the variance decompositions for the r state variables for horizons 1 to h, and where h+1 is the long-run variance decomposition). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Conditional Variance Decompositions - Initial Values',200,500,CurrINI);
                     end;
                     %
                     % ask if we should look at shock groups
                     %
                     PrintGroups = 0;
                     if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                        txt = 'Would you like to view results of the conditional variance decompositions for shock groups instead of for the individual shocks?';
                        answer = Query(txt,'question',140,'Conditional Variance Decompositions - Initial Values',500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups),size(FEVDs,3));
                           IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                           for i=1:size(FEVDs,3);
                              FEVD(:,:,i) = FEVDs(:,:,i)*IMatrix;
                           end;
                           FEVDs = FEVD;
                           PrintGroups = 1;
                        end;
                     end;
                     if PrintGroups==0;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\CFEVDsState-InitialValues-' DSGEModel.NameOfModel '.txt']);
                     else;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\CFEVDsState-ShockGroups-InitialValues' DSGEModel.NameOfModel '.txt']);
                     end;
                     %
                     % print to file
                     %
                     PrintStateCondVarianceDecompositions(ResFile,FEVDs,PrintGroups,DSGEModel,CurrINI,'initial values');
                     %
                     % display the results
                     %
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Conditional Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Initial Parameter Values',50,CurrINI,1,1);
                     end;
                  end;
               else;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Conditional Variance Decompositions - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'CondVDStatePriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,'Conditional Variance Decompositions For Prior - State Variables',550,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the posterior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection','Conditional Variance Decompositions For Prior - State Variables','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            %
            % First we check if the calculations have already been performed
            %
            if StateCVDExist(DSGEModel,NumPriorDraws,NumPriorDraws,1,0)==1;
               txt = 'YADA has located results for the conditional variance decompositions on disk. Would you like to use these results?';
               answer = Query(txt,'question',150,'Conditional Variance Decompositions For Prior - State Variables',550,'no',CurrINI);
            else;
               answer = 'No';
            end;
            if strcmp(lower(answer),'yes')==1;
               DoneCalc = 1;
            else;
               %
               % compute the conditional variance decompositions for all the prior draws
               %
               DoneCalc = DSGEStateConditionalFEVD(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,NumPriorDraws,1,0);
            end;
            if DoneCalc==1;
               %
               % ask if we should look at shock groups
               %
               PrintGroups = 0;
               if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                  txt = 'Would you like to view results of the conditional variance decompositions for shock groups instead of for the individual shocks?';
                  answer = Query(txt,'question',140,'Conditional Variance Decompositions For Prior - State Variables',550,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     PrintGroups = 1;
                  end;
               end;
               %
               % compute the distribution for the conditional variance decompositions
               %
               CVDs = DSGEStateCVDDistribution(DSGEModel,CurrINI,PrintGroups,NumPriorDraws,NumPriorDraws,1,0,[]);
               %
               % ask if we should save results to disk
               %
               txt = 'Would you like to save the conditional forecast error variance decompositions to file?';
               answer = Query(txt,'question',140,'Save - Conditional Variance Decompositions',550,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  StateVariableNames = DSGEModel.StateVariableNames;
                  if PrintGroups==0;
                     ShockNames = DSGEModel.StateShockNames;
                  else;
                     ShockNames = char(zeros(size(DSGEModel.ShockGroupNames)));
                     for i=1:size(DSGEModel.ShockGroupNames,1);
                        ShockNames(i,:) = strrep(DSGEModel.ShockGroupNames(i,:),'_',' ');
                     end;
                  end;
                  if PrintGroups==0;
                     file = FixFilePath([DSGEModel.OutputDirectory '\ConditionalVarianceDecompositionPriorDist-State-' int2str(NumPriorDraws) '.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDPriorDistState' int2str(NumPriorDraws) '.m']);
                  else;
                     file = FixFilePath([DSGEModel.OutputDirectory '\ConditionalVarianceDecompositionPriorDist-ShockGroup-State-' int2str(NumPriorDraws) '.mat']);
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDPriorDistShockGroupState' int2str(NumPriorDraws) '.m']);
                  end;
                  save(file,'StateVariableNames','ShockNames','CVDs');
                  %
                  % create a matlab file to read the data
                  %
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                  fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                  if PrintGroups==0;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                  else;
                     fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                  end;
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% structure with fields FEVD containing the posterior mean\n%% conditional variance decomposition and the vector field\n%% Quantiles with subfields FEVD and percent holding quantile\n%% data and quantile percent.\n%%\n');
                  fprintf(fid,'CVDs = DataStructure.CVDs;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  txt = ['The conditional forecast error variance decomposition for the state variables has been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: StateVariableNames (string matrix with the names of the state variables), ShockNames (string matrix with the names of the economic shocks), and CVDs (a structure with posterior mean and quantile data for the conditional variance decompositions). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                  About(txt,'information','Conditional Variance Decompositions For Prior - State Variables',200,550,CurrINI);
               end;
               %
               % display the results
               %
               if PrintGroups==0;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PriorDist-CVD-Prior-State' DSGEModel.NameOfModel '-' int2str(NumPriorDraws) '.txt']);
               else;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\PriorDist-CVD-Prior-State-ShockGroups-' DSGEModel.NameOfModel '-' int2str(NumPriorDraws) '.txt']);
               end;
               PrintStateConditionalCVD(ResFile,DSGEModel,CurrINI,CVDs,PrintGroups,NumPriorDraws,NumPriorDraws,1,0);
               if FileExist(ResFile)==1;
                  TextGUI(ResFile,['Conditional Variance Decompositions For Prior - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Prior Distribution - State Variables',50,CurrINI,1,1);
               end;
            else;
               DSGEModel = OldDSGEModel;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'CondVDStatePostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            %
            % we can now compute the conditional forecast error variance decompositions up to a given horizon
            %
            FEVDs = DSGEStateCondVarianceDecompostion(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI);
            %
            if (isempty(FEVDs)==0)&(length(size(FEVDs))==3);
               %
               % ask if we should save to disk
               %
               txt = 'Would you like to save the conditional variance decompositions for the state variables at posterior mode to file?';
               answer = Query(txt,'question',140,'Save - Conditional Variance Decompositions',500,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  file = FixFilePath([DSGEModel.OutputDirectory '\CondVarianceDecompositionsState-PosteriorMode.mat']);
                  StateVariableNames = DSGEModel.StateVariableNames;
                  ShockNames = DSGEModel.StateShockNames;
                  save(file,'FEVDs','StateVariableNames','ShockNames');
                  %
                  % create a matlab file to read the data
                  %
                  mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDStatePostMode.m']);
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                  fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% a 3D matrix of dimension nxqxh with the conditional variance decompositions\n%% for the r observed variables, the q economic shocks, and the h+1 forecast horizons\n%%\n');
                  fprintf(fid,'FEVDs = DataStructure.FEVDs;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  txt = ['The conditional variance decompositions for the state variables have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: StateVariableNames (string matrix with the names of the state variables), ShockNames (string matrix with the names of the economic shocks), and FEVDs (a 3D matrix of dimension rxqx(h+1) with the variance decompositions for the r state variables for horizons 1 to h, and where h+1 is the long-run variance decomposition). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                  About(txt,'information','Conditional Variance Decompositions - Posterior Mode',200,500,CurrINI);
               end;
               %
               % ask if we should look at shock groups
               %
               PrintGroups = 0;
               if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                  txt = 'Would you like to view results of the conditional variance decompositions for shock groups instead of for the individual shocks?';
                  answer = Query(txt,'question',140,'Conditional Variance Decompositions - Posterior Mode',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     FEVD = zeros(size(FEVDs,1),max(DSGEModel.ShockGroups),size(FEVDs,3));
                     IMatrix = SubIdentityMatrix(DSGEModel.ShockGroups);
                     for i=1:size(FEVDs,3);
                        FEVD(:,:,i) = FEVDs(:,:,i)*IMatrix;
                     end;
                     FEVDs = FEVD;
                     PrintGroups = 1;
                  end;
               end;
               if PrintGroups==0;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\CFEVDsState-PostMode-' DSGEModel.NameOfModel '.txt']);
               else;
                  ResFile = FixFilePath([DSGEModel.OutputDirectory '\CFEVDsState-ShockGroups-PostMode' DSGEModel.NameOfModel '.txt']);
               end;
               %
               % print to file
               %
               PrintStateCondVarianceDecompositions(ResFile,FEVDs,PrintGroups,DSGEModel,CurrINI,'posterior mode');
               %
               % display the results
               %
               if FileExist(ResFile)==1;
                  TextGUI(ResFile,['Conditional Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Mode Parameter Values',50,CurrINI,1,1);
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'CondVDStatePosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            theta = ModeData.thetaMode;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%               FirstPeriod = ModeData.DSGEModel.FirstPeriod;
%               LastPeriod = ModeData.DSGEModel.LastPeriod;
%            else;
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Conditional Variance Decompositions','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  NumDraws = length(LogPost);
                  clear('PostSample','LogPost','AcceptedDraws');
                  drawnow;
                  %
                  % select which posterior draws to use
                  %
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumDraws,:);
                  NumDraws = NumDraws-NumBurnin;
                  %
                  % check which draws we should use
                  %
                  if DSGEModel.PosteriorSampler<=7;
                     UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                     if length(UseDraws)<NumDraws;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        UsedDraws = length(UseDraws);
                     else;
                        UsedDraws = NumDraws;
                     end;
                  else;
                     UsedDraws = NumDraws;
                  end;
                  %
                  % First we check if the calculations have already been performed
                  %
                  if StateCVDExist(DSGEModel,UsedDraws,NumDraws,CurrChain,1)==1;
                     txt = 'YADA has located results for the conditional variance decompositions on disk. Would you like to use these results?';
                     answer = Query(txt,'question',150,'Conditional Variance Decompositions - State Variables',500,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  %
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                  else;
                     %
                     % compute the conditional variance decompositions for all the posterior draws
                     %
                     DoneCalc = DSGEStateConditionalFEVD(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,NumDraws,CurrChain,1);
                  end;
                  %
                  if DoneCalc==1;
                     %
                     % ask if we should look at shock groups
                     %
                     PrintGroups = 0;
                     if length(DSGEModel.ShockGroups)>max(DSGEModel.ShockGroups);
                        txt = 'Would you like to view results of the conditional variance decompositions for shock groups instead of for the individual shocks?';
                        answer = Query(txt,'question',140,'Conditional Variance Decompositions - State Variables',500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           PrintGroups = 1;
                        end;
                     end;
                     %
                     % compute the distribution for the conditional variance decompositions
                     %
                     CVDs = DSGEStateCVDDistribution(DSGEModel,CurrINI,PrintGroups,UsedDraws,NumDraws,CurrChain,1,Weights);
                     %
                     % ask if we should save results to disk
                     %
                     txt = 'Would you like to save the conditional forecast error variance decompositions to file?';
                     answer = Query(txt,'question',140,'Save - Conditional Variance Decompositions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        StateVariableNames = DSGEModel.StateVariableNames;
                        if PrintGroups==0;
                           ShockNames = DSGEModel.StateShockNames;
                        else;
                           ShockNames = char(zeros(size(DSGEModel.ShockGroupNames)));
                           for i=1:size(DSGEModel.ShockGroupNames,1);
                              ShockNames(i,:) = strrep(DSGEModel.ShockGroupNames(i,:),'_',' ');
                           end;
                        end;
                        if PrintGroups==0;
                           file = FixFilePath([DSGEModel.OutputDirectory '\ConditionalVarianceDecompositionDist-State-' int2str(CurrChain) '-' int2str(UsedDraws) '-' int2str(NumDraws) '.mat']);
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDDistState' int2str(CurrChain) int2str(UsedDraws) int2str(NumDraws) '.m']);
                        else;
                           file = FixFilePath([DSGEModel.OutputDirectory '\ConditionalVarianceDecompositionDist-ShockGroup-State-' int2str(CurrChain) '-' int2str(UsedDraws) '-' int2str(NumDraws) '.mat']);
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\CVDDistShockGroupState' int2str(CurrChain) int2str(UsedDraws) int2str(NumDraws) '.m']);
                        end;
                        save(file,'StateVariableNames','ShockNames','CVDs');
                        %
                        % create a matlab file to read the data
                        %
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                        fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                        if PrintGroups==0;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                        else;
                           fprintf(fid,'%%\n%% string matrix with the names of the economic shock groups\n%%\n');
                        end;
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        fprintf(fid,'%%\n%% structure with fields FEVD containing the posterior mean\n%% conditional variance decomposition and the vector field\n%% Quantiles with subfields FEVD and percent holding quantile\n%% data and quantile percent.\n%%\n');
                        fprintf(fid,'CVDs = DataStructure.CVDs;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        txt = ['The conditional forecast error variance decomposition for the state variables has been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 3 entries: StateVariableNames (string matrix with the names of the state variables), ShockNames (string matrix with the names of the economic shocks), and CVDs (a structure with posterior mean and quantile data for the conditional variance decompositions). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Conditional Variance Decompositions - State Variables',200,500,CurrINI);
                     end;
                     %
                     % display the results
                     %
                     if PrintGroups==0;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorDist-CVD-State-' int2str(CurrChain) '-' DSGEModel.NameOfModel '-' int2str(UsedDraws) '.' int2str(NumDraws) '.txt']);
                     else;
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\PosteriorDist-CVD-State-ShockGroups-' int2str(CurrChain) '-' DSGEModel.NameOfModel '-' int2str(UsedDraws) '.' int2str(NumDraws) '.txt']);
                     end;
                     PrintStateConditionalCVD(ResFile,DSGEModel,CurrINI,CVDs,PrintGroups,UsedDraws,NumDraws,CurrChain,1);
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Conditional Variance Decompositions - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution - State Variables',50,CurrINI,1,1);
                     end;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' int2str(CurrChain) ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
end;
set(controls.open,'UserData',DSGEModel);
set(controls.filemenu,'UserData',CurrINI);
%
% make sure that controls are enabled and disabled as they should
%
YADAEnableControls(DSGEModel,controls);

%
% end of DecompToolsMenuFunctions.m
%
