function ForecastToolsMenuFunctions(selector,maingui)
% ForecastToolsMenuFunctions: switch function for running prediction functions on the tools menu.
%
% USAGE:
%
%       ForecastToolsMenuFunctions(selector,maingui)
%
% REQUIRED INPUT: selector (string) that determines which sub-function should be applied.
%
% OPTIONAL INPUT: maingui (handle) to the main YADA GUI.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2025 European Central Bank.
%
%                       First version: May 10, 2010.
%                        This version: January 9, 2025.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 11-05-2010: Updated the documentation.
%
% * 03-06-2010: Fixed some text display issues.
%
% * 08-07-2010: Changed headers on About dialogs when "mcode" or "kalmanstatus" reports problems.
%
% * 20-07-2010: Information about the conditioning information is now also stored to disk.
%
% * 22-07-2010: Added the fields "KernelX" and "KernelY" to the UData structure when population moments
%               of the predictive distribution has been calculated. Took into account that
%               "SummarizeDSGEPredictions" now provides the "TotalVar" output variable.
%
% * 23-07-2010: Added calls to "NormalDensityValues" for a normal approximation of the marginal
%               predictive densities.
%
% * 18-11-2010: Took into account that "PredEventData" and "YObsEventData" now have 7 columns.
%
% * 19-11-2010: Took into account that the matrices now have 8 columns.
%
% * 17-12-2010: The function now supports the Klein and Sims DSGE model solvers.
%
% * 05-01-2011: Updated the documentation.
%
% * 11-01-2011: Made sure that "ModeFile" supports unix and mac paths.
%
% * 12-01-2011: Added support for unix and mac paths.
%
% * 25-01-2011: Took into account that "CalcTransformData" takes the input variable "TransMatrix".
%
% * 14-02-2011: Began work on the covariance matrix decomposition for the conditional forecasts.
%
% * 15-02-2011: Conditional forecasts should now have properly determined population covariance
%               matrices.
%
% * 22-03-2011: Began work on adapting conditional forecasting at posterior mode for the distribution
%               of a subset of the shocks method.
%
% * 23-03-2011: Finished the adaption of the posterior mode case for the subset shock method, added
%               the initial values case, the posterior and prior draws cases, and the prediction
%               event case.
%
% * 02-01-2012: Updated the documentation.
%
% * 07-02-2012: Changed the conditions under which the subset method can be used.
%
% * 28-02-2012: Began preparatory work for allowing the number of simulated paths to be unity for
%               fixed parameter values.
%
% * 21-03-2012: Began work on the height of the predictive density at posterior mode.
%
% * 22-03-2012: Continued working on the height of the predictive density.
%
% * 23-03-2012: Finished the predictive likelihood for the posterior mode.
%
% * 29-03-2012: Added selected variable indicator to stored file name for the.
%
% * 04-04-2012: Took into account that "DSGEPredDensityHeightTheta" has been renamed "DSGEPredictiveLikelihoodTheta"
%               and that "PrintDSGEPredDensityHeight" is now "PrintDSGEPredictiveLikelihood".
%
% * 05-04-2012: When storing predictive likelihood data to disk, the function now display information about
%               what is stored.
%
% * 26-04-2012: Began work on computing the predictive likelihood for the posterior distribution with the modified
%               harmonic mean.
%
% * 27-04-2012: Continued work on the function for the posterior distribution.
%
% * 30-04-2012: Finished the predictive likelihood code for the posterior distribution.
%
% * 14-05-2012: Made sure that a tic call is properly ended. Took into account that "DSGEPredictiveLikelihoodTheta"
%               now also provides the "MargPlugin" and "JointPlugin" output variables.
%
% * 21-08-2012: The predictive likelihood for posterior draws now use the importance sampling estimator.
%
% * 29-08-2012: Took into account that "DSGEPredictionDistribution" and "PredictionPathDistribution" now take the
%               input variable "ConfidenceRegionMethod". Fixed plugin estimate issues for the log predictive
%               likelihood at posterior mode.
%
% * 18-10-2012: Took into account that "PredLikeImportanceSampling" now also provides StdErr for the log predictive
%               likelihood.
%
% * 24-10-2012: Added the initial values case for the predictive likelihood and began work on the prior distribution
%               calculations.
%
% * 25-10-2012: Finished the prior distribution case for the predictive likelihood. Fixed some issues with clearing of
%               variables with larger data.
%
% * 03-01-2013: Updated the documentation.
%
% * 28-01-2014: Updated the documentation.
%
% * 19-08-2014: Took into account that the conditional forecasting functions for fixed parameters now accept the "ExtraShocks"
%               input variable.
%
% * 10-12-2014: Updated the questions for preditive likelihood computations.
%
% * 14-01-2015: Updated the documentation.
%
% * 26-02-2015: Took into account that "PredLikeImportanceSampling" now provides the additional output variables
%               "MinMaxCondLike" and "TestStd". In addition, the function name has been changed to "PredLikeMCI".
%
% * 12-06-2015: Started coding the selection of actuals for the predictive likelihood based on the posterior mode estimates.
%
% * 02-09-2015: Fixed the information displayed when the kalmanstatus is -1.
%
% * 27-01-2016: Remember Shoah.
%
% * 06-12-2016: The state-space matrices are now saved when running the conditional and unconditional
%               forecasts for given theta.
%
% * 20-02-2017: Began coding predictive likelihood calculations for now and backcasts.
%
% * 14-03-2017: Took into account that "DSGEPredictiveLikelihood" now requires "BackYData" as input.
%
% * 15-03-2017: Took into account that "PredLikeMCI" now provides the additional output variables
%               "LogPredLikeBackNow", "StdErrBackNow", "MinMaxCondLikeBackNow", and "TestStdBackNow".
%               These variables as well as "HistSampleStrMat" are now sent as input to the function
%               "PrintDSGEPredictiveLikelihood".
%
% * 20-06-2017: Began work on the marginal predictive moments function for the posterior draws.
%
% * 21-06-2017: Finished the marginal predictive moments function for the posterior and the prior
%               parameter draws.
%
% * 17-08-2017: Removed command that checks if the data in the forecast sample are available or just NaNs
%               for the marginal predictive moments as this data is not used.
%
% * 23-08-2017: Took into account that "LoadDSGEPosteriorDraws" now provides the output variable "Weights".
%
% * 24-08-2017: Took into account that "DSGEPredictionDistribution" takes the input variable "Weights".
%
% * 25-08-2017: Took into account that "PredLikeMCI", "DSGEPredictiveMoments", "DSGEPredictionPaths",
%               "LoadDSGEPredictionPaths", "DSGECondPredictionPaths", "DSGECondPredictionPathsWZ",
%               and "DSGECondPredictionPathsMixed" require the input variable "Weights".
%
% * 15-09-2017: Updated the documentation.
%
% * 24-10-2017: Took into account that the "DSGEPredictiveMoments" function can now compute back- and nowcasts.
%
% * 13-12-2017: Made sure that a subset of prior draws can be used when the model includes a system prior.
%
% * 08-01-2018: Updated the documentation.
%
% * 01-08-2018: The function supports user written model solver function.
%
% * 15-08-2018: Took into account the new error handling via the function YADALastError.
%
% * 29-08-2018: Updated the documentation.
%
% * 25-10-2018: Made sure that the name of the prior draws file reflects using a system prior.
%
% * 07-11-2018: Took into account that "PredictiveDistributionDLG" now takes the input variable "ObsVarMean".
%
% * 23-01-2019: Updated the documentation.
%
% * 21-03-2019: Began work on the predictive variance of the stationary distribution and its decomposition
%               into state, shock, measurement error, and parameter uncertainty for the posterior distribution.
%
% * 22-03-2019: Continued work on the above posterior distribution function.
%
% * 25-03-2019: Finished the posterior distribution part of the stationary predictive variance, and also completed
%               the prior distribution part.
%
% * 10-01-2020: Updated the documentation.
%
% * 25-08-2020: Took into account that "DSGEPredictiveMoments" require the input variable "ComputePIT". Began work
%               on the PIT functions for the prior and the posterior draws.
%
% * 26-08-2020: Finished the PIT function for the posterior draws.
%
% * 27-08-2020: Finished the PIT function for the prior draws.
%
% * 28-08-2020: Began work on the CRPS function for the prior and the posterior draws.
%
% * 31-08-2020: Finished the posterior and prior draws cases for the CRPS function.
%
% * 09-12-2020: Increased the size of the About dialog for ErrorStr.
%
% * 26-01-2021: Updated the documentation.
%
% * 12-05-2021: Took into account that "PrintDSGEPredictiveLikelihood" requires the IsAdaptiveLearning input
%               variable.
%
% * 14-05-2021: Updated the documentation.
%
% * 18-05-2021: Took into account that "PrintPredictiveMoments" now requires the input variable
%               "IsAdaptiveLearning".
%
% * 19-05-2021: Took into account that "PrintPITs" now requires the input variable "IsAdaptiveLearning".
%
% * 20-05-2021: Corrected a bug where thetaMode was set equal to the initial value when using the posterior
%               draws for the predictive distributions and the prediction event functions.
%
% * 25-05-2021: Took into account that "PrintCRPS" now requires the input variable "IsAdaptiveLearning".
%
% * 26-05-2021: CRPS output files now take into account if data are original or annualized.
%
% * 04-01-2022: Updated the documentation and fixed a bug when using simulated paths for PIT computations.
%
% * 11-02-2022: Added check to the CRPS calculations if the user has selected a large number of paths. Took
%               into account that PrintCRPS requires the input variable NumPredPaths.
%
% * 15-02-2022: Made some corrections when computing the CRPS and ES from paths related to the max forecast
%               horizon. Took into account that ComputePITsDSGEPaths take the input variable MaxPH and that
%               the prediction horizon for simulated paths can exceed the horizon for which true values over
%               this horizon are available.
%
% * 22-04-2022: Took into account that for the conditional forecasting cases B0 may already have been purged
%               of zero columns such that the number of columns is lower than the number of state shocks.
%
% * 17-05-2022: Added sub-sample selection for the SMC and MitISEM samplers when combining paths with
%               posterior draws for the CRPS and ES scores.
%
% * 18-05-2022: Added sub-sample selection for the SMC and MitISEM samplers when combining paths with
%               posterior draws for unconditional predictive distributions.
%
% * 19-05-2022: Added sub-sample selection for the SMC and MitISEM samplers when combining paths with
%               posterior draws for conditional predictive distributions, as well as for the unconditional
%               and conditional prediction event functions, and for the PIT estimation and marginal
%               predictive moment estimation.
%
% * 24-05-2022: The variable "DSGEModel.NameOfModel" now affects the names of saved files under CRPS and PIT
%               calculations.
%
% * 24-08-2022: Took into account that "DSGEPredictionPathsTheta" takes the new input variable "ExtraShocks".
%
% * 26-08-2022: Fixed a minor issue with the posterior distribution case for unconditional forecasts.
%
% * 05-01-2023: Updated the documentation.
%
% * 24-01-2023: Added driver support to "ConPredPostMode".
%
% * 25-01-2023: Added driver support to "UnconPredPostMode".
%
% * 09-02-2023: Made sure that driver support for "UnconPredPostMode" and "ConPredPostMode" also includes
%               forecasts of annualized observables and of transformed observables.
%
% * 17-02-2023: Removed the input variable ExtraShocks from DSGECondPredictionPathsTheta/WZ/Mixed.m.
%
% * 21-02-2023: Added the "maingui" input variable.
%
% * 16-03-2023: Updated the documentation.
%
% * 14-04-2023: Removed the input variable "ExtraShocks" to "DSGEPredictionPathsTheta".
%
% * 10-05-2023: Added function for viewing actuals data.
%
% * 19-06-2023: Fixed print bugs with missing comment signs.
%
% * 25-07-2023: Began work on the observation weight decompositions of the point forecasts
%               for the posterior mode estimates.
%
% * 26-07-2023: Continued work on the above case.
%
% * 27-07-2023: Finished the case as well as the initial values case.
%
% * 02-01-2024: Began work on the CRPS for conditional forecasts using the posterior draws.
%
% * 03-01-2024: Added the CRPS for conditional forecasts using the prior draws.
%
% * 17-01-2024: Updated the documentation.
%
% * 29-01-2024: Took into account that "ComputeCRPSDSGEPaths" no longer takes the input variable "Weights"
%               and that "PrintCRPS" now takes the input variable "IsZLB".
%
% * 31-01-2024: Removed to newline commands when producing script files for the CRPS and ES results.
%
% * 07-02-2024: Added function cases for computing the predictive likelihood for the conditional forecasts
%               using prior or posterior draws.
%
% * 08-02-2024: Finished the prior and posterior mode cases for the conditional forecasts.
%
% * 15-03-2024: Changed the lower vertical position of the TextGUI function from 32 pixels to 50.
%
% * 18-03-2024: Made sure that the PredictionEvent field is not changed unless user selects it.
%
% * 16-04-2024: Took into account that "PrintDSGEModestyStatistics" takes the "IsAdaptiveLearning"
%               input variable, and that "CondPredictiveDistributionDLG" takes the input variable
%               "ObsVarMean".
%
% * 26-04-2024: Took into account that "DSGEModestyStatistic" takes the "ModelStr" input variable.
%
% * 05-06-2024: Took into account that "ComputePredLikeDSGECondPaths" now supports adaptive learning
%               models as well as the rational expectations models.
%
% * 11-06-2024: Added CRPS calculations based on the normal distribution to the PIT calculations for
%               the posterior draws.
%
% * 12-06-2024: Same calculations for the prior draws.
%
% * 29-07-2024: Added the function cases for the marginal predictive moments for the conditional forecasts
%               using the prior and the posterior draws.
%
% * 30-07-2024: Finished the values for shocks case and wrote half of the Waggoner-Zha case for the posterior
%               draws.
%
% * 31-07-2024: Finished the Waggoner-Zha case as well as the mixed distribution case. Finished work on the
%               marginal predictice moments for the conditional forecasts using the prior draws, and started
%               work on the PITs based on the conditional forecasts using the posterior draws.
%
% * 01-08-2024: Finished the PITs for the posterior draws and began work on the prior draws case.
%
% * 09-01-2025: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% collect some inportant data structures
%
if nargin==1;
   maingui = findobj('Type','figure','Tag','YADA');
end;
controls = get(maingui,'UserData');
CurrINI = get(controls.filemenu,'UserData');
DSGEModel = get(controls.open,'UserData');
OrigDSGEModel = get(controls.openmenu,'UserData');
if MatlabNumber<7;
   lasterr = '';
end;
%
switch selector
   case 'UnconPredHeightInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % get the parameter data
         %
         [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
            ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
            if FileExist(ModeFile)==1;
               ErrorStr = '';
               if MatlabNumber>=8.0;
                  try;
                     ModeData = load(ModeFile);
                  catch ME;
                     ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                  end;
               else;
                  try;
                     ModeData = load(ModeFile);
                  catch;
                     ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                  end;
               end;
               if isempty(ErrorStr)==1;
                  theta = ModeData.theta;
                  thetaPositions = ModeData.thetaPositions;
                  ModelParameters = ModeData.ModelParameters;
                  ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                  ParameterNames = ModeData.ParameterNames;
                  thetaIndex = ModeData.thetaIndex;
                  UniformBounds = ModeData.UniformBounds;
                  LowerBound = ModeData.LowerBound;
                  InitStatus = 1;
               else;
                  About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
               end;
            end;
         end;
         %
         if InitStatus==1;
            [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
            %
            % check how many time periods to use for predictive distributions
            %
            MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
            %
            % check the maximum when we take NaNs into account
            %
            YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
            BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
            if isempty(DSGEModel.Actuals)==1;
               SelectedYData = 1;
               YDataStr = 'Actuals from original sample';
               action = 'ok';
            else;
               YDataStr = 'Actuals from original sample';
               m = length(DSGEModel.Actuals);
               for i=1:m;
                  YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
               end;
               [action,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','Predictive Likelihood - Initial Values','','',CurrINI);
               if (strcmp(lower(action),'ok')==1)&(SelectedYData>1);
                  YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                  BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
               end;
            end;
            %
            if strcmp(lower(action),'ok')==1;
               MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
               [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               MaxFH = min(MaxFH,MaxPH);
               YData = YData(:,1:MaxFH);
               %
               % matrix with exogenous variables
               %
               X = [];
               if DSGEModel.k>0;
                  if NumPredX<MaxFH;
                     X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
                  end;
                  if NumPredX>0;
                     X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
                  end;
               end;
               %
               % selection of variable 
               %
               if isempty(DSGEModel.PredictionVariables)==1;
                  PredictionVariables = ones(1,DSGEModel.n);
                  PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
               else;
                  PredictionVariables = DSGEModel.PredictionVariables;
               end;
               %
               [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
               if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                  %
                  % we may continue and store the new selection of prediction variables
                  %
                  DSGEModel.PredictionVariables = PredictionVariables;
                  %
                  % check if we should predict the original data or annualized data
                  %
                  if gcbo==controls.predict.unconditional.original.height.initialvalues;
                     IsOriginal = 1;
                     DataStr = 'Original';
                  else;
                     IsOriginal = 0;
                     DataStr = 'Annualized';
                  end;
                  StepLengthStr = get(controls.optimize.steplength,'String');
                  StepLength = str2num(StringTrim(StepLengthStr(DSGEModel.StepLengthHessian,:)));
                  %
                  % check if the user wants only the plugin estimate of the predictive likelihood
                  %
                  IsPlugin = 0;
                  txt = strvcat('Would you like to compute the plugin estimate only and skip the Laplace approximation?',' ','NOTE: The Laplace approximation requires that the Hessian matrix of the log posterior kernel is computed in addition to the plugin estimate. Moreover, the Laplace approximation is based on an optimal estimate of the parameters, i.e. that the gradient vector is (close to) zero. If you answer NO then YADA will compute both sets of values.');
                  answer = Query(txt,'question',400,'Predictive Likelihood - Initial Values',600,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     IsPlugin = 1;
                  end;
                  %
                  % compute the predictive density height
                  %
                  tic;
                  [JointPDH,MargPDH,LaplaceMargLike,PredVars,MargPlugin,JointPlugin,MargBackNowcast,status,kalmanstatus] = DSGEPredictiveLikelihoodTheta(theta,thetaPositions,thetaIndex,thetaDist,PriorDist,LowerBound,UniformBounds,ModelParameters,YData,X,BackYData,IsOriginal,IsPlugin,FirstPeriod,LastPeriod,StepLength,DSGEModel,CurrINI);
                  CompTime = toc;
                  %
                  % check if we have results
                  %
                  if isempty(JointPDH)==0;
                     %
                     % ask if we should the results to disk
                     %
                     %
                     SelectedVarStr = ismember((1:DSGEModel.n),DSGEModel.PredictionVariables);
                     SelectedVarStr = strrep(num2str(SelectedVarStr),' ','');
                     %
                     PredictionSampleStrMat = CreateFullSample(DSGEModel);
                     HistSampleStrMat = PredictionSampleStrMat(LastPeriod-1:LastPeriod,:);
                     PredictionSampleStrMat = PredictionSampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                     txt = ['Would you like to save the posterior mode results for the ' lower(DataStr) ' predictions to disk?'];
                     answer = Query(txt,'question',200,'Save - Predictive Likelihood',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        YNames = DSGEModel.VariableNames;
                        file = FixFilePath([DSGEModel.OutputDirectory '\DSGEPredictiveLikelihood-' DSGEModel.NameOfModel '-' DataStr '-' SelectedVarStr '-' strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.') '-InitialValues.mat']);
                        save(file,'JointPDH','MargPDH','LaplaceMargLike','MargPlugin','JointPlugin','MargBackNowcast','PredVars','YNames','PredictionSampleStrMat','HistSampleStrMat');
                        %
                        % create a matlab m-file to read the output.
                        %
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\PLike' DataStr SelectedVarStr strrep(PredictionSampleStrMat(1,:),':','_') strrep(PredictionSampleStrMat(MaxFH,:),':','_') 'InitVal.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        if IsPlugin==0;
                           fprintf(fid,'%%\n%% Predictive likelihood of joint predictions \n%%\n');
                           fprintf(fid,'JointPDH = DataStructure.JointPDH;\n');
                           fprintf(fid,'%%\n%% Predictive likelihood of marginal predictions \n%%\n');
                           fprintf(fid,'MargPDH = DataStructure.MargPDH;\n');
                           fprintf(fid,'%%\n%% Laplace approximation of log marginal likelihood for historical sample \n%%\n');
                           fprintf(fid,'LaplaceMargLike = DataStructure.LaplaceMargLike;\n');
                           NumEntries = '10';
                           AddText = 'JointPDH (vector with the values of the joint predictive likelihood), MargPDH (vector with the marginal predictive likelihood), LaplaceMargLike (scalar with the marginal likelihood for the historical sample), ';
                        else;
                           NumEntries = '7';
                           AddText = '';
                        end;
                        fprintf(fid,'%%\n%% Plugin estimate of the joint predictive likelihood \n%%\n');
                        fprintf(fid,'JointPlugin = DataStructure.JointPlugin;\n');
                        fprintf(fid,'%%\n%% Plugin estimate of the marginal predictive likelihood \n%%\n');
                        fprintf(fid,'MargPlugin = DataStructure.MargPlugin;\n');
                        fprintf(fid,'%%\n%% positions of predicted variables in YNames \n%%\n');
                        fprintf(fid,'PredVars = DataStructure.PredVars;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% string matrix with prediction sample dates \n%%\n');
                        fprintf(fid,'PredictionSampleStrMat = DataStructure.PredictionSampleStrMat;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        %
                        txt = ['The predictive likelihood results at initial values have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' NumEntries ' entries: ' AddText 'MargPlugin (vector with the plugin estimate of the marginal predictive likelihood), JointPlugin (vector with the plugin estimate of the joint predictive likelihood), MargBackNowcast (vector with marginalized conditional likelihood for back and nowcast), PredVars (cell array with the locations of the predicted variables), YNames (string matrix with the names of the observed variables), PredictionSampleStrMat (string matrix with the prediction sample dates), and HistSampleStrMat (string matrix with dates for back and nowcast). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Predictive Likelihood - Initial Values',500,600,CurrINI);
                     end;
                     %
                     % write to file
                     %
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\DSGEPredictiveLikelihood-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' DataStr '-' SelectedVarStr '-' strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.') '-InitialValues.txt']);
                     %
                     PrintDSGEPredictiveLikelihoodTheta(ResFile,JointPDH,MargPDH,LaplaceMargLike,JointPlugin,MargPlugin,MargBackNowcast,PredVars,PredictionSampleStrMat,HistSampleStrMat,YDataStr(SelectedYData,:),IsOriginal,IsPlugin,'initial values',[],CompTime,DSGEModel,CurrINI);
                     %
                     % display the results
                     %
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Predictive Likelihood - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Initial Values',50,CurrINI,1,0);
                     end;
                  end;
               elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                  txt = 'You didn''t select any variables to predict when computing the predictive likelihood. YADA is therefore unable to help you!';
                  About(txt,'information','Predictive Likelihood - Initial Values',150,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconPredHeightPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,'Predictive Likelihood - Prior Distribution',500,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
                  UniformBounds = ModeData.UniformBounds;
                  thetaIndex = ModeData.thetaIndex;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the prior draws data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the prior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection','Predictive Likelihood - Prior Distribution','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            clear('PriorData');
            %
            % determine the sample
            %
            [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
            %
            % check how many time periods to use for predictive distributions
            %
            MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
            %
            % check the maximum when we take NaNs into account
            %
            YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
            BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
            if isempty(DSGEModel.Actuals)==1;
               SelectedYData = 1;
               DataAction = 'ok';
               YDataStr = 'Actuals from original sample';
            else;
               YDataStr = 'Actuals from original sample';
               m = length(DSGEModel.Actuals);
               for i=1:m;
                  YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
               end;
               [DataAction,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','Predictive Likelihood - Prior Distribution','','',CurrINI);
               if (strcmp(lower(DataAction),'ok')==1)&(SelectedYData>1);
                  YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                  BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
               end;
            end;
            %
            if strcmp(lower(DataAction),'ok')==1;
               MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
               [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               MaxFH = min(MaxFH,MaxPH);
               YData = YData(:,1:MaxFH);
               %
               % matrix with exogenous variables
               %
               X = [];
               if DSGEModel.k>0;
                  if NumPredX<MaxFH;
                     X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
                  end;
                  if NumPredX>0;
                     X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
                  end;
               end;
               %
               % selection of variable 
               %
               if isempty(DSGEModel.PredictionVariables)==1;
                  PredictionVariables = ones(1,DSGEModel.n);
                  PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
               else;
                  PredictionVariables = DSGEModel.PredictionVariables;
               end;
               %
               [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
               if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                  %
                  % we may continue and store the new selection of prediction variables
                  %
                  DSGEModel.PredictionVariables = PredictionVariables;
                  %
                  % check if we should predict the original data or annualized data
                  %
                  if gcbo==controls.predict.unconditional.original.height.prior;
                     IsOriginal = 1;
                     DataStr = 'Original';
                  else;
                     IsOriginal = 0;
                     DataStr = 'Annualized';
                  end;
                  %
                  % check if the user wants to compute the marginal or the joint predictive likelihood
                  %
                  txt = 'Would you like to compute the marginal predictive likelikehood or the joint predictive likelihood?';
                  answer = Query(txt,'question',400,'Predictive Likelihood - Prior Distribution',500,'yes',CurrINI,{'Marginal' 'Joint'});
                  if strcmp(lower(answer),'marginal')==1;
                     IsMarginal = 1;
                     MargStr = 'Marginal';
                  else;
                     IsMarginal = 0;
                     MargStr = 'Joint';
                  end;
                  %
                  % check if results already exist on disk
                  %
                  if PredictiveLikelihoodExist(DSGEModel,SelectedYData,IsOriginal,IsMarginal,0,MaxFH,NumPriorDraws,0,NumPriorDraws,0)==1;
                     txt = ['YADA has located ' lower(MargStr) ' log posterior calculations for the ' lower(DataStr) ' data for the predictive likelihood on disk. Would you like to use these results?'];
                     answer = Query(txt,'question',200,[MargStr ' Predictive Likelihood - Prior Distribution'],500,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  tic;
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                  else;
                     %
                     % compute the predictive density height
                     %
                     DoneCalc = DSGEPredictiveLikelihood(thetaDraws',theta,thetaPositions,thetaIndex,thetaDist,PriorDist,LowerBound,UniformBounds,ModelParameters,YData,X,BackYData,SelectedYData,IsOriginal,0,IsMarginal,FirstPeriod,LastPeriod,NumPriorDraws,0,0,DSGEModel,CurrINI);
                  end;
                  clear('thetaDraws');
                  if DoneCalc==1;
                     %
                     % we can now do the remaining computations.
                     %
                     [LogPredLike,StdErr,PredVars,MinMaxCondLike,TestStd,LogPredLikeBackNow,StdErrBackNow,MinMaxCondLikeBackNow,TestStdBackNow] = PredLikeMCI(SelectedYData,NumPriorDraws,MaxFH,IsOriginal,IsMarginal,0,[],0,NumPriorDraws,0,DSGEModel);
                     CompTime = toc;
                     if isempty(LogPredLike)==0;
                        %
                        % ask the user if results should be saved to file
                        %
                        SelectedVarStr = ismember((1:DSGEModel.n),DSGEModel.PredictionVariables);
                        SelectedVarStr = strrep(num2str(SelectedVarStr),' ','');
                        %
                        PredictionSampleStrMat = CreateFullSample(DSGEModel);
                        HistSampleStrMat = PredictionSampleStrMat(LastPeriod-1:LastPeriod,:);
                        PredictionSampleStrMat = PredictionSampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                        txt = ['Would you like to save the prior draws results for the ' lower(DataStr) ' predictions to disk?'];
                        answer = Query(txt,'question',200,['Save - ' MargStr ' Predictive Likelihood'],500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           YNames = DSGEModel.VariableNames;
                           file = FixFilePath([DSGEModel.OutputDirectory '\DSGE' MargStr 'PredictiveLikelihood-Prior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' DataStr '-' SelectedVarStr '-' strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.') '-' int2str(NumPriorDraws) '.mat']);
                           if (IsOriginal==1)&(IsMarginal==1);
                              save(file,'LogPredLike','StdErr','LogPredLikeBackNow','StdErrBackNow','PredVars','YNames','PredictionSampleStrMat');
                           else;
                              save(file,'LogPredLike','StdErr','PredVars','YNames','PredictionSampleStrMat');
                           end;
                           %
                           % create a matlab m-file to read the output.
                           %
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\' MargStr(1) 'PLikePrior' int2str(SelectedYData) '_' DataStr(1) SelectedVarStr strrep(PredictionSampleStrMat(1,:),':','_') strrep(PredictionSampleStrMat(MaxFH,:),':','_') int2str(NumPriorDraws) '.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% Log predictive likelihood of %s predictions \n%%\n',lower(MargStr));
                           fprintf(fid,'LogPredLike = DataStructure.LogPredLike;\n');
                           fprintf(fid,'%%\n%% numerical standard errors of the log predictive likelihood of %s predictions \n%%\n',lower(MargStr));
                           fprintf(fid,'StdErr = DataStructure.StdErr;\n');
                           if (IsOriginal==1)&(IsMarginal==1);
                              fprintf(fid,'%%\n%% Log predictive likelihood of predictions for the back and nowcast \n%%\n',lower(MargStr));
                              fprintf(fid,'LogPredLikeBackNow = DataStructure.LogPredLikeBackNow;\n');
                              fprintf(fid,'%%\n%% numerical standard errors of the log predictive likelihood of the back and nowcasts \n%%\n',lower(MargStr));
                              fprintf(fid,'StdErrBackNow = DataStructure.StdErrBackNow;\n');
                              AddTxtStr = 'LogPredLikeBackNow (vector of dimension 2 with the values of the log predictive likelihood for the back- and nowcast), StdErrBackNow (vector of dimension 2 with the numerical standard errors of the log predictive likelihood for the back- and nowcast), ';
                              NumEntries = '7';
                           else;
                              AddTxtStr = '';
                              NumEntries = '5';
                           end;
                           fprintf(fid,'%%\n%% positions of predicted variables in YNames \n%%\n');
                           fprintf(fid,'PredVars = DataStructure.PredVars;\n');
                           fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                           fprintf(fid,'YNames = DataStructure.YNames;\n');
                           fprintf(fid,'%%\n%% string matrix with prediction sample dates \n%%\n');
                           fprintf(fid,'PredictionSampleStrMat = DataStructure.PredictionSampleStrMat;\n');
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                           %
                           txt = ['The ' lower(MargStr) ' predictive likelihood results for the prior draws have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' NumEntries 'entries: LogPredLike (vector of dimension hx1 with the values of the ' lower(MargStr) ' log predictive likelihood), StdErr (vector of dimension h with the numerical standard errors of the log predictive likelihood), ' AddTxtStr 'PredVars (cell array with the locations of the predicted variables), YNames (string matrix with the names of the observed variables), and PredictionSampleStrMat (string matrix with the prediction sample dates). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                           About(txt,'information',[MargStr ' Predictive Likelihood - Prior Distribution'],500,600,CurrINI);
                        end;
                        %
                        % write the results to text file
                        %
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE' MargStr 'PredictiveLikelihood-Prior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' DataStr '-' SelectedVarStr '-' strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.') '-' int2str(NumPriorDraws) '.txt']);
                        %
                        PrintDSGEPredictiveLikelihood(ResFile,LogPredLike,StdErr,PredVars,MinMaxCondLike,TestStd,LogPredLikeBackNow,StdErrBackNow,MinMaxCondLikeBackNow,TestStdBackNow,PredictionSampleStrMat,HistSampleStrMat,YDataStr(SelectedYData,:),IsOriginal,IsMarginal,0,0,NumPriorDraws,0,NumPriorDraws,[],CompTime,DSGEModel,CurrINI);
                        %
                        % display the results
                        %
                        if FileExist(ResFile)==1;
                           TextGUI(ResFile,[MargStr ' Predictive Likelihood - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Prior Distribution',50,CurrINI,1,0);
                        end;
                     else;
                        DSGEModel = OldDSGEModel;
                     end;
                  else;
                     CompTime = toc;
                     DSGEModel = OldDSGEModel;
                  end;
               elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                  clear('thetaDraws');
                  txt = 'You didn''t select any variables to predict when computing the predictive likelihood. YADA is therefore unable to help you!';
                  About(txt,'information','Predictive Likelihood - Prior Distribution',150,500,CurrINI);
               else;
                  DSGEModel = OldDSGEModel;
               end;
            else;
               DSGEModel = OldDSGEModel;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconPredHeightPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % File with the data needed to calculate the predictive distr
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         %
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            thetaIndex = ModeData.thetaIndex;
            thetaDist = ModeData.thetaDist;
            PriorDist = ModeData.PriorDist;
            LowerBound = ModeData.LowerBound;
            UniformBounds = ModeData.UniformBounds;
            ModelParameters = ModeData.ModelParameters;
            %
            [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
            %
            % check how many time periods to use for predictive distributions
            %
            MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
            %
            % check the maximum when we take NaNs into account
            %
            YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
            BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
            if isempty(DSGEModel.Actuals)==1;
               SelectedYData = 1;
               YDataStr = 'Actuals from original sample';
               action = 'ok';
            else;
               YDataStr = 'Actuals from original sample';
               m = length(DSGEModel.Actuals);
               for i=1:m;
                  YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
               end;
               [action,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','Predictive Likelihood - Posterior Mode','','',CurrINI);
               if (strcmp(lower(action),'ok')==1)&(SelectedYData>1);
                  YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                  BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
               end;
            end;
            %
            if strcmp(lower(action),'ok')==1;
               %
               % now check what is the maximum horizon we can use
               %
               MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
               [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               MaxFH = min(MaxFH,MaxPH);
               YData = YData(:,1:MaxFH);
               %
               % matrix with exogenous variables
               %
               X = [];
               if DSGEModel.k>0;
                  if NumPredX<MaxFH;
                     X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
                  end;
                  if NumPredX>0;
                     X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
                  end;
               end;
               %
               % selection of variable 
               %
               if isempty(DSGEModel.PredictionVariables)==1;
                  PredictionVariables = ones(1,DSGEModel.n);
                  PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
               else;
                  PredictionVariables = DSGEModel.PredictionVariables;
               end;
               %
               [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
               if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                  %
                  % we may continue and store the new selection of prediction variables
                  %
                  DSGEModel.PredictionVariables = PredictionVariables;
                  %
                  % check if we should predict the original data or annualized data
                  %
                  if gcbo==controls.predict.unconditional.original.height.postmode;
                     IsOriginal = 1;
                     DataStr = 'Original';
                  else;
                     IsOriginal = 0;
                     DataStr = 'Annualized';
                  end;
                  StepLengthStr = get(controls.optimize.steplength,'String');
                  StepLength = str2num(StringTrim(StepLengthStr(DSGEModel.StepLengthHessian,:)));
                  %
                  % check if the user wants only the plugin estimate of the predictive likelihood
                  %
                  IsPlugin = 0;
                  txt = strvcat('Would you like to compute the plugin estimate only and skip the Laplace approximation?',' ','NOTE: The Laplace approximation requires that the Hessian matrix of the log posterior kernel is computed in addition to the plugin estimate. If you answer NO then YADA will compute both sets of values.');
                  answer = Query(txt,'question',400,'Predictive Likelihood - Posterior Mode',600,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     IsPlugin = 1;
                  end;
                  %
                  % compute the predictive density height
                  %
                  tic;
                  [JointPDH,MargPDH,LaplaceMargLike,PredVars,MargPlugin,JointPlugin,MargBackNowcast] = DSGEPredictiveLikelihoodTheta(theta,thetaPositions,thetaIndex,thetaDist,PriorDist,LowerBound,UniformBounds,ModelParameters,YData,X,BackYData,IsOriginal,IsPlugin,FirstPeriod,LastPeriod,StepLength,DSGEModel,CurrINI);
                  CompTime = toc;
                  %
                  % check if we have results
                  %
                  if isempty(JointPDH)==0;
                     %
                     % ask if we should the results to disk
                     %
                     %
                     SelectedVarStr = ismember((1:DSGEModel.n),DSGEModel.PredictionVariables);
                     SelectedVarStr = strrep(num2str(SelectedVarStr),' ','');
                     %
                     PredictionSampleStrMat = CreateFullSample(DSGEModel);
                     HistSampleStrMat = PredictionSampleStrMat(LastPeriod-1:LastPeriod,:);
                     PredictionSampleStrMat = PredictionSampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                     txt = ['Would you like to save the posterior mode results for the ' lower(DataStr) ' predictions to disk?'];
                     answer = Query(txt,'question',200,'Save - Predictive Likelihood',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        YNames = DSGEModel.VariableNames;
                        file = FixFilePath([DSGEModel.OutputDirectory '\DSGEPredictiveLikelihood-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' DataStr '-' SelectedVarStr '-' strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.') '-PostMode.mat']);
                        save(file,'JointPDH','MargPDH','LaplaceMargLike','MargPlugin','JointPlugin','MargBackNowcast','PredVars','YNames','PredictionSampleStrMat','HistSampleStrMat');
                        %
                        % create a matlab m-file to read the output.
                        %
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\PLike' int2str(SelectedYData) '_' DataStr SelectedVarStr strrep(PredictionSampleStrMat(1,:),':','_') strrep(PredictionSampleStrMat(MaxFH,:),':','_') 'PostMode.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        if IsPlugin==0;
                           fprintf(fid,'%%\n%% Predictive likelihood of joint predictions \n%%\n');
                           fprintf(fid,'JointPDH = DataStructure.JointPDH;\n');
                           fprintf(fid,'%%\n%% Predictive likelihood of marginal predictions \n%%\n');
                           fprintf(fid,'MargPDH = DataStructure.MargPDH;\n');
                           fprintf(fid,'%%\n%% Laplace approximation of log marginal likelihood for historical sample \n%%\n');
                           fprintf(fid,'LaplaceMargLike = DataStructure.LaplaceMargLike;\n');
                           NumEntries = '10';
                           AddText = 'JointPDH (vector with the values of the joint predictive likelihood), MargPDH (vector with the marginal predictive likelihood), LaplaceMargLike (scalar with the marginal likelihood for the historical sample), ';
                        else;
                           NumEntries = '7';
                           AddText = '';
                        end;
                        fprintf(fid,'%%\n%% Plugin estimate of the joint predictive likelihood \n%%\n');
                        fprintf(fid,'JointPlugin = DataStructure.JointPlugin;\n');
                        fprintf(fid,'%%\n%% Plugin estimate of the marginal predictive likelihood \n%%\n');
                        fprintf(fid,'MargPlugin = DataStructure.MargPlugin;\n');
                        fprintf(fid,'%%\n%% Plugin estimate of the marginal conditional back and nowcast likelihood \n%%\n');
                        fprintf(fid,'MargBackNowcast = DataStructure.MargBackNowcast;\n');
                        fprintf(fid,'%%\n%% positions of predicted variables in YNames \n%%\n');
                        fprintf(fid,'PredVars = DataStructure.PredVars;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% string matrix with prediction sample dates \n%%\n');
                        fprintf(fid,'PredictionSampleStrMat = DataStructure.PredictionSampleStrMat;\n');
                        fprintf(fid,'%%\n%% string matrix with back and nowcast dates \n%%\n');
                        fprintf(fid,'HistSampleStrMat = DataStructure.HistSampleStrMat;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        %
                        txt = ['The predictive likelihood results at posterior mode have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' NumEntries ' entries: ' AddText 'MargPlugin (vector with the plugin estimate of the marginal predictive likelihood), JointPlugin (vector with the plugin estimate of the joint predictive likelihood), MargBackNowcast (vector with marginalized conditional likelihood for back and nowcast), PredVars (cell array with the locations of the predicted variables), YNames (string matrix with the names of the observed variables), PredictionSampleStrMat (string matrix with the prediction sample dates), and HistSampleStrMat (string matrix with dates for back and nowcast). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Predictive Likelihood - Posterior Mode',500,600,CurrINI);
                     end;
                     %
                     % write to file
                     %
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\DSGEPredictiveLikelihood-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' DataStr '-' SelectedVarStr '-' strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.') '-PostMode.txt']);
                     %
                     PrintDSGEPredictiveLikelihoodTheta(ResFile,JointPDH,MargPDH,LaplaceMargLike,JointPlugin,MargPlugin,MargBackNowcast,PredVars,PredictionSampleStrMat,HistSampleStrMat,YDataStr(SelectedYData,:),IsOriginal,IsPlugin,'posterior mode',[],CompTime,DSGEModel,CurrINI);
                     %
                     % display the results
                     %
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Predictive Likelihood - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Mode Parameter Values',50,CurrINI,1,0);
                     end;
                  end;
               elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                  txt = 'You didn''t select any variables to predict when computing the predictive likelihood. YADA is therefore unable to help you!';
                  About(txt,'information','Predictive Likelihood - Posterior Mode',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconPredHeightPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         %
         if isempty(ErrorStr)==1;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Predictive Likelihood - Posterior Distribution','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            %
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  clear('LogPost','AcceptedDraws','PostSample');
                  [NumPostDraws,NumParam] = size(thetaPostSample);
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumPostDraws,:);
                  NumDraws = NumPostDraws-NumBurnin;
                  %
                  % check if the user wishes a sub-sample
                  %
                  if DSGEModel.PosteriorSampler<=7;
                     txt = 'Would you like to use a sub-sample of the posterior draws when estimating the predictive likelihood?';
                     answer = Query(txt,'question',400,'Predictive Likelihood - Posterior Distribution',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        NumDraws = length(UseDraws);
                     end;
                  end;
                  %
                  % collect some required data
                  %
                  theta = ModeData.thetaMode;
                  thetaPositions = ModeData.thetaPositions;
                  thetaIndex = ModeData.thetaIndex;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  LowerBound = ModeData.LowerBound;
                  UniformBounds = ModeData.UniformBounds;
                  ModelParameters = ModeData.ModelParameters;
                  %
                  [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
                  %
                  % check how many time periods to use for predictive distributions
                  %
                  MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
                  %
                  % check the maximum when we take NaNs into account
                  %
                  YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
                  BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
                  if isempty(DSGEModel.Actuals)==1;
                     SelectedYData = 1;
                     DataAction = 'ok';
                     YDataStr = 'Actuals from original sample';
                  else;
                     YDataStr = 'Actuals from original sample';
                     m = length(DSGEModel.Actuals);
                     for i=1:m;
                        YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
                     end;
                     [DataAction,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','Predictive Likelihood - Posterior Distribution','','',CurrINI);
                     if (strcmp(lower(DataAction),'ok')==1)&(SelectedYData>1);
                        YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                        BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
                     end;
                  end;
                  %
                  if strcmp(lower(DataAction),'ok')==1;
                     MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
                     [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
                     MaxFH = min(MaxFH,MaxPH);
                     YData = YData(:,1:MaxFH);
                     %
                     % matrix with exogenous variables
                     %
                     X = [];
                     if DSGEModel.k>0;
                        if NumPredX<MaxFH;
                           X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
                        end;
                        if NumPredX>0;
                           X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
                        end;
                     end;
                     %
                     % selection of variable 
                     %
                     if isempty(DSGEModel.PredictionVariables)==1;
                        PredictionVariables = ones(1,DSGEModel.n);
                        PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
                     else;
                        PredictionVariables = DSGEModel.PredictionVariables;
                     end;
                     %
                     [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
                     if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                        %
                        % we may continue and store the new selection of prediction variables
                        %
                        DSGEModel.PredictionVariables = PredictionVariables;
                        %
                        % check if we should predict the original data or annualized data
                        %
                        if gcbo==controls.predict.unconditional.original.height.posterior;
                           IsOriginal = 1;
                           DataStr = 'Original';
                        else;
                           IsOriginal = 0;
                           DataStr = 'Annualized';
                        end;
                        %
                        % check if the user wants to compute the marginal or the joint predictive likelihood
                        %
                        txt = 'Would you like to compute the marginal predictive likelikehood or the joint predictive likelihood?';
                        answer = Query(txt,'question',400,'Predictive Likelihood - Posterior Distribution',500,'yes',CurrINI,{'Marginal' 'Joint'});
                        if strcmp(lower(answer),'marginal')==1;
                           IsMarginal = 1;
                           MargStr = 'Marginal';
                        else;
                           IsMarginal = 0;
                           MargStr = 'Joint';
                        end;
                        %
                        % check if results already exist on disk
                        %
                        if PredictiveLikelihoodExist(DSGEModel,SelectedYData,IsOriginal,IsMarginal,1,MaxFH,NumDraws,NumBurnin,NumPostDraws,CurrChain)==1;
                           txt = ['YADA has located ' lower(MargStr) ' log posterior calculations for the ' lower(DataStr) ' data for the predictive likelihood on disk. Would you like to use these results?'];
                           answer = Query(txt,'question',200,[MargStr ' Predictive Likelihood - Posterior Distribution'],500,'no',CurrINI);
                        else;
                           answer = 'No';
                        end;
                        tic;
                        if strcmp(lower(answer),'yes')==1;
                           DoneCalc = 1;
                        else;
                           %
                           % compute the predictive density height
                           %
                           DoneCalc = DSGEPredictiveLikelihood(thetaPostSample,theta,thetaPositions,thetaIndex,thetaDist,PriorDist,LowerBound,UniformBounds,ModelParameters,YData,X,BackYData,SelectedYData,IsOriginal,1,IsMarginal,FirstPeriod,LastPeriod,NumPostDraws,NumBurnin,CurrChain,DSGEModel,CurrINI);
                        end;
                        clear('thetaPostSample');
                        if DoneCalc==1;
                           %
                           % we can now do the remaining computations.
                           %
                           [LogPredLike,StdErr,PredVars,MinMaxCondLike,TestStd,LogPredLikeBackNow,StdErrBackNow,MinMaxCondLikeBackNow,TestStdBackNow] = PredLikeMCI(SelectedYData,NumDraws,MaxFH,IsOriginal,IsMarginal,1,Weights,NumBurnin,NumPostDraws,CurrChain,DSGEModel);
                           CompTime = toc;
                           %
                           if isempty(LogPredLike)==0;
                              %
                              % ask the user if results should be saved to file
                              %
                              SelectedVarStr = ismember((1:DSGEModel.n),DSGEModel.PredictionVariables);
                              SelectedVarStr = strrep(num2str(SelectedVarStr),' ','');
                              %
                              PredictionSampleStrMat = CreateFullSample(DSGEModel);
                              HistSampleStrMat = PredictionSampleStrMat(LastPeriod-1:LastPeriod,:);
                              PredictionSampleStrMat = PredictionSampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                              txt = ['Would you like to save the posterior draws results for the ' lower(DataStr) ' predictions to disk?'];
                              answer = Query(txt,'question',200,['Save - ' MargStr ' Predictive Likelihood'],500,'no',CurrINI);
                              if strcmp(lower(answer),'yes')==1;
                                 YNames = DSGEModel.VariableNames;
                                 file = FixFilePath([DSGEModel.OutputDirectory '\DSGE' MargStr 'PredictiveLikelihood-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' DataStr '-' SelectedVarStr '-' strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.') '-' int2str(NumDraws) '.' int2str(NumBurnin) '.' int2str(NumPostDraws) '-' int2str(CurrChain) '.mat']);
                                 if (IsOriginal==1)&(IsMarginal==1);
                                    save(file,'LogPredLike','StdErr','LogPredLikeBackNow','StdErrBackNow','PredVars','YNames','PredictionSampleStrMat','HistSampleStrMat');
                                 else;
                                    save(file,'LogPredLike','StdErr','PredVars','YNames','PredictionSampleStrMat');
                                 end;
                                 %
                                 % create a matlab m-file to read the output.
                                 %
                                 mfile = FixFilePath([DSGEModel.OutputDirectory '\' MargStr(1) 'PLike' int2str(SelectedYData) '_' DataStr(1) SelectedVarStr strrep(PredictionSampleStrMat(1,:),':','_') strrep(PredictionSampleStrMat(MaxFH,:),':','_') int2str(NumDraws) int2str(NumBurnin) int2str(NumPostDraws) int2str(CurrChain) '.m']);
                                 fid = fopen(mfile,'wt');
                                 fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                                 fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                                 fprintf(fid,'%%\n%% Log predictive likelihood of %s predictions \n%%\n',lower(MargStr));
                                 fprintf(fid,'LogPredLike = DataStructure.LogPredLike;\n');
                                 fprintf(fid,'%%\n%% numerical standard errors of the log predictive likelihood of %s predictions \n%%\n',lower(MargStr));
                                 fprintf(fid,'StdErr = DataStructure.StdErr;\n');
                                 if (IsOriginal==1)&(IsMarginal==1);
                                    fprintf(fid,'%%\n%% Log predictive likelihood of predictions for the back and nowcast \n%%\n',lower(MargStr));
                                    fprintf(fid,'LogPredLikeBackNow = DataStructure.LogPredLikeBackNow;\n');
                                    fprintf(fid,'%%\n%% numerical standard errors of the log predictive likelihood of the back and nowcasts \n%%\n',lower(MargStr));
                                    fprintf(fid,'StdErrBackNow = DataStructure.StdErrBackNow;\n');
                                    fprintf(fid,'%%\n%% string matrix with back- and nowcast sample dates \n%%\n');
                                    fprintf(fid,'HistSampleStrMat = DataStructure.HistSampleStrMat;\n');
                                    AddTxtStr = 'LogPredLikeBackNow (vector of dimension 2 with the values of the log predictive likelihood for the back- and nowcast), StdErrBackNow (vector of dimension 2 with the numerical standard errors of the log predictive likelihood for the back- and nowcast), HistSampleStrMat (string matrix with the back- and nowcast sample dates), ';
                                    NumEntries = '8';
                                 else;
                                    AddTxtStr = '';
                                    NumEntries = '5';
                                 end;
                                 fprintf(fid,'%%\n%% positions of predicted variables in YNames \n%%\n');
                                 fprintf(fid,'PredVars = DataStructure.PredVars;\n');
                                 fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                                 fprintf(fid,'YNames = DataStructure.YNames;\n');
                                 fprintf(fid,'%%\n%% string matrix with prediction sample dates \n%%\n');
                                 fprintf(fid,'PredictionSampleStrMat = DataStructure.PredictionSampleStrMat;\n');
                                 fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                                 %
                                 % end the script file
                                 %
                                 fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                                 fclose(fid);
                                 %
                                 txt = ['The ' lower(MargStr) ' predictive likelihood results for the posterior draws have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' NumEntries ' entries: LogPredLike (vector of dimension hx1 with the values of the ' lower(MargStr) ' log predictive likelihood), StdErr (vector of dimension h with the numerical standard errors of the log predictive likelihood), ' AddTxtStr 'PredVars (cell array with the locations of the predicted variables), YNames (string matrix with the names of the observed variables), and PredictionSampleStrMat (string matrix with the prediction sample dates). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                                 About(txt,'information',[MargStr ' Predictive Likelihood - Posterior Distribution'],500,600,CurrINI);
                              end;
                              %
                              % write the results to text file
                              %
                              ResFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE' MargStr 'PredictiveLikelihood-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' DataStr '-' SelectedVarStr '-' strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.') '-' int2str(NumDraws) '.' int2str(NumBurnin) '.' int2str(NumPostDraws) '-' int2str(CurrChain) '.txt']);
                              %
                              PrintDSGEPredictiveLikelihood(ResFile,LogPredLike,StdErr,PredVars,MinMaxCondLike,TestStd,LogPredLikeBackNow,StdErrBackNow,MinMaxCondLikeBackNow,TestStdBackNow,PredictionSampleStrMat,HistSampleStrMat,YDataStr(SelectedYData,:),IsOriginal,IsMarginal,1,0,NumDraws,NumBurnin,NumPostDraws,[],CompTime,DSGEModel,CurrINI);
                              %
                              % display the results
                              %
                              if FileExist(ResFile)==1;
                                 TextGUI(ResFile,[MargStr ' Predictive Likelihood - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution',50,CurrINI,1,0);
                              end;
                           end;
                        else;
                           CompTime = toc;
                        end;
                     elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                        clear('thetaPostSample');
                        txt = 'You didn''t select any variables to predict when computing the predictive likelihood. YADA is therefore unable to help you!';
                        About(txt,'information','Predictive Likelihood - Posterior Distribution',150,500,CurrINI);
                     end;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ConPredHeightPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         OriginalNumPredPathsValue = DSGEModel.NumPredPathsValue;
         if MatlabNumber>=8.0;
            try;
               AIMData = load(DSGEModel.AIMDataFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' DSGEModel.AIMDataFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               AIMData = load(DSGEModel.AIMDataFile);
            catch;
               ErrorStr = ['Unable to load the file "' DSGEModel.AIMDataFile '". Message caught is: ' YADALastError];
            end;
         end;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,'Predictive Likelihood - Prior Distribution',500,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
                  UniformBounds = ModeData.UniformBounds;
                  thetaIndex = ModeData.thetaIndex;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the prior draws data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the prior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection','CRPS - Prior Distribution','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            clear('PriorData');
            %
            % determine how many prediction paths to use
            %
            NumPredPathsStr = get(controls.forecast.predpaths,'String');
            NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
            UsePaths = 1;
            if NumPredPaths*NumPriorDraws>=10000000;
               txt = ['The total number of paths that the predictive likelihood calculations will use is equal ' int2str(NumPredPaths*NumPriorDraws) ' and it may take a very long time to finish them. Are you sure you wish to continue?'];
               answer = Query(txt,'question',400,'Predictive Likelihood - Prior Distribution',500,'no',CurrINI);
               if strcmp(lower(answer),'no')==1;
                  UsePaths = 0;
               end;
            end;
            %
            if UsePaths==1;
               %
               % determine the sample
               %
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
               DSGEModel.FirstPeriod = FirstPeriod;
               DSGEModel.LastPeriod = LastPeriod;
               %
               % check how many time periods to use for predictive distributions
               %
               MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
               %
               % check the maximum when we take NaNs into account
               %
               YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
               BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
               if isempty(DSGEModel.Actuals)==1;
                  SelectedYData = 1;
                  DataAction = 'ok';
                  YDataStr = 'Actuals from original sample';
               else;
                  YDataStr = 'Actuals from original sample';
                  m = length(DSGEModel.Actuals);
                  for i=1:m;
                     YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
                  end;
                  [DataAction,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','Predictive Likelihood - Prior Distribution','','',CurrINI);
                  if (strcmp(lower(DataAction),'ok')==1)&(SelectedYData>1);
                     YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                     BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
                  end;
               end;
            else;
               DataAction = 'cancel';
            end;
            %
            %
            if strcmp(lower(DataAction),'ok')==1;
               MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
               [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               MaxFH = min(MaxFH,MaxPH);
               YData = YData(:,1:MaxFH);
               %
               % matrix with exogenous variables
               %
               X = [];
               if DSGEModel.k>0;
                  if NumPredX<MaxPH;
                     X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                  end;
                  if NumPredX>0;
                     X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxPH))];
                  end;
               end;
               %
               % check the length of the conditioning sample
               %
               [status,NumPeriods] = CheckConditioningData(DSGEModel);
               %
               % check if we should adjust the X matrix
               %
               if MaxPH<NumPeriods;
                  NumPeriods = MaxPH;
               end;
               %
               % collect the conditional variables and the selected conditioning sample
               %
               Z = DSGEModel.Z(DSGEModel.ConditionalVariables,LastPeriod+1:LastPeriod+NumPeriods);
               if LastPeriod>=NumPeriods;
                  U = DSGEModel.U(DSGEModel.ConditionalVariables,LastPeriod-NumPeriods+1:LastPeriod);
               else;
                  %
                  % we have to create artifical initial conditions for the conditioning variables
                  %
                  U = [DSGEModel.U(DSGEModel.ConditionalVariables,1)*ones(1,NumPeriods-LastPeriod) DSGEModel.U(DSGEModel.ConditionalVariables,1:LastPeriod)];
               end;
               %
               % selection of variable 
               %
               if isempty(DSGEModel.PredictionVariables)==1;
                  PredictionVariables = ones(1,DSGEModel.n);
                  PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
               else;
                  PredictionVariables = DSGEModel.PredictionVariables;
               end;
               %
               [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
               if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                  %
                  % check if there are any matches between conditional variable names and predicted variable names
                  %
                  [status,VarStrMat] = CompareVariablesStrMat(DSGEModel.ZVariableNames(DSGEModel.ConditionalVariables,:),DSGEModel.VariableNames(PredictionVariables,:));
                  %
                  if status==1;
                     VarStr = vecstr(VarStrMat,',');
                     VarStr = VarStr(1:length(VarStr)-1);
                     txt = ['Some of the conditioning variables have the same name as the selected predicted variables. These variables are: ' VarStr '. Are you sure you wish to continue?'];
                     answer = Query(txt,'question',400,'Predictive Likelihood - Prior Distribution',600,'no',CurrINI);
                  else;
                     answer = 'yes';
                  end;
                  if strcmp(lower(answer),'yes')==1;
                     DSGEModel.PredictionVariables = PredictionVariables;
                     %
                     % Determine the prediction sample
                     %
                     SampleStrMat = CreateFullSample(DSGEModel);
                     PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                     SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                     %
                     %
                     if gcbo==controls.predict.conditional.original.height.prior;
                        AnnualizeData = 0;
                        AnnualStr = 'original';
                        QueryHead = 'Predictive Distributions (Predictive Likelihood) - Original Data';
                     elseif gcbo==controls.predict.conditional.annual.height.prior;
                        AnnualizeData = 1;
                        AnnualStr = 'annual';
                        QueryHead = 'Predictive Distributions (Predictive Likelihood) - Annualized Data';
                     end;
                     %
                     % check which method is used for dealing with the conditioning assumptions
                     %
                     if DSGEModel.ShockControlMethod==1;
                        ShockMethod = 'Direct-';
                     elseif DSGEModel.ShockControlMethod==2;
                        ShockMethod = 'WaggonerZha-';
                     else;
                        ShockMethod = 'Subset-';
                     end;
                     %
                     % check if prediction paths already exist
                     %
                     if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumPriorDraws,NumPredPaths,AnnualizeData,0,1,0)==1;
                        txt = 'YADA has located results for the predictive distribution on disk. Would you like to use these results?';
                        answer = Query(txt,'question',150,QueryHead,500,'no',CurrINI);
                     else;
                        answer = 'No';
                     end;
                     %
                     % check if we shall recompute
                     %
                     if strcmp(lower(answer),'yes')==1;
                        DoneCalc = 1;
                        tic;
                     else;
                        %
                        % ask if we should conduct prediction event calculations
                        %
                        txt = strvcat('Would you like YADA to calculate prediction event probabilities and perform risk analysis?',' ','NOTE: The results will only be stored to disk and will not be displayed.');
                        answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                              DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                           end;
                           %
                           % make sure that the prediction event length does not exceed the maximum prediction horizon
                           %
                           for i=1:DSGEModel.n;
                              if DSGEModel.PredictionEvent(i,3)>MaxPH;
                                 DSGEModel.PredictionEvent(i,3) = MaxPH;
                              end;
                           end;
                           %
                           % display a dialog for setting up an prediction event
                           %
                           [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                           if strcmp(lower(action),'ok')==1;
                              DSGEModel.PredictionEvent = PredictionEvent;
                              DSGEModel.RunPredictionEvent = 1;
                           else;
                              DSGEModel.RunPredictionEvent = 0;
                           end;
                        else;
                           DSGEModel.RunPredictionEvent = 0;
                        end;
                        %
                        % we can now compute the predictive distribution for the endogenous variables
                        % up to period MaxPH
                        %
                        tic;
                        %
                        % we can now compute the predictive distribution for the endogenous variables
                        % up to period MaxPH
                        %
                        if DSGEModel.ShockControlMethod==1;
                           [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPaths(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,0,1,0,[]);
                        elseif DSGEModel.ShockControlMethod==2;
                           [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsWZ(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,0,1,0,[]);
                        else;
                           %
                           % check if the selected method can actually be used
                           %
                           CondTxt = '';
                           if isempty(DSGEModel.MixedConditionalShocks)==1;
                              CondTxt = 'You haven''t selected any shocks for use which the distribution of a subset of the shocks conditioning method.';
                           elseif length(DSGEModel.MixedConditionalShocks)<length(DSGEModel.ConditionalVariables);
                              CondTxt = ['The number of shocks you have selected to use to ensure that the conditioning assumptions are satisfied under the distribution of a subset of the shocks conditioning method is not sufficient. You need at least ' int2str(length(DSGEModel.ConditionalVariables)) ' such shocks.'];
                           end;
                           if isempty(CondTxt)==1;
                              [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsMixed(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,0,1,0,[]);
                           else;
                              About(CondTxt,'information','Bad Shocks Selection - Distribution of Subset Shocks Method',300,550,CurrINI);
                              DoneCalc = 0;
                           end;
                        end;
                     end;
                     clear('thetaDraws');
                     if DoneCalc==1;
                        %
                        % we can now compute the log predictive likelihood
                        %
                        LogPredLike = ComputePredLikeDSGECondPaths(YData,PredictionVariables,NumPriorDraws,NumPredPaths,MaxPH,AnnualizeData,[],0,0,ShockMethod,DSGEModel,CurrINI);
                        CompTime = toc;
                        %
                        % ask the user if results should be saved to file
                        %
                        SelectedVarStr = ismember((1:DSGEModel.n),DSGEModel.PredictionVariables);
                        SelectedVarStr = strrep(num2str(SelectedVarStr),' ','');
                        %
                        PredictionSampleStrMat = CreateFullSample(DSGEModel);
                        PredictionSampleStrMat = PredictionSampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                        txt = ['Would you like to save the prior draws results for the ' lower(AnnualStr) ' predictions to disk?'];
                        answer = Query(txt,'question',200,'Save - Predictive Likelihood',500,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                           file = FixFilePath([DSGEModel.OutputDirectory '\PredictiveLikelihood-Cond-Prior-' DSGEModel.NameOfModel '-' ShockMethod int2str(SelectedYData) '.' AnnualStr '-' SelectedVarStr '-' int2str(MaxPH) '-' int2str(NumPriorDraws) '.' int2str(NumPredPaths) '-' SmpStr '.mat']);
                           YNames = DSGEModel.VariableNames;
                           save(file,'YNames','PredictionVariables','LogPredLike','PredDateVector','PredictionSampleStrMat');
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\PLikeCondPrior_' DSGEModel.NameOfModel '_' strrep(ShockMethod,'-','') '_' int2str(SelectedYData) '_' AnnualStr '_' SelectedVarStr '_' int2str(MaxPH) '_' int2str(NumPriorDraws) 'x' int2str(NumPredPaths) '_' strrep(SmpStr,'.','_') '.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                           fprintf(fid,'YNames = DataStructure.YNames;\n');
                           fprintf(fid,'%%\n%% Selected group of joint prediction variables\n%%\n');
                           fprintf(fid,'PredictionVariables = DataStructure.PredictionVariables;\n');
                           fprintf(fid,'%%\n%% n+1 x h matrix with the individual variable log predictive likelihoods\n%% and the joint predictive likelihood for each forecast horizon.\n%%\n');
                           fprintf(fid,'LogPredLike = DataStructure.LogPredLike;\n');
                           fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                           fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                           fprintf(fid,'%%\n%% string matrix with prediction sample dates \n%%\n');
                           fprintf(fid,'PredictionSampleStrMat = DataStructure.PredictionSampleStrMat;\n');
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                           %
                           txt = ['The predictive likelihood estimates for the individual and the selected jointly predicted variables based on the prior draws have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 5 entries: YNames (string matrix with the names of the observed variables), PredictionVariables (vector with integer values for the jointly predicted variables), LogPredLike (matrix with the individual variable log predictive likelihood values and the joint value for each forecast horizon), PredDateVector (vector with dates for the forecast horizon), and PredictionSampleStrMat (string matrix with the prediction sample dates). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                           About(txt,'information','Predictive Likelihood - Prior Distribution',500,600,CurrINI);
                        end;
                        %
                        % write the results to a text file
                        %
                        ResFile = FixFilePath([DSGEModel.OutputDirectory '\PredictiveLikelihood-Cond-Prior-' DSGEModel.NameOfModel '-' ShockMethod int2str(SelectedYData) '.' AnnualStr '-' SelectedVarStr '-' int2str(MaxPH) '-' int2str(NumPriorDraws) '.' int2str(NumPredPaths) '-' SmpStr '.txt']);
                        %
                        PrintZLBPredictiveLikelihood(ResFile,'DSGE',PredictionVariables,PredictionSampleStrMat,YDataStr(SelectedYData,:),LogPredLike,AnnualizeData,0,1,0,0,NumPriorDraws,[],NumPriorDraws,NumPredPaths,[],CompTime,DSGEModel,CurrINI);
                        %
                        % display the results
                        %
                        if FileExist(ResFile)==1;
                           TextGUI(ResFile,['Predictive Likelihood - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Prior Distribution',50,CurrINI,1,0);
                        end;
                     else;
                        CompTime = toc;
                     end;
                  end;
               elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                  txt = 'You didn''t select any variables to predict when computing the log predictive likelihood. YADA is therefore unable to help you!';
                  About(txt,'information','Predictive Likelihood - ZLB Prior Distribution',150,500,CurrINI);
               end;
            else;
               DSGEModel = OldDSGEModel;
            end;
         end;
         %
         % reset in case it was temporarily changed
         %
         DSGEModel.NumPredPathsValue = OriginalNumPredPathsValue;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ConPredHeightPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            if MatlabNumber>=8.0;
               try;
                  AIMData = load(DSGEModel.AIMDataFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' DSGEModel.AIMDataFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  AIMData = load(DSGEModel.AIMDataFile);
               catch;
                  ErrorStr = ['Unable to load the file "' DSGEModel.AIMDataFile '". Message caught is: ' YADALastError];
               end;
            end;
         end;
         %
         if strcmp(ErrorStr,'')==1;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Predictive Likelihood - Posterior Distribution','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            %
            %
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  clear('LogPost','AcceptedDraws','PostSample');
                  [NumPostDraws,NumParam] = size(thetaPostSample);
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumPostDraws,:);
                  NumDraws = NumPostDraws-NumBurnin;
                  %
                  % check if the user wishes a sub-sample
                  %
                  txt = 'Would you like to use a sub-sample of the posterior draws when estimating the predictive likelihood?';
                  answer = Query(txt,'question',400,'Predictive Likelihood - Posterior Distribution',500,'no',CurrINI);
                  if (DSGEModel.PosteriorSampler<=7)|(DSGEModel.PosteriorSampler==9);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        NumDraws = length(UseDraws);
                     end;
                  else;
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = WeightBasedPosteriorDraws(DSGEModel,CurrINI,'Predictive Likelihood - Posterior Distribution',Weights,[]);
                        if isempty(UseDraws)==1;
                           set(controls.about,'UserData',0);
                           return;
                        end;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        Weights = Weights(UseDraws,1);
                        Weights = Weights*length(Weights)/sum(Weights);
                        NumDraws = length(UseDraws);
                     end;
                  end;
                  %
                  % determine how many prediction paths to use
                  %
                  NumPredPathsStr = get(controls.forecast.predpaths,'String');
                  NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
                  if NumPredPaths==1;
                     NumPredPaths = 100;
                     DSGEModel.NumPredPathsValue = 1;
                  end;
                  UsePaths = 1;
                  if NumPredPaths*NumDraws>=10000000;
                     txt = ['The total number of paths that the predictive likelihood calculations will use is equal ' int2str(NumPredPaths*NumDraws) ' and it may take a very long time to finish them. Are you sure you wish to continue?'];
                     answer = Query(txt,'question',400,'Predictive Likelihood - Posterior Distribution',500,'no',CurrINI);
                     if strcmp(lower(answer),'no')==1;
                        UsePaths = 0;
                     end;
                  end;
                  %
                  % check if we should continue
                  %
                  if UsePaths==1;
                     %
                     % collect some required data
                     %
                     theta = ModeData.thetaMode;
                     thetaPositions = ModeData.thetaPositions;
                     thetaIndex = ModeData.thetaIndex;
                     thetaDist = ModeData.thetaDist;
                     PriorDist = ModeData.PriorDist;
                     LowerBound = ModeData.LowerBound;
                     UniformBounds = ModeData.UniformBounds;
                     ModelParameters = ModeData.ModelParameters;
                     %
                     [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
                     DSGEModel.FirstPeriod = FirstPeriod;
                     DSGEModel.LastPeriod = LastPeriod;
                     %
                     % check how many time periods to use for predictive distributions
                     %
                     MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
                     %
                     % check the maximum when we take NaNs into account
                     %
                     YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
                     BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
                     if isempty(DSGEModel.Actuals)==1;
                        SelectedYData = 1;
                        DataAction = 'ok';
                        YDataStr = 'Actuals from original sample';
                     else;
                        YDataStr = 'Actuals from original sample';
                        m = length(DSGEModel.Actuals);
                        for i=1:m;
                           YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
                        end;
                        [DataAction,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','Predictive Likelihood - Posterior Distribution','','',CurrINI);
                        if (strcmp(lower(DataAction),'ok')==1)&(SelectedYData>1);
                           YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                           BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
                        end;
                     end;
                  else;
                     DataAction = 'cancel';
                  end;
                  if strcmp(lower(DataAction),'ok')==1;
                     MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
                     [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
                     MaxFH = min(MaxFH,MaxPH);
                     YData = YData(:,1:MaxFH);
                     %
                     % matrix with exogenous variables
                     %
                     X = [];
                     if DSGEModel.k>0;
                        if NumPredX<MaxPH;
                           X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                        end;
                        if NumPredX>0;
                           X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxPH))];
                        end;
                     end;
                     %
                     % check the length of the conditioning sample
                     %
                     [status,NumPeriods] = CheckConditioningData(DSGEModel);
                     %
                     % check if we should adjust the X matrix
                     %
                     if MaxPH<NumPeriods;
                        NumPeriods = MaxPH;
                     end;
                     %
                     % collect the conditional variables and the selected conditioning sample
                     %
                     Z = DSGEModel.Z(DSGEModel.ConditionalVariables,LastPeriod+1:LastPeriod+NumPeriods);
                     if LastPeriod>=NumPeriods;
                        U = DSGEModel.U(DSGEModel.ConditionalVariables,LastPeriod-NumPeriods+1:LastPeriod);
                     else;
                        %
                        % we have to create artifical initial conditions for the conditioning variables
                        %
                        U = [DSGEModel.U(DSGEModel.ConditionalVariables,1)*ones(1,NumPeriods-LastPeriod) DSGEModel.U(DSGEModel.ConditionalVariables,1:LastPeriod)];
                     end;
                     %
                     % selection of variable 
                     %
                     if isempty(DSGEModel.PredictionVariables)==1;
                        PredictionVariables = ones(1,DSGEModel.n);
                        PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
                     else;
                        PredictionVariables = DSGEModel.PredictionVariables;
                     end;
                     %
                     [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
                     if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                        %
                        % check if there are any matches between conditional variable names and predicted variable names
                        %
                        [status,VarStrMat] = CompareVariablesStrMat(DSGEModel.ZVariableNames(DSGEModel.ConditionalVariables,:),DSGEModel.VariableNames(PredictionVariables,:));
                        %
                        if status==1;
                           VarStr = vecstr(VarStrMat,',');
                           VarStr = VarStr(1:length(VarStr)-1);
                           txt = ['Some of the conditioning variables have the same name as the selected predicted variables. These variables are: ' VarStr '. Are you sure you wish to continue?'];
                           answer = Query(txt,'question',400,'Predictive Likelihood - Posterior Distribution',600,'no',CurrINI);
                        else;
                           answer = 'yes';
                        end;
                        if strcmp(lower(answer),'yes')==1;
                           DSGEModel.PredictionVariables = PredictionVariables;
                           %
                           % Determine the prediction sample
                           %
                           SampleStrMat = CreateFullSample(DSGEModel);
                           PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                           SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                           %
                           %
                           if gcbo==controls.predict.conditional.original.height.posterior;
                              AnnualizeData = 0;
                              AnnualStr = 'original';
                              QueryHead = 'Predictive Distributions (Predictive Likelihood) - Original Data';
                           elseif gcbo==controls.predict.conditional.annual.height.posterior;
                              AnnualizeData = 1;
                              AnnualStr = 'annual';
                              QueryHead = 'Predictive Distributions (Predictive Likelihood) - Annualized Data';
                           end;
                           %
                           % check which method is used for dealing with the conditioning assumptions
                           %
                           if DSGEModel.ShockControlMethod==1;
                              ShockMethod = 'Direct-';
                           elseif DSGEModel.ShockControlMethod==2;
                              ShockMethod = 'WaggonerZha-';
                           else;
                              ShockMethod = 'Subset-';
                           end;
                           %
                           % check if we have already stored results to disk
                           %
                           if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumDraws,NumPredPaths,AnnualizeData,0,CurrChain,1)==1;
                              txt = 'YADA has located results for the predictive distribution on disk. Would you like to use these results?';
                              answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                           else;
                              answer = 'No';
                           end;
                           %
                           % check if we shall recompute
                           %
                           if strcmp(lower(answer),'yes')==1;
                              DoneCalc = 1;
                              tic;
                           else;
                              %
                              % ask if we should conduct prediction event calculations
                              %
                              txt = strvcat('Would you like YADA to calculate prediction event probabilities and perform risk analysis?',' ','NOTE: The results will only be stored to disk and will not be displayed.');
                              answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
                              if strcmp(lower(answer),'yes')==1;
                                 if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                                    DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                                 end;
                                 %
                                 % make sure that the prediction event length does not exceed the maximum prediction horizon
                                 %
                                 for i=1:DSGEModel.n;
                                    if DSGEModel.PredictionEvent(i,3)>MaxPH;
                                       DSGEModel.PredictionEvent(i,3) = MaxPH;
                                    end;
                                 end;
                                 %
                                 % display a dialog for setting up an prediction event
                                 %
                                 [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                                 if strcmp(lower(action),'ok')==1;
                                    DSGEModel.PredictionEvent = PredictionEvent;
                                    DSGEModel.RunPredictionEvent = 1;
                                 else;
                                    DSGEModel.RunPredictionEvent = 0;
                                 end;
                              else;
                                 DSGEModel.RunPredictionEvent = 0;
                              end;
                              %
                              % we can now compute the predictive distribution for the endogenous variables
                              % up to period MaxPH
                              %
                              tic;
                              %
                              % we can now compute the predictive distribution for the endogenous variables
                              % up to period MaxPH
                              %
                              if DSGEModel.ShockControlMethod==1;
                                 [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPaths(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,0,CurrChain,1,Weights);
                              elseif DSGEModel.ShockControlMethod==2;
                                 [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsWZ(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,0,CurrChain,1,Weights);
                              else;
                                 %
                                 % check if the selected method can actually be used
                                 %
                                 CondTxt = '';
                                 if isempty(DSGEModel.MixedConditionalShocks)==1;
                                    CondTxt = 'You haven''t selected any shocks for use which the distribution of a subset of the shocks conditioning method.';
                                 elseif length(DSGEModel.MixedConditionalShocks)<length(DSGEModel.ConditionalVariables);
                                    CondTxt = ['The number of shocks you have selected to use to ensure that the conditioning assumptions are satisfied under the distribution of a subset of the shocks conditioning method is not sufficient. You need at least ' int2str(length(DSGEModel.ConditionalVariables)) ' such shocks.'];
                                 end;
                                 if isempty(CondTxt)==1;
                                    [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsMixed(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,0,CurrChain,1,Weights);
                                 else;
                                    About(CondTxt,'information','Bad Shocks Selection - Distribution of Subset Shocks Method',300,550,CurrINI);
                                    DoneCalc = 0;
                                 end;
                              end;
                           end;
                           clear('thetaPostSample');
                           if DoneCalc==1;
                              %
                              % now compute the predictive likelihood with kernel density estimation for the predicted variables
                              %
                              LogPredLike = ComputePredLikeDSGECondPaths(YData,PredictionVariables,NumDraws,NumPredPaths,MaxPH,AnnualizeData,CurrChain,1,0,ShockMethod,DSGEModel,CurrINI);
                              CompTime = toc;
                              %
                              % ask the user if results should be saved to file
                              %
                              SelectedVarStr = ismember((1:DSGEModel.n),DSGEModel.PredictionVariables);
                              SelectedVarStr = strrep(num2str(SelectedVarStr),' ','');
                              %
                              PredictionSampleStrMat = CreateFullSample(DSGEModel);
                              PredictionSampleStrMat = PredictionSampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                              txt = ['Would you like to save the posterior draws results for the ' lower(AnnualStr) ' predictions to disk?'];
                              answer = Query(txt,'question',200,'Save - Predictive Likelihood',500,'no',CurrINI);
                              if strcmp(lower(answer),'yes')==1;
                                 [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                                 file = FixFilePath([DSGEModel.OutputDirectory '\PredictiveLikelihood-Cond-Posterior-' DSGEModel.NameOfModel '-' ShockMethod int2str(SelectedYData) '.' AnnualStr '-' SelectedVarStr '-' int2str(CurrChain) '-' int2str(MaxPH) '-' int2str(NumDraws) '.' int2str(NumPredPaths) '-' SmpStr '.mat']);
                                 YNames = DSGEModel.VariableNames;
                                 save(file,'YNames','PredictionVariables','LogPredLike','PredDateVector','PredictionSampleStrMat');
                                 mfile = FixFilePath([DSGEModel.OutputDirectory '\PLikeCondPosterior_' DSGEModel.NameOfModel '_' strrep(ShockMethod,'-','') '_' int2str(SelectedYData) '_' AnnualStr '_' SelectedVarStr '_' int2str(CurrChain) '_' int2str(MaxPH) '_' int2str(NumDraws) 'x' int2str(NumPredPaths) '_' strrep(SmpStr,'.','_') '.m']);
                                 fid = fopen(mfile,'wt');
                                 fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                                 fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                                 fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                                 fprintf(fid,'YNames = DataStructure.YNames;\n');
                                 fprintf(fid,'%%\n%% Selected group of joint prediction variables\n%%\n');
                                 fprintf(fid,'PredictionVariables = DataStructure.PredictionVariables;\n');
                                 fprintf(fid,'%%\n%% n+1 x h matrix with the individual variable log predictive likelihoods\n%% and the joint predictive likelihood for each forecast horizon.\n%%\n');
                                 fprintf(fid,'LogPredLike = DataStructure.LogPredLike;\n');
                                 fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                                 fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                                 fprintf(fid,'%%\n%% string matrix with prediction sample dates \n%%\n');
                                 fprintf(fid,'PredictionSampleStrMat = DataStructure.PredictionSampleStrMat;\n');
                                 fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                                 %
                                 % end the script file
                                 %
                                 fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                                 fclose(fid);
                                 %
                                 txt = ['The predictive likelihood estimates for the individual and the selected jointly predicted variables based on the posterior draws have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 5 entries: YNames (string matrix with the names of the observed variables), PredictionVariables (vector with integer values for the jointly predicted variables), LogPredLike (matrix with the individual variable log predictive likelihood values and the joint value for each forecast horizon), PredDateVector (vector with dates for the forecast horizon), and PredictionSampleStrMat (string matrix with the prediction sample dates). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                                 About(txt,'information','Predictive Likelihood - Posterior Distribution',500,600,CurrINI);
                              end;
                              %
                              % write the results to a text file
                              %
                              ResFile = FixFilePath([DSGEModel.OutputDirectory '\PredictiveLikelihood-Cond-Posterior-' DSGEModel.NameOfModel '-' ShockMethod int2str(SelectedYData) '.' AnnualStr '-' SelectedVarStr '-' int2str(CurrChain) '-' int2str(MaxPH) '-' int2str(NumDraws) '.' int2str(NumPredPaths) '-' SmpStr '.txt']);
                              %
                              PrintZLBPredictiveLikelihood(ResFile,'DSGE',PredictionVariables,PredictionSampleStrMat,YDataStr(SelectedYData,:),LogPredLike,AnnualizeData,1,1,0,0,NumDraws,NumBurnin,NumPostDraws,NumPredPaths,[],CompTime,DSGEModel,CurrINI);
                              %
                              % display the results
                              %
                              if FileExist(ResFile)==1;
                                 TextGUI(ResFile,['Predictive Likelihood - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution',50,CurrINI,1,0);
                              end;
                           else;
                              CompTime = toc;
                           end;
                        else;
                           clear('thetaPostSample');
                        end;
                     elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                        clear('thetaPostSample');
                        txt = 'You didn''t select any variables to predict when computing the log predictive likelihood. YADA is therefore unable to help you!';
                        About(txt,'information','Predictive Likelihood - Posterior Distribution',150,500,CurrINI);
                     else;
                        clear('thetaPostSample');
                     end;
                  else;
                     clear('thetaPostSample');
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconMargPredMomentsPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,'Marginal Predictive Moments - Prior Distribution',500,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
                  UniformBounds = ModeData.UniformBounds;
                  thetaIndex = ModeData.thetaIndex;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the prior draws data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the prior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection','Marginal Predictive Moments - Prior Distribution','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            clear('PriorData');
            %
            [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
            DSGEModel.FirstPeriod = FirstPeriod;
            DSGEModel.LastPeriod = LastPeriod;
            %
            % check how many time periods to use for predictive distributions
            %
            MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
            %
            % check the maximum when we take NaNs into account
            %
            YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
            %MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
            [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
            MaxFH = min(MaxFH,MaxPH);
            YData = YData(:,1:MaxFH);
            %
            % matrix with exogenous variables
            %
            X = [];
            if DSGEModel.k>0;
               if NumPredX<MaxFH;
                  X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
               end;
               if NumPredX>0;
                  X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
               end;
            end;
            %
            % Determine the prediction sample
            %
            SampleStrMat = CreateFullSample(DSGEModel);
            PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
            BNSampleStrMat = SampleStrMat(LastPeriod-1:LastPeriod,:);
            SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
            %
            % check if older calculations exists given that such may be used
            %
            MatFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-PredictiveMoments-Prior-' DSGEModel.NameOfModel '-' SmpStr '-' int2str(MaxFH) '.' int2str(NumPriorDraws) '.mat']);
            if FileExist(MatFile)==1;
               txt = ['YADA has located prior draws based estimates of the marginal predictive moments on disk. Would you like to use these results?'];
               answer = Query(txt,'question',200,'Marginal Predictive Moments - Prior Distribution',500,'no',CurrINI);
            else;
               answer = 'No';
            end;
            %
            tic;
            if strcmp(lower(answer),'yes')==1;
               DoneCalc = 1;
            else;
               DoneCalc = DSGEPredictiveMoments(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,MaxFH,NumPriorDraws,[],0,[],SmpStr,0);
            end;
            clear('thetaDraws');
            if DoneCalc==1;
               %
               % load the results
               %
               CompTime = toc;
               MPM = load(MatFile);
               PredY = MPM.MeanPredictY;
               n = DSGEModel.n;
               CovPred = zeros(n,n,MaxFH);
               for i=1:MaxFH;
                  CovPred(:,:,i) = MPM.MeasureCov+MPM.ShockCov(:,:,i)+MPM.StateCov(:,:,i)+MPM.ParameterCov(:,:,i);
               end;
               BNCov = [];
               BNPredictY = [];
               if isfield(MPM,'BNPredictY')==1;
                  BNPredictY = MPM.BNPredictY;
                  if isempty(MPM.BNPredictY)==0;
                     if isfield(MPM,'BNCov')==1;
                        BNCov = MPM.BNCov;
                     else;
                        BNCov = MPM.BNObsCov+MPM.BNParamCov;
                        save(MatFile,'BNCov','-APPEND');
                     end;
                     IsBackCast = 1;
                  else;
                     IsBackCast = 0;
                  end;
               else;
                  IsBackCast = 0;
               end;
               if isfield(MPM,'BNSampleStrMat')==0;
                  save(MatFile,'BNSampleStrMat','-APPEND');
               end;
               %
               if isfield(MPM,'CovPred')==0;
                  save(MatFile,'CovPred','PredictionSampleStrMat','-APPEND');
               end;
               if isfield(MPM,'YData')==0;
                  save(MatFile,'YData','-APPEND');
               end;
               %
               % aske if the user wants to have easy access to the results
               %
               txt = ['The marginal predictive moments using the prior draws have been saved to the file "' GetFilename(MatFile) '" in the "' GetPath(MatFile) '" directory. Would you like YADA to write an m-file to give you direct access to these results?'];
               answer = Query(txt,'question',300,'Marginal Predictive Moments - Prior Distribution',600,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  YNames = DSGEModel.VariableNames;
                  if isfield(MPM,'YNames')==0;
                     save(MatFile,'YNames','-APPEND');
                  end;
                  mfile = FixFilePath([DSGEModel.OutputDirectory '\' strrep(strrep(GetName(MatFile),'-',''),'.','') '.m']);
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(MatFile) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(MatFile));
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  fprintf(fid,'%%\n%% string matrix with prediction sample dates \n%%\n');
                  fprintf(fid,'PredictionSampleStrMat = DataStructure.PredictionSampleStrMat;\n');
                  fprintf(fid,'%%\n%% matrix with the mean predictions of the observed variables \n%%\n');
                  fprintf(fid,'MeanPredictY = DataStructure.MeanPredictY;\n');
                  fprintf(fid,'%%\n%% 3D matrix with the marginal prediction covariances \n%%\n');
                  fprintf(fid,'CovPred = DataStructure.CovPred;\n');
                  fprintf(fid,'%%\n%% 2D matrix with the part due to the measurement errors \n%%\n');
                  fprintf(fid,'MeasureCov = DataStructure.MeasureCov;\n');
                  fprintf(fid,'%%\n%% 3D matrix with the part due to the shock uncertainty \n%%\n');
                  fprintf(fid,'ShockCov = DataStructure.ShockCov;\n');
                  fprintf(fid,'%%\n%% 3D matrix with the part due to the state uncertainty \n%%\n');
                  fprintf(fid,'StateCov = DataStructure.StateCov;\n');
                  fprintf(fid,'%%\n%% 3D matrix with the part due to parameter uncertainty \n%%\n');
                  fprintf(fid,'ParameterCov = DataStructure.ParameterCov;\n');
                  fprintf(fid,'%%\n%% matrix with the actuals for the prediction sample \n%%\n');
                  fprintf(fid,'YData = DataStructure.YData;\n');
                  if IsBackCast==1;
                     fprintf(fid,'%%\n%% string matrix with back- and nowcast sample dates \n%%\n');
                     fprintf(fid,'BNSampleStrMat = DataStructure.BNSampleStrMat;\n');
                     fprintf(fid,'%%\n%% matrix with the mean back- and nowcasts of the observed variables \n%%\n');
                     fprintf(fid,'BNPredictY = DataStructure.BNPredictY;\n');
                     fprintf(fid,'%%\n%% 3D matrix with the marginal back- and nowcasts covariances \n%%\n');
                     fprintf(fid,'BNCov = DataStructure.BNCov;\n');
                     fprintf(fid,'%%\n%% 3D matrix with the part due to shocks and states \n%%\n');
                     fprintf(fid,'BNObsCov = DataStructure.BNObsCov;\n');
                     fprintf(fid,'%%\n%% 3D matrix with the part due to parameter uncertainty\n%%\n');
                     fprintf(fid,'BNParamCov = DataStructure.BNParamCov;\n');
                  end;
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  %
                  txt = ['You can access the marginal predictive moments estimated from the prior distribution through the file: "' GetFilename(mfile) '", located in the "' GetPath(mfile) '" directory.'];
                  About(txt,'information','Marginal Predictive Moments - Prior Distribution',500,600,CurrINI);
               end;
               %
               % write to a text file
               %
               ResFile = strrep(MatFile,'.mat','.txt');
               PrintPredictiveMoments(ResFile,PredY,CovPred,PredictionSampleStrMat,BNPredictY,BNCov,BNSampleStrMat,[],NumPriorDraws,NumPriorDraws,0,0,0,0,CompTime,DSGEModel,CurrINI);
               if FileExist(ResFile)==1;
                  TextGUI(ResFile,['Marginal Predictive Moments - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Prior Distribution',50,CurrINI,1,0);
               end;
            else;
               DSGEModel = OldDSGEModel;
               CompTime = toc;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconMargPredMomentsPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if isempty(ErrorStr)==1;
            %
            % if there are multiple chains, check which one to use if necessary
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' int2str(i)]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Marginal Predictive Moments - Posterior Distribution','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  clear('LogPost','AcceptedDraws','PostSample');
                  [NumPostDraws,NumParam] = size(thetaPostSample);
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumPostDraws,:);
                  NumDraws = NumPostDraws-NumBurnin;
                  %
                  % check if the user wishes a sub-sample
                  %
                  txt = 'Would you like to use a sub-sample of the posterior draws when estimating the marginal predictive moments?';
                  answer = Query(txt,'question',400,'Marginal Predictive Moments - Posterior Distribution',500,'no',CurrINI);
                  if (DSGEModel.PosteriorSampler<=7)|(DSGEModel.PosteriorSampler==9);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        NumDraws = length(UseDraws);
                     end;
                  else;
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = WeightBasedPosteriorDraws(DSGEModel,CurrINI,'Marginal Predictive Moments - Posterior Distribution',Weights,[]);
                        if isempty(UseDraws)==1;
                           set(controls.about,'UserData',0);
                           return;
                        end;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        Weights = Weights(UseDraws,1);
                        Weights = Weights*length(Weights)/sum(Weights);
                        NumDraws = length(UseDraws);
                     end;
                  end;
                  %
                  % collect some required data
                  %
                  theta = ModeData.thetaMode;
                  thetaPositions = ModeData.thetaPositions;
                  thetaIndex = ModeData.thetaIndex;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  LowerBound = ModeData.LowerBound;
                  UniformBounds = ModeData.UniformBounds;
                  ModelParameters = ModeData.ModelParameters;
                  %
                  [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
                  DSGEModel.FirstPeriod = FirstPeriod;
                  DSGEModel.LastPeriod = LastPeriod;
                  %
                  % check how many time periods to use for predictive distributions
                  %
                  MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
                  %
                  % check the maximum when we take NaNs into account
                  %
                  YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
                  %MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
                  [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
                  MaxFH = min(MaxFH,MaxPH);
                  YData = YData(:,1:MaxFH);
                  %
                  % matrix with exogenous variables
                  %
                  X = [];
                  if DSGEModel.k>0;
                     if NumPredX<MaxFH;
                        X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
                     end;
                     if NumPredX>0;
                        X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
                     end;
                  end;
                  %
                  % Determine the prediction sample
                  %
                  SampleStrMat = CreateFullSample(DSGEModel);
                  PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                  BNSampleStrMat = SampleStrMat(LastPeriod-1:LastPeriod,:);
                  SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                  %
                  % check if older calculations exists given that such may be used
                  %
                  MatFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-PredictiveMoments-' DSGEModel.NameOfModel '-' SmpStr '-' int2str(CurrChain) '-' int2str(MaxFH) '.' int2str(NumDraws) '-' int2str(NumPostDraws) '.mat']);
                  if FileExist(MatFile)==1;
                     txt = ['YADA has located posterior draws based estimates of the marginal predictive moments on disk. Would you like to use these results?'];
                     answer = Query(txt,'question',200,'Marginal Predictive Moments - Posterior Distribution',500,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  tic;
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                  else;
                     DoneCalc = DSGEPredictiveMoments(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,MaxFH,NumPostDraws,CurrChain,1,Weights,SmpStr,0);
                  end;
                  clear('thetaPostSample');
                  if DoneCalc==1;
                     %
                     % load the results
                     %
                     CompTime = toc;
                     MPM = load(MatFile);
                     PredY = MPM.MeanPredictY;
                     n = DSGEModel.n;
                     CovPred = zeros(n,n,MaxFH);
                     for i=1:MaxFH;
                        CovPred(:,:,i) = MPM.MeasureCov+MPM.ShockCov(:,:,i)+MPM.StateCov(:,:,i)+MPM.ParameterCov(:,:,i);
                     end;
                     BNCov = [];
                     BNPredictY = [];
                     if isfield(MPM,'BNPredictY')==1;
                        BNPredictY = MPM.BNPredictY;
                        if isempty(MPM.BNPredictY)==0;
                           if isfield(MPM,'BNCov')==1;
                              BNCov = MPM.BNCov;
                           else;
                              BNCov = MPM.BNObsCov+MPM.BNParamCov;
                              save(MatFile,'BNCov','-APPEND');
                           end;
                           IsBackCast = 1;
                        else;
                           IsBackCast = 0;
                        end;
                     else;
                        IsBackCast = 0;
                     end;
                     if isfield(MPM,'BNSampleStrMat')==0;
                        save(MatFile,'BNSampleStrMat','-APPEND');
                     end;
                     %
                     if isfield(MPM,'CovPred')==0;
                        save(MatFile,'CovPred','PredictionSampleStrMat','-APPEND');
                     end;
                     if isfield(MPM,'YData')==0;
                        save(MatFile,'YData','-APPEND');
                     end;
                     %
                     % ask if the user wants to have easy access to the results
                     %
                     txt = ['The marginal predictive moments using the posterior draws have been saved to the file "' GetFilename(MatFile) '" in the "' GetPath(MatFile) '" directory. Would you like YADA to write an m-file to give you direct access to these results?'];
                     answer = Query(txt,'question',300,'Marginal Predictive Moments - Posterior Distribution',600,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        YNames = DSGEModel.VariableNames;
                        if isfield(MPM,'YNames')==0;
                           save(MatFile,'YNames','-APPEND');
                        end;
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\' strrep(strrep(GetName(MatFile),'-',''),'.','') '.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(MatFile) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(MatFile));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% string matrix with prediction sample dates \n%%\n');
                        fprintf(fid,'PredictionSampleStrMat = DataStructure.PredictionSampleStrMat;\n');
                        fprintf(fid,'%%\n%% matrix with the mean predictions of the observed variables \n%%\n');
                        fprintf(fid,'MeanPredictY = DataStructure.MeanPredictY;\n');
                        fprintf(fid,'%%\n%% 3D matrix with the marginal prediction covariances \n%%\n');
                        fprintf(fid,'CovPred = DataStructure.CovPred;\n');
                        fprintf(fid,'%%\n%% 2D matrix with the part due to the measurement errors \n%%\n');
                        fprintf(fid,'MeasureCov = DataStructure.MeasureCov;\n');
                        fprintf(fid,'%%\n%% 3D matrix with the part due to the shock uncertainty \n%%\n');
                        fprintf(fid,'ShockCov = DataStructure.ShockCov;\n');
                        fprintf(fid,'%%\n%% 3D matrix with the part due to the state uncertainty \n%%\n');
                        fprintf(fid,'StateCov = DataStructure.StateCov;\n');
                        fprintf(fid,'%%\n%% 3D matrix with the part due to parameter uncertainty \n%%\n');
                        fprintf(fid,'ParameterCov = DataStructure.ParameterCov;\n');
                        fprintf(fid,'%%\n%% matrix with the actuals for the prediction sample \n%%\n');
                        fprintf(fid,'YData = DataStructure.YData;\n');
                        if IsBackCast==1;
                           fprintf(fid,'%%\n%% string matrix with back- and nowcast sample dates \n%%\n');
                           fprintf(fid,'BNSampleStrMat = DataStructure.BNSampleStrMat;\n');
                           fprintf(fid,'%%\n%% matrix with the mean back- and nowcasts of the observed variables \n%%\n');
                           fprintf(fid,'BNPredictY = DataStructure.BNPredictY;\n');
                           fprintf(fid,'%%\n%% 3D matrix with the marginal back- and nowcasts covariances \n%%\n');
                           fprintf(fid,'BNCov = DataStructure.BNCov;\n');
                           fprintf(fid,'%%\n%% 3D matrix with the part due to shocks and states \n%%\n');
                           fprintf(fid,'BNObsCov = DataStructure.BNObsCov;\n');
                           fprintf(fid,'%%\n%% 3D matrix with the part due to parameter uncertainty\n%%\n');
                           fprintf(fid,'BNParamCov = DataStructure.BNParamCov;\n');
                        end;
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        %
                        txt = ['You can access the marginal predictive moments estimated from the posterior distribution through the file: "' GetFilename(mfile) '", located in the "' GetPath(mfile) '" directory.'];
                        About(txt,'information','Marginal Predictive Moments - Posterior Distribution',500,600,CurrINI);
                     end;
                     %
                     % write to a text file
                     %
                     ResFile = strrep(MatFile,'.mat','.txt');
                     PrintPredictiveMoments(ResFile,PredY,CovPred,PredictionSampleStrMat,BNPredictY,BNCov,BNSampleStrMat,[],NumDraws,NumPostDraws,NumBurnin,1,0,0,CompTime,DSGEModel,CurrINI);
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Marginal Predictive Moments - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution',50,CurrINI,1,0);
                     end;
                  else;
                     CompTime = toc;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ConMargPredMomentsPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,'Marginal Predictive Moments - Prior Distribution',500,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
                  UniformBounds = ModeData.UniformBounds;
                  thetaIndex = ModeData.thetaIndex;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the prior draws data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the prior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection','Marginal Predictive Moments - Prior Distribution','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            clear('PriorData');
            %
            [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
            DSGEModel.FirstPeriod = FirstPeriod;
            DSGEModel.LastPeriod = LastPeriod;
            %
            % check how many time periods to use for predictive distributions
            %
            MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
            %
            % check the maximum when we take NaNs into account
            %
            YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
            [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
            MaxFH = min(MaxFH,MaxPH);
            YData = YData(:,1:MaxFH);
            %
            % matrix with exogenous variables
            %
            X = [];
            if DSGEModel.k>0;
               if NumPredX<MaxFH;
                  X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
               end;
               if NumPredX>0;
                  X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
               end;
            end;
            %
            % check the length of the conditioning sample
            %
            [status,NumPeriods] = CheckConditioningData(DSGEModel);
            %
            % check if we should adjust the X matrix
            %
            if MaxFH<NumPeriods;
               NumPeriods = MaxFH;
            end;
            %
            % collect the conditional variables and the selected conditioning sample
            %
            Z = DSGEModel.Z(DSGEModel.ConditionalVariables,LastPeriod+1:LastPeriod+NumPeriods);
            if LastPeriod>=NumPeriods;
               U = DSGEModel.U(DSGEModel.ConditionalVariables,LastPeriod-NumPeriods+1:LastPeriod);
            else;
               %
               % we have to create artifical initial conditions for the conditioning variables
               %
               U = [DSGEModel.U(DSGEModel.ConditionalVariables,1)*ones(1,NumPeriods-LastPeriod) DSGEModel.U(DSGEModel.ConditionalVariables,1:LastPeriod)];
            end;
            %
            % Determine the prediction sample
            %
            SampleStrMat = CreateFullSample(DSGEModel);
            PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
            SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
            %
            % check which method is used for dealing with the conditioning assumptions
            %
            if DSGEModel.ShockControlMethod==1;
               ShockMethod = 'Direct-';
            elseif DSGEModel.ShockControlMethod==2;
               ShockMethod = 'WaggonerZha-';
            else;
               ShockMethod = 'Subset-';
            end;
            %
            % check if older calculations exists given that such may be used
            %
            MatFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-CondPredictiveMoments-' ShockMethod 'Prior-' DSGEModel.NameOfModel '-' SmpStr '-' int2str(MaxFH) '.' int2str(NumPriorDraws) '.mat']);
            if FileExist(MatFile)==1;
               txt = ['YADA has located prior draws based estimates of the marginal predictive moments on disk. Would you like to use these results?'];
               answer = Query(txt,'question',200,'Marginal Predictive Moments - Prior Distribution',500,'no',CurrINI);
            else;
               answer = 'No';
            end;
            %
            tic;
            if strcmp(lower(answer),'yes')==1;
               DoneCalc = 1;
            else;
               if DSGEModel.ShockControlMethod==1;
                  DoneCalc = DSGECondPredictiveMoments(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxFH,NumPriorDraws,[],0,[],SmpStr,0);
               elseif DSGEModel.ShockControlMethod==2;
                  DoneCalc = DSGECondPredictiveMomentsWZ(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxFH,NumPriorDraws,[],0,[],SmpStr,0);
               else;
                  DoneCalc = DSGECondPredictiveMomentsMixed(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxFH,NumPriorDraws,[],0,[],SmpStr,0);
               end;
            end;
            clear('thetaDraws');
            if DoneCalc==1;
               %
               % load the results
               %
               CompTime = toc;
               MPM = load(MatFile);
               PredY = MPM.MeanPredictY;
               n = DSGEModel.n;
               CovPred = zeros(n,n,MaxFH);
               for i=1:MaxFH;
                  CovPred(:,:,i) = MPM.MeasureCov(:,:,i)+MPM.ShockCov(:,:,i)+MPM.StateCov(:,:,i)+MPM.ParameterCov(:,:,i);
               end;
               %
               if isfield(MPM,'CovPred')==0;
                  save(MatFile,'CovPred','PredictionSampleStrMat','-APPEND');
               end;
               if isfield(MPM,'YData')==0;
                  save(MatFile,'YData','-APPEND');
               end;
               %
               % ask if the user wants to have easy access to the results
               %
               txt = ['The marginal predictive moments for the conditional forecasts and using the prior draws have been saved to the file "' GetFilename(MatFile) '" in the "' GetPath(MatFile) '" directory. Would you like YADA to write an m-file to give you direct access to these results?'];
               answer = Query(txt,'question',300,'Marginal Predictive Moments - Prior Distribution',600,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  YNames = DSGEModel.VariableNames;
                  if isfield(MPM,'YNames')==0;
                     save(MatFile,'YNames','-APPEND');
                  end;
                  mfile = FixFilePath([DSGEModel.OutputDirectory '\' strrep(strrep(GetName(MatFile),'-',''),'.','') '.m']);
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(MatFile) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(MatFile));
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  fprintf(fid,'%%\n%% string matrix with prediction sample dates \n%%\n');
                  fprintf(fid,'PredictionSampleStrMat = DataStructure.PredictionSampleStrMat;\n');
                  fprintf(fid,'%%\n%% matrix with the mean predictions of the observed variables \n%%\n');
                  fprintf(fid,'MeanPredictY = DataStructure.MeanPredictY;\n');
                  fprintf(fid,'%%\n%% 3D matrix with the marginal prediction covariances \n%%\n');
                  fprintf(fid,'CovPred = DataStructure.CovPred;\n');
                  fprintf(fid,'%%\n%% 2D matrix with the part due to the measurement errors \n%%\n');
                  fprintf(fid,'MeasureCov = DataStructure.MeasureCov;\n');
                  fprintf(fid,'%%\n%% 3D matrix with the part due to the shock uncertainty \n%%\n');
                  fprintf(fid,'ShockCov = DataStructure.ShockCov;\n');
                  fprintf(fid,'%%\n%% 3D matrix with the part due to the state uncertainty \n%%\n');
                  fprintf(fid,'StateCov = DataStructure.StateCov;\n');
                  fprintf(fid,'%%\n%% 3D matrix with the part due to parameter uncertainty \n%%\n');
                  fprintf(fid,'ParameterCov = DataStructure.ParameterCov;\n');
                  fprintf(fid,'%%\n%% matrix with the actuals for the prediction sample \n%%\n');
                  fprintf(fid,'YData = DataStructure.YData;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  %
                  txt = ['You can access the marginal predictive moments estimated from the prior distribution through the file: "' GetFilename(mfile) '", located in the "' GetPath(mfile) '" directory.'];
                  About(txt,'information','Marginal Predictive Moments - Prior Distribution',500,600,CurrINI);
               end;
               %
               % write to a text file
               %
               ResFile = strrep(MatFile,'.mat','.txt');
               PrintPredictiveMoments(ResFile,PredY,CovPred,PredictionSampleStrMat,[],[],[],[],NumPriorDraws,NumPriorDraws,0,0,1,0,CompTime,DSGEModel,CurrINI);
               if FileExist(ResFile)==1;
                  TextGUI(ResFile,['Marginal Predictive Moments - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Prior Distribution',50,CurrINI,1,0);
               end;
            else;
               DSGEModel = OldDSGEModel;
               CompTime = toc;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ConMargPredMomentsPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if isempty(ErrorStr)==1;
            %
            % if there are multiple chains, check which one to use if necessary
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' int2str(i)]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Marginal Predictive Moments - Posterior Distribution','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  clear('LogPost','AcceptedDraws','PostSample');
                  [NumPostDraws,NumParam] = size(thetaPostSample);
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumPostDraws,:);
                  NumDraws = NumPostDraws-NumBurnin;
                  %
                  % check if the user wishes a sub-sample
                  %
                  txt = 'Would you like to use a sub-sample of the posterior draws when estimating the marginal predictive moments?';
                  answer = Query(txt,'question',400,'Marginal Predictive Moments - Posterior Distribution',500,'no',CurrINI);
                  if (DSGEModel.PosteriorSampler<=7)|(DSGEModel.PosteriorSampler==9);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        NumDraws = length(UseDraws);
                     end;
                  else;
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = WeightBasedPosteriorDraws(DSGEModel,CurrINI,'Marginal Predictive Moments - Posterior Distribution',Weights,[]);
                        if isempty(UseDraws)==1;
                           set(controls.about,'UserData',0);
                           return;
                        end;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        Weights = Weights(UseDraws,1);
                        Weights = Weights*length(Weights)/sum(Weights);
                        NumDraws = length(UseDraws);
                     end;
                  end;
                  %
                  % collect some required data
                  %
                  theta = ModeData.thetaMode;
                  thetaPositions = ModeData.thetaPositions;
                  thetaIndex = ModeData.thetaIndex;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  LowerBound = ModeData.LowerBound;
                  UniformBounds = ModeData.UniformBounds;
                  ModelParameters = ModeData.ModelParameters;
                  %
                  [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
                  DSGEModel.FirstPeriod = FirstPeriod;
                  DSGEModel.LastPeriod = LastPeriod;
                  %
                  % check how many time periods to use for predictive distributions
                  %
                  MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
                  %
                  % check the maximum when we take NaNs into account
                  %
                  YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
                  [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
                  MaxFH = min(MaxFH,MaxPH);
                  YData = YData(:,1:MaxFH);
                  %
                  % matrix with exogenous variables
                  %
                  X = [];
                  if DSGEModel.k>0;
                     if NumPredX<MaxFH;
                        X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
                     end;
                     if NumPredX>0;
                        X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
                     end;
                  end;
                  %
                  % check the length of the conditioning sample
                  %
                  [status,NumPeriods] = CheckConditioningData(DSGEModel);
                  %
                  % check if we should adjust the X matrix
                  %
                  if MaxFH<NumPeriods;
                     NumPeriods = MaxFH;
                  end;
                  %
                  % collect the conditional variables and the selected conditioning sample
                  %
                  Z = DSGEModel.Z(DSGEModel.ConditionalVariables,LastPeriod+1:LastPeriod+NumPeriods);
                  if LastPeriod>=NumPeriods;
                     U = DSGEModel.U(DSGEModel.ConditionalVariables,LastPeriod-NumPeriods+1:LastPeriod);
                  else;
                     %
                     % we have to create artifical initial conditions for the conditioning variables
                     %
                     U = [DSGEModel.U(DSGEModel.ConditionalVariables,1)*ones(1,NumPeriods-LastPeriod) DSGEModel.U(DSGEModel.ConditionalVariables,1:LastPeriod)];
                  end;
                  %
                  % Determine the prediction sample
                  %
                  SampleStrMat = CreateFullSample(DSGEModel);
                  PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                  SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                  %
                  % check which method is used for dealing with the conditioning assumptions
                  %
                  if DSGEModel.ShockControlMethod==1;
                     ShockMethod = 'Direct-';
                  elseif DSGEModel.ShockControlMethod==2;
                     ShockMethod = 'WaggonerZha-';
                  else;
                     ShockMethod = 'Subset-';
                  end;
                  %
                  % check if older calculations exists given that such may be used
                  %
                  MatFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-CondPredictiveMoments-' ShockMethod DSGEModel.NameOfModel '-' SmpStr '-' int2str(CurrChain) '-' int2str(MaxFH) '.' int2str(NumDraws) '-' int2str(NumPostDraws) '.mat']);
                  if FileExist(MatFile)==1;
                     txt = ['YADA has located posterior draws based estimates of the marginal predictive moments on disk for the conditional forecasts. Would you like to use these results?'];
                     answer = Query(txt,'question',200,'Marginal Predictive Moments - Posterior Distribution',500,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  tic;
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                  else;
                     if DSGEModel.ShockControlMethod==1;
                        DoneCalc = DSGECondPredictiveMoments(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxFH,NumPostDraws,CurrChain,1,Weights,SmpStr,0);
                     elseif DSGEModel.ShockControlMethod==2;
                        DoneCalc = DSGECondPredictiveMomentsWZ(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxFH,NumPostDraws,CurrChain,1,Weights,SmpStr,0);
                     else;
                        DoneCalc = DSGECondPredictiveMomentsMixed(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxFH,NumPostDraws,CurrChain,1,Weights,SmpStr,0);
                     end;
                  end;
                  clear('thetaPostSample');
                  if DoneCalc==1;
                     %
                     % load results from the mat-file
                     %
                     CompTime = toc;
                     MPM = load(MatFile);
                     PredY = MPM.MeanPredictY;
                     n = DSGEModel.n;
                     CovPred = zeros(n,n,MaxFH);
                     for i=1:MaxFH;
                        CovPred(:,:,i) = MPM.MeasureCov(:,:,i)+MPM.ShockCov(:,:,i)+MPM.StateCov(:,:,i)+MPM.ParameterCov(:,:,i);
                     end;
                     %
                     if isfield(MPM,'CovPred')==0;
                        save(MatFile,'CovPred','PredictionSampleStrMat','-APPEND');
                     end;
                     if isfield(MPM,'YData')==0;
                        save(MatFile,'YData','-APPEND');
                     end;
                     %
                     % ask if the user wants to have easy access to the results
                     %
                     txt = ['The marginal predictive moments for the conditional forecasts and using the posterior draws have been saved to the file "' GetFilename(MatFile) '" in the "' GetPath(MatFile) '" directory. Would you like YADA to write an m-file to give you direct access to these results?'];
                     answer = Query(txt,'question',300,'Marginal Predictive Moments - Posterior Distribution',600,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        YNames = DSGEModel.VariableNames;
                        if isfield(MPM,'YNames')==0;
                           save(MatFile,'YNames','-APPEND');
                        end;
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\' strrep(strrep(GetName(MatFile),'-',''),'.','') '.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(MatFile) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(MatFile));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% string matrix with prediction sample dates \n%%\n');
                        fprintf(fid,'PredictionSampleStrMat = DataStructure.PredictionSampleStrMat;\n');
                        fprintf(fid,'%%\n%% matrix with the mean predictions of the observed variables \n%%\n');
                        fprintf(fid,'MeanPredictY = DataStructure.MeanPredictY;\n');
                        fprintf(fid,'%%\n%% 3D matrix with the marginal prediction covariances \n%%\n');
                        fprintf(fid,'CovPred = DataStructure.CovPred;\n');
                        fprintf(fid,'%%\n%% 2D matrix with the part due to the measurement errors \n%%\n');
                        fprintf(fid,'MeasureCov = DataStructure.MeasureCov;\n');
                        fprintf(fid,'%%\n%% 3D matrix with the part due to the shock uncertainty \n%%\n');
                        fprintf(fid,'ShockCov = DataStructure.ShockCov;\n');
                        fprintf(fid,'%%\n%% 3D matrix with the part due to the state uncertainty \n%%\n');
                        fprintf(fid,'StateCov = DataStructure.StateCov;\n');
                        fprintf(fid,'%%\n%% 3D matrix with the part due to parameter uncertainty \n%%\n');
                        fprintf(fid,'ParameterCov = DataStructure.ParameterCov;\n');
                        fprintf(fid,'%%\n%% matrix with the actuals for the prediction sample \n%%\n');
                        fprintf(fid,'YData = DataStructure.YData;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        %
                        txt = ['You can access the marginal predictive moments estimated from the posterior distribution through the file: "' GetFilename(mfile) '", located in the "' GetPath(mfile) '" directory.'];
                        About(txt,'information','Marginal Predictive Moments - Posterior Distribution',500,600,CurrINI);
                     end;
                     %
                     % write to a text file
                     %
                     ResFile = strrep(MatFile,'.mat','.txt');
                     PrintPredictiveMoments(ResFile,PredY,CovPred,PredictionSampleStrMat,[],[],[],[],NumDraws,NumPostDraws,NumBurnin,1,1,0,CompTime,DSGEModel,CurrINI);
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Marginal Predictive Moments - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution',50,CurrINI,1,0);
                     end;
                  else;
                     CompTime = toc;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ConPITPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,'Probability Integral Transform - Prior Distribution',500,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
                  UniformBounds = ModeData.UniformBounds;
                  thetaIndex = ModeData.thetaIndex;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the prior draws data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the prior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection','Probability Integral Transform - Prior Distribution','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            clear('PriorData');
            %
            [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
            DSGEModel.FirstPeriod = FirstPeriod;
            DSGEModel.LastPeriod = LastPeriod;
            %
            % check how many time periods to use for predictive distributions
            %
            MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
            %
            % check the maximum when we take NaNs into account
            %
            YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
            %BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
            if isempty(DSGEModel.Actuals)==1;
               SelectedYData = 1;
               DataAction = 'ok';
               YDataStr = 'Actuals from original sample';
            else;
               YDataStr = 'Actuals from original sample';
               m = length(DSGEModel.Actuals);
               for i=1:m;
                  YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
               end;
               [DataAction,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','Probability Integral Transform - Posterior Distribution','','',CurrINI);
               if (strcmp(lower(DataAction),'ok')==1)&(SelectedYData>1);
                  YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                  %BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
               end;
            end;
            %
            if strcmp(lower(DataAction),'ok')==1;
               MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
               [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               MaxFH = min(MaxFH,MaxPH);
               YData = YData(:,1:MaxFH);
               %
               % matrix with exogenous variables
               %
               X = [];
               XP = [];
               if DSGEModel.k>0;
                  if NumPredX<MaxFH;
                     X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
                  end;
                  if NumPredX>0;
                     X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
                  end;
                  if NumPredX<MaxPH;
                     XP = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                  end;
                  if NumPredX>0;
                     XP = [XP DSGEModel.PredictedX(:,1:min(NumPredX,MaxPH))];
                  end;
               end;
               %
               % check the length of the conditioning sample
               %
               [status,NumPeriods] = CheckConditioningData(DSGEModel);
               %
               % check if we should adjust the X matrix
               %
               if MaxFH<NumPeriods;
                  NumPeriods = MaxFH;
               end;
               %
               % collect the conditional variables and the selected conditioning sample
               %
               Z = DSGEModel.Z(DSGEModel.ConditionalVariables,LastPeriod+1:LastPeriod+NumPeriods);
               if LastPeriod>=NumPeriods;
                  U = DSGEModel.U(DSGEModel.ConditionalVariables,LastPeriod-NumPeriods+1:LastPeriod);
               else;
                  %
                  % we have to create artifical initial conditions for the conditioning variables
                  %
                  U = [DSGEModel.U(DSGEModel.ConditionalVariables,1)*ones(1,NumPeriods-LastPeriod) DSGEModel.U(DSGEModel.ConditionalVariables,1:LastPeriod)];
               end;
               %
               % selection of variable 
               %
               if isempty(DSGEModel.PredictionVariables)==1;
                  PredictionVariables = ones(1,DSGEModel.n);
                  PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
               else;
                  PredictionVariables = DSGEModel.PredictionVariables;
               end;
               %
               [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
               if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                  DSGEModel.PredictionVariables = PredictionVariables;
                  %
                  % Determine the prediction sample
                  %
                  SampleStrMat = CreateFullSample(DSGEModel);
                  PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                  SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                  %
                  % check which method is used for dealing with the conditioning assumptions
                  %
                  if DSGEModel.ShockControlMethod==1;
                     ShockMethod = 'Direct-';
                  elseif DSGEModel.ShockControlMethod==2;
                     ShockMethod = 'WaggonerZha-';
                  else;
                     ShockMethod = 'Subset-';
                  end;
                  %
                  % check if older calculations exists given that such may be used
                  %
                  MatFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-CondPredictiveMoments-' ShockMethod 'Prior-' DSGEModel.NameOfModel '-' SmpStr '-' int2str(MaxFH) '.' int2str(NumPriorDraws) '.mat']);
                  if FileExist(MatFile)==1;
                     %
                     % check if the PITMoments have been stored
                     %
                     ForecastData = load(MatFile);
                     if (isfield(ForecastData,'PITMoments')==1)&(length(ForecastData.PITMoments)>0);
                        txt = ['YADA has located prior draws based estimates of the marginal predictive moments on disk for the conditional forecasts. Would you like to use these results?'];
                        answer = Query(txt,'question',200,'Marginal Predictive Moments - Prior Distribution',500,'no',CurrINI);
                     else;
                        answer = 'No';
                     end;
                     clear('ForecastData');
                  else;
                     answer = 'No';
                  end;
                  tic;
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                  else;
                     if DSGEModel.ShockControlMethod==1;
                        DoneCalc = DSGECondPredictiveMoments(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxFH,NumPriorDraws,[],0,[],SmpStr,1);
                     elseif DSGEModel.ShockControlMethod==2;
                        DoneCalc = DSGECondPredictiveMomentsWZ(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxFH,NumPriorDraws,[],0,[],SmpStr,1);
                     else;
                        DoneCalc = DSGECondPredictiveMomentsMixed(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxFH,NumPriorDraws,[],0,[],SmpStr,1);
                     end;
                  end;
                  %
                  if DoneCalc==1;
                     %
                     % we can now do the PIT calculations based on the moments
                     %
                     [PITMatrix,BNPITMatrix] = ComputePITs(YData,DSGEModel.Y(:,LastPeriod-1:LastPeriod),[],PredictionVariables,MatFile,[],0,(exist('mvncdf')~=0),CurrINI);
                     CompTimeStepOne = toc;
                     %
                     % check if the user also wants to study PITs based on simulated paths
                     %
                     txt = 'YADA can also estimate probability integral transform (PIT) values based on simulated paths from the conditional predictive distribution. Would you like to run these calculations as well?';
                     answer = Query(txt,'question',200,'Probability Integral Transform - Prior Distribution',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % setup the necessary variables for computing or loading simulated paths from the predictive distribution
                        %
                        % determine how many prediction paths to use
                        %
                        NumPredPathsStr = get(controls.forecast.predpaths,'String');
                        NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
                        %
                        TransData = 0;
                        AnnualizeData = 0;
                        AnnualStr = 'original';
                        QueryHead = 'Predictive Distributions - Original Data';
                        if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumPriorDraws,NumPredPaths,AnnualizeData,TransData,[],0)==1;
                           txt = 'YADA has located results for the predictive distribution on disk. Would you like to use these results?';
                           answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                        else;
                           answer = 'No';
                        end;
                        %
                        % check if we shall recompute
                        %
                        if strcmp(lower(answer),'yes')==1;
                           DoneCalc2 = 1;
                           tic;
                        else;
                           %
                           % ask if we should conduct prediction event calculations
                           %
                           txt = strvcat('Would you like YADA to calculate prediction event probabilities and perform risk analysis?',' ','NOTE: The results will only be stored to disk and will not be displayed.');
                           answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
                           if strcmp(lower(answer),'yes')==1;
                              if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                                 DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                              end;
                              %
                              % make sure that the prediction event length does not exceed the maximum prediction horizon
                              %
                              for i=1:DSGEModel.n;
                                 if DSGEModel.PredictionEvent(i,3)>MaxPH;
                                    DSGEModel.PredictionEvent(i,3) = MaxPH;
                                 end;
                              end;
                              %
                              % display a dialog for setting up an prediction event
                              %
                              [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                              if strcmp(lower(action),'ok')==1;
                                 DSGEModel.PredictionEvent = PredictionEvent;
                                 DSGEModel.RunPredictionEvent = 1;
                              else;
                                 DSGEModel.RunPredictionEvent = 0;
                              end;
                           else;
                              DSGEModel.RunPredictionEvent = 0;
                           end;
                           %
                           % we can now compute the predictive distribution for the endogenous variables
                           % up to period MaxPH
                           %
                           [DoneCalc2,PredEventData,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGEPredictionPaths(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,XP,MaxPH,NumPredPaths,AnnualizeData,TransData,1,0,[]);
                           tic;
                           if DSGEModel.ShockControlMethod==1;
                              [DoneCalc2,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPaths(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,XP,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,1,0,[]);
                           elseif DSGEModel.ShockControlMethod==2;
                              [DoneCalc2,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsWZ(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,XP,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,1,0,[]);
                           else;
                              %
                              % check if the selected method can actually be used
                              %
                              CondTxt = '';
                              if isempty(DSGEModel.MixedConditionalShocks)==1;
                                 CondTxt = 'You haven''t selected any shocks for use which the distribution of a subset of the shocks conditioning method.';
                              elseif length(DSGEModel.MixedConditionalShocks)<length(DSGEModel.ConditionalVariables);
                                 CondTxt = ['The number of shocks you have selected to use to ensure that the conditioning assumptions are satisfied under the distribution of a subset of the shocks conditioning method is not sufficient. You need at least ' int2str(length(DSGEModel.ConditionalVariables)) ' such shocks.'];
                              end;
                              if isempty(CondTxt)==1;
                                 [DoneCalc2,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsMixed(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,XP,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,1,0,[]);
                              else;
                                 About(CondTxt,'information','Bad Shocks Selection - Distribution of Subset Shocks Method',300,550,CurrINI);
                                 DoneCalc2 = 0;
                              end;
                           end;
                        end;
                        %
                        if DoneCalc2==1;
                           %
                           % compute PITs based on the paths from the predictive distribution
                           %
                           PathPITMatrix = ComputePITsDSGEPaths(YData,NumPriorDraws,NumPredPaths,MaxPH,[],0,1,ShockMethod,[],DSGEModel,CurrINI);
                           CompTimeStepTwo = toc;
                        else;
                           %
                           % make sure that path based estimates are empty
                           %
                           PathPITMatrix = [];
                           CompTimeStepTwo = [];
                        end;
                     else;
                        %
                        % make sure that path based estimates are empty
                        %
                        PathPITMatrix = [];
                        CompTimeStepTwo = [];
                        NumPredPaths = 0;
                     end;
                     %
                     % check if the user want to compute CRPS statistics based on the predictive moments
                     %
                     IsCRPS = 0;
                     txt = 'Would you like to compute the CRPS statistics for the individual observed variables using the predictive mean, standard deviation and a normal distribution?';
                     answer = Query(txt,'question',300,'Probability Integral Transform - Prior Distribution',600,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        IsCRPS = 1;
                        %
                        % use the mat-file above
                        %
                        MPM = load(MatFile);
                        PredY = MPM.MeanPredictY;
                        n = DSGEModel.n;
                        CovPred = zeros(n,n,MaxFH);
                        for i=1:MaxFH;
                           CovPred(:,:,i) = MPM.MeasureCov(:,:,i)+MPM.ShockCov(:,:,i)+MPM.StateCov(:,:,i)+MPM.ParameterCov(:,:,i);
                        end;
                        %
                        if isfield(MPM,'CovPred')==0;
                           save(MatFile,'CovPred','PredictionSampleStrMat','-APPEND');
                        end;
                        if isfield(MPM,'YData')==0;
                           save(MatFile,'YData','-APPEND');
                        end;
                        %
                        % compute the CRPS for a normal distribution
                        %
                        [CRPSMatrix,BackCRPS] = CRPSNormalDistribution(YData,PredY,CovPred,[],[],[]);
                        save(MatFile,'CRPSMatrix','-APPEND');
                     end;
                     %
                     % check if the user wants to store the results to disk
                     %
                     txt = 'Would you like to save the probability integral transform estimates to file?';
                     answer = Query(txt,'question',300,'Probability Integral Transform - Prior Distribution',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                        file = FixFilePath([DSGEModel.OutputDirectory '\PITs-Prior-Cond-' ShockMethod DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' int2str(MaxPH) '-' int2str(NumPriorDraws) '.' int2str(NumPredPaths) '-' SmpStr '.mat']);
                        YNames = DSGEModel.VariableNames;
                        save(file,'YNames','PredictionVariables','PITMatrix','PredDateVector');
                        if isempty(PathPITMatrix)==0;
                           save(file,'PathPITMatrix','-APPEND');
                        end;
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\PITsPrior_Cond_' strrep(ShockMethod,'-','_') DSGEModel.NameOfModel '_' int2str(SelectedYData) '_' int2str(MaxPH) '_' int2str(NumPriorDraws) 'x' int2str(NumPredPaths) '_' strrep(SmpStr,'.','_') '.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% Selected group of joint prediction variables\n%%\n');
                        fprintf(fid,'PredictionVariables = DataStructure.PredictionVariables;\n');
                        fprintf(fid,'%%\n%% n+1 x h matrix with the individual variable uniform PITs and the joint uniform PIT\n%%\n%% for each forecast horizon. Use norminv to transform to normal.\n%%\n');
                        fprintf(fid,'PITMatrix = DataStructure.PITMatrix;\n');
                        NumEntries = 3;
                        if isempty(PathPITMatrix)==0;
                           fprintf(fid,'%%\n%% n x h matrix with the individual variable uniform PITs using the prediction\n%%\n%% paths for each forecast horizon. Use norminv to transform to normal.\n%%\n');
                           fprintf(fid,'PathPITMatrix = DataStructure.PathPITMatrix;\n');
                           NumEntries = NumEntries+1;
                           PathTxt = 'PathPITMatrix (matrix with the individual variable uniform PITs using the prediction paths for each forecast horizon), ';
                        else;
                           PathTxt = '';
                        end;
                        if IsCRPS==1;
                           fprintf(fid,'%%\n%% n x h matrix with the individual variable CRPS values for each forecast\n%%\n%% horizon using a normal distribution.\n%%\n');
                           fprintf(fid,'CRPSMatrix = DataStructure.CRPSMatrix;\n');
                           save(file,'CRPSMatrix','-APPEND');
                           CRPSText = 'CRPSMatrix (matrix with the individual variable CRPS values for each forecast), ';
                           NumEntries = NumEntries+1;
                        else;
                           CRPSText = '';
                        end;
                        fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                        fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        NumEntries = NumEntries+1;
                        %
                        txt = ['The probability integral transform (PIT) estimates (uniform under the assumption of well-calibrated) for the prior draws have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' int2str(NumEntries) ' entries: YNames (string matrix with the names of the observed variables), PredictionVariables (vector with integer values for the jointly predicted variables), PITMatrix (matrix with the individual variable uniform PITs and the joint predicted variable uniform PIT for each forecast horizon), ' PathTxt CRPSText 'and PredDateVector (vector with dates for the forecast horizon). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Probability Integral Transform - Prior Distribution',500,600,CurrINI);
                     end;
                     %
                     % write the results to a text file
                     %
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\PITs-Prior-Cond-' ShockMethod DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' int2str(MaxPH) '-' int2str(NumPriorDraws) '.' int2str(NumPredPaths) '-' SmpStr '.txt']);
                     PrintPITs(ResFile,'DSGE',PredictionVariables,PredictionSampleStrMat,'',YDataStr(SelectedYData,:),PITMatrix,[],PathPITMatrix,0,1,0,NumPriorDraws,[],NumPriorDraws,[],CompTimeStepOne,CompTimeStepTwo,DSGEModel,CurrINI);
                     %
                     % check if file exists and display it then
                     %
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Probability Integral Transform - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Prior Distribution',50,CurrINI,1,0);
                     end;
                  else;
                     CompTimeStepOne = toc;
                  end;
               elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                  clear('thetaDraws');
                  txt = 'You didn''t select any variables to predict when computing the probability integral transform (PIT). YADA is therefore unable to help you!';
                  About(txt,'information','Probability Integral Transform - Prior Distribution',150,500,CurrINI);
               else;
                  DSGEModel = OldDSGEModel;
               end;
            else;
               DSGEModel = OldDSGEModel;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ConPITPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         %
         if isempty(ErrorStr)==1;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Probability Integral Transform - Posterior Distribution','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            %
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  clear('LogPost','AcceptedDraws','PostSample');
                  [NumPostDraws,NumParam] = size(thetaPostSample);
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumPostDraws,:);
                  NumDraws = NumPostDraws-NumBurnin;
                  %
                  % check if the user wishes a sub-sample
                  %
                  txt = 'Would you like to use a sub-sample of the posterior draws when estimating the probability integral transform?';
                  answer = Query(txt,'question',400,'Probability Integral Transform - Posterior Distribution',500,'no',CurrINI);
                  if (DSGEModel.PosteriorSampler<=7)|(DSGEModel.PosteriorSampler==9);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        NumDraws = length(UseDraws);
                     end;
                  else;
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = WeightBasedPosteriorDraws(DSGEModel,CurrINI,'Probability Integral Transform - Posterior Distribution',Weights,[]);
                        if isempty(UseDraws)==1;
                           set(controls.about,'UserData',0);
                           return;
                        end;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        Weights = Weights(UseDraws,1);
                        Weights = Weights*length(Weights)/sum(Weights);
                        NumDraws = length(UseDraws);
                     end;
                  end;
                  %
                  % collect some required data
                  %
                  theta = ModeData.thetaMode;
                  thetaPositions = ModeData.thetaPositions;
                  thetaIndex = ModeData.thetaIndex;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  LowerBound = ModeData.LowerBound;
                  UniformBounds = ModeData.UniformBounds;
                  ModelParameters = ModeData.ModelParameters;
                  %
                  [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
                  DSGEModel.FirstPeriod = FirstPeriod;
                  DSGEModel.LastPeriod = LastPeriod;
                  %
                  % check how many time periods to use for predictive distributions
                  %
                  MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
                  %
                  % check the maximum when we take NaNs into account
                  %
                  YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
                  %BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
                  if isempty(DSGEModel.Actuals)==1;
                     SelectedYData = 1;
                     DataAction = 'ok';
                     YDataStr = 'Actuals from original sample';
                  else;
                     YDataStr = 'Actuals from original sample';
                     m = length(DSGEModel.Actuals);
                     for i=1:m;
                        YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
                     end;
                     [DataAction,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','Probability Integral Transform - Posterior Distribution','','',CurrINI);
                     if (strcmp(lower(DataAction),'ok')==1)&(SelectedYData>1);
                        YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                        %BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
                     end;
                  end;
                  %
                  if strcmp(lower(DataAction),'ok')==1;
                     MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
                     [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
                     MaxFH = min(MaxFH,MaxPH);
                     YData = YData(:,1:MaxFH);
                     %
                     % matrix with exogenous variables
                     %
                     X = [];
                     XP = [];
                     if DSGEModel.k>0;
                        if NumPredX<MaxFH;
                           X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
                        end;
                        if NumPredX>0;
                           X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
                        end;
                        if NumPredX<MaxPH;
                           XP = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                        end;
                        if NumPredX>0;
                           XP = [XP DSGEModel.PredictedX(:,1:min(NumPredX,MaxPH))];
                        end;
                     end;
                     %
                     % check the length of the conditioning sample
                     %
                     [status,NumPeriods] = CheckConditioningData(DSGEModel);
                     %
                     % check if we should adjust the X matrix
                     %
                     if MaxFH<NumPeriods;
                        NumPeriods = MaxFH;
                     end;
                     %
                     % collect the conditional variables and the selected conditioning sample
                     %
                     Z = DSGEModel.Z(DSGEModel.ConditionalVariables,LastPeriod+1:LastPeriod+NumPeriods);
                     if LastPeriod>=NumPeriods;
                        U = DSGEModel.U(DSGEModel.ConditionalVariables,LastPeriod-NumPeriods+1:LastPeriod);
                     else;
                        %
                        % we have to create artifical initial conditions for the conditioning variables
                        %
                        U = [DSGEModel.U(DSGEModel.ConditionalVariables,1)*ones(1,NumPeriods-LastPeriod) DSGEModel.U(DSGEModel.ConditionalVariables,1:LastPeriod)];
                     end;
                     %
                     % selection of variable 
                     %
                     if isempty(DSGEModel.PredictionVariables)==1;
                        PredictionVariables = ones(1,DSGEModel.n);
                        PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
                     else;
                        PredictionVariables = DSGEModel.PredictionVariables;
                     end;
                     %
                     [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
                     if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                        DSGEModel.PredictionVariables = PredictionVariables;
                        %
                        % Determine the prediction sample
                        %
                        SampleStrMat = CreateFullSample(DSGEModel);
                        PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                        SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                        %
                        % check which method is used for dealing with the conditioning assumptions
                        %
                        if DSGEModel.ShockControlMethod==1;
                           ShockMethod = 'Direct-';
                        elseif DSGEModel.ShockControlMethod==2;
                           ShockMethod = 'WaggonerZha-';
                        else;
                           ShockMethod = 'Subset-';
                        end;
                        %
                        % check if older calculations exists given that such may be used
                        %
                        MatFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-CondPredictiveMoments-' ShockMethod DSGEModel.NameOfModel '-' SmpStr '-' int2str(CurrChain) '-' int2str(MaxFH) '.' int2str(NumDraws) '-' int2str(NumPostDraws) '.mat']);
                        if FileExist(MatFile)==1;
                           %
                           % check if the PITMoments have been stored
                           %
                           ForecastData = load(MatFile);
                           if (isfield(ForecastData,'PITMoments')==1)&(length(ForecastData.PITMoments)>0);
                              txt = ['YADA has located posterior draws based estimates of the marginal predictive moments on disk for the conditional forecasts. Would you like to use these results?'];
                              answer = Query(txt,'question',200,'Marginal Predictive Moments - Posterior Distribution',500,'no',CurrINI);
                           else;
                              answer = 'No';
                           end;
                           clear('ForecastData');
                        else;
                           answer = 'No';
                        end;
                        tic;
                        if strcmp(lower(answer),'yes')==1;
                           DoneCalc = 1;
                        else;
                           if DSGEModel.ShockControlMethod==1;
                              DoneCalc = DSGECondPredictiveMoments(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxFH,NumPostDraws,CurrChain,1,Weights,SmpStr,1);
                           elseif DSGEModel.ShockControlMethod==2;
                              DoneCalc = DSGECondPredictiveMomentsWZ(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxFH,NumPostDraws,CurrChain,1,Weights,SmpStr,1);
                           else;
                              DoneCalc = DSGECondPredictiveMomentsMixed(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxFH,NumPostDraws,CurrChain,1,Weights,SmpStr,1);
                           end;
                        end;
                        %
                        if DoneCalc==1;
                           %
                           % we can now do the PIT calculations based on the moments
                           %
                           [PITMatrix,BNPITMatrix] = ComputePITs(YData,DSGEModel.Y(:,LastPeriod-1:LastPeriod),[],PredictionVariables,MatFile,Weights,1,(exist('mvncdf')~=0),CurrINI);
                           CompTimeStepOne = toc;
                           %
                           % check if the user also wants to study PITs based on simulated paths
                           %
                           txt = 'YADA can also estimate probability integral transform (PIT) values based on simulated paths from the conditional predictive distribution. Would you like to run these calculations as well?';
                           answer = Query(txt,'question',200,'Probability Integral Transform - Posterior Distribution',500,'no',CurrINI);
                           if strcmp(lower(answer),'yes')==1;
                              %
                              % setup the necessary variables for computing or loading simulated paths from the predictive distribution
                              %
                              % determine how many prediction paths to use
                              %
                              NumPredPathsStr = get(controls.forecast.predpaths,'String');
                              NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
                              %
                              TransData = 0;
                              AnnualizeData = 0;
                              AnnualStr = 'original';
                              QueryHead = 'Predictive Distributions - Original Data';
                              if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumDraws,NumPredPaths,AnnualizeData,TransData,CurrChain,1)==1;
                                 txt = 'YADA has located results for the predictive distribution on disk. Would you like to use these results?';
                                 answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                              else;
                                 answer = 'No';
                              end;
                              %
                              % check if we shall recompute
                              %
                              if strcmp(lower(answer),'yes')==1;
                                 DoneCalc2 = 1;
                                 tic;
                              else;
                                 %
                                 % ask if we should conduct prediction event calculations
                                 %
                                 txt = strvcat('Would you like YADA to calculate prediction event probabilities and perform risk analysis?',' ','NOTE: The results will only be stored to disk and will not be displayed.');
                                 answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
                                 if strcmp(lower(answer),'yes')==1;
                                    if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                                       DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                                    end;
                                    %
                                    % make sure that the prediction event length does not exceed the maximum prediction horizon
                                    %
                                    for i=1:DSGEModel.n;
                                       if DSGEModel.PredictionEvent(i,3)>MaxPH;
                                          DSGEModel.PredictionEvent(i,3) = MaxPH;
                                       end;
                                    end;
                                    %
                                    % display a dialog for setting up an prediction event
                                    %
                                    [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                                    if strcmp(lower(action),'ok')==1;
                                       DSGEModel.PredictionEvent = PredictionEvent;
                                       DSGEModel.RunPredictionEvent = 1;
                                    else;
                                       DSGEModel.RunPredictionEvent = 0;
                                    end;
                                 else;
                                    DSGEModel.RunPredictionEvent = 0;
                                 end;
                                 %
                                 % we can now compute the predictive distribution for the endogenous variables
                                 % up to period MaxPH
                                 %
                                 tic;
                                 if DSGEModel.ShockControlMethod==1;
                                    [DoneCalc2,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPaths(thetaPostSample,ModeData.thetaMode,thetaPositions,ModelParameters,DSGEModel,CurrINI,XP,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights);
                                 elseif DSGEModel.ShockControlMethod==2;
                                    [DoneCalc2,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsWZ(thetaPostSample,ModeData.thetaMode,thetaPositions,ModelParameters,DSGEModel,CurrINI,XP,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights);
                                 else;
                                    %
                                    % check if the selected method can actually be used
                                    %
                                    CondTxt = '';
                                    if isempty(DSGEModel.MixedConditionalShocks)==1;
                                       CondTxt = 'You haven''t selected any shocks for use which the distribution of a subset of the shocks conditioning method.';
                                    elseif length(DSGEModel.MixedConditionalShocks)<length(DSGEModel.ConditionalVariables);
                                       CondTxt = ['The number of shocks you have selected to use to ensure that the conditioning assumptions are satisfied under the distribution of a subset of the shocks conditioning method is not sufficient. You need at least ' int2str(length(DSGEModel.ConditionalVariables)) ' such shocks.'];
                                    end;
                                    if isempty(CondTxt)==1;
                                       [DoneCalc2,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsMixed(thetaPostSample,ModeData.thetaMode,thetaPositions,ModelParameters,DSGEModel,CurrINI,XP,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights);
                                    else;
                                       About(CondTxt,'information','Bad Shocks Selection - Distribution of Subset Shocks Method',300,550,CurrINI);
                                       DoneCalc2 = 0;
                                    end;
                                 end;
                              end;
                              %
                              if DoneCalc2==1;
                                 %
                                 % compute PITs based on the paths from the predictive distribution
                                 %
                                 PathPITMatrix = ComputePITsDSGEPaths(YData,NumDraws,NumPredPaths,MaxPH,CurrChain,1,1,ShockMethod,Weights,DSGEModel,CurrINI);
                                 CompTimeStepTwo = toc;
                              else;
                                 %
                                 % make sure that path based estimates are empty
                                 %
                                 PathPITMatrix = [];
                                 CompTimeStepTwo = [];
                              end;
                           else;
                              %
                              % make sure that path based estimates are empty
                              %
                              PathPITMatrix = [];
                              CompTimeStepTwo = [];
                              NumPredPaths = 0;
                           end;
                           clear('thetaPostSample');
                           %
                           % check if the user want to compute CRPS statistics based on the predictive moments
                           %
                           IsCRPS = 0;
                           txt = 'Would you like to compute the CRPS statistics for the individual observed variables using the predictive mean, standard deviation and a normal distribution?';
                           answer = Query(txt,'question',300,'Probability Integral Transform - Posterior Distribution',600,'no',CurrINI);
                           if strcmp(lower(answer),'yes')==1;
                              IsCRPS = 1;
                              %
                              % use the mat-file above
                              %
                              MPM = load(MatFile);
                              PredY = MPM.MeanPredictY;
                              n = DSGEModel.n;
                              CovPred = zeros(n,n,MaxFH);
                              for i=1:MaxFH;
                                 CovPred(:,:,i) = MPM.MeasureCov(:,:,i)+MPM.ShockCov(:,:,i)+MPM.StateCov(:,:,i)+MPM.ParameterCov(:,:,i);
                              end;
                              %
                              if isfield(MPM,'CovPred')==0;
                                 save(MatFile,'CovPred','PredictionSampleStrMat','-APPEND');
                              end;
                              if isfield(MPM,'YData')==0;
                                 save(MatFile,'YData','-APPEND');
                              end;
                              %
                              % compute the CRPS for a normal distribution
                              %
                              [CRPSMatrix,BackCRPS] = CRPSNormalDistribution(YData,PredY,CovPred,[],[],[]);
                              save(MatFile,'CRPSMatrix','-APPEND');
                           end;
                           %
                           % check if the user wants to store the results to disk
                           %
                           txt = 'Would you like to save the probability integral transform estimates to file?';
                           answer = Query(txt,'question',300,'Probability Integral Transform - Posterior Distribution',500,'no',CurrINI);
                           if strcmp(lower(answer),'yes')==1;
                              [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                              file = FixFilePath([DSGEModel.OutputDirectory '\PITs-Posterior-Cond-' ShockMethod DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' int2str(CurrChain) '-' int2str(MaxPH) '-' int2str(NumDraws) '.' int2str(NumPredPaths) '-' SmpStr '.mat']);
                              YNames = DSGEModel.VariableNames;
                              save(file,'YNames','PredictionVariables','PITMatrix','PredDateVector');
                              if isempty(PathPITMatrix)==0;
                                 save(file,'PathPITMatrix','-APPEND');
                              end;
                              mfile = FixFilePath([DSGEModel.OutputDirectory '\PITsPosterior_Cond_' strrep(ShockMethod,'-','_') DSGEModel.NameOfModel '_' int2str(SelectedYData) '_' int2str(CurrChain) '_' int2str(MaxPH) '_' int2str(NumDraws) 'x' int2str(NumPredPaths) '_' strrep(SmpStr,'.','_') '.m']);
                              fid = fopen(mfile,'wt');
                              fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                              fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                              fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                              fprintf(fid,'YNames = DataStructure.YNames;\n');
                              fprintf(fid,'%%\n%% Selected group of joint prediction variables\n%%\n');
                              fprintf(fid,'PredictionVariables = DataStructure.PredictionVariables;\n');
                              fprintf(fid,'%%\n%% n+1 x h matrix with the individual variable uniform PITs and the joint uniform PIT\n%%\n%% for each forecast horizon. Use norminv to transform to normal.\n%%\n');
                              fprintf(fid,'PITMatrix = DataStructure.PITMatrix;\n');
                              NumEntries = 3;
                              if isempty(PathPITMatrix)==0;
                                 fprintf(fid,'%%\n%% n x h matrix with the individual variable uniform PITs using the prediction\n%%\n%% paths for each forecast horizon. Use norminv to transform to normal.\n%%\n');
                                 fprintf(fid,'PathPITMatrix = DataStructure.PathPITMatrix;\n');
                                 NumEntries = NumEntries+1;
                                 PathTxt = 'PathPITMatrix (matrix with the individual variable uniform PITs using the prediction paths for each forecast horizon), ';
                              else;
                                 PathTxt = '';
                              end;
                              if IsCRPS==1;
                                 fprintf(fid,'%%\n%% n x h matrix with the individual variable CRPS values for each forecast\n%%\n%% horizon using a normal distribution.\n%%\n');
                                 fprintf(fid,'CRPSMatrix = DataStructure.CRPSMatrix;\n');
                                 save(file,'CRPSMatrix','-APPEND');
                                 CRPSText = 'CRPSMatrix (matrix with the individual variable CRPS values for each forecast), ';
                                 NumEntries = NumEntries+1;
                              else;
                                 CRPSText = '';
                              end;
                              fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                              fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                              fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                              %
                              % end the script file
                              %
                              fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                              fclose(fid);
                              NumEntries = NumEntries+1;
                              %
                              txt = ['The probability integral transform (PIT) estimates (uniform under the assumption of well-calibrated) for the posterior draws have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' int2str(NumEntries) ' entries: YNames (string matrix with the names of the observed variables), PredictionVariables (vector with integer values for the jointly predicted variables), PITMatrix (matrix with the individual variable uniform PITs and the joint predicted variable uniform PIT for each forecast horizon), ' PathTxt CRPSText 'and PredDateVector (vector with dates for the forecast horizon). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                              About(txt,'information','Probability Integral Transform - Posterior Distribution',500,600,CurrINI);
                           end;
                           %
                           % write the results to a text file
                           %
                           ResFile = FixFilePath([DSGEModel.OutputDirectory '\PITs-Posterior-Cond-' ShockMethod DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' int2str(CurrChain) '-' int2str(MaxPH) '-' int2str(NumDraws) '.' int2str(NumPredPaths) '-' SmpStr '.txt']);
                           PrintPITs(ResFile,'DSGE',PredictionVariables,PredictionSampleStrMat,'',YDataStr(SelectedYData,:),PITMatrix,[],PathPITMatrix,1,1,0,NumDraws,NumBurnin,NumPostDraws,[],CompTimeStepOne,CompTimeStepTwo,DSGEModel,CurrINI);
                           %
                           % check if file exists and display it then
                           %
                           if FileExist(ResFile)==1;
                              TextGUI(ResFile,['Probability Integral Transform - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution',50,CurrINI,1,0);
                           end;
                        else;
                           CompTimeStepOne = toc;
                           clear('thetaPostSample');
                        end;
                     elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                        clear('thetaPostSample');
                        txt = 'You didn''t select any variables to predict when computing the probability integral transform. YADA is therefore unable to help you!';
                        About(txt,'information','Probability Integral Transform - Posterior Distribution',150,500,CurrINI);
                     end;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconPITPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,'Probability Integral Transform - Prior Distribution',500,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
                  UniformBounds = ModeData.UniformBounds;
                  thetaIndex = ModeData.thetaIndex;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the prior draws data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the prior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection','Probability Integral Transform - Prior Distribution','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            clear('PriorData');
            %
            % determine the sample
            %
            [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
            DSGEModel.FirstPeriod = FirstPeriod;
            DSGEModel.LastPeriod = LastPeriod;
            %
            % check how many time periods to use for predictive distributions
            %
            MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
            %
            % check the maximum when we take NaNs into account
            %
            YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
            BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
            if isempty(DSGEModel.Actuals)==1;
               SelectedYData = 1;
               DataAction = 'ok';
               YDataStr = 'Actuals from original sample';
            else;
               YDataStr = 'Actuals from original sample';
               m = length(DSGEModel.Actuals);
               for i=1:m;
                  YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
               end;
               [DataAction,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','Probability Integral Transform - Prior Distribution','','',CurrINI);
               if (strcmp(lower(DataAction),'ok')==1)&(SelectedYData>1);
                  YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                  BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
               end;
            end;
            %
            if strcmp(lower(DataAction),'ok')==1;
               MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
               [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               MaxFH = min(MaxFH,MaxPH);
               YData = YData(:,1:MaxFH);
               %
               % matrix with exogenous variables
               %
               X = [];
               XP = [];
               if DSGEModel.k>0;
                  if NumPredX<MaxFH;
                     X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
                  end;
                  if NumPredX>0;
                     X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
                  end;
                  if NumPredX<MaxPH;
                     XP = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                  end;
                  if NumPredX>0;
                     XP = [XP DSGEModel.PredictedX(:,1:min(NumPredX,MaxPH))];
                  end;
               end;
               %
               % selection of variable 
               %
               if isempty(DSGEModel.PredictionVariables)==1;
                  PredictionVariables = ones(1,DSGEModel.n);
                  PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
               else;
                  PredictionVariables = DSGEModel.PredictionVariables;
               end;
               %
               [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
               if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                  %
                  % we may continue and store the new selection of prediction variables
                  %
                  DSGEModel.PredictionVariables = PredictionVariables;
                  %
                  % Determine the prediction sample
                  %
                  SampleStrMat = CreateFullSample(DSGEModel);
                  PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                  BNSampleStrMat = SampleStrMat(LastPeriod-1:LastPeriod,:);
                  SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                  %
                  % check if older calculations exists given that such may be used
                  %
                  MatFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-PredictiveMoments-Prior-' DSGEModel.NameOfModel '-' SmpStr '-' int2str(MaxFH) '.' int2str(NumPriorDraws) '.mat']);
                  PITMomentExist = 0;
                  if FileExist(MatFile)==1;
                     CheckData = load(MatFile);
                     if isfield(CheckData,'PITMoments')==1;
                        if isempty(CheckData.PITMoments)==0;
                           PITMomentExist = 1;
                        end;
                     end;
                     clear('CheckData');
                  end;
                  if PITMomentExist==1;
                     txt = 'YADA has located prior draws based estimates of the moments on disk that can be used for the probability integral transform (PIT). Would you like to use these results?';
                     answer = Query(txt,'question',200,'Probability Integral Transform - Prior Distribution',500,'yes',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  tic;
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                  else;
                     DoneCalc = DSGEPredictiveMoments(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,MaxFH,NumPriorDraws,[],0,[],SmpStr,1);
                  end;
                  if DoneCalc==1;
                     %
                     % we can now do the PIT calculations based on the moments
                     %
                     [PITMatrix,BNPITMatrix] = ComputePITs(YData,DSGEModel.Y(:,LastPeriod-1:LastPeriod),BackYData,PredictionVariables,MatFile,[],0,(exist('mvncdf')~=0),CurrINI);
                     CompTimeStepOne = toc;
                     %
                     % check if the user also wants to study PITs based on simulated paths
                     %
                     txt = 'YADA can also estimate probability integral transform (PIT) values based on simulated paths from the predictive distribution. Would you like to run these calculations as well?';
                     answer = Query(txt,'question',200,'Probability Integral Transform - Prior Distribution',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % setup the necessary variables for computing or loading simulated paths from the predictive distribution
                        %
                        % determine how many prediction paths to use
                        %
                        NumPredPathsStr = get(controls.forecast.predpaths,'String');
                        NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
                        %
                        TransData = 0;
                        AnnualizeData = 0;
                        AnnualStr = 'original';
                        QueryHead = 'Predictive Distributions For Prior - Original Data';
                        if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','','',DSGEModel.NameOfModel,MaxPH,NumPriorDraws,NumPredPaths,AnnualizeData,TransData,1,0)==1;
                           txt = 'YADA has located results for the predictive distribution on disk. Would you like to use these results?';
                           answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                        else;
                           answer = 'No';
                        end;
                        %
                        % check if we shall recompute
                        %
                        if strcmp(lower(answer),'yes')==1;
                           DoneCalc2 = 1;
                           tic;
                        else;
                           %
                           % ask if we should conduct prediction event calculations
                           %
                           txt = strvcat('Would you like YADA to calculate prediction event probabilities and perform risk analysis?',' ','NOTE: The results will only be stored to disk and will not be displayed.');
                           answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
                           if strcmp(lower(answer),'yes')==1;
                              if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                                 DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                              end;
                              %
                              % make sure that the prediction event length does not exceed the maximum prediction horizon
                              %
                              for i=1:DSGEModel.n;
                                 if DSGEModel.PredictionEvent(i,3)>MaxPH;
                                    DSGEModel.PredictionEvent(i,3) = MaxPH;
                                 end;
                              end;
                              %
                              % display a dialog for setting up an prediction event
                              %
                              [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                              if strcmp(lower(action),'ok')==1;
                                 DSGEModel.PredictionEvent = PredictionEvent;
                                 DSGEModel.RunPredictionEvent = 1;
                              else;
                                 DSGEModel.RunPredictionEvent = 0;
                              end;
                           else;
                              DSGEModel.RunPredictionEvent = 0;
                           end;
                           %
                           % we can now compute the predictive distribution for the endogenous variables
                           % up to period MaxPH
                           %
                           tic;
                           [DoneCalc2,PredEventData,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGEPredictionPaths(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,XP,MaxPH,NumPredPaths,AnnualizeData,TransData,1,0,[]);
                        end;
                        %
                        if DoneCalc2==1;
                           %
                           % compute PITs based on the paths from the predictive distribution
                           %
                           PathPITMatrix = ComputePITsDSGEPaths(YData,NumPriorDraws,NumPredPaths,MaxPH,1,0,0,'',[],DSGEModel,CurrINI);
                           CompTimeStepTwo = toc;
                        else;
                           %
                           % make sure that path based estimates are empty
                           %
                           PathPITMatrix = [];
                           CompTimeStepTwo = [];
                        end;
                     else;
                        %
                        % make sure that path based estimates are empty
                        %
                        PathPITMatrix = [];
                        CompTimeStepTwo = [];
                        NumPredPaths = 0;
                     end;
                     clear('thetaDraws');
                     %
                     % check if the user want to compute CRPS statistics based on the predictive moments
                     %
                     IsCRPS = 0;
                     IsBackCast = 0;
                     txt = 'Would you like to compute the CRPS statistics for the individual observed variables using the predictive mean, standard deviation and a normal distribution?';
                     answer = Query(txt,'question',300,'Probability Integral Transform - Prior Distribution',600,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        IsCRPS = 1;
                        %
                        % Determine the prediction sample
                        %
                        SampleStrMat = CreateFullSample(DSGEModel);
                        PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                        BNSampleStrMat = SampleStrMat(LastPeriod-1:LastPeriod,:);
                        SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                        %
                        % check if older calculations exists given that such may be used
                        %
                        MatFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-PredictiveMoments-Prior-' DSGEModel.NameOfModel '-' SmpStr '-' int2str(MaxFH) '.' int2str(NumPriorDraws) '.mat']);
                        MPM = load(MatFile);
                        PredY = MPM.MeanPredictY;
                        n = DSGEModel.n;
                        CovPred = zeros(n,n,MaxFH);
                        for i=1:MaxFH;
                           CovPred(:,:,i) = MPM.MeasureCov+MPM.ShockCov(:,:,i)+MPM.StateCov(:,:,i)+MPM.ParameterCov(:,:,i);
                        end;
                        BNCov = [];
                        BNPredictY = [];
                        if isfield(MPM,'BNPredictY')==1;
                           BNPredictY = MPM.BNPredictY;
                           if isempty(MPM.BNPredictY)==0;
                              if isfield(MPM,'BNCov')==1;
                                 BNCov = MPM.BNCov;
                              else;
                                 BNCov = MPM.BNObsCov+MPM.BNParamCov;
                                 save(MatFile,'BNCov','-APPEND');
                              end;
                              IsBackCast = 1;
                           else;
                              IsBackCast = 0;
                           end;
                        else;
                           IsBackCast = 0;
                        end;
                        if isfield(MPM,'BNSampleStrMat')==0;
                           save(MatFile,'BNSampleStrMat','-APPEND');
                        end;
                        %
                        if isfield(MPM,'CovPred')==0;
                           save(MatFile,'CovPred','PredictionSampleStrMat','-APPEND');
                        end;
                        if isfield(MPM,'YData')==0;
                           save(MatFile,'YData','-APPEND');
                        end;
                        %
                        % compute the CRPS for a normal distribution
                        %
                        if IsBackCast==1;
                           [CRPSMatrix,BackCRPS] = CRPSNormalDistribution(YData,PredY,CovPred,BackYData,BNPredictY,BNCov);
                        else;
                           [CRPSMatrix,BackCRPS] = CRPSNormalDistribution(YData,PredY,CovPred,[],[],[]);
                        end;
                        save(MatFile,'CRPSMatrix','-APPEND');
                        if min(min(isnan(BackCRPS)))==1;
                           IsBackCast = 0;
                        end;
                        if IsBackCast==1;
                           save(MatFile,'BackCRPS','-APPEND');
                        end;
                     end;
                     %
                     % check if the user wants to store the results to disk
                     %
                     txt = 'Would you like to save the probability integral transform estimates to file?';
                     answer = Query(txt,'question',300,'Probability Integral Transform - Prior Distribution',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                        file = FixFilePath([DSGEModel.OutputDirectory '\PITs-Prior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' int2str(MaxPH) '-' int2str(NumPriorDraws) '.' int2str(NumPredPaths) '-' SmpStr '.mat']);
                        YNames = DSGEModel.VariableNames;
                        save(file,'YNames','PredictionVariables','PITMatrix','PredDateVector');
                        if isempty(BNPITMatrix)==0;
                           save(file,'BNPITMatrix','-APPEND')
                        end;
                        if isempty(PathPITMatrix)==0;
                           save(file,'PathPITMatrix','-APPEND');
                        end;
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\PITsPrior_' DSGEModel.NameOfModel '_' int2str(SelectedYData) '_' int2str(MaxPH) '_' int2str(NumPriorDraws) 'x' int2str(NumPredPaths) '_' strrep(SmpStr,'.','_') '.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% Selected group of joint prediction variables\n%%\n');
                        fprintf(fid,'PredictionVariables = DataStructure.PredictionVariables;\n');
                        fprintf(fid,'%%\n%% n+1 x h matrix with the individual variable uniform PITs and the joint uniform PIT\n%%\n%% for each forecast horizon. Use norminv to transform to normal.\n%%\n');
                        fprintf(fid,'PITMatrix = DataStructure.PITMatrix;\n');
                        NumEntries = 3;
                        if isempty(BNPITMatrix)==0;
                           fprintf(fid,'%%\n%% n+1 x 2 matrix with the individual variable uniform PITs and the joint uniform PIT\n%%\n%% for the backcast and the nowcast. Use norminv to transform to normal.\n%%\n');
                           fprintf(fid,'BNPITMatrix = DataStructure.BNPITMatrix;\n');
                           NumEntries = NumEntries+1;
                           BNTxt = 'BNPITMatrix (matrix with the individual variable uniform PITs and the joint predicted variable uniform PIT for the backcast and the nowcast), ';
                        else;
                           BNTxt = '';
                        end;
                        if isempty(PathPITMatrix)==0;
                           fprintf(fid,'%%\n%% n x h matrix with the individual variable uniform PITs using the prediction\n%%\n%% paths for each forecast horizon. Use norminv to transform to normal.\n%%\n');
                           fprintf(fid,'PathPITMatrix = DataStructure.PathPITMatrix;\n');
                           NumEntries = NumEntries+1;
                           PathTxt = 'PathPITMatrix (matrix with the individual variable uniform PITs using the prediction paths for each forecast horizon), ';
                        else;
                           PathTxt = '';
                        end;
                        if IsCRPS==1;
                           fprintf(fid,'%%\n%% n x h matrix with the individual variable CRPS values for each forecast\n%%\n%% horizon using a normal distribution.\n%%\n');
                           fprintf(fid,'CRPSMatrix = DataStructure.CRPSMatrix;\n');
                           save(file,'CRPSMatrix','-APPEND');
                           if IsBackCast==1;
                              save(file,'BackCRPS','-APPEND');
                           end;
                           if IsBackCast==1;
                              NumEntries = NumEntries+2;
                              fprintf(fid,'%%\n%% n x h matrix with the individual variable CRPS values for each backcast\n%%\n%% and nowcast using a normal distribution.\n%%\n');
                              fprintf(fid,'BackCRPS = DataStructure.BackCRPS;\n');
                              CRPSText = 'CRPSMatrix (matrix with the individual variable CRPS values for each forecast), BackCRPS (matrix with the individual CRPS values for each backcast and nowcast), ';
                           else;
                              CRPSText = 'CRPSMatrix (matrix with the individual variable CRPS values for each forecast), ';
                              NumEntries = NumEntries+1;
                           end;
                        else;
                           CRPSText = '';
                        end;
                        fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                        fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        NumEntries = NumEntries+1;
                        %
                        txt = ['The probability integral transform (PIT) estimates (uniform under the assumption of well-calibrated) for the prior draws have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' int2str(NumEntries) ' entries: YNames (string matrix with the names of the observed variables), PredictionVariables (vector with integer values for the jointly predicted variables), PITMatrix (matrix with the individual variable uniform PITs and the joint predicted variable uniform PIT for each forecast horizon), ' BNTxt PathTxt CRPSText 'and PredDateVector (vector with dates for the forecast horizon). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Probability Integral Transform - Prior Distribution',500,600,CurrINI);
                     end;
                     %
                     % write the results to a text file
                     %
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\PITs-Prior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' int2str(MaxPH) '-' int2str(NumPriorDraws) '.' int2str(NumPredPaths) '-' SmpStr '.txt']);
                     PrintPITs(ResFile,'DSGE',PredictionVariables,PredictionSampleStrMat,BNSampleStrMat,YDataStr(SelectedYData,:),PITMatrix,BNPITMatrix,PathPITMatrix,0,0,0,NumPriorDraws,[],NumPriorDraws,[],CompTimeStepOne,CompTimeStepTwo,DSGEModel,CurrINI);
                     %
                     % check if file exists and display it then
                     %
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Probability Integral Transform - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Prior Distribution',50,CurrINI,1,0);
                     end;
                  else;
                     CompTime = toc;
                     clear('thetaDraws');
                  end;
               elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                  clear('thetaDraws');
                  txt = 'You didn''t select any variables to predict when computing the probability integral transform (PIT). YADA is therefore unable to help you!';
                  About(txt,'information','Probability Integral Transform - Prior Distribution',150,500,CurrINI);
               else;
                  DSGEModel = OldDSGEModel;
               end;
            else;
               DSGEModel = OldDSGEModel;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconPITPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         %
         if isempty(ErrorStr)==1;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Probability Integral Transform - Posterior Distribution','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            %
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  clear('LogPost','AcceptedDraws','PostSample');
                  [NumPostDraws,NumParam] = size(thetaPostSample);
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumPostDraws,:);
                  NumDraws = NumPostDraws-NumBurnin;
                  %
                  % check if the user wishes a sub-sample
                  %
                  txt = 'Would you like to use a sub-sample of the posterior draws when estimating the probability integral transform?';
                  answer = Query(txt,'question',400,'Probability Integral Transform - Posterior Distribution',500,'no',CurrINI);
                  if (DSGEModel.PosteriorSampler<=7)|(DSGEModel.PosteriorSampler==9);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        NumDraws = length(UseDraws);
                     end;
                  else;
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = WeightBasedPosteriorDraws(DSGEModel,CurrINI,'Probability Integral Transform - Posterior Distribution',Weights,[]);
                        if isempty(UseDraws)==1;
                           set(controls.about,'UserData',0);
                           return;
                        end;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        Weights = Weights(UseDraws,1);
                        Weights = Weights*length(Weights)/sum(Weights);
                        NumDraws = length(UseDraws);
                     end;
                  end;
                  %
                  % collect some required data
                  %
                  theta = ModeData.thetaMode;
                  thetaPositions = ModeData.thetaPositions;
                  thetaIndex = ModeData.thetaIndex;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  LowerBound = ModeData.LowerBound;
                  UniformBounds = ModeData.UniformBounds;
                  ModelParameters = ModeData.ModelParameters;
                  %
                  [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
                  DSGEModel.FirstPeriod = FirstPeriod;
                  DSGEModel.LastPeriod = LastPeriod;
                  %
                  % check how many time periods to use for predictive distributions
                  %
                  MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
                  %
                  % check the maximum when we take NaNs into account
                  %
                  YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
                  BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
                  if isempty(DSGEModel.Actuals)==1;
                     SelectedYData = 1;
                     DataAction = 'ok';
                     YDataStr = 'Actuals from original sample';
                  else;
                     YDataStr = 'Actuals from original sample';
                     m = length(DSGEModel.Actuals);
                     for i=1:m;
                        YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
                     end;
                     [DataAction,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','Probability Integral Transform - Posterior Distribution','','',CurrINI);
                     if (strcmp(lower(DataAction),'ok')==1)&(SelectedYData>1);
                        YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                        BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
                     end;
                  end;
                  %
                  if strcmp(lower(DataAction),'ok')==1;
                     MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
                     [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
                     MaxFH = min(MaxFH,MaxPH);
                     YData = YData(:,1:MaxFH);
                     %
                     % matrix with exogenous variables
                     %
                     X = [];
                     XP = [];
                     if DSGEModel.k>0;
                        if NumPredX<MaxFH;
                           X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
                        end;
                        if NumPredX>0;
                           X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
                        end;
                        if NumPredX<MaxPH;
                           XP = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                        end;
                        if NumPredX>0;
                           XP = [XP DSGEModel.PredictedX(:,1:min(NumPredX,MaxPH))];
                        end;
                     end;
                     %
                     % selection of variable 
                     %
                     if isempty(DSGEModel.PredictionVariables)==1;
                        PredictionVariables = ones(1,DSGEModel.n);
                        PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
                     else;
                        PredictionVariables = DSGEModel.PredictionVariables;
                     end;
                     %
                     [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
                     if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                        DSGEModel.PredictionVariables = PredictionVariables;
                        %
                        % Determine the prediction sample
                        %
                        SampleStrMat = CreateFullSample(DSGEModel);
                        PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                        BNSampleStrMat = SampleStrMat(LastPeriod-1:LastPeriod,:);
                        SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                        %
                        % check if older calculations exists given that such may be used
                        %
                        MatFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-PredictiveMoments-' DSGEModel.NameOfModel '-' SmpStr '-' int2str(CurrChain) '-' int2str(MaxFH) '.' int2str(NumDraws) '-' int2str(NumPostDraws) '.mat']);
                        PITMomentExist = 0;
                        if FileExist(MatFile)==1;
                           CheckData = load(MatFile);
                           if isfield(CheckData,'PITMoments')==1;
                              if isempty(CheckData.PITMoments)==0;
                                 PITMomentExist = 1;
                              end;
                           end;
                           clear('CheckData');
                        end;
                        if PITMomentExist==1;
                           txt = 'YADA has located posterior draws based estimates of the moments on disk that can be used for the probability integral transform (PIT). Would you like to use these results?';
                           answer = Query(txt,'question',200,'Probability Integral Transform - Posterior Distribution',500,'yes',CurrINI);
                        else;
                           answer = 'No';
                        end;
                        tic;
                        if strcmp(lower(answer),'yes')==1;
                           DoneCalc = 1;
                        else;
                           DoneCalc = DSGEPredictiveMoments(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,MaxFH,NumPostDraws,CurrChain,1,Weights,SmpStr,1);
                        end;
                        if DoneCalc==1;
                           %
                           % we can now do the PIT calculations based on the moments
                           %
                           [PITMatrix,BNPITMatrix] = ComputePITs(YData,DSGEModel.Y(:,LastPeriod-1:LastPeriod),BackYData,PredictionVariables,MatFile,Weights,1,(exist('mvncdf')~=0),CurrINI);
                           CompTimeStepOne = toc;
                           %
                           % check if the user also wants to study PITs based on simulated paths
                           %
                           txt = 'YADA can also estimate probability integral transform (PIT) values based on simulated paths from the predictive distribution. Would you like to run these calculations as well?';
                           answer = Query(txt,'question',200,'Probability Integral Transform - Posterior Distribution',500,'no',CurrINI);
                           if strcmp(lower(answer),'yes')==1;
                              %
                              % setup the necessary variables for computing or loading simulated paths from the predictive distribution
                              %
                              % determine how many prediction paths to use
                              %
                              NumPredPathsStr = get(controls.forecast.predpaths,'String');
                              NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
                              %
                              TransData = 0;
                              AnnualizeData = 0;
                              AnnualStr = 'original';
                              QueryHead = 'Predictive Distributions - Original Data';
                              if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','','',DSGEModel.NameOfModel,MaxPH,NumDraws,NumPredPaths,AnnualizeData,TransData,CurrChain,1)==1;
                                 txt = 'YADA has located results for the predictive distribution on disk. Would you like to use these results?';
                                 answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                              else;
                                 answer = 'No';
                              end;
                              %
                              % check if we shall recompute
                              %
                              if strcmp(lower(answer),'yes')==1;
                                 DoneCalc2 = 1;
                                 tic;
                              else;
                                 %
                                 % ask if we should conduct prediction event calculations
                                 %
                                 txt = strvcat('Would you like YADA to calculate prediction event probabilities and perform risk analysis?',' ','NOTE: The results will only be stored to disk and will not be displayed.');
                                 answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
                                 if strcmp(lower(answer),'yes')==1;
                                    if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                                       DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                                    end;
                                    %
                                    % make sure that the prediction event length does not exceed the maximum prediction horizon
                                    %
                                    for i=1:DSGEModel.n;
                                       if DSGEModel.PredictionEvent(i,3)>MaxPH;
                                          DSGEModel.PredictionEvent(i,3) = MaxPH;
                                       end;
                                    end;
                                    %
                                    % display a dialog for setting up an prediction event
                                    %
                                    [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                                    if strcmp(lower(action),'ok')==1;
                                       DSGEModel.PredictionEvent = PredictionEvent;
                                       DSGEModel.RunPredictionEvent = 1;
                                    else;
                                       DSGEModel.RunPredictionEvent = 0;
                                    end;
                                 else;
                                    DSGEModel.RunPredictionEvent = 0;
                                 end;
                                 %
                                 % we can now compute the predictive distribution for the endogenous variables
                                 % up to period MaxPH
                                 %
                                 tic;
                                 [DoneCalc2,PredEventData,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGEPredictionPaths(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,XP,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights);
                              end;
                              %
                              if DoneCalc2==1;
                                 %
                                 % compute PITs based on the paths from the predictive distribution
                                 %
                                 PathPITMatrix = ComputePITsDSGEPaths(YData,NumDraws,NumPredPaths,MaxPH,CurrChain,1,0,'',Weights,DSGEModel,CurrINI);
                                 CompTimeStepTwo = toc;
                              else;
                                 %
                                 % make sure that path based estimates are empty
                                 %
                                 PathPITMatrix = [];
                                 CompTimeStepTwo = [];
                              end;
                           else;
                              %
                              % make sure that path based estimates are empty
                              %
                              PathPITMatrix = [];
                              CompTimeStepTwo = [];
                              NumPredPaths = 0;
                           end;
                           clear('thetaPostSample');
                           %
                           % check if the user want to compute CRPS statistics based on the predictive moments
                           %
                           IsCRPS = 0;
                           IsBackCast = 0;
                           txt = 'Would you like to compute the CRPS statistics for the individual observed variables using the predictive mean, standard deviation and a normal distribution?';
                           answer = Query(txt,'question',300,'Probability Integral Transform - Posterior Distribution',600,'no',CurrINI);
                           if strcmp(lower(answer),'yes')==1;
                              IsCRPS = 1;
                              %
                              % Determine the prediction sample
                              %
                              SampleStrMat = CreateFullSample(DSGEModel);
                              PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                              BNSampleStrMat = SampleStrMat(LastPeriod-1:LastPeriod,:);
                              SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                              %
                              % check if older calculations exists given that such may be used
                              %
                              MatFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-PredictiveMoments-' DSGEModel.NameOfModel '-' SmpStr '-' int2str(CurrChain) '-' int2str(MaxFH) '.' int2str(NumDraws) '-' int2str(NumPostDraws) '.mat']);
                              MPM = load(MatFile);
                              PredY = MPM.MeanPredictY;
                              n = DSGEModel.n;
                              CovPred = zeros(n,n,MaxFH);
                              for i=1:MaxFH;
                                 CovPred(:,:,i) = MPM.MeasureCov+MPM.ShockCov(:,:,i)+MPM.StateCov(:,:,i)+MPM.ParameterCov(:,:,i);
                              end;
                              BNCov = [];
                              BNPredictY = [];
                              if isfield(MPM,'BNPredictY')==1;
                                 BNPredictY = MPM.BNPredictY;
                                 if isempty(MPM.BNPredictY)==0;
                                    if isfield(MPM,'BNCov')==1;
                                       BNCov = MPM.BNCov;
                                    else;
                                       BNCov = MPM.BNObsCov+MPM.BNParamCov;
                                       save(MatFile,'BNCov','-APPEND');
                                    end;
                                    IsBackCast = 1;
                                 else;
                                    IsBackCast = 0;
                                 end;
                              else;
                                 IsBackCast = 0;
                              end;
                              if isfield(MPM,'BNSampleStrMat')==0;
                                 save(MatFile,'BNSampleStrMat','-APPEND');
                              end;
                              %
                              if isfield(MPM,'CovPred')==0;
                                 save(MatFile,'CovPred','PredictionSampleStrMat','-APPEND');
                              end;
                              if isfield(MPM,'YData')==0;
                                 save(MatFile,'YData','-APPEND');
                              end;
                              %
                              % compute the CRPS for a normal distribution
                              %
                              if IsBackCast==1;
                                 [CRPSMatrix,BackCRPS] = CRPSNormalDistribution(YData,PredY,CovPred,BackYData,BNPredictY,BNCov);
                              else;
                                 [CRPSMatrix,BackCRPS] = CRPSNormalDistribution(YData,PredY,CovPred,[],[],[]);
                              end;
                              save(MatFile,'CRPSMatrix','-APPEND');
                              if min(min(isnan(BackCRPS)))==1;
                                 IsBackCast = 0;
                              end;
                              if IsBackCast==1;
                                 save(MatFile,'BackCRPS','-APPEND');
                              end;
                           end;
                           %
                           % check if the user wants to store the results to disk
                           %
                           txt = 'Would you like to save the probability integral transform estimates to file?';
                           answer = Query(txt,'question',300,'Probability Integral Transform - Posterior Distribution',500,'no',CurrINI);
                           if strcmp(lower(answer),'yes')==1;
                              [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                              file = FixFilePath([DSGEModel.OutputDirectory '\PITs-Posterior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' int2str(CurrChain) '-' int2str(MaxPH) '-' int2str(NumDraws) '.' int2str(NumPredPaths) '-' SmpStr '.mat']);
                              YNames = DSGEModel.VariableNames;
                              save(file,'YNames','PredictionVariables','PITMatrix','PredDateVector');
                              if isempty(BNPITMatrix)==0;
                                 save(file,'BNPITMatrix','-APPEND')
                              end;
                              if isempty(PathPITMatrix)==0;
                                 save(file,'PathPITMatrix','-APPEND');
                              end;
                              mfile = FixFilePath([DSGEModel.OutputDirectory '\PITsPosterior_' DSGEModel.NameOfModel '_' int2str(SelectedYData) '_' int2str(CurrChain) '_' int2str(MaxPH) '_' int2str(NumDraws) 'x' int2str(NumPredPaths) '_' strrep(SmpStr,'.','_') '.m']);
                              fid = fopen(mfile,'wt');
                              fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                              fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                              fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                              fprintf(fid,'YNames = DataStructure.YNames;\n');
                              fprintf(fid,'%%\n%% Selected group of joint prediction variables\n%%\n');
                              fprintf(fid,'PredictionVariables = DataStructure.PredictionVariables;\n');
                              fprintf(fid,'%%\n%% n+1 x h matrix with the individual variable uniform PITs and the joint uniform PIT\n%%\n%% for each forecast horizon. Use norminv to transform to normal.\n%%\n');
                              fprintf(fid,'PITMatrix = DataStructure.PITMatrix;\n');
                              NumEntries = 3;
                              if isempty(BNPITMatrix)==0;
                                 fprintf(fid,'%%\n%% n+1 x 2 matrix with the individual variable uniform PITs and the joint uniform PIT\n%%\n%% for the backcast and the nowcast. Use norminv to transform to normal.\n%%\n');
                                 fprintf(fid,'BNPITMatrix = DataStructure.BNPITMatrix;\n');
                                 NumEntries = NumEntries+1;
                                 BNTxt = 'BNPITMatrix (matrix with the individual variable uniform PITs and the joint predicted variable uniform PIT for the backcast and the nowcast), ';
                              else;
                                 BNTxt = '';
                              end;
                              if isempty(PathPITMatrix)==0;
                                 fprintf(fid,'%%\n%% n x h matrix with the individual variable uniform PITs using the prediction\n%%\n%% paths for each forecast horizon. Use norminv to transform to normal.\n%%\n');
                                 fprintf(fid,'PathPITMatrix = DataStructure.PathPITMatrix;\n');
                                 NumEntries = NumEntries+1;
                                 PathTxt = 'PathPITMatrix (matrix with the individual variable uniform PITs using the prediction paths for each forecast horizon), ';
                              else;
                                 PathTxt = '';
                              end;
                              if IsCRPS==1;
                                 fprintf(fid,'%%\n%% n x h matrix with the individual variable CRPS values for each forecast\n%%\n%% horizon using a normal distribution.\n%%\n');
                                 fprintf(fid,'CRPSMatrix = DataStructure.CRPSMatrix;\n');
                                 save(file,'CRPSMatrix','-APPEND');
                                 if IsBackCast==1;
                                    save(file,'BackCRPS','-APPEND');
                                 end;
                                 if IsBackCast==1;
                                    NumEntries = NumEntries+2;
                                    fprintf(fid,'%%\n%% n x h matrix with the individual variable CRPS values for each backcast\n%%\n%% and nowcast using a normal distribution.\n%%\n');
                                    fprintf(fid,'BackCRPS = DataStructure.BackCRPS;\n');
                                    CRPSText = 'CRPSMatrix (matrix with the individual variable CRPS values for each forecast), BackCRPS (matrix with the individual CRPS values for each backcast and nowcast), ';
                                 else;
                                    CRPSText = 'CRPSMatrix (matrix with the individual variable CRPS values for each forecast), ';
                                    NumEntries = NumEntries+1;
                                 end;
                              else;
                                 CRPSText = '';
                              end;
                              fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                              fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                              fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                              %
                              % end the script file
                              %
                              fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                              fclose(fid);
                              NumEntries = NumEntries+1;
                              %
                              txt = ['The probability integral transform (PIT) estimates (uniform under the assumption of well-calibrated) for the posterior draws have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' int2str(NumEntries) ' entries: YNames (string matrix with the names of the observed variables), PredictionVariables (vector with integer values for the jointly predicted variables), PITMatrix (matrix with the individual variable uniform PITs and the joint predicted variable uniform PIT for each forecast horizon), ' BNTxt PathTxt CRPSText 'and PredDateVector (vector with dates for the forecast horizon). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                              About(txt,'information','Probability Integral Transform - Posterior Distribution',500,600,CurrINI);
                           end;
                           %
                           % write the results to a text file
                           %
                           ResFile = FixFilePath([DSGEModel.OutputDirectory '\PITs-Posterior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' int2str(CurrChain) '-' int2str(MaxPH) '-' int2str(NumDraws) '.' int2str(NumPredPaths) '-' SmpStr '.txt']);
                           PrintPITs(ResFile,'DSGE',PredictionVariables,PredictionSampleStrMat,BNSampleStrMat,YDataStr(SelectedYData,:),PITMatrix,BNPITMatrix,PathPITMatrix,1,0,0,NumDraws,NumBurnin,NumPostDraws,[],CompTimeStepOne,CompTimeStepTwo,DSGEModel,CurrINI);
                           %
                           % check if file exists and display it then
                           %
                           if FileExist(ResFile)==1;
                              TextGUI(ResFile,['Probability Integral Transform - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution',50,CurrINI,1,0);
                           end;
                        else;
                           CompTime = toc;
                           clear('thetaPostSample');
                        end;
                     elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                        clear('thetaPostSample');
                        txt = 'You didn''t select any variables to predict when computing the probability integral transform. YADA is therefore unable to help you!';
                        About(txt,'information','Probability Integral Transform - Posterior Distribution',150,500,CurrINI);
                     end;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconCRPSPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,'CRPS - Prior Distribution',500,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
                  UniformBounds = ModeData.UniformBounds;
                  thetaIndex = ModeData.thetaIndex;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the prior draws data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the prior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection','CRPS - Prior Distribution','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            clear('PriorData');
            %
            % determine how many prediction paths to use
            %
            NumPredPathsStr = get(controls.forecast.predpaths,'String');
            NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
            UsePaths = 1;
            if NumPredPaths*NumPriorDraws>=100000;
               txt = ['The total number of paths that the CRPS calculations will use is equal ' int2str(NumPredPaths*NumPriorDraws) ' and it may take a very long time to finish them. Are you sure you wish to continue?'];
               answer = Query(txt,'question',400,'CRPS - Prior Distribution',500,'no',CurrINI);
               if strcmp(lower(answer),'no')==1;
                  UsePaths = 0;
               end;
            end;
            %
            if UsePaths==1;
               %
               % determine the sample
               %
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
               DSGEModel.FirstPeriod = FirstPeriod;
               DSGEModel.LastPeriod = LastPeriod;
               %
               % check how many time periods to use for predictive distributions
               %
               MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
               %
               % check the maximum when we take NaNs into account
               %
               YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
               BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
               if isempty(DSGEModel.Actuals)==1;
                  SelectedYData = 1;
                  DataAction = 'ok';
                  YDataStr = 'Actuals from original sample';
               else;
                  YDataStr = 'Actuals from original sample';
                  m = length(DSGEModel.Actuals);
                  for i=1:m;
                     YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
                  end;
                  [DataAction,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','CRPS - Prior Distribution','','',CurrINI);
                  if (strcmp(lower(DataAction),'ok')==1)&(SelectedYData>1);
                     YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                     BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
                  end;
               end;
            else;
               DataAction = 'cancel';
            end;
            %
            if strcmp(lower(DataAction),'ok')==1;
               MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
               [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               MaxFH = min(MaxFH,MaxPH);
               YData = YData(:,1:MaxFH);
               %
               % matrix with exogenous variables
               %
               X = [];
               if DSGEModel.k>0;
                  if NumPredX<MaxPH;
                     X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                  end;
                  if NumPredX>0;
                     X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxPH))];
                  end;
               end;
               %
               % selection of variable 
               %
               if isempty(DSGEModel.PredictionVariables)==1;
                  PredictionVariables = ones(1,DSGEModel.n);
                  PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
               else;
                  PredictionVariables = DSGEModel.PredictionVariables;
               end;
               %
               [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
               if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                  %
                  % we may continue and store the new selection of prediction variables
                  %
                  DSGEModel.PredictionVariables = PredictionVariables;
                  %
                  % Determine the prediction sample
                  %
                  SampleStrMat = CreateFullSample(DSGEModel);
                  PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                  SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                  %
                  if gcbo==controls.predict.unconditional.original.crps.prior;
                     TransData = 0;
                     AnnualizeData = 0;
                     AnnualStr = 'original';
                     QueryHead = 'Predictive Distributions For Prior (CRPS) - Original Data';
                  elseif gcbo==controls.predict.unconditional.annual.crps.prior;
                     TransData = 0;
                     AnnualizeData = 1;
                     AnnualStr = 'annual';
                     QueryHead = 'Predictive Distributions For Prior (CRPS) - Annualized Data';
                  end;
                  if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','','',DSGEModel.NameOfModel,MaxPH,NumPriorDraws,NumPredPaths,AnnualizeData,TransData,1,0)==1;
                     txt = 'YADA has located results for the predictive distribution on disk. Would you like to use these results?';
                     answer = Query(txt,'question',150,QueryHead,500,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  %
                  % check if we shall recompute
                  %
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                     tic;
                  else;
                     %
                     % ask if we should conduct prediction event calculations
                     %
                     txt = strvcat('Would you like YADA to calculate prediction event probabilities and perform risk analysis?',' ','NOTE: The results will only be stored to disk and will not be displayed.');
                     answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                           DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                        end;
                        %
                        % make sure that the prediction event length does not exceed the maximum prediction horizon
                        %
                        for i=1:DSGEModel.n;
                           if DSGEModel.PredictionEvent(i,3)>MaxPH;
                              DSGEModel.PredictionEvent(i,3) = MaxPH;
                           end;
                        end;
                        %
                        % display a dialog for setting up an prediction event
                        %
                        [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                        if strcmp(lower(action),'ok')==1;
                           DSGEModel.PredictionEvent = PredictionEvent;
                           DSGEModel.RunPredictionEvent = 1;
                        else;
                           DSGEModel.RunPredictionEvent = 0;
                        end;
                     else;
                        DSGEModel.RunPredictionEvent = 0;
                     end;
                     %
                     % we can now compute the predictive distribution for the endogenous variables
                     % up to period MaxPH
                     %
                     tic;
                     [DoneCalc,PredEventData,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGEPredictionPaths(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,MaxPH,NumPredPaths,AnnualizeData,TransData,1,0,[]);
                  end;
                  clear('thetaDraws');
                  if DoneCalc==1;
                     %
                     % we can now compute the continuous ranked probability scores
                     %
                     CRPSMatrix = ComputeCRPSDSGEPaths(YData,PredictionVariables,NumPriorDraws,NumPredPaths,MaxPH,AnnualizeData,1,0,'','',DSGEModel,CurrINI);
                     CompTime = toc;
                     %
                     % check if the user wants to store the results to disk
                     %
                     txt = 'Would you like to save the continuous ranked probability score (CRPS) and energy score (ES) estimates to file?';
                     answer = Query(txt,'question',300,'CRPS - Prior Distribution',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                        file = FixFilePath([DSGEModel.OutputDirectory '\CRPS-Prior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' int2str(MaxPH) '-' int2str(NumPriorDraws) '.' int2str(NumPredPaths) '-' SmpStr '.mat']);
                        YNames = DSGEModel.VariableNames;
                        save(file,'YNames','PredictionVariables','CRPSMatrix','PredDateVector');
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\CRPSPrior_' DSGEModel.NameOfModel '_' int2str(SelectedYData) '_' int2str(MaxPH) '_' int2str(NumPriorDraws) 'x' int2str(NumPredPaths) '_' strrep(SmpStr,'.','_') '.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% Selected group of joint prediction variables\n%%\n');
                        fprintf(fid,'PredictionVariables = DataStructure.PredictionVariables;\n');
                        fprintf(fid,'%%\n%% n+1 x h matrix with the individual variable CRPS and the joint energy score\n%% for each forecast horizon.\n%%\n');
                        fprintf(fid,'CRPSMatrix = DataStructure.CRPSMatrix;\n');
                        fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                        fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        %
                        txt = ['The continuous probability score (CRPS) estimates and the energy scores for the jointly predicted variables based on the prior draws have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 4 entries: YNames (string matrix with the names of the observed variables), PredictionVariables (vector with integer values for the jointly predicted variables), CRPSMatrix (matrix with the individual variable CRPS values and the joint energy score for each forecast horizon), and PredDateVector (vector with dates for the forecast horizon). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','CRPS - Prior Distribution',500,600,CurrINI);
                     end;
                     %
                     % write the results to a text file
                     %
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\CRPS-Prior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' int2str(MaxPH) '-' int2str(NumPriorDraws) '.' int2str(NumPredPaths) '-' SmpStr '.txt']);
                     PrintCRPS(ResFile,'DSGE',PredictionVariables,PredictionSampleStrMat,YDataStr(SelectedYData,:),CRPSMatrix,AnnualizeData,0,0,0,0,NumPriorDraws,[],NumPriorDraws,NumPredPaths,[],CompTime,DSGEModel,CurrINI);
                     %
                     % check if file exists and display it then
                     %
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['CRPS & ES - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Prior Distribution',50,CurrINI,1,0);
                     end;
                  else;
                     CompTime = toc;
                  end;
               elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                  clear('thetaDraws');
                  txt = 'You didn''t select any variables to predict when computing the continuous ranked probability score. YADA is therefore unable to help you!';
                  About(txt,'information','CRPS - Prior Distribution',150,500,CurrINI);
               else;
                  DSGEModel = OldDSGEModel;
               end;
            else;
               DSGEModel = OldDSGEModel;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconCRPSPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         %
         if isempty(ErrorStr)==1;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','CRPS - Posterior Distribution','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            %
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  clear('LogPost','AcceptedDraws','PostSample');
                  [NumPostDraws,NumParam] = size(thetaPostSample);
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumPostDraws,:);
                  NumDraws = NumPostDraws-NumBurnin;
                  %
                  % check if the user wishes a sub-sample
                  %
                  txt = 'Would you like to use a sub-sample of the posterior draws when estimating the continuous ranked probability score (CRPS)?';
                  answer = Query(txt,'question',400,'CRPS - Posterior Distribution',500,'no',CurrINI);
                  if (DSGEModel.PosteriorSampler<=7)|(DSGEModel.PosteriorSampler==9);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        NumDraws = length(UseDraws);
                     end;
                  else;
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = WeightBasedPosteriorDraws(DSGEModel,CurrINI,'CRPS - Posterior Distribution',Weights,[]);
                        if isempty(UseDraws)==1;
                           set(controls.about,'UserData',0);
                           return;
                        end;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        Weights = Weights(UseDraws,1);
                        Weights = Weights*length(Weights)/sum(Weights);
                        NumDraws = length(UseDraws);
                     end;
                  end;
                  %
                  % determine how many prediction paths to use
                  %
                  NumPredPathsStr = get(controls.forecast.predpaths,'String');
                  NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
                  UsePaths = 1;
                  if NumPredPaths*NumDraws>100000;
                     txt = ['The total number of paths that the CRPS calculations will use is equal ' int2str(NumPredPaths*NumDraws) ' and it may take a very long time to finish them. Are you sure you wish to continue?'];
                     answer = Query(txt,'question',400,'CRPS - Posterior Distribution',500,'no',CurrINI);
                     if strcmp(lower(answer),'no')==1;
                        UsePaths = 0;
                     end;
                  end;
                  %
                  % check if we should continue
                  %
                  if UsePaths==1;
                     %
                     % collect some required data
                     %
                     theta = ModeData.thetaMode;
                     thetaPositions = ModeData.thetaPositions;
                     thetaIndex = ModeData.thetaIndex;
                     thetaDist = ModeData.thetaDist;
                     PriorDist = ModeData.PriorDist;
                     LowerBound = ModeData.LowerBound;
                     UniformBounds = ModeData.UniformBounds;
                     ModelParameters = ModeData.ModelParameters;
                     %
                     [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
                     DSGEModel.FirstPeriod = FirstPeriod;
                     DSGEModel.LastPeriod = LastPeriod;
                     %
                     % check how many time periods to use for predictive distributions
                     %
                     MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
                     %
                     % check the maximum when we take NaNs into account
                     %
                     YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
                     BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
                     if isempty(DSGEModel.Actuals)==1;
                        SelectedYData = 1;
                        DataAction = 'ok';
                        YDataStr = 'Actuals from original sample';
                     else;
                        YDataStr = 'Actuals from original sample';
                        m = length(DSGEModel.Actuals);
                        for i=1:m;
                           YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
                        end;
                        [DataAction,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','CRPS - Posterior Distribution','','',CurrINI);
                        if (strcmp(lower(DataAction),'ok')==1)&(SelectedYData>1);
                           YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                           BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
                        end;
                     end;
                  else;
                     DataAction = 'cancel';
                  end;
                  %
                  if strcmp(lower(DataAction),'ok')==1;
                     MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
                     [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
                     MaxFH = min(MaxFH,MaxPH);
                     YData = YData(:,1:MaxFH);
                     %
                     % matrix with exogenous variables
                     %
                     X = [];
                     if DSGEModel.k>0;
                        if NumPredX<MaxPH;
                           X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                        end;
                        if NumPredX>0;
                           X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxPH))];
                        end;
                     end;
                     %
                     % selection of variable 
                     %
                     if isempty(DSGEModel.PredictionVariables)==1;
                        PredictionVariables = ones(1,DSGEModel.n);
                        PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
                     else;
                        PredictionVariables = DSGEModel.PredictionVariables;
                     end;
                     %
                     [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
                     if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                        DSGEModel.PredictionVariables = PredictionVariables;
                        %
                        % Determine the prediction sample
                        %
                        SampleStrMat = CreateFullSample(DSGEModel);
                        PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                        SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                        %
                        if gcbo==controls.predict.unconditional.original.crps.posterior;
                           TransData = 0;
                           AnnualizeData = 0;
                           AnnualStr = 'original';
                           QueryHead = 'Predictive Distributions (CRPS) - Original Data';
                        elseif gcbo==controls.predict.unconditional.annual.crps.posterior;
                           TransData = 0;
                           AnnualizeData = 1;
                           AnnualStr = 'annual';
                           QueryHead = 'Predictive Distributions (CRPS) - Annualized Data';
                        end;
                        if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','','',DSGEModel.NameOfModel,MaxPH,NumDraws,NumPredPaths,AnnualizeData,TransData,CurrChain,1)==1;
                           txt = 'YADA has located results for the predictive distribution on disk. Would you like to use these results?';
                           answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                        else;
                           answer = 'No';
                        end;
                        %
                        % check if we shall recompute
                        %
                        if strcmp(lower(answer),'yes')==1;
                           DoneCalc = 1;
                           tic;
                        else;
                           %
                           % ask if we should conduct prediction event calculations
                           %
                           txt = strvcat('Would you like YADA to calculate prediction event probabilities and perform risk analysis?',' ','NOTE: The results will only be stored to disk and will not be displayed.');
                           answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
                           if strcmp(lower(answer),'yes')==1;
                              if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                                 DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                              end;
                              %
                              % make sure that the prediction event length does not exceed the maximum prediction horizon
                              %
                              for i=1:DSGEModel.n;
                                 if DSGEModel.PredictionEvent(i,3)>MaxPH;
                                    DSGEModel.PredictionEvent(i,3) = MaxPH;
                                 end;
                              end;
                              %
                              % display a dialog for setting up an prediction event
                              %
                              [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                              if strcmp(lower(action),'ok')==1;
                                 DSGEModel.PredictionEvent = PredictionEvent;
                                 DSGEModel.RunPredictionEvent = 1;
                              else;
                                 DSGEModel.RunPredictionEvent = 0;
                              end;
                           else;
                              DSGEModel.RunPredictionEvent = 0;
                           end;
                           %
                           % we can now compute the predictive distribution for the endogenous variables
                           % up to period MaxPH
                           %
                           tic;
                           [DoneCalc,PredEventData,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGEPredictionPaths(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights);
                        end;
                        clear('thetaPostSample');
                        if DoneCalc==1;
                           %
                           % we can now compute the continuous ranked probability scores
                           %
                           CRPSMatrix = ComputeCRPSDSGEPaths(YData,PredictionVariables,NumDraws,NumPredPaths,MaxPH,AnnualizeData,CurrChain,1,'','',DSGEModel,CurrINI);
                           CompTime = toc;
                           %
                           % check if the user wants to store the results to disk
                           %
                           txt = 'Would you like to save the continuous ranked probability score (CRPS) and energy score (ES) estimates to file?';
                           answer = Query(txt,'question',300,'CRPS - Posterior Distribution',500,'no',CurrINI);
                           if strcmp(lower(answer),'yes')==1;
                              [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                              file = FixFilePath([DSGEModel.OutputDirectory '\CRPS-Posterior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '.' int2str(AnnualizeData) '-' int2str(CurrChain) '-' int2str(MaxPH) '-' int2str(NumDraws) '.' int2str(NumPredPaths) '-' SmpStr '.mat']);
                              YNames = DSGEModel.VariableNames;
                              save(file,'YNames','PredictionVariables','CRPSMatrix','PredDateVector');
                              mfile = FixFilePath([DSGEModel.OutputDirectory '\CRPSPosterior_' DSGEModel.NameOfModel '_' int2str(SelectedYData) '_' int2str(AnnualizeData) '_' int2str(CurrChain) '_' int2str(MaxPH) '_' int2str(NumDraws) 'x' int2str(NumPredPaths) '_' strrep(SmpStr,'.','_') '.m']);
                              fid = fopen(mfile,'wt');
                              fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                              fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                              fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                              fprintf(fid,'YNames = DataStructure.YNames;\n');
                              fprintf(fid,'%%\n%% Selected group of joint prediction variables\n%%\n');
                              fprintf(fid,'PredictionVariables = DataStructure.PredictionVariables;\n');
                              fprintf(fid,'%%\n%% n+1 x h matrix with the individual variable CRPS and the joint energy score\n%% for each forecast horizon.\n%%\n');
                              fprintf(fid,'CRPSMatrix = DataStructure.CRPSMatrix;\n');
                              fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                              fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                              fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                              %
                              % end the script file
                              %
                              fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                              fclose(fid);
                              %
                              txt = ['The continuous probability score (CRPS) estimates and the energy scores for the jointly predicted variables based on the posterior draws have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 4 entries: YNames (string matrix with the names of the observed variables), PredictionVariables (vector with integer values for the jointly predicted variables), CRPSMatrix (matrix with the individual variable CRPS values and the joint energy score for each forecast horizon), and PredDateVector (vector with dates for the forecast horizon). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                              About(txt,'information','CRPS - Posterior Distribution',500,600,CurrINI);
                           end;
                           %
                           % write the results to a text file
                           %
                           ResFile = FixFilePath([DSGEModel.OutputDirectory '\CRPS-Posterior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '.' int2str(AnnualizeData) '-' int2str(CurrChain) '-' int2str(MaxPH) '-' int2str(NumDraws) '.' int2str(NumPredPaths) '-' SmpStr '.txt']);
                           PrintCRPS(ResFile,'DSGE',PredictionVariables,PredictionSampleStrMat,YDataStr(SelectedYData,:),CRPSMatrix,AnnualizeData,1,0,0,0,NumDraws,NumBurnin,NumPostDraws,NumPredPaths,[],CompTime,DSGEModel,CurrINI);
                           %
                           % check if file exists and display it then
                           %
                           if FileExist(ResFile)==1;
                              TextGUI(ResFile,['CRPS & ES - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution',50,CurrINI,1,0);
                           end;
                        else;
                           CompTime = toc;
                        end;
                     elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                        clear('thetaPostSample');
                        txt = 'You didn''t select any variables to predict when computing the continuous ranked probability score. YADA is therefore unable to help you!';
                        About(txt,'information','CRPS - Posterior Distribution',150,500,CurrINI);
                     end;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ConCRPSPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,'CRPS - Prior Distribution',500,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
                  UniformBounds = ModeData.UniformBounds;
                  thetaIndex = ModeData.thetaIndex;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         if InitStatus==1;
            %
            % load the prior draws data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the prior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection','CRPS - Prior Distribution','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            clear('PriorData');%
            % determine how many prediction paths to use
            %
            NumPredPathsStr = get(controls.forecast.predpaths,'String');
            NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
            UsePaths = 1;
            if NumPredPaths*NumPriorDraws>=100000;
               txt = ['The total number of paths that the CRPS calculations will use is equal ' int2str(NumPredPaths*NumPriorDraws) ' and it may take a very long time to finish them. Are you sure you wish to continue?'];
               answer = Query(txt,'question',400,'CRPS - Prior Distribution',500,'no',CurrINI);
               if strcmp(lower(answer),'no')==1;
                  UsePaths = 0;
               end;
            end;
            %
            if UsePaths==1;
               %
               % determine the sample
               %
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
               DSGEModel.FirstPeriod = FirstPeriod;
               DSGEModel.LastPeriod = LastPeriod;
               %
               % check how many time periods to use for predictive distributions
               %
               MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
               %
               % check the maximum when we take NaNs into account
               %
               YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
               BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
               if isempty(DSGEModel.Actuals)==1;
                  SelectedYData = 1;
                  DataAction = 'ok';
                  YDataStr = 'Actuals from original sample';
               else;
                  YDataStr = 'Actuals from original sample';
                  m = length(DSGEModel.Actuals);
                  for i=1:m;
                     YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
                  end;
                  [DataAction,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','CRPS - Prior Distribution','','',CurrINI);
                  if (strcmp(lower(DataAction),'ok')==1)&(SelectedYData>1);
                     YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                     BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
                  end;
               end;
            else;
               DataAction = 'cancel';
            end;
            %
            if strcmp(lower(DataAction),'ok')==1;
               MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
               [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               MaxFH = min(MaxFH,MaxPH);
               YData = YData(:,1:MaxFH);
               %
               % matrix with exogenous variables
               %
               X = [];
               if DSGEModel.k>0;
                  if NumPredX<MaxPH;
                     X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                  end;
                  if NumPredX>0;
                     X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxPH))];
                  end;
               end;
               %
               % check the length of the conditioning sample
               %
               [status,NumPeriods] = CheckConditioningData(DSGEModel);
               %
               % check if we should adjust the X matrix
               %
               if MaxPH<NumPeriods;
                  NumPeriods = MaxPH;
               end;
               %
               % collect the conditional variables and the selected conditioning sample
               %
               Z = DSGEModel.Z(DSGEModel.ConditionalVariables,LastPeriod+1:LastPeriod+NumPeriods);
               if LastPeriod>=NumPeriods;
                  U = DSGEModel.U(DSGEModel.ConditionalVariables,LastPeriod-NumPeriods+1:LastPeriod);
               else;
                  %
                  % we have to create artifical initial conditions for the conditioning variables
                  %
                  U = [DSGEModel.U(DSGEModel.ConditionalVariables,1)*ones(1,NumPeriods-LastPeriod) DSGEModel.U(DSGEModel.ConditionalVariables,1:LastPeriod)];
               end;
               %
               % selection of variable 
               %
               if isempty(DSGEModel.PredictionVariables)==1;
                  PredictionVariables = ones(1,DSGEModel.n);
                  PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
               else;
                  PredictionVariables = DSGEModel.PredictionVariables;
               end;
               %
               [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
               if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                  %
                  % we may continue and store the new selection of prediction variables
                  %
                  DSGEModel.PredictionVariables = PredictionVariables;
                  %
                  % Determine the prediction sample
                  %
                  SampleStrMat = CreateFullSample(DSGEModel);
                  PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                  SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                  %
                  if gcbo==controls.predict.conditional.original.crps.prior;
                     TransData = 0;
                     AnnualizeData = 0;
                     AnnualStr = 'original';
                     QueryHead = 'Predictive Distributions For Prior (CRPS) - Original Data';
                  elseif gcbo==controls.predict.conditional.annual.crps.prior;
                     TransData = 0;
                     AnnualizeData = 1;
                     AnnualStr = 'annual';
                     QueryHead = 'Predictive Distributions For Prior (CRPS) - Annualized Data';
                  end;
                  %
                  % check which method is used for dealing with the conditioning assumptions
                  %
                  if DSGEModel.ShockControlMethod==1;
                     ShockMethod = 'Direct-';
                  elseif DSGEModel.ShockControlMethod==2;
                     ShockMethod = 'WaggonerZha-';
                  else;
                     ShockMethod = 'Subset-';
                  end;
                  %
                  % check if prediction paths already exist
                  %
                  if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumPriorDraws,NumPredPaths,AnnualizeData,TransData,1,0)==1;
                     txt = 'YADA has located results for the predictive distribution on disk. Would you like to use these results?';
                     answer = Query(txt,'question',150,QueryHead,500,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  %
                  % check if we shall recompute
                  %
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                     tic;
                  else;
                     %
                     % ask if we should conduct prediction event calculations
                     %
                     txt = strvcat('Would you like YADA to calculate prediction event probabilities and perform risk analysis?',' ','NOTE: The results will only be stored to disk and will not be displayed.');
                     answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                           DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                        end;
                        %
                        % make sure that the prediction event length does not exceed the maximum prediction horizon
                        %
                        for i=1:DSGEModel.n;
                           if DSGEModel.PredictionEvent(i,3)>MaxPH;
                              DSGEModel.PredictionEvent(i,3) = MaxPH;
                           end;
                        end;
                        %
                        % display a dialog for setting up an prediction event
                        %
                        [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                        if strcmp(lower(action),'ok')==1;
                           DSGEModel.PredictionEvent = PredictionEvent;
                           DSGEModel.RunPredictionEvent = 1;
                        else;
                           DSGEModel.RunPredictionEvent = 0;
                        end;
                     else;
                        DSGEModel.RunPredictionEvent = 0;
                     end;
                     %
                     % we can now compute the predictive distribution for the endogenous variables
                     % up to period MaxPH
                     %
                     tic;
                     %
                     % we can now compute the predictive distribution for the endogenous variables
                     % up to period MaxPH
                     %
                     if DSGEModel.ShockControlMethod==1;
                        [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPaths(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,1,0,[]);
                     elseif DSGEModel.ShockControlMethod==2;
                        [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsWZ(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,1,0,[]);
                     else;
                        %
                        % check if the selected method can actually be used
                        %
                        CondTxt = '';
                        if isempty(DSGEModel.MixedConditionalShocks)==1;
                           CondTxt = 'You haven''t selected any shocks for use which the distribution of a subset of the shocks conditioning method.';
                        elseif length(DSGEModel.MixedConditionalShocks)<length(DSGEModel.ConditionalVariables);
                           CondTxt = ['The number of shocks you have selected to use to ensure that the conditioning assumptions are satisfied under the distribution of a subset of the shocks conditioning method is not sufficient. You need at least ' int2str(length(DSGEModel.ConditionalVariables)) ' such shocks.'];
                        end;
                        if isempty(CondTxt)==1;
                           [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsMixed(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,1,0,[]);
                        else;
                           About(CondTxt,'information','Bad Shocks Selection - Distribution of Subset Shocks Method',300,550,CurrINI);
                           DoneCalc = 0;
                        end;
                     end;
                  end;
                  clear('thetaDraws');
                  if DoneCalc==1;
                     %
                     % we can now compute the continuous ranked probability scores
                     %
                     CRPSMatrix = ComputeCRPSDSGEPaths(YData,PredictionVariables,NumPriorDraws,NumPredPaths,MaxPH,AnnualizeData,1,0,'Cond',ShockMethod,DSGEModel,CurrINI);
                     CompTime = toc;
                     %
                     % check if the user wants to store the results to disk
                     %
                     txt = 'Would you like to save the continuous ranked probability score (CRPS) and energy score (ES) estimates to file?';
                     answer = Query(txt,'question',300,'CRPS - Prior Distribution',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                        file = FixFilePath([DSGEModel.OutputDirectory '\CRPS-Conditional-' ShockMethod 'Prior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' int2str(MaxPH) '-' int2str(NumPriorDraws) '.' int2str(NumPredPaths) '-' SmpStr '.mat']);
                        YNames = DSGEModel.VariableNames;
                        save(file,'YNames','PredictionVariables','CRPSMatrix','PredDateVector');
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\CRPSCond' strrep(ShockMethod,'-','_') 'Prior_' DSGEModel.NameOfModel '_' int2str(SelectedYData) '_' int2str(MaxPH) '_' int2str(NumPriorDraws) 'x' int2str(NumPredPaths) '_' strrep(SmpStr,'.','_') '.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% Selected group of joint prediction variables\n%%\n');
                        fprintf(fid,'PredictionVariables = DataStructure.PredictionVariables;\n');
                        fprintf(fid,'%%\n%% n+1 x h matrix with the individual variable CRPS and the joint energy score\n%%\n for each forecast horizon.\n%%\n');
                        fprintf(fid,'CRPSMatrix = DataStructure.CRPSMatrix;\n');
                        fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                        fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        %
                        txt = ['The continuous probability score (CRPS) estimates and the energy scores for the jointly predicted variables based on the prior draws have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 4 entries: YNames (string matrix with the names of the observed variables), PredictionVariables (vector with integer values for the jointly predicted variables), CRPSMatrix (matrix with the individual variable CRPS values and the joint energy score for each forecast horizon), and PredDateVector (vector with dates for the forecast horizon). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','CRPS - Prior Distribution',500,600,CurrINI);
                     end;
                     %
                     % write the results to a text file
                     %
                     ResFile = FixFilePath([DSGEModel.OutputDirectory '\CRPS-Conditional-' ShockMethod 'Prior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '-' int2str(MaxPH) '-' int2str(NumPriorDraws) '.' int2str(NumPredPaths) '-' SmpStr '.txt']);
                     PrintCRPS(ResFile,'DSGE',PredictionVariables,PredictionSampleStrMat,YDataStr(SelectedYData,:),CRPSMatrix,AnnualizeData,0,1,0,0,NumPriorDraws,[],NumPriorDraws,NumPredPaths,[],CompTime,DSGEModel,CurrINI);
                     %
                     % check if file exists and display it then
                     %
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['CRPS & ES - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Prior Distribution',50,CurrINI,1,0);
                     end;
                  else;
                     CompTime = toc;
                  end;
               elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                  clear('thetaDraws');
                  txt = 'You didn''t select any variables to predict when computing the continuous ranked probability score. YADA is therefore unable to help you!';
                  About(txt,'information','CRPS - Prior Distribution',150,500,CurrINI);
               else;
                  DSGEModel = OldDSGEModel;
               end;
            else;
               DSGEModel = OldDSGEModel;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ConCRPSPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         %
         if strcmp(ErrorStr,'')==1;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','CRPS - Posterior Distribution','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            %
            %
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  clear('LogPost','AcceptedDraws','PostSample');
                  [NumPostDraws,NumParam] = size(thetaPostSample);
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumPostDraws,:);
                  NumDraws = NumPostDraws-NumBurnin;
                  %
                  % check if the user wishes a sub-sample
                  %
                  txt = 'Would you like to use a sub-sample of the posterior draws when estimating the continuous ranked probability score (CRPS)?';
                  answer = Query(txt,'question',400,'CRPS - Posterior Distribution',500,'no',CurrINI);
                  if (DSGEModel.PosteriorSampler<=7)|(DSGEModel.PosteriorSampler==9);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        NumDraws = length(UseDraws);
                     end;
                  else;
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = WeightBasedPosteriorDraws(DSGEModel,CurrINI,'CRPS - Posterior Distribution',Weights,[]);
                        if isempty(UseDraws)==1;
                           set(controls.about,'UserData',0);
                           return;
                        end;
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        Weights = Weights(UseDraws,1);
                        Weights = Weights*length(Weights)/sum(Weights);
                        NumDraws = length(UseDraws);
                     end;
                  end;
                  %
                  % determine how many prediction paths to use
                  %
                  NumPredPathsStr = get(controls.forecast.predpaths,'String');
                  NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
                  UsePaths = 1;
                  if NumPredPaths*NumDraws>100000;
                     txt = ['The total number of paths that the CRPS calculations will use is equal ' int2str(NumPredPaths*NumDraws) ' and it may take a very long time to finish them. Are you sure you wish to continue?'];
                     answer = Query(txt,'question',400,'CRPS - Posterior Distribution',500,'no',CurrINI);
                     if strcmp(lower(answer),'no')==1;
                        UsePaths = 0;
                     end;
                  end;
                  %
                  % check if we should continue
                  %
                  if UsePaths==1;
                     %
                     % collect some required data
                     %
                     theta = ModeData.thetaMode;
                     thetaPositions = ModeData.thetaPositions;
                     thetaIndex = ModeData.thetaIndex;
                     thetaDist = ModeData.thetaDist;
                     PriorDist = ModeData.PriorDist;
                     LowerBound = ModeData.LowerBound;
                     UniformBounds = ModeData.UniformBounds;
                     ModelParameters = ModeData.ModelParameters;
                     %
                     [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
                     DSGEModel.FirstPeriod = FirstPeriod;
                     DSGEModel.LastPeriod = LastPeriod;
                     %
                     % check how many time periods to use for predictive distributions
                     %
                     MaxFH = CalcMaxForecastHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod);
                     %
                     % check the maximum when we take NaNs into account
                     %
                     YData = DSGEModel.Y(:,LastPeriod+1:LastPeriod+MaxFH);
                     BackYData = DSGEModel.Y(:,LastPeriod-1:LastPeriod);
                     if isempty(DSGEModel.Actuals)==1;
                        SelectedYData = 1;
                        DataAction = 'ok';
                        YDataStr = 'Actuals from original sample';
                     else;
                        YDataStr = 'Actuals from original sample';
                        m = length(DSGEModel.Actuals);
                        for i=1:m;
                           YDataStr = strvcat(YDataStr,DSGEModel.Actuals(i).title);
                        end;
                        [DataAction,SelectedYData] = SelectionDlg(YDataStr,1,'Select the actuals dataset to use','Data Selection','CRPS - Posterior Distribution','','',CurrINI);
                        if (strcmp(lower(DataAction),'ok')==1)&(SelectedYData>1);
                           YData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod+1:LastPeriod+MaxFH);
                           BackYData = DSGEModel.Actuals(SelectedYData-1).data(:,LastPeriod-1:LastPeriod);
                        end;
                     end;
                  else;
                     DataAction = 'cancel';
                  end;
                  %
                  if strcmp(lower(DataAction),'ok')==1;
                     MaxFH = max((sum(~isnan(YData),1)>0).*(1:MaxFH));
                     [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
                     MaxFH = min(MaxFH,MaxPH);
                     YData = YData(:,1:MaxFH);
                     %
                     % matrix with exogenous variables
                     %
                     X = [];
                     if DSGEModel.k>0;
                        if NumPredX<MaxPH;
                           X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                        end;
                        if NumPredX>0;
                           X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxPH))];
                        end;
                     end;
                     %
                     % check the length of the conditioning sample
                     %
                     [status,NumPeriods] = CheckConditioningData(DSGEModel);
                     %
                     % check if we should adjust the X matrix
                     %
                     if MaxPH<NumPeriods;
                        NumPeriods = MaxPH;
                     end;
                     %
                     % collect the conditional variables and the selected conditioning sample
                     %
                     Z = DSGEModel.Z(DSGEModel.ConditionalVariables,LastPeriod+1:LastPeriod+NumPeriods);
                     if LastPeriod>=NumPeriods;
                        U = DSGEModel.U(DSGEModel.ConditionalVariables,LastPeriod-NumPeriods+1:LastPeriod);
                     else;
                        %
                        % we have to create artifical initial conditions for the conditioning variables
                        %
                        U = [DSGEModel.U(DSGEModel.ConditionalVariables,1)*ones(1,NumPeriods-LastPeriod) DSGEModel.U(DSGEModel.ConditionalVariables,1:LastPeriod)];
                     end;
                     %
                     % selection of variable 
                     %
                     if isempty(DSGEModel.PredictionVariables)==1;
                        PredictionVariables = ones(1,DSGEModel.n);
                        PredictionVariables = PredictionVariables .* (1:DSGEModel.n);
                     else;
                        PredictionVariables = DSGEModel.PredictionVariables;
                     end;
                     %
                     [Action,PredictionVariables] = SelectCondVarShockDLG('init','Prediction Variables','',DSGEModel.VariableNames,PredictionVariables,CurrINI);
                     if (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==0);
                        DSGEModel.PredictionVariables = PredictionVariables;
                        %
                        % Determine the prediction sample
                        %
                        SampleStrMat = CreateFullSample(DSGEModel);
                        PredictionSampleStrMat = SampleStrMat(LastPeriod+1:LastPeriod+MaxFH,:);
                        SmpStr = [strrep(PredictionSampleStrMat(1,:),':','.') '.' strrep(PredictionSampleStrMat(MaxFH,:),':','.')];
                        %                        %
                        if gcbo==controls.predict.conditional.original.crps.posterior;
                           TransData = 0;
                           AnnualizeData = 0;
                           AnnualStr = 'original';
                           QueryHead = 'Predictive Distributions (CRPS) - Original Data';
                        elseif gcbo==controls.predict.conditional.annual.crps.posterior;
                           TransData = 0;
                           AnnualizeData = 1;
                           AnnualStr = 'annual';
                           QueryHead = 'Predictive Distributions (CRPS) - Annualized Data';
                        end;
                        %
                        % check which method is used for dealing with the conditioning assumptions
                        %
                        if DSGEModel.ShockControlMethod==1;
                           ShockMethod = 'Direct-';
                        elseif DSGEModel.ShockControlMethod==2;
                           ShockMethod = 'WaggonerZha-';
                        else;
                           ShockMethod = 'Subset-';
                        end;
                        %
                        % check if prediction paths already exist
                        %
                        if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumDraws,NumPredPaths,AnnualizeData,TransData,CurrChain,1)==1;
                           txt = 'YADA has located results for the predictive distribution on disk. Would you like to use these results?';
                           answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                        else;
                           answer = 'No';
                        end;
                        %
                        % check if we shall recompute
                        %
                        if strcmp(lower(answer),'yes')==1;
                           DoneCalc = 1;
                           tic;
                        else;
                           %
                           % ask if we should conduct prediction event calculations
                           %
                           txt = strvcat('Would you like YADA to calculate prediction event probabilities and perform risk analysis?',' ','NOTE: The results will only be stored to disk and will not be displayed.');
                           answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
                           if strcmp(lower(answer),'yes')==1;
                              if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                                 DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                              end;
                              %
                              % make sure that the prediction event length does not exceed the maximum prediction horizon
                              %
                              for i=1:DSGEModel.n;
                                 if DSGEModel.PredictionEvent(i,3)>MaxPH;
                                    DSGEModel.PredictionEvent(i,3) = MaxPH;
                                 end;
                              end;
                              %
                              % display a dialog for setting up an prediction event
                              %
                              [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                              if strcmp(lower(action),'ok')==1;
                                 DSGEModel.PredictionEvent = PredictionEvent;
                                 DSGEModel.RunPredictionEvent = 1;
                              else;
                                 DSGEModel.RunPredictionEvent = 0;
                              end;
                           else;
                              DSGEModel.RunPredictionEvent = 0;
                           end;
                           %
                           % we can now compute the predictive distribution for the endogenous variables
                           % up to period MaxPH
                           %
                           tic;
                           %
                           % we can now compute the predictive distribution for the endogenous variables
                           % up to period MaxPH
                           %
                           if DSGEModel.ShockControlMethod==1;
                              [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPaths(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights);
                           elseif DSGEModel.ShockControlMethod==2;
                              [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsWZ(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights);
                           else;
                              %
                              % check if the selected method can actually be used
                              %
                              CondTxt = '';
                              if isempty(DSGEModel.MixedConditionalShocks)==1;
                                 CondTxt = 'You haven''t selected any shocks for use which the distribution of a subset of the shocks conditioning method.';
                              elseif length(DSGEModel.MixedConditionalShocks)<length(DSGEModel.ConditionalVariables);
                                 CondTxt = ['The number of shocks you have selected to use to ensure that the conditioning assumptions are satisfied under the distribution of a subset of the shocks conditioning method is not sufficient. You need at least ' int2str(length(DSGEModel.ConditionalVariables)) ' such shocks.'];
                              end;
                              if isempty(CondTxt)==1;
                                 [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsMixed(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights);
                              else;
                                 About(CondTxt,'information','Bad Shocks Selection - Distribution of Subset Shocks Method',300,550,CurrINI);
                                 DoneCalc = 0;
                              end;
                           end;
                        end;
                        clear('thetaPostSample');
                        if DoneCalc==1;
                           %
                           % we can now compute the continuous ranked probability scores
                           %
                           CRPSMatrix = ComputeCRPSDSGEPaths(YData,PredictionVariables,NumDraws,NumPredPaths,MaxPH,AnnualizeData,CurrChain,1,'Cond',ShockMethod,DSGEModel,CurrINI);
                           CompTime = toc;
                           %
                           % check if the user wants to store the results to disk
                           %
                           txt = 'Would you like to save the continuous ranked probability score (CRPS) and energy score (ES) estimates to file?';
                           answer = Query(txt,'question',300,'CRPS - Posterior Distribution',500,'no',CurrINI);
                           if strcmp(lower(answer),'yes')==1;
                              [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                              file = FixFilePath([DSGEModel.OutputDirectory '\CRPS-Conditional-' ShockMethod 'Posterior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '.' int2str(AnnualizeData) '-' int2str(CurrChain) '-' int2str(MaxPH) '-' int2str(NumDraws) '.' int2str(NumPredPaths) '-' SmpStr '.mat']);
                              YNames = DSGEModel.VariableNames;
                              save(file,'YNames','PredictionVariables','CRPSMatrix','PredDateVector');
                              mfile = FixFilePath([DSGEModel.OutputDirectory '\CRPSCond' strrep(ShockMethod,'-','_') 'Posterior_' DSGEModel.NameOfModel '_' int2str(SelectedYData) '_' int2str(AnnualizeData) '_' int2str(CurrChain) '_' int2str(MaxPH) '_' int2str(NumDraws) 'x' int2str(NumPredPaths) '_' strrep(SmpStr,'.','_') '.m']);
                              fid = fopen(mfile,'wt');
                              fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                              fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                              fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                              fprintf(fid,'YNames = DataStructure.YNames;\n');
                              fprintf(fid,'%%\n%% Selected group of joint prediction variables\n%%\n');
                              fprintf(fid,'PredictionVariables = DataStructure.PredictionVariables;\n');
                              fprintf(fid,'%%\n%% n+1 x h matrix with the individual variable CRPS and the joint energy score\n%%\n for each forecast horizon.\n%%\n');
                              fprintf(fid,'CRPSMatrix = DataStructure.CRPSMatrix;\n');
                              fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                              fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                              fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                              %
                              % end the script file
                              %
                              fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                              fclose(fid);
                              %
                              txt = ['The continuous probability score (CRPS) estimates and the energy scores for the jointly predicted variables based on the posterior draws have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 4 entries: YNames (string matrix with the names of the observed variables), PredictionVariables (vector with integer values for the jointly predicted variables), CRPSMatrix (matrix with the individual variable CRPS values and the joint energy score for each forecast horizon), and PredDateVector (vector with dates for the forecast horizon). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                              About(txt,'information','CRPS - Posterior Distribution',500,600,CurrINI);
                           end;
                           %
                           % write the results to a text file
                           %
                           ResFile = FixFilePath([DSGEModel.OutputDirectory '\CRPS-Conditional-' ShockMethod 'Posterior-' DSGEModel.NameOfModel '-' int2str(SelectedYData) '.' int2str(AnnualizeData) '-' int2str(CurrChain) '-' int2str(MaxPH) '-' int2str(NumDraws) '.' int2str(NumPredPaths) '-' SmpStr '.txt']);
                           PrintCRPS(ResFile,'DSGE',PredictionVariables,PredictionSampleStrMat,YDataStr(SelectedYData,:),CRPSMatrix,AnnualizeData,1,1,0,0,NumDraws,NumBurnin,NumPostDraws,NumPredPaths,[],CompTime,DSGEModel,CurrINI);
                           %
                           % check if file exists and display it then
                           %
                           if FileExist(ResFile)==1;
                              TextGUI(ResFile,['CRPS & ES - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution',50,CurrINI,1,0);
                           end;
                        else;
                           CompTime = toc;
                        end;
                     elseif (strcmp(lower(Action),'ok')==1)&(isempty(PredictionVariables)==1);
                        clear('thetaPostSample');
                        txt = 'You didn''t select any variables to predict when computing the continuous ranked probability score. YADA is therefore unable to help you!';
                        About(txt,'information','CRPS - Posterior Distribution',150,500,CurrINI);
                     end;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconStationaryPredVariancePriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check if the posterior mode file exists
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            ErrorStr = '';
            if MatlabNumber>=8.0;
               try;
                  ModeData = load(ModeFile);
               catch ME;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
               end;
            else;
               try;
                  ModeData = load(ModeFile);
               catch;
                  ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
               end;
            end;
            if strcmp(ErrorStr,'')==1;
               if FileExist(DSGEModel.PriorFile)==1;
                  txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                  answer = Query(txt,'question',200,'Stationary Predictive Variance - Prior Distribution',500,'no',CurrINI);
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  InitStatus = 1;
                  theta = ModeData.theta;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  ParameterNames = ModeData.ParameterNames;
                  LowerBound = ModeData.LowerBound;
                  ModelParameters = ModeData.ModelParameters;
                  thetaPositions = ModeData.thetaPositions;
                  UniformBounds = ModeData.UniformBounds;
                  thetaIndex = ModeData.thetaIndex;
               else;
                  [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
               end;
            else;
               InitStatus = 0;
               About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
            end;
         else;
            [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
         end;
         %
         if InitStatus==1;
            %
            % load the prior draws data
            %
            if FileExist(DSGEModel.SystemPriorFile)==0;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
            else;
               PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
            end;
            PriorData = load(PriorDrawsFile);
            thetaDraws = PriorData.thetaDraws;
            NumPriorDraws = size(thetaDraws,2);
            %
            % check if we have a system prior and if so, use a subset of the prior draws
            %
            OldDSGEModel = DSGEModel;
            if FileExist(DSGEModel.SystemPriorFile)==1;
               if DSGEModel.PosteriorSampler>7;
                  [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection','Stationary Predictive Variance - Prior Distribution','','',CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PostDrawsPercentValue = SelectedOption;
                  end;
               else;
                  action = 'ok';
               end;
               if strcmp(lower(action),'ok')==1;
                  UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                  if length(UseDraws)<NumPriorDraws;
                     thetaDraws = thetaDraws(:,UseDraws);
                     NumPriorDraws = length(UseDraws);
                  end;
               end;
            end;
            clear('PriorData');
            %
            [MaxFH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
            %
            % matrix with exogenous variables
            %
            X = [];
            if DSGEModel.k>0;
               if NumPredX<MaxFH;
                  X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
               end;
               if NumPredX>0;
                  X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
               end;
            end;
            %
            % check if older calculations exists given that such may be used
            %
            MatFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-StationaryPredictiveVariance-Prior-' DSGEModel.NameOfModel '-' int2str(MaxFH) '.' int2str(NumPriorDraws) '.mat']);
            if FileExist(MatFile)==1;
               txt = ['YADA has located posterior draws based estimates of the stationary predictive variances on disk. Would you like to use these results?'];
               answer = Query(txt,'question',200,'Stationary Predictive Variance - Posterior Distribution',500,'no',CurrINI);
            else;
               answer = 'No';
            end;
            % 
            tic;
            if strcmp(lower(answer),'yes')==1;
               DoneCalc = 1;
            else;
               DoneCalc = DSGEStationaryPredictiveVariance(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,MaxFH,NumPriorDraws,[],0,[]);
            end;
            CompTime = toc;
            clear('thetaDraws');
            if DoneCalc==1;
               %
               % load the results
               %
               SPC = load(MatFile);
               MeasureCov = SPC.MeasureCov;
               ShockCov = SPC.ShockCov;
               StateCov = SPC.StateCov;
               ParameterCov = SPC.ParameterCov;
               TotalCov = SPC.TotalCov;
               %
               % ask if the user wants to have easy access to the results
               %
               txt = ['The stationary predictive variances using the prior draws have been saved to the file "' GetFilename(MatFile) '" in the "' GetPath(MatFile) '" directory. Would you like YADA to write an m-file to give you direct access to these results?'];
               answer = Query(txt,'question',300,'Stationary Predictive Variance - Prior Distribution',600,'no',CurrINI);
               if strcmp(lower(answer),'yes')==1;
                  YNames = DSGEModel.VariableNames;
                  if isfield(SPC,'YNames')==0;
                     save(MatFile,'YNames','-APPEND');
                  end;
                  mfile = FixFilePath([DSGEModel.OutputDirectory '\' strrep(strrep(GetName(MatFile),'-',''),'.','') '.m']);
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(MatFile) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(MatFile));
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  fprintf(fid,'%%\n%% 3D matrix with the marginal prediction covariances \n%%\n');
                  fprintf(fid,'TotalCov = DataStructure.TotalCov;\n');
                  fprintf(fid,'%%\n%% 2D matrix with the part due to the measurement errors \n%%\n');
                  fprintf(fid,'MeasureCov = DataStructure.MeasureCov;\n');
                  fprintf(fid,'%%\n%% 3D matrix with the part due to the shock uncertainty \n%%\n');
                  fprintf(fid,'ShockCov = DataStructure.ShockCov;\n');
                  fprintf(fid,'%%\n%% 3D matrix with the part due to the state uncertainty \n%%\n');
                  fprintf(fid,'StateCov = DataStructure.StateCov;\n');
                  fprintf(fid,'%%\n%% 3D matrix with the part due to parameter uncertainty \n%%\n');
                  fprintf(fid,'ParameterCov = DataStructure.ParameterCov;\n');
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  %
                  txt = ['You can access the stationary predictive variances estimated from the prior distribution through the file: "' GetFilename(mfile) '", located in the "' GetPath(mfile) '" directory.'];
                  About(txt,'information','Stationary Predictive Variance - Prior Distribution',500,600,CurrINI);
               end;
               %
               % write to a text file
               %
               ResFile = strrep(MatFile,'.mat','.txt');
               PrintStationaryPredictiveVariance(ResFile,MeasureCov,ShockCov,StateCov,ParameterCov,TotalCov,[],NumPriorDraws,NumPriorDraws,0,0,CompTime,DSGEModel,CurrINI);
               if FileExist(ResFile)==1;
                  TextGUI(ResFile,['Stationary Predictive Variance - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Prior Distribution',50,CurrINI,1,0);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconStationaryPredVariancePosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if isempty(ErrorStr)==1;
            %
            % if there are multiple chains, check which one to use if necessary
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' int2str(i)]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Stationary Predictive Variance - Posterior Distribution','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  clear('LogPost','AcceptedDraws','PostSample');
                  [NumPostDraws,NumParam] = size(thetaPostSample);
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumPostDraws,:);
                  NumDraws = NumPostDraws-NumBurnin;
                  %
                  % check if the user wishes a sub-sample
                  %
                  if DSGEModel.PosteriorSampler<=7;
                     txt = 'Would you like to use a sub-sample of the posterior draws when estimating the marginal predictive moments?';
                     answer = Query(txt,'question',400,'Stationary Predictive Variance - Posterior Distribution',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % check which draws we should use
                        %
                        UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumDraws);
                        thetaPostSample = thetaPostSample(UseDraws,:);
                        NumDraws = length(UseDraws);
                     end;
                  end;
                  %
                  % collect some required data
                  %
                  theta = ModeData.thetaMode;
                  thetaPositions = ModeData.thetaPositions;
                  thetaIndex = ModeData.thetaIndex;
                  thetaDist = ModeData.thetaDist;
                  PriorDist = ModeData.PriorDist;
                  LowerBound = ModeData.LowerBound;
                  UniformBounds = ModeData.UniformBounds;
                  ModelParameters = ModeData.ModelParameters;
                  %
                  [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
                  DSGEModel.FirstPeriod = FirstPeriod;
                  DSGEModel.LastPeriod = LastPeriod;
                  %
                  [MaxFH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
                  %
                  % matrix with exogenous variables
                  %
                  X = [];
                  if DSGEModel.k>0;
                     if NumPredX<MaxFH;
                        X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxFH-NumPredX));
                     end;
                     if NumPredX>0;
                        X = [X DSGEModel.PredictedX(:,1:min(NumPredX,MaxFH))];
                     end;
                  end;
                  %
                  % check if older calculations exists given that such may be used
                  %
                  MatFile = FixFilePath([DSGEModel.OutputDirectory '\DSGE-StationaryPredictiveVariance-' DSGEModel.NameOfModel '-' int2str(CurrChain) '-' int2str(MaxFH) '.' int2str(NumDraws) '-' int2str(NumPostDraws) '.mat']);
                  if FileExist(MatFile)==1;
                     txt = ['YADA has located posterior draws based estimates of the stationary predictive variances on disk. Would you like to use these results?'];
                     answer = Query(txt,'question',200,'Stationary Predictive Variance - Posterior Distribution',500,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  % 
                  tic;
                  if strcmp(lower(answer),'yes')==1;
                     DoneCalc = 1;
                  else;
                     DoneCalc = DSGEStationaryPredictiveVariance(thetaPostSample,theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,MaxFH,NumPostDraws,CurrChain,1,Weights);
                  end;
                  CompTime = toc;
                  clear('thetaPostSample');
                  if DoneCalc==1;
                     %
                     % load the results
                     %
                     SPC = load(MatFile);
                     MeasureCov = SPC.MeasureCov;
                     ShockCov = SPC.ShockCov;
                     StateCov = SPC.StateCov;
                     ParameterCov = SPC.ParameterCov;
                     TotalCov = SPC.TotalCov;
                     %
                     % ask if the user wants to have easy access to the results
                     %
                     txt = ['The stationary predictive variances using the posterior draws have been saved to the file "' GetFilename(MatFile) '" in the "' GetPath(MatFile) '" directory. Would you like YADA to write an m-file to give you direct access to these results?'];
                     answer = Query(txt,'question',300,'Stationary Predictive Variance - Posterior Distribution',600,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        YNames = DSGEModel.VariableNames;
                        if isfield(SPC,'YNames')==0;
                           save(MatFile,'YNames','-APPEND');
                        end;
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\' strrep(strrep(GetName(MatFile),'-',''),'.','') '.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(MatFile) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(MatFile));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% 3D matrix with the marginal prediction covariances \n%%\n');
                        fprintf(fid,'TotalCov = DataStructure.TotalCov;\n');
                        fprintf(fid,'%%\n%% 2D matrix with the part due to the measurement errors \n%%\n');
                        fprintf(fid,'MeasureCov = DataStructure.MeasureCov;\n');
                        fprintf(fid,'%%\n%% 3D matrix with the part due to the shock uncertainty \n%%\n');
                        fprintf(fid,'ShockCov = DataStructure.ShockCov;\n');
                        fprintf(fid,'%%\n%% 3D matrix with the part due to the state uncertainty \n%%\n');
                        fprintf(fid,'StateCov = DataStructure.StateCov;\n');
                        fprintf(fid,'%%\n%% 3D matrix with the part due to parameter uncertainty \n%%\n');
                        fprintf(fid,'ParameterCov = DataStructure.ParameterCov;\n');
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        %
                        txt = ['You can access the stationary predictive variances estimated from the posterior distribution through the file: "' GetFilename(mfile) '", located in the "' GetPath(mfile) '" directory.'];
                        About(txt,'information','Stationary Predictive Variance - Posterior Distribution',500,600,CurrINI);
                     end;
                     %
                     % write to a text file
                     %
                     ResFile = strrep(MatFile,'.mat','.txt');
                     PrintStationaryPredictiveVariance(ResFile,MeasureCov,ShockCov,StateCov,ParameterCov,TotalCov,[],NumDraws,NumPostDraws,NumBurnin,1,CompTime,DSGEModel,CurrINI);
                     if FileExist(ResFile)==1;
                        TextGUI(ResFile,['Stationary Predictive Variance - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution',50,CurrINI,1,0);
                     end;
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UncondObsWeightDecompInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view graphs of the observation weight decompositions before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Observation Weight Decompositions - Initial Values',450,'no',CurrINI);
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
               if gcbo==controls.predict.unconditional.original.obsweightdecomp.initialvalues;
                  DataStr = 'Original';
                  IsOriginal = 1;
               elseif gcbo==controls.predict.unconditional.annual.obsweightdecomp.initialvalues;
                  DataStr = 'Annual';
                  IsOriginal = 0;
               end;
               if MatlabNumber>=8.0;
                  try;
                     if DSGEModel.UseDoublingAlgorithm<=3;
                        [StateDecomp,mcode,kalmanstatus] = DSGEObservationWeightsTheta(theta,thetaPositions,ModelParameters,1,DSGEModel,CurrINI);
                     else;
                        [StateDecomp,mcode,kalmanstatus] = DSGEObservationWeightsThetaDiffuse(theta,thetaPositions,ModelParameters,1,DSGEModel,CurrINI);
                     end;
                  catch ME;
                     WaitHandle = findobj('Type','figure','Tag','WaitDLG');
                     if (isempty(WaitHandle)==0)&(IsHandle(WaitHandle)==1);
                        WaitControls = get(WaitHandle,'UserData');
                        set(WaitControls.text,'UserData','done');
                        delete(WaitHandle);
                        drawnow;
                        pause(0.02);
                     end;
                     StateDecomp = [];
                     mcode = 1;
                     kalmanstatus = 0;
                     txt = 'There was an error running the observation weight function. The most likely reason is that matlab ran out of memory.';
                     if isempty(YADALastError(ME))==0;
                        txt = [txt ' YADA caught the following message: ' YADALastError(ME)];
                     end;
                     About(txt,'information','Observation Weight Decompositions - Initial Values',400,500,CurrINI);
                  end;
               else;
                  try;
                     if DSGEModel.UseDoublingAlgorithm<=3;
                        [StateDecomp,mcode,kalmanstatus] = DSGEObservationWeightsTheta(theta,thetaPositions,ModelParameters,1,DSGEModel,CurrINI);
                     else;
                        [StateDecomp,mcode,kalmanstatus] = DSGEObservationWeightsThetaDiffuse(theta,thetaPositions,ModelParameters,1,DSGEModel,CurrINI);
                     end;
                  catch;
                     WaitHandle = findobj('Type','figure','Tag','WaitDLG');
                     if (isempty(WaitHandle)==0)&(IsHandle(WaitHandle)==1);
                        WaitControls = get(WaitHandle,'UserData');
                        set(WaitControls.text,'UserData','done');
                        delete(WaitHandle);
                        drawnow;
                        pause(0.02);
                     end;
                     StateDecomp = [];
                     mcode = 1;
                     kalmanstatus = 0;
                     txt = 'There was an error running the observation weight function. The most likely reason is that matlab ran out of memory.';
                     if isempty(YADALastError)==0;
                        txt = [txt ' YADA caught the following message: ' YADALastError];
                     end;
                     About(txt,'information','Observation Weight Decompositions - Initial Values',400,500,CurrINI);
                  end;
               end;
               if (mcode==1)&(kalmanstatus==0);
                  if isempty(StateDecomp)==0;
                     %
                     % compute the decompositions for the forecast paths
                     %
                     T = length(StateDecomp.DateVector);
                     %
                     % the decomposition of the state variables at the end of the
                     % historical sample is the foundation of the decomposition of
                     % the point forecast path.
                     %
                     % this matrix should be rx*(n+1)
                     %
                     % where the last column holds the initial value part of the decomp
                     %
                     KsiTTDecomp = squeeze(StateDecomp.StateUpdateDecomp(:,T,:));
                     %
                     % determine the forecast horizon and the steady-state
                     %
                     [DSGEModel.FirstPeriod,DSGEModel.LastPeriod] = CreateSubSample(DSGEModel);
                     %
                     % check how many time periods to use for predictive distributions
                     %
                     [h,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
                     %
                     % matrix with exogenous variables
                     %
                     X = [];
                     if DSGEModel.k>0;
                        if NumPredX<h;
                           X = DSGEModel.X(:,DSGEModel.LastPeriod+1:DSGEModel.LastPeriod+(h-NumPredX));
                        end;
                        if NumPredX>0;
                           X = [X DSGEModel.PredictedX(:,1:NumPredX)];
                        end;
                     end;
                     %
                     % compute the point forecast obs weight decomposition
                     %
                     [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,h);
                     [PredMean,Yss,YTh,status] = DSGEPointForecastObsWeightDecomp(StateDecomp.Ksitt(:,T),KsiTTDecomp,StateDecomp.A,StateDecomp.H,StateDecomp.F,StateDecomp.Y,X,h,IsOriginal,DSGEModel);
                     %
                     % check if the calculations were completed
                     %
                     if status==1;
                        %
                        % ask if the user wants to save to file
                        %
                        txt = ['Would you like to save the observation weight decompositions of the ' lower(DataStr) ' point forecasts at initial values to disk?'];
                        answer = Query(txt,'question',200,'Save - Point Forecast Observation Weight Decompositions',600,'no',CurrINI);
                        if strcmp(lower(answer),'yes')==1;
                           YNames = DSGEModel.VariableNames;
                           file = FixFilePath([DSGEModel.OutputDirectory '\PointForecastObsDecomp-' DataStr '-InitialValues.mat']);
                           save(file,'YNames','PredDateVector','PredMean','Yss','YTh');
                           %
                           % create the script file
                           %
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\PointForecastObsDecomp' DataStr 'InitVal.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% string matrix with names of the observed variables\n%%\n');
                           fprintf(fid,'YNames = DataStructure.YNames;\n');
                           fprintf(fid,'%%\n%% matrix with point forecasts\n%%\n');
                           fprintf(fid,'PredMean = DataStructure.PredMean;\n');
                           fprintf(fid,'%%\n%% matrix with steady-state point forecasts\n%%\n');
                           fprintf(fid,'Yss = DataStructure.Yss;\n');
                           fprintf(fid,'%%\n%% matrix with observation weight decomposition of point forecasts\n%% into observed variables and the initial values of the state variables\n%%\n');
                           fprintf(fid,'YTh = DataStructure.YTh;\n');
                           fprintf(fid,'%%\n%% vector with numeric dates for the prediction sample\n%%\n');
                           fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                           txt = ['The observation weight decompositions of the point forecasts at initial values have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 5 entries: YNames (string matrix with the names of the observed variables), PredMean (matrix with the point forecasts), Yss (matrix with the steady-state point forecasts), YTh (matrix with the observation weight decomposition of the point forecasts into the observed variables and the initial values of the state variables), and PredDateVector (vector with dates for the prediction sample). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                           About(txt,'information','Point Forecast Observation Weight Decompositions - Initial Values',400,600,CurrINI);
                        end;
                        %
                        % display the results
                        %
                        PointForecastObsWeightDecompDLG('init',PredMean,Yss,YTh,PredDateVector,DataStr,'Posterior Mode',DSGEModel,CurrINI);
                     end;
                  end;
               elseif (mcode==1)&(kalmanstatus~=0);
                  if kalmanstatus==1;
                     txt = 'The state variables are not stationary at the initial values.';
                  else;
                     txt = 'The covariance matrix of the forecast of the observed variables in period t conditional on data until t-1 is not positive definite for some time period t. This implies that the log-likelihood value is a NaN (or a complex number) in Matlab.';
                  end;
                  About(txt,'information','Observation Weight Decompositions - Initial Values',200,500,CurrINI);
               elseif mcode~=1;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Observation Weight Decompositions - Initial Values',200,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UncondObsWeightDecompPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         %
         % File with the data needed to calculate the impulse responses
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            %
            % determine if we have original data or annualized data
            %
            if DSGEModel.RunDriver==0;
               if gcbo==controls.predict.unconditional.original.obsweightdecomp.postmode;
                  DataStr = 'Original';
                  IsOriginal = 1;
               elseif gcbo==controls.predict.unconditional.annual.obsweightdecomp.postmode;
                  DataStr = 'Annual';
                  IsOriginal = 0;
               end;
            else;
               if strcmp(lower(DSGEModel.answers{1}),'original')==1;
                  DataStr = 'Original';
                  IsOriginal = 1;
               else;
                  DataStr = 'Annual';
                  IsOriginal = 0;
               end;
            end;
            %
            % check if we can compute the decompositions
            %
            if MatlabNumber>=8.0;
               try;
                  if DSGEModel.UseDoublingAlgorithm<=3;
                     StateDecomp = DSGEObservationWeightsTheta(theta,thetaPositions,ModelParameters,1,DSGEModel,CurrINI);
                  else;
                     StateDecomp = DSGEObservationWeightsThetaDiffuse(theta,thetaPositions,ModelParameters,1,DSGEModel,CurrINI);
                  end;
               catch ME;
                  WaitHandle = findobj('Type','figure','Tag','WaitDLG');
                  if (isempty(WaitHandle)==0)&(IsHandle(WaitHandle)==1);
                     WaitControls = get(WaitHandle,'UserData');
                     set(WaitControls.text,'UserData','done');
                     delete(WaitHandle);
                     drawnow;
                     pause(0.02);
                  end;
                  StateDecomp = [];
                  if DSGEModel.RunDriver==0;
                     txt = 'There was an error running the observation weight function. The most likely reason is that matlab ran out of memory.';
                     if isempty(YADALastError(ME))==0;
                        txt = [txt ' YADA caught the following message: ' YADALastError(ME)];
                     end;
                     About(txt,'information','Observation Weight Decompositions - Posterior Mode',400,500,CurrINI);
                  else;
                     SetLogText(strvcat('There was an error running the obs. weight function.','The most likely reason is not enough memory.',' '));
                  end;
               end;
            else;
               try;
                  if DSGEModel.UseDoublingAlgorithm<=3;
                     StateDecomp = DSGEObservationWeightsTheta(theta,thetaPositions,ModelParameters,1,DSGEModel,CurrINI);
                  else;
                     StateDecomp = DSGEObservationWeightsThetaDiffuse(theta,thetaPositions,ModelParameters,1,DSGEModel,CurrINI);
                  end;
               catch;
                  WaitHandle = findobj('Type','figure','Tag','WaitDLG');
                  if (isempty(WaitHandle)==0)&(IsHandle(WaitHandle)==1);
                     WaitControls = get(WaitHandle,'UserData');
                     set(WaitControls.text,'UserData','done');
                     delete(WaitHandle);
                     drawnow;
                     pause(0.02);
                  end;
                  StateDecomp = [];
                  if DSGEModel.RunDriver==0;
                     txt = 'There was an error running the observation weight function. The most likely reason is that matlab ran out of memory.';
                     if isempty(YADALastError)==0;
                        txt = [txt ' YADA caught the following message: ' YADALastError];
                     end;
                     About(txt,'information','Point Forecast Observation Weight Decompositions - Posterior Mode',400,500,CurrINI);
                  else;
                     SetLogText(strvcat('There was an error running the obs. weight function.','The most likely reason is not enough memory.',' '));
                  end;
               end;
            end;
            if isempty(StateDecomp)==0;
               %
               % compute the decompositions for the forecast paths
               %
               T = length(StateDecomp.DateVector);
               %
               % the decomposition of the state variables at the end of the
               % historical sample is the foundation of the decomposition of
               % the point forecast path.
               %
               % this matrix should be rx*(n+1)
               %
               % where the last column holds the initial value part of the decomp
               %
               KsiTTDecomp = squeeze(StateDecomp.StateUpdateDecomp(:,T,:));
               %
               % determine the forecast horizon and the steady-state
               %
               [DSGEModel.FirstPeriod,DSGEModel.LastPeriod] = CreateSubSample(DSGEModel);
               %
               % check how many time periods to use for predictive distributions
               %
               [h,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               %
               % matrix with exogenous variables
               %
               X = [];
               if DSGEModel.k>0;
                  if NumPredX<h;
                     X = DSGEModel.X(:,DSGEModel.LastPeriod+1:DSGEModel.LastPeriod+(h-NumPredX));
                  end;
                  if NumPredX>0;
                     X = [X DSGEModel.PredictedX(:,1:NumPredX)];
                  end;
               end;
               %
               % compute the point forecast obs weight decomposition
               %
               [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,h);
               [PredMean,Yss,YTh,status] = DSGEPointForecastObsWeightDecomp(StateDecomp.Ksitt(:,T),KsiTTDecomp,StateDecomp.A,StateDecomp.H,StateDecomp.F,StateDecomp.Y,X,h,IsOriginal,DSGEModel);
               %
               % check if the calculations were completed
               %
               if status==1;
                  %
                  % ask if the user wants to save to file
                  %
                  if DSGEModel.RunDriver==0;
                     txt = ['Would you like to save the observation weight decompositions of the ' lower(DataStr) ' point forecasts at posterior mode to disk?'];
                     answer = Query(txt,'question',200,'Save - Point Forecast Observation Weight Decompositions',600,'no',CurrINI);
                  else;
                     answer = DSGEModel.answers{2};
                  end;
                  if strcmp(lower(answer),'yes')==1;
                     YNames = DSGEModel.VariableNames;
                     file = FixFilePath([DSGEModel.OutputDirectory '\PointForecastObsDecomp-' DataStr '-PostMode.mat']);
                     save(file,'YNames','PredDateVector','PredMean','Yss','YTh');
                     %
                     % create the script file
                     %
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\PointForecastObsDecomp' DataStr 'PostMode.m']);
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                     fprintf(fid,'%%\n%% string matrix with names of the observed variables\n%%\n');
                     fprintf(fid,'YNames = DataStructure.YNames;\n');
                     fprintf(fid,'%%\n%% matrix with point forecasts\n%%\n');
                     fprintf(fid,'PredMean = DataStructure.PredMean;\n');
                     fprintf(fid,'%%\n%% matrix with steady-state point forecasts\n%%\n');
                     fprintf(fid,'Yss = DataStructure.Yss;\n');
                     fprintf(fid,'%%\n%% matrix with observation weight decomposition of point forecasts\n%% into observed variables and the initial values of the state variables\n%%\n');
                     fprintf(fid,'YTh = DataStructure.YTh;\n');
                     fprintf(fid,'%%\n%% vector with numeric dates for the prediction sample\n%%\n');
                     fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     if DSGEModel.RunDriver==0;
                        txt = ['The observation weight decompositions of the point forecasts at posterior mode have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains 5 entries: YNames (string matrix with the names of the observed variables), PredMean (matrix with the point forecasts), Yss (matrix with the steady-state point forecasts), YTh (matrix with the observation weight decomposition of the point forecasts into the observed variables and the initial values of the state variables), and PredDateVector (vector with dates for the prediction sample). To access this data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Point Forecast Observation Weight Decompositions - Posterior Mode',400,600,CurrINI);
                     end;
                  end;
                  %
                  % display the results
                  %
                  if DSGEModel.RunDriver==0;
                     PointForecastObsWeightDecompDLG('init',PredMean,Yss,YTh,PredDateVector,DataStr,'Posterior Mode',DSGEModel,CurrINI);
                  else;
                     SetLogText(strvcat('* Finished calculations.',' '));
                  end;
               end;
            end;
         else;
            About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconPredInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view graphs of the predictive distributions of the observed variables before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Predictive Distributions - Initial Values',500,'no',CurrINI);
         end;
         %
         % check if we should check transformations functions
         %
         if gcbo==controls.predict.unconditional_transformed_initialvalues;
            ErrorStr = '';
            DTStatus = VerifyDataTransformation(DSGEModel.VariableNames,DSGEModel.YTransformation,0);
            if DTStatus==1;
               [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
            else;
               ErrorStr = 'You haven''t specified all the necessary fields for computing transformations of the observed variables.';
               HeaderStr = 'Missing Transformation Information';
            end;
            if isempty(ErrorStr)==0;
               About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
               answer = 'no';
            end;
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the input files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
               %
               % check how many time periods to use for predictive distributions
               %
               [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               %
               % matrix with exogenous variables
               %
               X = [];
               if DSGEModel.k>0;
                  if NumPredX<MaxPH;
                     X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                  end;
                  if NumPredX>0;
                     X = [X DSGEModel.PredictedX(:,1:NumPredX)];
                  end;
               end;
               %
               % check if we should annualize or not
               %
               if gcbo==controls.predict.unconditional_original_initialvalues;
                  TransData = 0;
                  AnnualizeData = 0;
                  AnnualStr = 'original';
               elseif gcbo==controls.predict.unconditional_annual_initialvalues;
                  TransData = 0;
                  AnnualizeData = 1;
                  AnnualStr = 'annual';
               else;
                  TransData = 1;
                  AnnualizeData = 0;
                  AnnualStr = 'transformed';
               end;
               %
               % determine how many prediction paths to use
               %
               NumPredPathsStr = get(controls.forecast.predpaths,'String');
               NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
               %
               % ask if we should conduct prediction event calculations
               %
               if NumPredPaths>1;
                  txt = 'Would you like YADA to calculate prediction event probabilities and perform risk analysis?';
                  answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
               else;
                  answer = 'No';
               end;
               if strcmp(lower(answer),'yes')==1;
                  if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                     DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                  end;
                  %
                  % make sure that the prediction event length does not exceed the maximum prediction horizon
                  %
                  for i=1:DSGEModel.n;
                     if DSGEModel.PredictionEvent(i,3)>MaxPH;
                        DSGEModel.PredictionEvent(i,3) = MaxPH;
                     end;
                  end;
                  %
                  % display a dialog for setting up an prediction event
                  %
                  [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PredictionEvent = PredictionEvent;
                     DSGEModel.RunPredictionEvent = 1;
                  else;
                     DSGEModel.RunPredictionEvent = 0;
                  end;
               else;
                  DSGEModel.RunPredictionEvent = 0;
               end;
               %
               % we can now compute the predictive distribution for the endogenous variables
               % up to period MaxPh
               %
               if DSGEModel.RandomNumberValue==1;
                  randn('state',0);
               else;
                  randn('state',sum(100*clock));
               end;
               [PredPaths,PredData,PredEventData,YObsEventData,mcode,kalmanstatus] = DSGEPredictionPathsTheta(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,MaxPH,NumPredPaths,AnnualizeData,TransData,' At Initial Values');
               %
               if (mcode==1)&(kalmanstatus==0);
                  %
                  % we're hopefully OK
                  %
                  if isempty(PredPaths)==0;
                     %
                     % the computations went OK. Compute point estimates from predictive distribution and
                     % quantiles
                     %
                     [MeanPrediction,Quantiles] = PredictionPathDistribution(PredPaths,DSGEModel.Percentiles,DSGEModel.ConfidenceRegionMethod);
                     %
                     % compute the mean error bias in percent
                     %
                     MeanErrorBias = max(max(abs((PredData.PredMean-MeanPrediction)./PredData.PredMean)));
                     if DSGEModel.AdjustPredictionPaths==0;
                        %
                        % ask if the prediction distribution should be corrected
                        %
                        txt = ['The absolute mean error bias from using the simulated draws is ' num2str(MeanErrorBias,'%0.4f') ' percent relative to the theoretical mean. Would you like to adjust that predictive distribution such that it matches the theoretical mean?'];
                        answer = Query(txt,'question',140,'Mean Error Bias - Predictive Distributions',500,'yes',CurrINI);
                     else;
                        answer = 'Yes';
                     end;
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % adjust the quantiles to match
                        %
                        for i=1:length(Quantiles);
                           OlVal = Quantiles(i).Quantile;
                           Quantiles(i).Quantile = Quantiles(i).Quantile+(PredData.PredMean-MeanPrediction);
                        end;
                        MeanPrediction = PredData.PredMean;
                     end;
                     %
                     % compute the forecast errors based on the mean predictions
                     %
                     PredictionErrors = CalculatePredictionErrors(MeanPrediction,AnnualizeData,TransData,'DSGE',DSGEModel);
                     %
                     % check if the user wants to save the data
                     %
                     txt = ['Would you like to save the predictive distributions for the ' AnnualStr ' data at initial values to file?'];
                     answer = Query(txt,'question',140,'Save - Predictive Distributions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,size(MeanPrediction,2));
                        file = FixFilePath([DSGEModel.OutputDirectory '\PredictiveDist-' AnnualStr '-' num2str(MaxPH,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod 'InitialValues.mat']);
                        YNames = DSGEModel.VariableNames;
                        DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,PredEndYear,PredEndPeriod,DSGEModel.DataFrequency);
                        Y = DSGEModel.Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                        if (length(DateVector)>size(Y,2))&(TransData==0);
                           DateVector = DateVector(1,1:size(Y,2));
                        end;
                        EstimationStartPeriod = DSGEModel.KalmanFirstObservation;
                        EstimationStartPeriodOrig = EstimationStartPeriod;
                        YOrig = Y;
                        DateVectorOrig = DateVector;
                        if AnnualizeData==1;
                           Y = Annualize(Y,DSGEModel.annual,DSGEModel.annualscale);
                           EstimationStartPeriod = max(1,EstimationStartPeriod-(length(DateVector)-size(Y,2)));
                           DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                        end;
                        if TransData==1;
                           [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
                           Y = YData';
                           if size(Y,2)==DSGEModel.T;
                              Y = Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                           else;
                              T2 = size(Y,2);
                              if (FirstPeriod-(DSGEModel.T-T2))>=1;
                                 Y = Y(:,FirstPeriod-(DSGEModel.T-T2):min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                              else;
                                 Y = Y(:,1:min((LastPeriod+MaxPH),size(DSGEModel.Y,2))-(DSGEModel.T-T2));
                                 DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                              end;
                           end;
                        end;
                        %
                        A = PredData.A;
                        H = PredData.H;
                        R = PredData.R;
                        F = PredData.F;
                        B0 = PredData.B0;
                        %
                        PredMeanKsiStates = PredData.xiStates;
                        PredMean = PredData.PredMean;
                        StateVariableNames = DSGEModel.StateVariableNames;
                        KernelX = PredData.KernelX;
                        KernelY = PredData.KernelY;
                        if isempty(PredEventData)==1;
                           save(file,'A','H','R','F','B0','MeanPrediction','PredMean','PredMeanKsiStates','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','StateVariableNames','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig');
                        else;
                           save(file,'A','H','R','F','B0','MeanPrediction','PredMean','PredMeanKsiStates','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','StateVariableNames','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig','PredictionEvent','PredEventData','YObsEventData');
                        end;
                        %
                        % create a matlab m-file to read the output.
                        %
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\PD' AnnualStr num2str(MaxPH,'%0.0f') DSGEModel.SubEndYear DSGEModel.SubEndPeriod 'InitVal.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% M E A S U R E M E N T   E Q U A T I O N\n');
                        fprintf(fid,'%%\n%% matrix with parameters on exogenous variables\n%%\n');
                        fprintf(fid,'A = DataStructure.A;\n');
                        fprintf(fid,'%%\n%% matrix with parameters on state variables\n%%\n');
                        fprintf(fid,'H = DataStructure.H;\n');
                        fprintf(fid,'%%\n%% matrix with measurement error covariances\n%%\n');
                        fprintf(fid,'R = DataStructure.R;\n');
                        fprintf(fid,'%%\n%% S T A T E   E Q U A T I O N\n');
                        fprintf(fid,'%%\n%% matrix with state transition parameters\n%%\n');
                        fprintf(fid,'F = DataStructure.F;\n');
                        fprintf(fid,'%%\n%% matrix with shock parameters\n%%\n');
                        fprintf(fid,'B0 = DataStructure.B0;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% matrix with the mean predictions of the observed variables\n%%\n');
                        fprintf(fid,'MeanPrediction = DataStructure.MeanPrediction;\n');
                        fprintf(fid,'%%\n%% matrix with the population mean predictions of the observed variables\n%%\n');
                        fprintf(fid,'PredMean = DataStructure.PredMean;\n');
                        fprintf(fid,'%%\n%% matrix with the population mean predictions of the state variables\n%%\n');
                        fprintf(fid,'PredMeanKsiStates = DataStructure.PredMeanKsiStates;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                        fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                        fprintf(fid,'%%\n%% matrix with the errors from the mean predictions of the observed variables\n%%\n');
                        fprintf(fid,'PredictionErrors = DataStructure.PredictionErrors;\n');
                        fprintf(fid,'%%\n%% vector structure with quantiles from the predictive distribution\n%% the structure has %0.0f entries with fields "Quantile" and "percent"\n%% the first field is a matrix and the second a positive number between 0 and 100\n%%\n',length(Quantiles));
                        fprintf(fid,'Quantiles = DataStructure.Quantiles;\n');
                        if isempty(KernelX)==0;
                           fprintf(fid,'%%\n%% matrix with x-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                           fprintf(fid,'KernelX = DataStructure.KernelX;\n');
                           fprintf(fid,'%%\n%% matrix with y-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                           fprintf(fid,'KernelY = DataStructure.KernelX;\n');
                           KStr = 'KernelX (matrix with x-axis for kernel density estimates of marginal predictive distribution), KernelY (matrix with y-axis values for kernel density estimates of marginal predictive distribution), ';
                           KVal = 2;
                        else;
                           KStr = '';
                           KVal = 0;
                        end;
                        fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                        fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                        fprintf(fid,'%%\n%% observed variables\n%%\n');
                        fprintf(fid,'Y = DataStructure.Y;\n');
                        fprintf(fid,'%%\n%% vector with dates for the observed variables\n%%\n');
                        fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                        if isempty(PredEventData)==0;
                           fprintf(fid,'%%\n%% matrix with the prediction event definitions. The first column\n%% holds the upper bound, the second column\n%% the lower bound, and third the length of the event.\n%%\n');
                           fprintf(fid,'PredictionEvent = DataStructure.PredictionEvent;\n');
                           fprintf(fid,'%%\n%% matrix with prediction event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                           fprintf(fid,'PredEventData = DataStructure.PredEventData;\n');
                           fprintf(fid,'%%\n%% matrix with observed event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                           fprintf(fid,'YObsEventData = DataStructure.YObsEventData;\n');
                           NumEntries = int2str(18+KVal);
                           ExtraEntry = 'PredictionEvent (matrix with the upper and lower bound of the event and the length of the event), PredEventData (matrix with the number of true prediction events, the number of events below the lower bound for the event, the number of events above the upper bound for the event, the number of events tested in the columns, the sum and sum of squared deviations from lower bound when below lower bound, the sum and sum of squared deviations from upper bound when above upper bound), YObsEventData (matrix with the number of true events for prediction paths whose mean is the observed data, the number of events below the lower bound for the event, the number of events above the upper bound for the event, the number of events tested in the columns, the sum and sum of squared of deviations from lower bound when below lower bound, the sum and sum of squared of deviations from upper bound when above upper bound), ';
                        else;
                           NumEntries = int2str(15+KVal);
                           ExtraEntry = '';
                        end;
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        %
                        txt = ['The predictive distributions have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' NumEntries ' entries: the 5 state space matrices (A, H, R, F, B0), YNames (string matrix with the names of the observed variables), StateVariableNames (string matrix with the names of the state variables), MeanPrediction (matrix with the mean predictions), PredMean (matrix with the population mean of the predictions), PredMeanKsiStates (matrix with the population mean of the predictions of the state variables), PredictionErrors (matrix with errors for the mean predictions), Quantiles (vector structure with 2 fields: Quantile and percent), ' KStr 'PredDateVector (vector with dates for the predictions), Y (matrix) with the observed variables, ' ExtraEntry 'and DateVector (vector with dates for the observed variables). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Predictive Distributions - Initial Values',500,600,CurrINI);
                     end;
                     if isempty(PredEventData)==0;
                        %
                        % write prediction event results to file
                        %
                        file = FixFilePath([DSGEModel.OutputDirectory '\PredictiveDist-' AnnualStr '-' num2str(MaxPH,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '-InitialValues.txt']);
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                        PrintPredictionEvent(file,DSGEModel.VariableNames,PredEventData,YObsEventData,DSGEModel.PredictionEvent,[PredStartYear ':' PredStartPeriod '-' PredEndYear ':' PredEndPeriod],MaxPH,NumPredPaths,1,CurrINI);
                        %
                        % displays the file if it exists
                        %
                        if FileExist(file)==1;
                           TextGUI(file,['Prediction Events - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Initial Parameter Values',50,CurrINI,1,0);
                        end;
                     end;
                     %
                     if size(PredData.A,1)==1;
                        ObsVarMean = PredData.A';
                     else;
                        ObsVarMean = [];
                     end;
                     %
                     % Open a dialog for displaying predictive distributions
                     %
                     PredictiveDistributionDLG('init',DSGEModel,CurrINI,MeanPrediction,ObsVarMean,Quantiles,PredData.KernelX,PredData.KernelY,'Initial Values','DSGE',AnnualStr,1);
                  end;
               elseif (mcode==1)&(kalmanstatus~=0);
                  if kalmanstatus==1;
                     txt = 'The state variables are not stationary at the initial values.';
                  else;
                     txt = 'The covariance matrix of the forecast of the observed variables in period t conditional on data until t-1 is not positive definite for some time period t. This implies that the log-likelihood value is a NaN (or a complex number) in Matlab.';
                  end;
                  About(txt,'information','Predictive Distributions - Initial Values',200,500,CurrINI);
               elseif mcode~=1;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Predictive Distributions - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ConPredInitialValues'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check first if posterior mode results exists. If they do we load initial values from this file.
         % Otherwise we have to do a bunch of checking
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         if FileExist(ModeFile)==1;
            answer = 'Yes';
         else;
            %
            % Ask if the user really wants to look at these before estimating the posterior mode
            %
            txt = 'Are you sure you want to view graphs of the conditional predictive distributions of the observed variables before running the posterior mode estimation routine?';
            answer = Query(txt,'question',150,'Conditional Predictive Distributions - Initial Values',500,'no',CurrINI);
         end;
         %
         % check if we should check transformations functions
         %
         if gcbo==controls.predict.conditional_transformed_initialvalues;
            ErrorStr = '';
            DTStatus = VerifyDataTransformation(DSGEModel.VariableNames,DSGEModel.YTransformation,0);
            if DTStatus==1;
               [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
            else;
               ErrorStr = 'You haven''t specified all the necessary fields for computing transformations of the observed variables.';
               HeaderStr = 'Missing Transformation Information';
            end;
            if isempty(ErrorStr)==0;
               About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
               answer = 'no';
            end;
         end;
         %
         if strcmp(lower(answer),'yes')==1;
            %
            % posterior mode estimation has not been completed yet. We therefore need to check all the imput files
            %
            [InitStatus,theta,thetaPositions,ModelParameters] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            if (InitStatus==0)&(FileExist(DSGEModel.PriorFile)==0);
               if FileExist(ModeFile)==1;
                  ErrorStr = '';
                  if MatlabNumber>=8.0;
                     try;
                        ModeData = load(ModeFile);
                     catch ME;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                     end;
                  else;
                     try;
                        ModeData = load(ModeFile);
                     catch;
                        ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                     end;
                  end;
                  if isempty(ErrorStr)==1;
                     theta = ModeData.theta;
                     thetaPositions = ModeData.thetaPositions;
                     ModelParameters = ModeData.ModelParameters;
                     ModelParameters = ThetaToModelParameters(ModelParameters,theta,thetaPositions);
                     InitStatus = 1;
                  else;
                     About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
                  end;
               end;
            end;
            %
            if InitStatus==1;
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
               %
               % check how many time periods to use for predictive distributions
               %
               [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               %
               % matrix with exogenous variables
               %
               X = [];
               if DSGEModel.k>0;
                  if NumPredX<MaxPH;
                     X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                  end;
                  if NumPredX>0;
                     X = [X DSGEModel.PredictedX(:,1:NumPredX)];
                  end;
               end;
               %
               % check the length of the conditioning sample
               %
               [status,NumPeriods] = CheckConditioningData(DSGEModel);
               %
               % check if we should adjust the X matrix
               %
               if MaxPH<NumPeriods;
                  NumPeriods = MaxPH;
               end;
               %
               % collect the conditional variables and the selected conditioning sample
               %
               Z = DSGEModel.Z(DSGEModel.ConditionalVariables,LastPeriod+1:LastPeriod+NumPeriods);
               if LastPeriod>=NumPeriods;
                  U = DSGEModel.U(DSGEModel.ConditionalVariables,LastPeriod-NumPeriods+1:LastPeriod);
               else;
                  %
                  % we have to create artifical initial conditions for the conditioning variables
                  %
                  U = [DSGEModel.U(DSGEModel.ConditionalVariables,1)*ones(1,NumPeriods-LastPeriod) DSGEModel.U(DSGEModel.ConditionalVariables,1:LastPeriod)];
               end;
               %
               % check if we should annualize or not
               %
               if gcbo==controls.predict.conditional_original_initialvalues;
                  TransData = 0;
                  AnnualizeData = 0;
                  AnnualStr = 'original';
               elseif gcbo==controls.predict.conditional_annual_initialvalues;
                  TransData = 0;
                  AnnualizeData = 1;
                  AnnualStr = 'annual';
               else;
                  TransData = 1;
                  AnnualizeData = 0;
                  AnnualStr = 'transformed';
               end;
               %
               % determine how many prediction paths to use
               %
               NumPredPathsStr = get(controls.forecast.predpaths,'String');
               NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
               %
               % ask if we should conduct prediction event calculations
               %
               if NumPredPaths>1;
                  txt = 'Would you like YADA to calculate prediction event probabilities and perform risk analysis?';
                  answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
               else;
                  answer = 'No';
               end;
               if strcmp(lower(answer),'yes')==1;
                  if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                     DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                  end;
                  %
                  % make sure that the prediction event length does not exceed the maximum prediction horizon
                  %
                  for i=1:DSGEModel.n;
                     if DSGEModel.PredictionEvent(i,3)>MaxPH;
                        DSGEModel.PredictionEvent(i,3) = MaxPH;
                     end;
                  end;
                  %
                  % display a dialog for setting up an prediction event
                  %
                  [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PredictionEvent = PredictionEvent;
                     DSGEModel.RunPredictionEvent = 1;
                  else;
                     DSGEModel.RunPredictionEvent = 0;
                  end;
               else;
                  DSGEModel.RunPredictionEvent = 0;
               end;
               %
               % we can now compute the predictive distribution for the endogenous variables
               % up to period MaxPh
               %
               if DSGEModel.RandomNumberValue==1;
                  randn('state',0);
               else;
                  randn('state',sum(100*clock));
               end;
               if DSGEModel.ShockControlMethod==1;
                  [PredPaths,PredData,PredEventData,YObsEventData,MultiModestyStat,UniModestyStat,MeanUniModestyLZ,mcode,kalmanstatus] = DSGECondPredictionPathsTheta(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,' At Initial Values');
               elseif DSGEModel.ShockControlMethod==2;
                  [PredPaths,PredData,PredEventData,YObsEventData,MultiModestyStat,UniModestyStat,MeanUniModestyLZ,mcode,kalmanstatus] = DSGECondPredictionPathsThetaWZ(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,' At Initial Values');
               else;
                  %
                  % check if the selected method can actually be used
                  %
                  CondTxt = '';
                  if isempty(DSGEModel.MixedConditionalShocks)==1;
                     CondTxt = 'You haven''t selected any shocks for use which the distribution of a subset of the shocks conditioning method.';
                  elseif length(DSGEModel.MixedConditionalShocks)<length(DSGEModel.ConditionalVariables);
                     CondTxt = ['The number of shocks you have selected to use to ensure that the conditioning assumptions are satisfied under the distribution of a subset of the shocks conditioning method is not sufficient. You need at least ' int2str(length(DSGEModel.ConditionalVariables)) ' such shocks.'];
                  end;
                  if isempty(CondTxt)==1;
                     [PredPaths,PredData,PredEventData,YObsEventData,MultiModestyStat,UniModestyStat,MeanUniModestyLZ,mcode,kalmanstatus] = DSGECondPredictionPathsThetaMixed(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,' At Initial Values');
                  else;
                     About(CondTxt,'information','Bad Shocks Selection - Distribution of Subset Shocks Method',300,550,CurrINI);
                     PredPaths = [];
                  end;
               end;
               %
               if (mcode==1)&(kalmanstatus==0);
                  %
                  % we're hopefully OK
                  %
                  if isempty(PredPaths)==0;
                     %
                     % the computations went OK. Compute point estimates from predictive distribution and
                     % quantiles
                     %
                     [MeanPrediction,Quantiles] = PredictionPathDistribution(PredPaths,DSGEModel.Percentiles,DSGEModel.ConfidenceRegionMethod);
                     %
                     % compute the mean error bias in percent
                     %
                     MeanErrorBias = max(max(abs((PredData.PredMean-MeanPrediction)./PredData.PredMean)));
                     if DSGEModel.AdjustPredictionPaths==0;
                        %
                        % ask if the prediction distribution should be corrected
                        %
                        txt = ['The absolute mean error bias from using the simulated draws is ' num2str(MeanErrorBias,'%0.4f') ' percent relative to the theoretical mean. Would you like to adjust that predictive distribution such that it matches the theoretical mean?'];
                        answer = Query(txt,'question',140,'Mean Error Bias - Conditional Predictive Distributions',500,'yes',CurrINI);
                     else;
                        answer = 'Yes';
                     end;
                     AdjustMean = 0;
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % adjust the quantiles to match
                        %
                        for i=1:length(Quantiles);
                           OlVal = Quantiles(i).Quantile;
                           Quantiles(i).Quantile = Quantiles(i).Quantile+(PredData.PredMean-MeanPrediction);
                        end;
                        MeanPrediction = PredData.PredMean;
                        PredData.MeanPredPath = PredData.OrigPredMean;
                        AdjustMean = 1;
                     end;
                     %
                     % compute the forecast errors based on the mean predictions
                     %
                     PredictionErrors = CalculatePredictionErrors(MeanPrediction,AnnualizeData,TransData,'DSGE',DSGEModel);
                     %
                     % check if we have modesty statistics to deal with
                     %
                     if AnnualizeData==0;
                        %
                        % check how often we have a greater value of column 1 than column 2 in MultiModestyStat
                        %
                        MultiPValue = sum(MultiModestyStat(:,1)<=MultiModestyStat(:,2))/NumPredPaths;
                        MeanMultiModesty = (1/NumPredPaths)*[sum(MultiModestyStat(:,1)) sum(MultiModestyStat(:,2))];
                        MeanUniModesty = zeros(1,DSGEModel.n);
                        for i=1:DSGEModel.n;
                           MeanUniModesty(1,i) = (1/NumPredPaths)*sum(UniModestyStat(:,i));
                        end;
                        if exist('YADAchi2cdf')==2;
                           ChiSqPValue = 1-YADAchi2cdf(MeanMultiModesty(1),DSGEModel.n);
                        else;
                           if exist('chi2cdf')==2;
                              ChiSqPValue = 1-chi2cdf(MeanMultiModesty(1),DSGEModel.n);
                           else;
                              ChiSqPValue = 1-YADACheapchi2cdf(MeanMultiModesty(1),DSGEModel.n);
                           end;
                        end;
                        PrintDSGEModestyStatistics(DSGEModel,CurrINI,'Initial Values',1,0,MaxPH,NumPeriods,1,NumPredPaths,MultiPValue,MeanMultiModesty,MeanUniModesty,MeanUniModestyLZ,PredData.etaShocks,PredData.ShockNames,'');
                     else;
                        MultiPValue = [];
                        MeanMultiModesty = [];
                        MeanUniModesty = [];
                        ChiSqPValue = [];
                     end;
                     %
                     % check if the user wants to save the data
                     %
                     txt = ['Would you like to save the conditional predictive distributions for the ' AnnualStr ' data at initial values to file?'];
                     answer = Query(txt,'question',140,'Save - Conditional Predictive Distributions',500,'no',CurrINI);
                     drawnow;
                     if strcmp(lower(answer),'yes')==1;
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,size(MeanPrediction,2));
                        file = FixFilePath([DSGEModel.OutputDirectory '\CondPredictiveDist-' int2str(DSGEModel.ShockControlMethod) '-' AnnualStr '-' num2str(MaxPH,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '-InitialValues.mat']);
                        YNames = DSGEModel.VariableNames;
                        PredMean = PredData.PredMean;
                        DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,PredEndYear,PredEndPeriod,DSGEModel.DataFrequency);
                        Y = DSGEModel.Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                        if (length(DateVector)>size(Y,2))&(TransData==1);
                           DateVector = DateVector(1,1:size(Y,2));
                        end;
                        if size(PredData.B0,2)==size(DSGEModel.StateShockNames,1);
                           [B0_h,KeepShocks] = RemoveRedundantColumns(PredData.B0);
                           ShockNames = DSGEModel.StateShockNames(KeepShocks,:);
                        else;
                           ShockNames = PredData.ShockNames;
                        end;
                        %
                        % check if we should compute the shock scenarios for the predictions
                        %
                        if FileExist(FixFilePath([pwd '\addons\sss\DSGEPredictionShockScenarios.m']))==1;
                           if AdjustMean==1;
                              ShockScenarioResults = PredData.ShockScenarioResults;
                              wtT = zeros(DSGEModel.n,MaxPH);
                           else;
                              if isempty(DSGEModel.X)==0;
                                 [ShockScenarioResults,ShockNames,wtT,SmoothShocks] = DSGEPredictionShockScenarios(PredData.A,PredData.H,PredData.R,PredData.F,PredData.B0,DSGEModel,DSGEModel.Y(:,FirstPeriod:LastPeriod),PredData.MeanPredPath,DSGEModel.X(:,FirstPeriod:LastPeriod),X,AnnualizeData);
                              else;
                                 [ShockScenarioResults,ShockNames,wtT,SmoothShocks] = DSGEPredictionShockScenarios(PredData.A,PredData.H,PredData.R,PredData.F,PredData.B0,DSGEModel,DSGEModel.Y(:,FirstPeriod:LastPeriod),PredData.MeanPredPath,[],X,AnnualizeData);
                              end;
                           end;
                        else;
                           ShockScenarioResults = [];
                           ShockNames = '';
                           wtT = [];
                           SmoothShocks = [];
                        end;
                        %
                        if (FileExist(FixFilePath([pwd '\addons\sss\DSGEPredictionShockScenarios.m']))==1)&(NumPredX<MaxPH);
                           %
                           % matrices with observed data and exogenous variables over the prediction period.
                           %
                           if isempty(DSGEModel.X)==0;
                              DataX = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                           else;
                              DataX = [];
                           end;
                           DataY = DSGEModel.Y(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                           %
                           % check if we should compute shock scenarios for the observed data over the prediction sample
                           %
                           if isempty(DSGEModel.X)==0;
                              [DataShockScenarioResults,DataShockNames,DatawtT,SmoothShocks,Yinit] = DSGEPredictionShockScenarios(PredData.A,PredData.H,PredData.R,PredData.F,PredData.B0,DSGEModel,DSGEModel.Y(:,FirstPeriod:LastPeriod),DataY,DSGEModel.X(:,FirstPeriod:LastPeriod),DataX,AnnualizeData);
                           else;
                              [DataShockScenarioResults,DataShockNames,DatawtT,SmoothShocks,Yinit] = DSGEPredictionShockScenarios(PredData.A,PredData.H,PredData.R,PredData.F,PredData.B0,DSGEModel,DSGEModel.Y(:,FirstPeriod:LastPeriod),DataY,[],DataX,AnnualizeData);
                           end;
                           if AnnualizeData==1;
                              DataY = Annualize([Yinit DataY],DSGEModel.annual,DSGEModel.annualscale);
                           end;
                        else;
                           DataY = [];
                           DataShockScenarioResults = [];
                           SmoothShocks = [];
                           DatawtT = [];
                        end;
                        %
                        A = PredData.A;
                        H = PredData.H;
                        R = PredData.R;
                        F = PredData.F;
                        B0 = PredData.B0;
                        %
                        ConditionalShockNames = DSGEModel.StateShockNames(DSGEModel.ConditionalShocks,:);
                        EstimationStartPeriod = DSGEModel.KalmanFirstObservation;
                        EstimationStartPeriodOrig = EstimationStartPeriod;
                        YOrig = Y;
                        DateVectorOrig = DateVector;
                        PredMeanKsiStates = PredData.xiStates;
                        PredMeanEtaShocks = PredData.etaShocks;
                        KsiStates = PredData.KsitT;
                        StateVariableNames = DSGEModel.StateVariableNames;
                        KernelX = PredData.KernelX;
                        KernelY = PredData.KernelY;
                        if AnnualizeData==1;
                           Y = Annualize(Y,DSGEModel.annual,DSGEModel.annualscale);
                           EstimationStartPeriod = max(1,EstimationStartPeriod-(length(DateVector)-size(Y,2)));
                           DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                        end;
                        %
                        if TransData==1;
                           [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
                           Y = YData';
                           if size(Y,2)==DSGEModel.T;
                              Y = Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                           else;
                              T2 = size(Y,2);
                              if (FirstPeriod-(DSGEModel.T-T2))>=1;
                                 Y = Y(:,FirstPeriod-(DSGEModel.T-T2):min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                              else;
                                 Y = Y(:,1:min((LastPeriod+MaxPH),size(DSGEModel.Y,2))-(DSGEModel.T-T2));
                                 DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                              end;
                           end;
                        end;
                        %
                        if FileExist(FixFilePath([pwd '\addons\sss\DSGEPredictionShockScenarios.m']))==1;
                           if isempty(PredEventData)==1;
                              save(file,'A','H','R','F','B0','MeanPrediction','PredMean','PredMeanKsiStates','PredMeanEtaShocks','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','KsiStates','StateVariableNames','ShockScenarioResults','ShockNames','wtT','DataY','DataShockScenarioResults','DatawtT','ConditionalShockNames','MeanMultiModesty','MultiPValue','ChiSqPValue','MeanUniModesty','MeanUniModestyLZ','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig');
                           else;
                              save(file,'A','H','R','F','B0','MeanPrediction','PredMean','PredMeanKsiStates','PredMeanEtaShocks','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','KsiStates','StateVariableNames','ShockScenarioResults','ShockNames','wtT','DataY','DataShockScenarioResults','DatawtT','ConditionalShockNames','MeanMultiModesty','MultiPValue','ChiSqPValue','MeanUniModesty','MeanUniModestyLZ','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig','PredictionEvent','PredEventData','YObsEventData');
                           end;
                        else;
                           if isempty(PredEventData)==1;
                              save(file,'A','H','R','F','B0','MeanPrediction','PredMean','PredMeanKsiStates','PredMeanEtaShocks','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','KsiStates','StateVariableNames','ShockNames','MeanMultiModesty','MultiPValue','ChiSqPValue','MeanUniModesty','MeanUniModestyLZ','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig');
                           else;
                              save(file,'A','H','R','F','B0','MeanPrediction','PredMean','PredMeanKsiStates','PredMeanEtaShocks','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','KsiStates','StateVariableNames','ShockNames','MeanMultiModesty','MultiPValue','ChiSqPValue','MeanUniModesty','MeanUniModestyLZ','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig','PredictionEvent','PredEventData','YObsEventData');
                           end;
                        end;
                        %
                        % create a matlab m-file to read the output.
                        %
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\CondPD' int2str(DSGEModel.ShockControlMethod) AnnualStr num2str(MaxPH,'%0.0f') DSGEModel.SubEndYear DSGEModel.SubEndPeriod 'InitVal.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% M E A S U R E M E N T   E Q U A T I O N\n');
                        fprintf(fid,'%%\n%% matrix with parameters on exogenous variables\n%%\n');
                        fprintf(fid,'A = DataStructure.A;\n');
                        fprintf(fid,'%%\n%% matrix with parameters on state variables\n%%\n');
                        fprintf(fid,'H = DataStructure.H;\n');
                        fprintf(fid,'%%\n%% matrix with measurement error covariances\n%%\n');
                        fprintf(fid,'R = DataStructure.R;\n');
                        fprintf(fid,'%%\n%% S T A T E   E Q U A T I O N\n');
                        fprintf(fid,'%%\n%% matrix with state transition parameters\n%%\n');
                        fprintf(fid,'F = DataStructure.F;\n');
                        fprintf(fid,'%%\n%% matrix with shock parameters\n%%\n');
                        fprintf(fid,'B0 = DataStructure.B0;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% string matrix with the names of the state variables\n%%\n');
                        fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                        if AdjustMean==0;
                           fprintf(fid,'%%\n%% matrix with the mean of the simulated predictions of the observed variables\n%%\n');
                        else;
                           fprintf(fid,'%%\n%% matrix with the corrected mean of the simulated predictions of the observed variables\n%%\n');
                        end;
                        fprintf(fid,'MeanPrediction = DataStructure.MeanPrediction;\n');
                        fprintf(fid,'%%\n%% matrix with the population mean of the predictions of the observed variables\n%%\n');
                        fprintf(fid,'PredMean = DataStructure.PredMean;\n');
                        fprintf(fid,'%%\n%% matrix with the population mean of the predictions of the state variables\n%%\n');
                        fprintf(fid,'PredMeanKsiStates = DataStructure.PredMeanKsiStates;\n');
                        fprintf(fid,'%%\n%% matrix with the population mean of the predictions of the economic shocks\n%%\n');
                        fprintf(fid,'PredMeanEtaShocks = DataStructure.PredMeanEtaShocks;\n');
                        fprintf(fid,'%%\n%% matrix with the errors from the mean predictions of the observed variables\n%%\n');
                        fprintf(fid,'PredictionErrors = DataStructure.PredictionErrors;\n');
                        fprintf(fid,'%%\n%% vector structure with quantiles from the predictive distribution\n%% the structure has %0.0f entries with fields "Quantile" and "percent"\n%% the first field is a matrix and the second a positive number between 0 and 100\n%%\n',length(Quantiles));
                        fprintf(fid,'Quantiles = DataStructure.Quantiles;\n');
                        if isempty(KernelX)==0;
                           fprintf(fid,'%%\n%% matrix with x-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                           fprintf(fid,'KernelX = DataStructure.KernelX;\n');
                           fprintf(fid,'%%\n%% matrix with y-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                           fprintf(fid,'KernelY = DataStructure.KernelY;\n');
                           KStr = 'KernelX (matrix with x-axis for kernel density estimates of marginal predictive distribution), KernelY (matrix with y-axis values for kernel density estimates of marginal predictive distribution), ';
                           KVal = 2;
                        else;
                           KStr = '';
                           KVal = 0;
                        end;
                        fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                        fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                        fprintf(fid,'%%\n%% observed variables\n%%\n');
                        fprintf(fid,'Y = DataStructure.Y;\n');
                        fprintf(fid,'%%\n%% matrix with smooth estimates of the state variables\n%%\n');
                        fprintf(fid,'KsiStates = DataStructure.KsiStates;\n');
                        fprintf(fid,'%%\n%% vector with dates for the observed variables\n%%\n');
                        fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                        fprintf(fid,'%%\n%% Names for the economic shocks\n%%\n');
                        fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                        if FileExist(FixFilePath([pwd '\addons\sss\DSGEPredictionShockScenarios.m']))==1;
                           fprintf(fid,'%%\n%% 3D matrix with shock scenarios over the prediction sample\n%%\n');
                           fprintf(fid,'ShockScenarioResults = DataStructure.ShockScenarioResults;\n');
                           fprintf(fid,'%%\n%% estimates of the measurement errors over the prediction sample\n%%\n');
                           fprintf(fid,'wtT = DataStructure.wtT;\n');
                           fprintf(fid,'%%\n%% string matrix with names of the economic shocks that are manipulated\n%% to achieve the conditioning assumptions\n%%\n');
                           fprintf(fid,'ConditionalShockNames = DataStructure.ConditionalShockNames;\n');
                           fprintf(fid,'%%\n%% The observed variables for the prediction sample\n%%\n');
                           fprintf(fid,'DataY = DataStructure.DataY;\n');
                           fprintf(fid,'%%\n%% 3D matrix with shock scenarios over the prediction sample for the observed data\n%%\n');
                           fprintf(fid,'DataShockScenarioResults = DataStructure.DataShockScenarioResults;\n');
                           fprintf(fid,'%%\n%% estimates of the measurement errors over the prediction sample using the observed data\n%%\n');
                           fprintf(fid,'DatawtT = DataStructure.DatawtT;\n');
                           SVal = 6;
                           ShockStr = 'ShockScenarioResults (3D matrix of dimension nxhxq with the shocks scenarios for the mean predictions of the observed variables), wtT (matrix with estimated measurement errors over the prediction sample for the mean predictions of the observed variables), ConditionalShockNames (string matrix with names for the shocks used to achieve the conditioning assumptions), DataY (matrix with the observed data for the prediction sample), DataShockScenarioResults (3D matrix with shock scenarios for the observed variables over the prediction sample), DatawtT (estimates of the measurement errors over the prediction sample for the observed variables), ';
                        else;
                           ShockStr = '';
                           SVal = 0;
                        end;
                        if isempty(PredEventData)==0;
                           fprintf(fid,'%%\n%% matrix with the prediction event definitions. The first column\n%% holds the upper bound, the second column\n%% the lower bound, and third the length of the event.\n%%\n');
                           fprintf(fid,'PredictionEvent = DataStructure.PredictionEvent;\n');
                           fprintf(fid,'%%\n%% matrix with prediction event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                           fprintf(fid,'PredEventData = DataStructure.PredEventData;\n');
                           fprintf(fid,'%%\n%% matrix with observed event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                           fprintf(fid,'YObsEventData = DataStructure.YObsEventData;\n');
                           NumEntries = int2str(21+SVal+KVal);
                           ExtraEntry = 'PredictionEvent (matrix with the upper and lower bound of the event and the length of the event), PredEventData (matrix with the number of true events, the number of events below the lower bound for the event, the number of events above the upper bound for the event, the number of events tested in the columns, the sum and sum of squared deviations from lower bound when below lower bound, the sum and sum of squared deviations from upper bound when above upper bound), YObsEventData (matrix with the number of true events for prediction paths whose mean is the observed data, the number of events below the lower bound for the event, the number of events above the upper bound for the event, the number of events tested in the columns, the sum and sum of squared of deviations from lower bound when below lower bound, the sum and sum of squared of deviations from upper bound when above upper bound), ';
                        else;
                           NumEntries = int2str(18+SVal+KVal);
                           ExtraEntry = '';
                        end;
                        if AnnualizeData==0;
                           fprintf(fid,'%%\n%% vector with the mean of the multivariate modesty statistic and its reference statistic\n%%\n');
                           fprintf(fid,'MeanMultiModesty = DataStructure.MeanMultiModesty;\n');
                           fprintf(fid,'%%\n%% tail probability based on the reference statistic\n%%\n');
                           fprintf(fid,'MultiPValue = DataStructure.MultiPValue;\n');
                           fprintf(fid,'%%\n%% tail probability based on the chi-square distribution\n%%\n');
                           fprintf(fid,'ChiSqPValue = DataStructure.ChiSqPValue;\n');
                           fprintf(fid,'%%\n%% Adolfson, Lasen, Lind and Villani univariate modesty statistic\n%%\n');
                           fprintf(fid,'MeanUniModesty = DataStructure.MeanUniModesty;\n');
                           fprintf(fid,'%%\n%% Leeper and Zha univariate modesty statistic\n%%\n');
                           fprintf(fid,'MeanUniModestyLZ = DataStructure.MeanUniModestyLZ;\n');
                           NumEntries = num2str(str2num(NumEntries)+5,'%0.0f');
                           ExtraEntry = [ExtraEntry 'MeanMultiModesty (1x2 vector with the mean of the multivariate modesty statistic and the mean of the multivariate reference modesty statistic), MultiPValue (scalar with the tail probability of the modesty statistic), ChiSqPValue (scalar with the tail probability of the modesty statistic using the chi-square distribution), MeanUniModesty (vector with the univariate modesty statistic from ALLV), MeanUniModestyLZ (vector with the univariate Leeper-Zha modesty statistic), '];
                        end;
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        %
                        txt = ['The conditional predictive distributions have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' NumEntries ' entries: the 5 state space matrices (A, H, R, F, B0), YNames (string matrix with the names of the observed variables), MeanPrediction (matrix with the selected mean predictions), PredMean (matrix with the population mean predictions), PredMeanKsiStates (matrix with the population mean of the predictions of the state variables), PredMeanEtaShocks (matrix with the population mean of the predictions of the economic shocks), PredictionErrors (matrix with errors for the mean predictions), Quantiles (vector structure with 2 fields: Quantile and percent), ' KStr 'PredDateVector (vector with dates for the predictions), Y (matrix with the observed variables), KsiStates (matrix with smooth estimates of the state variables), StateVariableNames (string matrix with the names of the state variables), ShockNames (string matrix with the names for the economic shocks), ' ShockStr ExtraEntry 'and DateVector (vector with dates for the observed variables). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Conditional Predictive Distributions - Initial Values',500,600,CurrINI);
                     end;
                     if isempty(PredEventData)==0;
                        %
                        % write prediction event results to file
                        %
                        file = FixFilePath([DSGEModel.OutputDirectory '\CondPredictiveDist-' int2str(DSGEModel.ShockControlMethod) '-' AnnualStr '-' num2str(MaxPH,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '-InitialValues.txt']);
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                        PrintPredictionEvent(file,DSGEModel.VariableNames,PredEventData,YObsEventData,DSGEModel.PredictionEvent,[PredStartYear ':' PredStartPeriod '-' PredEndYear ':' PredEndPeriod],MaxPH,NumPredPaths,1,CurrINI);
                        %
                        % displays the file if it exists
                        %
                        if FileExist(file)==1;
                           TextGUI(file,['Prediction Events - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Initial Parameter Values',50,CurrINI,1,0);
                        end;
                     end;
                     %
                     if size(PredData.A,1)==1;
                        ObsVarMean = PredData.A';
                     else;
                        ObsVarMean = [];
                     end;
                     %
                     % Open a dialog for displaying predictive distributions
                     %
                     CondPredictiveDistributionDLG('init',DSGEModel,CurrINI,MeanPrediction,ObsVarMean,Quantiles,PredData.KernelX,PredData.KernelY,'Initial Values','DSGE',AnnualStr,1);
                  end;
               elseif (mcode==1)&(kalmanstatus~=0);
                  if kalmanstatus==1;
                     txt = 'The state variables are not stationary at the initial values.';
                  else;
                     txt = 'The covariance matrix of the forecast of the observed variables in period t conditional on data until t-1 is not positive definite for some time period t. This implies that the log-likelihood value is a NaN (or a complex number) in Matlab.';
                  end;
                  About(txt,'information','Conditional Predictive Distributions - Initial Values',200,500,CurrINI);
               elseif mcode~=1;
                  if mcode==2;
                     mcodeStr = 'Roots are not correctly computed by real_schur.'
                  elseif mcode==3;
                     mcodeStr = 'Too many big roots.';
                  elseif mcode==35;
                     mcodeStr = 'Too many big roots, and q(:,right) is singular.';
                  elseif mcode==4;
                     mcodeStr = 'Too few big roots.';
                  elseif mcode==45;
                     mcodeStr = 'Too few big roots, and q(:,right) is singular.';
                  elseif mcode==5;
                     mcodeStr = 'q(:,right) is singular.';
                  elseif mcode==61;
                     mcodeStr = 'Too many exact shiftrights.';
                  elseif mcode==62;
                     mcodeStr = 'Too many numeric shiftrights.';
                  elseif mcode==7;
                     mcodeStr = 'Infinite or NaN values detected.';
                  elseif mcode==8;
                     mcodeStr = 'The function "compute_aim_matrices" returns complex numbers.';
                  elseif mcode==-1;
                     mcodeStr = 'No stable solution.';
                  elseif mcode==-2;
                     mcodeStr = 'Too many large generalized eigenvalues.';
                  elseif mcode==-3;
                     mcodeStr = 'Too few large generalized eigenvalues.';
                  else;
                     mcodeStr = 'Return code not properly specified.';
                  end;
                  if DSGEModel.ModelSolver==1;
                     SolverStr = 'AiM';
                  elseif DSGEModel.ModelSolver==2;
                     SolverStr = 'Klein';
                  elseif DSGEModel.ModelSolver==3;
                     SolverStr = 'Gensys';
                  elseif DSGEModel.ModelSolver==4;
                     SolverStr = ['Own algorithm (' GetName(DSGEModel.ModelSolverFile) ')'];
                  end;
                  SetLogText(strvcat(['   STATUS: ' mcodeStr],' '));
                  txt = ['The ' SolverStr ' solver provided the return code: ' num2str(mcode) ', i.e., "' mcodeStr '" You have to change your initial parameter values.'];
                  About(txt,'information','Conditional Predictive Distributions - Initial Values',120,500,CurrINI);
               end;
            end;
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconPredPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check if we should check transformations functions
         %
         ErrorStr = '';
         if gcbo==controls.predict.unconditional_transformed_posterior;
            DTStatus = VerifyDataTransformation(DSGEModel.VariableNames,DSGEModel.YTransformation,0);
            if DTStatus==1;
               [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
            else;
               ErrorStr = 'You haven''t specified all the necessary fields for computing transformations of the observed variables.';
               HeaderStr = 'Missing Transformation Information';
            end;
         end;
         %
         if isempty(ErrorStr)==1;
            %
            % are we using annualized data, transformed or the original
            %
            if gcbo==controls.predict.unconditional_original_prior;
               TransData = 0;
               AnnualizeData = 0;
               AnnualStr = 'original';
               QueryHead = 'Predictive Distributions For Prior - Original Data';
            elseif gcbo==controls.predict.unconditional_annual_prior;
               TransData = 0;
               AnnualizeData = 1;
               AnnualStr = 'annual';
               QueryHead = 'Predictive Distributions For Prior - Annualized Data';
            else;
               TransData = 1;
               AnnualizeData = 0;
               AnnualStr = 'transformed';
               QueryHead = 'Predictive Distributions For Prior - Transformed Data';
            end;
            %
            % check if the posterior mode file exists
            %
            ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
            if FileExist(ModeFile)==1;
               ErrorStr = '';
               if MatlabNumber>=8.0;
                  try;
                     ModeData = load(ModeFile);
                  catch ME;
                     ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                  end;
               else;
                  try;
                     ModeData = load(ModeFile);
                  catch;
                     ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                  end;
               end;
               if strcmp(ErrorStr,'')==1;
                  if FileExist(DSGEModel.PriorFile)==1;
                     txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                     answer = Query(txt,'question',200,QueryHead,500,'no',CurrINI);
                  else;
                     answer = 'Yes';
                  end;
                  if strcmp(lower(answer),'yes')==1;
                     InitStatus = 1;
                     theta = ModeData.theta;
                     thetaDist = ModeData.thetaDist;
                     PriorDist = ModeData.PriorDist;
                     ParameterNames = ModeData.ParameterNames;
                     LowerBound = ModeData.LowerBound;
                     ModelParameters = ModeData.ModelParameters;
                     thetaPositions = ModeData.thetaPositions;
                  else;
                     [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
                  end;
               else;
                  InitStatus = 0;
                  About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
               end;
            else;
               [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            end;
            if InitStatus==1;
               %
               % load the data
               %
               if FileExist(DSGEModel.SystemPriorFile)==0;
                  PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
               else;
                  PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
               end;
               PriorData = load(PriorDrawsFile);
               thetaDraws = PriorData.thetaDraws;
               NumPriorDraws = size(thetaDraws,2);
               %
               % check if we have a system prior and if so, use a subset of the prior draws
               %
               OldDSGEModel = DSGEModel;
               if FileExist(DSGEModel.SystemPriorFile)==1;
                  if DSGEModel.PosteriorSampler>7;
                     [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection',QueryHead,'','',CurrINI);
                     if strcmp(lower(action),'ok')==1;
                        DSGEModel.PostDrawsPercentValue = SelectedOption;
                     end;
                  else;
                     action = 'ok';
                  end;
                  if strcmp(lower(action),'ok')==1;
                     UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                     if length(UseDraws)<NumPriorDraws;
                        thetaDraws = thetaDraws(:,UseDraws);
                        NumPriorDraws = length(UseDraws);
                     end;
                  end;
               end;
               %
               % initialize the random number generator
               %
               if DSGEModel.RandomNumberValue==1;
                  randn('state',0);
                  rand('state',0);
               else;
                  randn('state',sum(100*clock));
                  rand('state',sum(100*clock));
               end;
               %
               % determine the sample and setup the data
               %
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
               %
               % check how many time periods to use for predictive distributions
               %
               [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               %
               % matrix with exogenous variables
               %
               X = [];
               if DSGEModel.k>0;
                  if NumPredX<MaxPH;
                     X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                  end;
                  if NumPredX>0;
                     X = [X DSGEModel.PredictedX(:,1:NumPredX)];
                  end;
               end;
               %
               % determine how many prediction paths to use
               %
               NumPredPathsStr = get(controls.forecast.predpaths,'String');
               NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
               %
               % check if we have already stored results to disk
               %
               if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','','',DSGEModel.NameOfModel,MaxPH,NumPriorDraws,NumPredPaths,AnnualizeData,TransData,1,0)==1;
                  txt = 'YADA has located results for the predictive distribution on disk. Would you like to use these results?';
                  answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
               else;
                  answer = 'No';
               end;
               if strcmp(lower(answer),'yes')==1;
                  [PredEventData,PredictionEvent,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = LoadDSGEPredictionUncertainty(DSGEModel.OutputDirectory,'','',DSGEModel.NameOfModel,MaxPH,NumPriorDraws,NumPredPaths,AnnualizeData,TransData,1,0);
                  DoneCalc = 1;
               else;
                  %
                  % ask if we should conduct prediction event calculations
                  %
                  txt = 'Would you like YADA to calculate prediction event probabilities and perform risk analysis?';
                  answer = Query(txt,'question',140,'Prediction Events - Prior',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                        DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                     end;
                     %
                     % make sure that the prediction event length does not exceed the maximum prediction horizon
                     %
                     for i=1:DSGEModel.n;
                        if DSGEModel.PredictionEvent(i,3)>MaxPH;
                           DSGEModel.PredictionEvent(i,3) = MaxPH;
                        end;
                     end;
                     %
                     % display a dialog for setting up an prediction event
                     %
                     [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                     if strcmp(lower(action),'ok')==1;
                        DSGEModel.PredictionEvent = PredictionEvent;
                        DSGEModel.RunPredictionEvent = 1;
                     else;
                        DSGEModel.RunPredictionEvent = 0;
                     end;
                  else;
                     DSGEModel.RunPredictionEvent = 0;
                  end;
                  %
                  % we can now compute the predictive distribution for the endogenous variables
                  % up to period MaxPH
                  %
                  [DoneCalc,PredEventData,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGEPredictionPaths(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,MaxPH,NumPredPaths,AnnualizeData,TransData,1,0,[]);
               end;
               %
               % check if we should show any results
               %
               if DoneCalc==1;
                  %
                  % yes, now we need to calculate some distribution properties
                  %
                  [MeanPrediction,CovPrediction,Quantiles,KernelX,KernelY] = DSGEPredictionDistribution(DSGEModel.n,DSGEModel.OutputDirectory,'','',DSGEModel.NameOfModel,MaxPH,NumPriorDraws,NumPredPaths,AnnualizeData,TransData,1,0,[],DSGEModel.Percentiles,DSGEModel.VariableNames,DSGEModel.ConfidenceRegionMethod,CurrINI);
                  %
                  % compute the forecast errors based on the mean predictions
                  %
                  PredictionErrors = CalculatePredictionErrors(MeanPrediction,AnnualizeData,TransData,'DSGE',DSGEModel);
                  %
                  % check if the user wants to save the data
                  %
                  txt = ['Would you like to save the predictive distributions for the ' AnnualStr ' data to file?'];
                  answer = Query(txt,'question',140,'Save - Predictive Distributions',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,size(MeanPrediction,2));
                     file = FixFilePath([DSGEModel.OutputDirectory '\PredictivePriorDist-' AnnualStr '-' num2str(MaxPH,'%0.0f') '-' num2str(NumPriorDraws,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '.mat']);
                     YNames = DSGEModel.VariableNames;
                     DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,PredEndYear,PredEndPeriod,DSGEModel.DataFrequency);
                     Y = DSGEModel.Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                     if (length(DateVector)>size(Y,2))&(TransData==0);
                        DateVector = DateVector(1,1:size(Y,2));
                     end;
                     EstimationStartPeriod = DSGEModel.KalmanFirstObservation;
                     EstimationStartPeriodOrig = EstimationStartPeriod;
                     YOrig = Y;
                     DateVectorOrig = DateVector;
                     if AnnualizeData==1;
                        Y = Annualize(Y,DSGEModel.annual,DSGEModel.annualscale);
                        EstimationStartPeriod = max(1,EstimationStartPeriod-(length(DateVector)-size(Y,2)));
                        DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                     end;
                     if TransData==1;
                        [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
                        Y = YData';
                        if size(Y,2)==DSGEModel.T;
                           Y = Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                        else;
                           T2 = size(Y,2);
                           if (FirstPeriod-(DSGEModel.T-T2))>=1;
                              Y = Y(:,FirstPeriod-(DSGEModel.T-T2):min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                           else;
                              Y = Y(:,1:min((LastPeriod+MaxPH),size(DSGEModel.Y,2))-(DSGEModel.T-T2));
                              DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                           end;
                        end;
                     end;
                     if isempty(PredEventData)==1;
                        save(file,'MeanPrediction','CovPrediction','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','StateCov','ShockCov','MeasureCov','ParameterCov','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig');
                     else;
                        save(file,'MeanPrediction','CovPrediction','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','StateCov','ShockCov','MeasureCov','ParameterCov','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig','PredictionEvent','PredEventData');
                     end;
                     %
                     % create a matlab m-file to read the output.
                     %
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\PPD' AnnualStr num2str(MaxPH,'%0.0f') num2str(NumPriorDraws,'%0.0f') num2str(NumPredPaths,'%0.0f') DSGEModel.SubEndYear DSGEModel.SubEndPeriod '.m']);
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                     fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                     fprintf(fid,'YNames = DataStructure.YNames;\n');
                     fprintf(fid,'%%\n%% matrix with the mean predictions of the observed variables\n%%\n');
                     fprintf(fid,'MeanPrediction = DataStructure.MeanPrediction;\n');
                     fprintf(fid,'%%\n%% 3D matrix (nxnxh) with the sample covariance of the predictions of the observed variables\n%%\n');
                     fprintf(fid,'CovPrediction = DataStructure.CovPrediction;\n');
                     fprintf(fid,'%%\n%% matrix with the errors from the mean predictions of the observed variables\n%%\n');
                     fprintf(fid,'PredictionErrors = DataStructure.PredictionErrors;\n');
                     fprintf(fid,'%%\n%% vector structure with quantiles from the predictive distribution\n%% the structure has %0.0f entries with fields "Quantile" and "percent"\n%% the first field is a matrix and the second a positive number between 0 and 100\n%%\n',length(Quantiles));
                     fprintf(fid,'Quantiles = DataStructure.Quantiles;\n');
                     fprintf(fid,'%%\n%% matrix with x-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                     fprintf(fid,'KernelX = DataStructure.KernelX;\n');
                     fprintf(fid,'%%\n%% matrix with y-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                     fprintf(fid,'KernelY = DataStructure.KernelY;\n');
                     fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                     fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                     fprintf(fid,'%%\n%% observed variables\n%%\n');
                     fprintf(fid,'Y = DataStructure.Y;\n');
                     fprintf(fid,'%%\n%% vector with dates for the observed variables\n%%\n');
                     fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                     if (AnnualizeData==0)&(TransData==0);
                        fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to state uncertainty\n%%\n');
                        fprintf(fid,'StateCov = DataStructure.StateCov;\n');
                        fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to shock uncertainty\n%%\n');
                        fprintf(fid,'ShockCov = DataStructure.ShockCov;\n');
                        fprintf(fid,'%%\n%% 2D Error covariance matrix (nxn) part due to measurement error uncertainty\n%%\n');
                        fprintf(fid,'MeasureCov = DataStructure.MeasureCov;\n');
                        fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to parameter uncertainty\n%%\n');
                        fprintf(fid,'ParameterCov = DataStructure.ParameterCov;\n');
                        CovDecompStr = 'StateCov (3D error covariance matrix with part due to state uncertainty), ShockCov (3D error covariance matrix with part due to shock uncertainty), MeasureCov (2D error covariance matrix with part due to measurement error uncertainty), ParameterCov (3D covariance matrix with part due to parameter uncertainty), ';
                     else;
                        CovDecompStr = '';
                     end;
                     if isempty(PredEventData)==0;
                        fprintf(fid,'%%\n%% matrix with the prediction event definitions. The first column\n%% holds the upper bound, the second column\n%% the lower bound, and third the length of the event.\n%%\n');
                        fprintf(fid,'PredictionEvent = DataStructure.PredictionEvent;\n');
                        fprintf(fid,'%%\n%% matrix with prediction event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                        fprintf(fid,'PredEventData = DataStructure.PredEventData;\n');
                        if (AnnualizeData==0)&(TransData==0);
                           NumEntries = '16';
                        else;
                           NumEntries = '12';
                        end;
                        ExtraEntry = 'PredictionEvent (matrix with the upper and lower bound of the event and the length of the event), PredEventData (matrix with the number of true events, the number of events below the lower bound for the event, the number of events above the upper bound for the event, the number of events tested in the columns, the sum and sum of squared deviations from lower bound when below lower bound, the sum and sum of squared deviations from upper bound when above upper bound), ';
                     else;
                        if (AnnualizeData==0)&(TransData==0);
                           NumEntries = '14';
                        else;
                           NumEntries = '10';
                        end;
                        ExtraEntry = '';
                     end;
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     %
                     txt = ['The predictive distributions have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' NumEntries ' entries: YNames (string matrix with the names of the observed variables), MeanPrediction (matrix with the mean predictions), CovPrediction (3D matrix with the sample covariances of the predictions), PredictionErrors (matrix with errors for the mean prediction), Quantiles (vector structure with 2 fields: Quantile and percent), KernelX (matrix with x-axis for kernel density estimates of marginal predictive distribution), KernelY (matrix with y-axis values for kernel density estimates of marginal predictive distribution), PredDateVector (vector with dates for the predictions), Y (matrix with the observed variables), ' CovDecompStr ExtraEntry 'and DateVector (vector with dates for the observed variables). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                     About(txt,'information','Predictive Distributions - Prior',500,600,CurrINI);
                  end;
                  if isempty(PredEventData)==0;
                     %
                     % write prediction event results to file
                     %
                     file = FixFilePath([DSGEModel.OutputDirectory '\PredictivePriorDist-' AnnualStr '-' num2str(MaxPH,'%0.0f') '-' num2str(NumPriorDraws,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '.txt']);
                     [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                     PrintPredictionEvent(file,DSGEModel.VariableNames,PredEventData,[],PredictionEvent,[PredStartYear ':' PredStartPeriod '-' PredEndYear ':' PredEndPeriod],MaxPH,NumPredPaths,NumPriorDraws,CurrINI);
                     %
                     % displays the file if it exists
                     %
                     if FileExist(file)==1;
                        TextGUI(file,['Prediction Events For Prior - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Prior Distribution - Unconditional Predictions',50,CurrINI,1,0);
                     end;
                  end;
                  %
                  % summarize the information in the uncertainty variables more conveniently
                  %
                  if isempty(StateCov)==0;
                     [StateVar,ShockVar,MeasureVar,ParameterVar,TotalVar] = SummarizeDSGEPredictions(StateCov,ShockCov,MeasureCov,ParameterCov);
                     %
                     % Open a dialog for displaying predictive distributions
                     %
                     UData.StateVar = StateVar;
                     UData.ShockVar = ShockVar;
                     UData.MeasureVar = MeasureVar;
                     UData.ParameterVar = ParameterVar;
                     [UData.KernelX,UData.KernelY] = NormalDensityValues(MeanPrediction,TotalVar,2^8);
                  else;
                     UData = [];
                  end;
                  PredictiveDistributionDLG('init',DSGEModel,CurrINI,MeanPrediction,[],Quantiles,KernelX,KernelY,'','DSGE',AnnualStr,0,UData);
               else;
                  DSGEModel = OldDSGEModel;
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ConPredPriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % check if we should check transformations functions
         %
         ErrorStr = '';
         if gcbo==controls.predict.conditional_transformed_posterior;
            DTStatus = VerifyDataTransformation(DSGEModel.VariableNames,DSGEModel.YTransformation,0);
            if DTStatus==1;
               [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
            else;
               ErrorStr = 'You haven''t specified all the necessary fields for computing transformations of the observed variables.';
               HeaderStr = 'Missing Transformation Information';
            end;
         end;
         %
         if isempty(ErrorStr)==1;
            %
            % are we using annualized data or the original
            %
            if gcbo==controls.predict.conditional_original_prior;
               TransData = 0;
               AnnualizeData = 0;
               AnnualStr = 'original';
               QueryHead = 'Conditional Predictive Distributions For Prior - Original Data';
            elseif gcbo==controls.predict.conditional_annual_prior;
               TransData = 0;
               AnnualizeData = 1;
               AnnualStr = 'annual';
               QueryHead = 'Conditional Predictive Distributions For Prior - Annualized Data';
            else;
               TransData = 1;
               AnnualizeData = 0;
               AnnualStr = 'transformed';
               QueryHead = 'Conditional Predictive Distributions For Prior - Transformed Data';
            end;
            %
            % check if the posterior mode file exists
            %
            ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
            if FileExist(ModeFile)==1;
               ErrorStr = '';
               if MatlabNumber>=8.0;
                  try;
                     ModeData = load(ModeFile);
                  catch ME;
                     ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
                  end;
               else;
                  try;
                     ModeData = load(ModeFile);
                  catch;
                     ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
                  end;
               end;
               if strcmp(ErrorStr,'')==1;
                  if FileExist(DSGEModel.PriorFile)==1;
                     txt = ['Would you like to use the prior information stored in the posterior mode results file "' GetFilename(ModeFile) '"? If you answer ''No'', YADA will reread the prior file "' GetFilename(DSGEModel.PriorFile) '".'];
                     answer = Query(txt,'question',200,QueryHead,500,'no',CurrINI);
                  else;
                     answer = 'Yes';
                  end;
                  if strcmp(lower(answer),'yes')==1;
                     InitStatus = 1;
                     theta = ModeData.theta;
                     thetaDist = ModeData.thetaDist;
                     PriorDist = ModeData.PriorDist;
                     ParameterNames = ModeData.ParameterNames;
                     LowerBound = ModeData.LowerBound;
                     ModelParameters = ModeData.ModelParameters;
                     thetaPositions = ModeData.thetaPositions;
                  else;
                     [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
                  end;
               else;
                  InitStatus = 0;
                  About(ErrorStr,'information','YADA - Bad MAT File',500,600,CurrINI);
               end;
            else;
               [InitStatus,theta,thetaPositions,ModelParameters,thetaDist,PriorDist,ParameterNames,thetaIndex,UniformBounds,LowerBound] = InitializeDSGEModelSimulation(DSGEModel,CurrINI);
            end;
            if InitStatus==1;
               %
               % load the data
               %
               if FileExist(DSGEModel.SystemPriorFile)==0;
                  PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-' DSGEModel.NameOfModel '.mat']);
               else;
                  PriorDrawsFile = FixFilePath([DSGEModel.OutputDirectory '\priordraws\PriorDraws-SystemPrior-' DSGEModel.NameOfModel '.mat']);
               end;
               PriorData = load(PriorDrawsFile);
               thetaDraws = PriorData.thetaDraws;
               NumPriorDraws = size(thetaDraws,2);
               %
               % check if we have a system prior and if so, use a subset of the prior draws
               %
               OldDSGEModel = DSGEModel;
               if FileExist(DSGEModel.SystemPriorFile)==1;
                  if DSGEModel.PosteriorSampler>7;
                     [action,SelectedOption] = SelectionDlg(get(controls.posterior.usepostdraws,'String'),DSGEModel.PostDrawsPercentValue,'Select the percent of prior draws to use (cancel means all draws):','Prior Draws Selection',QueryHead,'','',CurrINI);
                     if strcmp(lower(action),'ok')==1;
                        DSGEModel.PostDrawsPercentValue = SelectedOption;
                     end;
                  else;
                     action = 'ok';
                  end;
                  if strcmp(lower(action),'ok')==1;
                     UseDraws = KeepPosteriorDraws(DSGEModel,controls.posterior.usepostdraws,NumPriorDraws);
                     if length(UseDraws)<NumPriorDraws;
                        thetaDraws = thetaDraws(:,UseDraws);
                        NumPriorDraws = length(UseDraws);
                     end;
                  end;
               end;
               %
               % initialize the random number generator
               %
               if DSGEModel.RandomNumberValue==1;
                  randn('state',0);
                  rand('state',0);
               else;
                  randn('state',sum(100*clock));
                  rand('state',sum(100*clock));
               end;
               %
               % determine the sample and setup the data
               %
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
               %
               % check how many time periods to use for predictive distributions
               %
               [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
               %
               % matrix with exogenous variables
               %
               X = [];
               if DSGEModel.k>0;
                  if NumPredX<MaxPH;
                     X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                  end;
                  if NumPredX>0;
                     X = [X DSGEModel.PredictedX(:,1:NumPredX)];
                  end;
               end;
               %
               % check the length of the conditioning sample
               %
               [status,NumPeriods] = CheckConditioningData(DSGEModel);
               %
               % check if we should adjust the X matrix
               %
               if MaxPH<NumPeriods;
                  NumPeriods = MaxPH;
               end;
               %
               % collect the conditional variables and the selected conditioning sample
               %
               Z = DSGEModel.Z(DSGEModel.ConditionalVariables,LastPeriod+1:LastPeriod+NumPeriods);
               if LastPeriod>=NumPeriods;
                  U = DSGEModel.U(DSGEModel.ConditionalVariables,LastPeriod-NumPeriods+1:LastPeriod);
               else;
                  %
                  % we have to create artifical initial conditions for the conditioning variables
                  %
                  U = [DSGEModel.U(DSGEModel.ConditionalVariables,1)*ones(1,NumPeriods-LastPeriod) DSGEModel.U(DSGEModel.ConditionalVariables,1:LastPeriod)];
               end;
               %
               % check which method is used for dealing with the conditioning assumptions
               %
               if DSGEModel.ShockControlMethod==1;
                  ShockMethod = 'Direct-';
               elseif DSGEModel.ShockControlMethod==2;
                  ShockMethod = 'WaggonerZha-';
               else;
                  ShockMethod = 'Subset-';
               end;
               %
               % determine how many prediction paths to use
               %
               NumPredPathsStr = get(controls.forecast.predpaths,'String');
               NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
               %
               % check if we have already stored results to disk
               %
               if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumPriorDraws,NumPredPaths,AnnualizeData,TransData,1,0)==1;
                  txt = 'YADA has located results for the conditional predictive distribution on disk. Would you like to use these results?';
                  answer = Query(txt,'question',150,QueryHead,500,'no',CurrINI);
               else;
                  answer = 'No';
               end;
               if strcmp(lower(answer),'yes')==1;
                  [PredEventData,PredictionEvent,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = LoadDSGEPredictionUncertainty(DSGEModel.OutputDirectory,'Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumPriorDraws,NumPredPaths,AnnualizeData,TransData,1,0);
                  DoneCalc = 1;
               else;
                  %
                  % ask if we should conduct prediction event calculations
                  %
                  txt = 'Would you like YADA to calculate prediction event probabilities and perform risk analysis?';
                  answer = Query(txt,'question',140,'Prediction Events - Prior',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                        DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                     end;
                     %
                     % make sure that the prediction event length does not exceed the maximum prediction horizon
                     %
                     for i=1:DSGEModel.n;
                        if DSGEModel.PredictionEvent(i,3)>MaxPH;
                           DSGEModel.PredictionEvent(i,3) = MaxPH;
                        end;
                     end;
                     %
                     % display a dialog for setting up an prediction event
                     %
                     [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                     if strcmp(lower(action),'ok')==1;
                        DSGEModel.PredictionEvent = PredictionEvent;
                        DSGEModel.RunPredictionEvent = 1;
                     else;
                        DSGEModel.RunPredictionEvent = 0;
                     end;
                  else;
                     DSGEModel.RunPredictionEvent = 0;
                  end;
                  %
                  % we can now compute the predictive distribution for the endogenous variables
                  % up to period MaxPH
                  %
                  if DSGEModel.ShockControlMethod==1;
                     [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPaths(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,1,0,[]);
                  elseif DSGEModel.ShockControlMethod==2;
                     [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsWZ(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,1,0,[]);
                  else;
                     %
                     % check if the selected method can actually be used
                     %
                     CondTxt = '';
                     if isempty(DSGEModel.MixedConditionalShocks)==1;
                        CondTxt = 'You haven''t selected any shocks for use which the distribution of a subset of the shocks conditioning method.';
                     elseif length(DSGEModel.MixedConditionalShocks)<length(DSGEModel.ConditionalVariables);
                        CondTxt = ['The number of shocks you have selected to use to ensure that the conditioning assumptions are satisfied under the distribution of a subset of the shocks conditioning method is not sufficient. You need at least ' int2str(length(DSGEModel.ConditionalVariables)) ' such shocks.'];
                     end;
                     if isempty(CondTxt)==1;
                        [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsMixed(thetaDraws',theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,1,0,[]);
                     else;
                        About(CondTxt,'information','Bad Shocks Selection - Distribution of Subset Shocks Method',300,550,CurrINI);
                        DoneCalc = 0;
                     end;
                  end;
               end;
               %
               % check if we should show any results
               %
               if DoneCalc==1;
                  %
                  % yes, now we need to calculate some distribution properties
                  %
                  [MeanPrediction,CovPrediction,Quantiles,KernelX,KernelY] = DSGEPredictionDistribution(DSGEModel.n,DSGEModel.OutputDirectory,'Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumPriorDraws,NumPredPaths,AnnualizeData,TransData,1,0,[],DSGEModel.Percentiles,DSGEModel.VariableNames,DSGEModel.ConfidenceRegionMethod,CurrINI);
                  %
                  % compute the forecast errors based on the mean predictions
                  %
                  PredictionErrors = CalculatePredictionErrors(MeanPrediction,AnnualizeData,TransData,'DSGE',DSGEModel);
                  %
                  % check if we should evaluate modesty test data
                  %
                  if AnnualizeData==0;
                     [MultiPValue,MeanMultiModesty,MeanUniModesty,MeanUniModestyLZ] = DSGEModestyStatistics(DSGEModel.OutputDirectory,'DSGE',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumPriorDraws,NumPredPaths,1,0,DSGEModel.n,'');
                     if exist('YADAchi2cdf')==2;
                        ChiSqPValue = 1-YADAchi2cdf(MeanMultiModesty(1),DSGEModel.n);
                     else;
                        if exist('chi2cdf')==2;
                           ChiSqPValue = 1-chi2cdf(MeanMultiModesty(1),DSGEModel.n);
                        else;
                           ChiSqPValue = 1-YADACheapchi2cdf(MeanMultiModesty(1),DSGEModel.n);
                        end;
                     end;
                     %
                     % print results to file
                     %
                     PrintDSGEModestyStatistics(DSGEModel,CurrINI,1,0,0,MaxPH,NumPeriods,NumPriorDraws,NumPredPaths,MultiPValue,MeanMultiModesty,MeanUniModesty,MeanUniModestyLZ,ShockMean,ShockNames,'');
                  else;
                     ChiSqPValue = [];
                     MultiPValue = [];
                     MeanMultiModesty = [];
                     MeanUniModesty = [];
                     MeanUniModestyLZ = [];
                  end;
                  %
                  % check if the user wants to save the data
                  %
                  txt = ['Would you like to save the conditional predictive distributions for the ' AnnualStr ' data to file?'];
                  answer = Query(txt,'question',140,'Save - Conditional Predictive Distributions',500,'no',CurrINI);
                  if strcmp(lower(answer),'yes')==1;
                     [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,size(MeanPrediction,2));
                     file = FixFilePath([DSGEModel.OutputDirectory '\CondPredictivePriorDist-' int2str(DSGEModel.ShockControlMethod) '-' AnnualStr '-' num2str(MaxPH,'%0.0f') '-' num2str(NumPriorDraws,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '.mat']);
                     YNames = DSGEModel.VariableNames;
                     DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,PredEndYear,PredEndPeriod,DSGEModel.DataFrequency);
                     Y = DSGEModel.Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                     if (length(DateVector)>size(Y,2))&(TransData==0);
                        DateVector = DateVector(1,1:size(Y,2));
                     end;
                     EstimationStartPeriod = DSGEModel.KalmanFirstObservation;
                     EstimationStartPeriodOrig = EstimationStartPeriod;
                     YOrig = Y;
                     DateVectorOrig = DateVector;
                     if AnnualizeData==1;
                        Y = Annualize(Y,DSGEModel.annual,DSGEModel.annualscale);
                        EstimationStartPeriod = max(1,EstimationStartPeriod-(length(DateVector)-size(Y,2)));
                        DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                     end;
                     %
                     if TransData==1;
                        [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
                        Y = YData';
                        if size(Y,2)==DSGEModel.T;
                           Y = Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                        else;
                           T2 = size(Y,2);
                           if (FirstPeriod-(DSGEModel.T-T2))>=1;
                              Y = Y(:,FirstPeriod-(DSGEModel.T-T2):min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                           else;
                              Y = Y(:,1:min((LastPeriod+MaxPH),size(DSGEModel.Y,2))-(DSGEModel.T-T2));
                              DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                           end;
                        end;
                     end;
                     %
                     if isempty(PredEventData)==1;
                        save(file,'MeanPrediction','CovPrediction','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','StateCov','ShockCov','MeasureCov','ParameterCov','MeanMultiModesty','MultiPValue','ChiSqPValue','MeanUniModesty','MeanUniModestyLZ','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig');
                     else;
                        save(file,'MeanPrediction','CovPrediction','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','StateCov','ShockCov','MeasureCov','ParameterCov','MeanMultiModesty','MultiPValue','ChiSqPValue','MeanUniModesty','MeanUniModestyLZ','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig','PredictionEvent','PredEventData');
                     end;
                     %
                     % create a matlab m-file to read the output.
                     %
                     mfile = FixFilePath([DSGEModel.OutputDirectory '\CondPPD' int2str(DSGEModel.ShockControlMethod) AnnualStr num2str(MaxPH,'%0.0f') num2str(NumPriorDraws,'%0.0f') num2str(NumPredPaths,'%0.0f') DSGEModel.SubEndYear DSGEModel.SubEndPeriod '.m']);
                     fid = fopen(mfile,'wt');
                     fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                     fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                     fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                     fprintf(fid,'YNames = DataStructure.YNames;\n');
                     fprintf(fid,'%%\n%% matrix with the mean predictions of the observed variables\n%%\n');
                     fprintf(fid,'MeanPrediction = DataStructure.MeanPrediction;\n');
                     fprintf(fid,'%%\n%% 3D matrix (nxnxh) with the sample covariance of the predictions of the observed variables\n%%\n');
                     fprintf(fid,'CovPrediction = DataStructure.CovPrediction;\n');
                     fprintf(fid,'%%\n%% matrix with the errors from the mean predictions of the observed variables\n%%\n');
                     fprintf(fid,'PredictionErrors = DataStructure.PredictionErrors;\n');
                     fprintf(fid,'%%\n%% vector structure with quantiles from the predictive distribution\n%% the structure has %0.0f entries with fields "Quantile" and "percent"\n%% the first field is a matrix and the second a positive number between 0 and 100\n%%\n',length(Quantiles));
                     fprintf(fid,'Quantiles = DataStructure.Quantiles;\n');
                     fprintf(fid,'%%\n%% matrix with x-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                     fprintf(fid,'KernelX = DataStructure.KernelX;\n');
                     fprintf(fid,'%%\n%% matrix with y-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                     fprintf(fid,'KernelY = DataStructure.KernelY;\n');
                     fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                     fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                     fprintf(fid,'%%\n%% observed variables\n%%\n');
                     fprintf(fid,'Y = DataStructure.Y;\n');
                     fprintf(fid,'%%\n%% vector with dates for the observed variables\n%%\n');
                     fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                     if (AnnualizeData==0)&(TransData==0);
                        fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to state uncertainty\n%%\n');
                        fprintf(fid,'StateCov = DataStructure.StateCov;\n');
                        fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to shock uncertainty\n%%\n');
                        fprintf(fid,'ShockCov = DataStructure.ShockCov;\n');
                        fprintf(fid,'%%\n%% 2D Error covariance matrix (nxn) part due to measurement error uncertainty\n%%\n');
                        fprintf(fid,'MeasureCov = DataStructure.MeasureCov;\n');
                        fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to parameter uncertainty\n%%\n');
                        fprintf(fid,'ParameterCov = DataStructure.ParameterCov;\n');
                        CovDecompStr = 'StateCov (3D error covariance matrix with part due to state uncertainty), ShockCov (3D error covariance matrix with part due to shock uncertainty), MeasureCov (2D error covariance matrix with part due to measurement error uncertainty), ParameterCov (3D covariance matrix with part due to parameter uncertainty), ';
                     else;
                        CovDecompStr = '';
                     end;
                     if isempty(PredEventData)==0;
                        fprintf(fid,'%%\n%% matrix with the prediction event definitions. The first column\n%% holds the upper bound, the second column\n%% the lower bound, and third the length of the event.\n%%\n');
                        fprintf(fid,'PredictionEvent = DataStructure.PredictionEvent;\n');
                        fprintf(fid,'%%\n%% matrix with prediction event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                        fprintf(fid,'PredEventData = DataStructure.PredEventData;\n');
                        if (AnnualizeData==0)&(TransData==0);
                           NumEntries = '16';
                        else;
                           NumEntries = '12';
                        end;
                        ExtraEntry = 'PredictionEvent (matrix with the upper and lower bound of the event and the length of the event), PredEventData (matrix with the number of true events, the number of events below the lower bound for the event, the number of events above the upper bound for the event, the number of events tested in the columns, the sum and sum of squared deviations from lower bound when below lower bound, the sum and sum of squared deviations from upper bound when above upper bound), ';
                     else;
                        if (AnnualizeData==0)&(TransData==0);
                           NumEntries = '14';
                        else;
                           NumEntries = '10';
                        end;
                        ExtraEntry = '';
                     end;
                     if AnnualizeData==0;
                        fprintf(fid,'%%\n%% vector with the mean of the multivariate modesty statistic and its reference statistic\n%%\n');
                        fprintf(fid,'MeanMultiModesty = DataStructure.MeanMultiModesty;\n');
                        fprintf(fid,'%%\n%% tail probability based on the reference statistic\n%%\n');
                        fprintf(fid,'MultiPValue = DataStructure.MultiPValue;\n');
                        fprintf(fid,'%%\n%% tail probability based on the chi-square distribution\n%%\n');
                        fprintf(fid,'ChiSqPValue = DataStructure.ChiSqPValue;\n');
                        fprintf(fid,'%%\n%% Adolfson, Lasen, Lind and Villani univariate modesty statistic\n%%\n');
                        fprintf(fid,'MeanUniModesty = DataStructure.MeanUniModesty;\n');
                        fprintf(fid,'%%\n%% Leeper and Zha univariate modesty statistic\n%%\n');
                        fprintf(fid,'MeanUniModestyLZ = DataStructure.MeanUniModestyLZ;\n');
                        NumEntries = num2str(str2num(NumEntries)+5,'%0.0f');
                        ExtraEntry = [ExtraEntry 'MeanMultiModesty (1x2 vector with the mean of the multivariate modesty statistic and the mean of the multivariate reference modesty statistic), MultiPValue (scalar with the tail probability of the modesty statistic), ChiSqPValue (scalar with the tail probability of the modesty statistic using the chi-square distribution), MeanUniModesty (vector with the univariate modesty statistic from ALLV), MeanUniModestyLZ (vector with the univariate Leeper-Zha modesty statistic), '];
                     end;
                     fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                     %
                     % end the script file
                     %
                     fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                     fclose(fid);
                     %
                     txt = ['The conditional predictive distributions have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' NumEntries ' entries: YNames (string matrix with the names of the observed variables), MeanPrediction (matrix with the mean predictions), CovPrediction (3D matrix with the sample covariances of the predictions), PredictionErrors (matrix with errors for the mean predictions), Quantiles (vector structure with 2 fields: Quantile and percent), KernelX (matrix with x-axis for kernel density estimates of marginal predictive distribution), KernelY (matrix with y-axis values for kernel density estimates of marginal predictive distribution), PredDateVector (vector with dates for the predictions), Y (matrix) with the observed variables, ' CovDecompStr ExtraEntry 'and DateVector (vector with dates for the observed variables). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                     About(txt,'information','Conditional Predictive Distributions - Prior',500,600,CurrINI);
                  end;
                  if isempty(PredEventData)==0;
                     %
                     % write prediction event results to file
                     %
                     file = FixFilePath([DSGEModel.OutputDirectory '\CondPredictivePriorDist-' int2str(DSGEModel.ShockControlMethod) '-' AnnualStr '-' num2str(MaxPH,'%0.0f') '-' num2str(NumPriorDraws,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '.txt']);
                     [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                     PrintPredictionEvent(file,DSGEModel.VariableNames,PredEventData,[],PredictionEvent,[PredStartYear ':' PredStartPeriod '-' PredEndYear ':' PredEndPeriod],MaxPH,NumPredPaths,NumPriorDraws,CurrINI);
                     %
                     % displays the file if it exists
                     %
                     if FileExist(file)==1;
                        TextGUI(file,['Prediction Events For Prior - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Prior Distribution - Conditional Predictions',50,CurrINI,1,0);
                     end;
                  end;
                  %
                  % summarize the information in the uncertainty variables more conveniently
                  %
                  if isempty(StateCov)==0;
                     [StateVar,ShockVar,MeasureVar,ParameterVar,TotalVar] = SummarizeDSGEPredictions(StateCov,ShockCov,MeasureCov,ParameterCov);
                     %
                     % Open a dialog for displaying predictive distributions
                     %
                     UData.StateVar = StateVar;
                     UData.ShockVar = ShockVar;
                     UData.MeasureVar = MeasureVar;
                     UData.ParameterVar = ParameterVar;
                     [UData.KernelX,UData.KernelY] = NormalDensityValues(MeanPrediction,TotalVar,2^8);
                  else;
                     UData = [];
                  end;
                  %
                  % make sure that UData is empty until the forecast error variance decompositions have been solved
                  % under conditional forecasting
                  %
                  CondPredictiveDistributionDLG('init',DSGEModel,CurrINI,MeanPrediction,[],Quantiles,KernelX,KernelY,'','DSGE',AnnualStr,0,UData);
               else;
                  DSGEModel = OldDSGEModel;
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconPredPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the predictive distr
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         %
         % check if we should check transformations functions
         %
         if (isempty(ErrorStr)==1)&(gcbo==controls.predict.unconditional_transformed_postmode);
            DTStatus = VerifyDataTransformation(DSGEModel.VariableNames,DSGEModel.YTransformation,0);
            if DTStatus==1;
               [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
            else;
               ErrorStr = 'You haven''t specified all the necessary fields for computing transformations of the observed variables.';
               HeaderStr = 'Missing Transformation Information';
            end;
         end;
         %
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%               FirstPeriod = ModeData.DSGEModel.FirstPeriod;
%               LastPeriod = ModeData.DSGEModel.LastPeriod;
%            else;
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            %
            % check how many time periods to use for predictive distributions
            %
            [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
            %
            % matrix with exogenous variables
            %
            X = [];
            if DSGEModel.k>0;
               if NumPredX<MaxPH;
                  X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
               end;
               if NumPredX>0;
                  X = [X DSGEModel.PredictedX(:,1:NumPredX)];
               end;
            end;
            %
            % check if we should annualize or not
            %
            if gcbo==controls.predict.unconditional_original_postmode;
               TransData = 0;
               AnnualizeData = 0;
               AnnualStr = 'original';
            elseif gcbo==controls.predict.unconditional_annual_postmode;
               TransData = 0;
               AnnualizeData = 1;
               AnnualStr = 'annual';
            elseif isfield(DSGEModel,'answers')==1;
               if strcmp(lower(DSGEModel.answers{1}),'original')==1;
                  TransData = 0;
                  AnnualizeData = 0;
                  AnnualStr = 'original';
               elseif strcmp(lower(DSGEModel.answers{1}),'annual')==1;
                  TransData = 0;
                  AnnualizeData = 1;
                  AnnualStr = 'annual';
               else;
                  TransData = 1;
                  AnnualizeData = 0;
                  AnnualStr = 'transformed';
               end;
            else;
               TransData = 1;
               AnnualizeData = 0;
               AnnualStr = 'transformed';
            end;
            %
            % determine how many prediction paths to use
            %
            NumPredPathsStr = get(controls.forecast.predpaths,'String');
            NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
            %
            % ask if we should conduct prediction event calculations
            %
            if DSGEModel.RunDriver==0;
               if NumPredPaths>1;
                  txt = 'Would you like YADA to calculate prediction event probabilities and perform risk analysis?';
                  answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
               else;
                  answer = 'No';
               end;
            else;
               if NumPredPaths>1;
                  answer = DSGEModel.answers{2};
               else;
                  answer = 'No';
               end;
            end;
            if strcmp(lower(answer),'yes')==1;
               if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                  DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
               end;
               %
               % make sure that the prediction event length does not exceed the maximum prediction horizon
               %
               for i=1:DSGEModel.n;
                  if DSGEModel.PredictionEvent(i,3)>MaxPH;
                     DSGEModel.PredictionEvent(i,3) = MaxPH;
                  end;
               end;
               %
               % display a dialog for setting up an prediction event
               %
               [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
               if strcmp(lower(action),'ok')==1;
                  DSGEModel.PredictionEvent = PredictionEvent;
                  DSGEModel.RunPredictionEvent = 1;
               else;
                  DSGEModel.RunPredictionEvent = 0;
               end;
            else;
               DSGEModel.RunPredictionEvent = 0;
            end;
            %
            % we can now compute the predictive distribution for the endogenous variables
            % up to period MaxPh
            %
            if DSGEModel.RandomNumberValue==1;
               randn('state',0);
            else;
               randn('state',sum(100*clock));
            end;
            [PredPaths,PredData,PredEventData,YObsEventData] = DSGEPredictionPathsTheta(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,MaxPH,NumPredPaths,AnnualizeData,TransData,' At Posterior Mode');
            if isempty(PredPaths)==0;
               %
               % the computations went OK. Compute point estimates from predictive distribution and
               % quantiles
               %
               [MeanPrediction,Quantiles] = PredictionPathDistribution(PredPaths,DSGEModel.Percentiles,DSGEModel.ConfidenceRegionMethod);
               %
               % compute the mean error bias in percent
               %
               MeanErrorBias = max(max(abs((PredData.PredMean-MeanPrediction)./PredData.PredMean)));
               if DSGEModel.AdjustPredictionPaths==0;
                  %
                  % ask if the prediction distribution should be corrected
                  %
                  if DSGEModel.RunDriver==0;
                     txt = ['The absolute mean error bias from using the simulated draws is ' num2str(MeanErrorBias,'%0.4f') ' percent relative to the theoretical mean. Would you like to adjust that predictive distribution such that it matches the theoretical mean?'];
                     answer = Query(txt,'question',140,'Mean Error Bias - Predictive Distributions',500,'yes',CurrINI);
                  else;
                     answer = DSGEModel.answers{3};
                  end;
               else;
                  answer = 'Yes';
               end;
               if strcmp(lower(answer),'yes')==1;
                  %
                  % adjust the quantiles to match
                  %
                  for i=1:length(Quantiles);
                     OlVal = Quantiles(i).Quantile;
                     Quantiles(i).Quantile = Quantiles(i).Quantile+(PredData.PredMean-MeanPrediction);
                  end;
                  MeanPrediction = PredData.PredMean;
               end;
               %
               % compute the forecast errors based on the mean predictions
               %
               PredictionErrors = CalculatePredictionErrors(MeanPrediction,AnnualizeData,TransData,'DSGE',DSGEModel);
               %
               % check if the user wants to save the data
               %
               if DSGEModel.RunDriver==0;
                  txt = ['Would you like to save the predictive distributions for the ' AnnualStr ' data at posterior mode to file?'];
                  answer = Query(txt,'question',140,'Save - Predictive Distributions',500,'no',CurrINI);
               else;
                  answer = DSGEModel.answers{4};
               end;
               if strcmp(lower(answer),'yes')==1;
                  if DSGEModel.RunDriver==1;
                     SetLogText(strvcat('* Saving results to: ',['     ' DSGEModel.OutputDirectory]));
                  end;
                  [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,size(MeanPrediction,2));
                  file = FixFilePath([DSGEModel.OutputDirectory '\PredictiveDist-' AnnualStr '-' num2str(MaxPH,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '-PosteriorMode.mat']);
                  YNames = DSGEModel.VariableNames;
                  DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,PredEndYear,PredEndPeriod,DSGEModel.DataFrequency);
                  Y = DSGEModel.Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                  if (length(DateVector)>size(Y,2))&(TransData==0);
                     DateVector = DateVector(1,1:size(Y,2));
                  end;
                  EstimationStartPeriod = DSGEModel.KalmanFirstObservation;
                  EstimationStartPeriodOrig = EstimationStartPeriod;
                  YOrig = Y;
                  DateVectorOrig = DateVector;
                  if AnnualizeData==1;
                     Y = Annualize(Y,DSGEModel.annual,DSGEModel.annualscale);
                     EstimationStartPeriod = max(1,EstimationStartPeriod-(length(DateVector)-size(Y,2)));
                     DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                  end;
                  if TransData==1;
                     [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
                     Y = YData';
                     if size(Y,2)==DSGEModel.T;
                        Y = Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                     else;
                        T2 = size(Y,2);
                        if (FirstPeriod-(DSGEModel.T-T2))>=1;
                           Y = Y(:,FirstPeriod-(DSGEModel.T-T2):min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                        else;
                           Y = Y(:,1:min((LastPeriod+MaxPH),size(DSGEModel.Y,2))-(DSGEModel.T-T2));
                           DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                        end;
                     end;
                  end;
                  PredMeanKsiStates = PredData.xiStates;
                  PredMean = PredData.PredMean;
                  StateVariableNames = DSGEModel.StateVariableNames;
                  %
                  A = PredData.A;
                  H = PredData.H;
                  R = PredData.R;
                  F = PredData.F;
                  B0 = PredData.B0;
                  %
                  ShockPaths = PredData.Shocks;
                  HistState = PredData.HistState;
                  MeasureErrorPaths = PredData.MeasError;
                  ShockNames = PredData.ShockNames;
                  KernelX = PredData.KernelX;
                  KernelY = PredData.KernelY;
                  if isempty(PredEventData)==1;
                     save(file,'A','H','R','F','B0','PredPaths','ShockPaths','MeasureErrorPaths','HistState','MeanPrediction','PredMean','PredMeanKsiStates','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','StateVariableNames','ShockNames','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig');
                  else;
                     save(file,'A','H','R','F','B0','PredPaths','ShockPaths','MeasureErrorPaths','HistState','MeanPrediction','PredMean','PredMeanKsiStates','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','StateVariableNames','ShockNames','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig','PredictionEvent','PredEventData','YObsEventData');
                  end;
                  %
                  % create a matlab m-file to read the output.
                  %
                  mfile = FixFilePath([DSGEModel.OutputDirectory '\PD' AnnualStr num2str(MaxPH,'%0.0f') DSGEModel.SubEndYear DSGEModel.SubEndPeriod 'PostMode.m']);
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% M E A S U R E M E N T   E Q U A T I O N\n');
                  fprintf(fid,'%%\n%% matrix with parameters on exogenous variables\n%%\n');
                  fprintf(fid,'A = DataStructure.A;\n');
                  fprintf(fid,'%%\n%% matrix with parameters on state variables\n%%\n');
                  fprintf(fid,'H = DataStructure.H;\n');
                  fprintf(fid,'%%\n%% matrix with measurement error covariances\n%%\n');
                  fprintf(fid,'R = DataStructure.R;\n');
                  fprintf(fid,'%%\n%% S T A T E   E Q U A T I O N\n');
                  fprintf(fid,'%%\n%% matrix with state transition parameters\n%%\n');
                  fprintf(fid,'F = DataStructure.F;\n');
                  fprintf(fid,'%%\n%% matrix with shock parameters\n%%\n');
                  fprintf(fid,'B0 = DataStructure.B0;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the state variables variables\n%%\n');
                  fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the economic shocks\n%%\n');
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%%  3D matrix with all the prediction paths for the observed variables\n%%\n');
                  fprintf(fid,'PredPaths = DataStructure.PredPaths;\n');
                  fprintf(fid,'%%\n%% Underlying draws of the economic shocks for all paths\n%%\n');
                  fprintf(fid,'ShockPaths = DataStructure.ShockPaths;\n');
                  fprintf(fid,'%%\n%% Underlying draws of the neasurement errors for all paths\n%%\n');
                  fprintf(fid,'MeasureErrorPaths = DataStructure.MeasureErrorPaths;\n');
                  fprintf(fid,'%%\n%% Underlying draws of the state variables before the predictions\n%%\n');
                  fprintf(fid,'HistState = DataStructure.HistState;\n');
                  fprintf(fid,'%%\n%% matrix with the sample mean predictions of the observed variables\n%%\n');
                  fprintf(fid,'MeanPrediction = DataStructure.MeanPrediction;\n');
                  fprintf(fid,'%%\n%% matrix with the population mean of the predictions of the observed variables\n%%\n');
                  fprintf(fid,'PredMean = DataStructure.PredMean;\n');
                  fprintf(fid,'%%\n%% matrix with the population mean of the predictions of the state variables\n%%\n');
                  fprintf(fid,'PredMeanKsiStates = DataStructure.PredMeanKsiStates;\n');
                  fprintf(fid,'%%\n%% matrix with the errors from the mean predictions of the observed variables\n%%\n');
                  fprintf(fid,'PredictionErrors = DataStructure.PredictionErrors;\n');
                  fprintf(fid,'%%\n%% vector structure with quantiles from the predictive distribution\n%% the structure has %0.0f entries with fields "Quantile" and "percent"\n%% the first field is a matrix and the second a positive number between 0 and 100\n%%\n',length(Quantiles));
                  fprintf(fid,'Quantiles = DataStructure.Quantiles;\n');
                  if isempty(KernelX)==0;
                     fprintf(fid,'%%\n%% matrix with x-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                     fprintf(fid,'KernelX = DataStructure.KernelX;\n');
                     fprintf(fid,'%%\n%% matrix with y-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                     fprintf(fid,'KernelY = DataStructure.KernelY;\n');
                     KStr = 'KernelX (matrix with x-axis for kernel density estimates of marginal predictive distribution), KernelY (matrix with y-axis values for kernel density estimates of marginal predictive distribution), ';
                     KVal = 2;
                  else;
                     KStr = '';
                     KVal = 0;
                  end;
                  fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                  fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                  fprintf(fid,'%%\n%% observed variables\n%%\n');
                  fprintf(fid,'Y = DataStructure.Y;\n');
                  fprintf(fid,'%%\n%% vector with dates for the observed variables\n%%\n');
                  fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                  if isempty(PredEventData)==0;
                     fprintf(fid,'%%\n%% matrix with the prediction event definitions. The first column\n%% holds the upper bound, the second column\n%% the lower bound, and third the length of the event.\n%%\n');
                     fprintf(fid,'PredictionEvent = DataStructure.PredictionEvent;\n');
                     fprintf(fid,'%%\n%% matrix with prediction event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                     fprintf(fid,'PredEventData = DataStructure.PredEventData;\n');
                     fprintf(fid,'%%\n%% matrix with observed event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                     fprintf(fid,'YObsEventData = DataStructure.YObsEventData;\n');
                     NumEntries = int2str(23+KVal);
                     ExtraEntry = 'PredictionEvent (matrix with the upper and lower bound of the event and the length of the event), PredEventData (matrix with the number of true prediction events, the number of events below the lower bound for the event, the number of events above the upper bound for the event, the number of events tested in the columns, the sum and sum of squared deviations from lower bound when below lower bound, the sum and sum of squared deviations from upper bound when above upper bound), YObsEventData (matrix with the number of true events for prediction paths whose mean is the observed data, the number of events below the lower bound for the event, the number of events above the upper bound for the event, the number of events tested in the columns, the sum and sum of squared of deviations from lower bound when below lower bound, the sum and sum of squared of deviations from upper bound when above upper bound), ';
                  else;
                     NumEntries = int2str(20+KVal);
                     ExtraEntry = '';
                  end;
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  %
                  if DSGEModel.RunDriver==0;
                     txt = ['The predictive distributions have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' NumEntries ' entries: the 5 state space matrices (A, H, R, F, B0), YNames (string matrix with the names of the observed variables), StateVariableNames (string matrix with the names of the state variables), ShockNames (string matrix with the names of the economic shocks), PredPaths (3D matrix with the prediction paths for the observed variables), ShockPaths (3D matrix with the underlying economic shocks for the prediction paths), MeasureErrorPaths (3D matrix with the underlying draws of the measurement errors for the prediction paths), HistState (matrix with the underlying draws of the state variables from the period prior to the predictions), MeanPrediction (matrix with the sample mean predictions), PredMean (matrix with the population mean predictions), PredMeanKsiStates (matrix with the population mean state predictions), PredictionErrors (matrix with errors for the mean predictions), Quantiles (vector structure with 2 fields: Quantile and percent), ' KStr 'PredDateVector (vector with dates for the predictions), Y (matrix) with the observed variables, ' ExtraEntry 'and DateVector (vector with dates for the observed variables). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                     About(txt,'information','Predictive Distributions - Posterior Mode',700,600,CurrINI);
                  end;
               end;
               if isempty(PredEventData)==0;
                  %
                  % write prediction event results to file
                  %
                  file = FixFilePath([DSGEModel.OutputDirectory '\PredictiveDist-' AnnualStr '-' num2str(MaxPH,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '-PosteriorMode.txt']);
                  [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                  PrintPredictionEvent(file,DSGEModel.VariableNames,PredEventData,YObsEventData,DSGEModel.PredictionEvent,[PredStartYear ':' PredStartPeriod '-' PredEndYear ':' PredEndPeriod],MaxPH,NumPredPaths,1,CurrINI);
                  %
                  % displays the file if it exists
                  %
                  if FileExist(file)==1;
                     TextGUI(file,['Prediction Events - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Mode Parameter Values',50,CurrINI,1,0);
                  end;
               end;
               %
               if size(PredData.A,1)==1;
                  ObsVarMean = PredData.A';
               else;
                  ObsVarMean = [];
               end;
               %
               % Open a dialog for displaying predictive distributions
               %
               if DSGEModel.RunDriver==0;
                  PredictiveDistributionDLG('init',DSGEModel,CurrINI,MeanPrediction,ObsVarMean,Quantiles,PredData.KernelX,PredData.KernelY,'Posterior Mode','DSGE',AnnualStr,1);
               else;
                  SetLogText(strvcat('* Finished calculations.',' '));
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'ConPredPostMode'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         %
         % File with the data needed to calculate the predictive distr
         %
         drawnow;
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         %
         % check if we should check transformations functions
         %
         if (isempty(ErrorStr)==1)&(gcbo==controls.predict.conditional_transformed_postmode);
            DTStatus = VerifyDataTransformation(DSGEModel.VariableNames,DSGEModel.YTransformation,0);
            if DTStatus==1;
               [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
            else;
               ErrorStr = 'You haven''t specified all the necessary fields for computing transformations of the observed variables.';
               HeaderStr = 'Missing Transformation Information';
            end;
         end;
         %
         if strcmp(ErrorStr,'')==1;
            theta = ModeData.thetaMode;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%               FirstPeriod = ModeData.DSGEModel.FirstPeriod;
%               LastPeriod = ModeData.DSGEModel.LastPeriod;
%            else;
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            %
            % check how many time periods to use for predictive distributions
            %
            [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
            %
            % matrix with exogenous variables
            %
            X = [];
            if DSGEModel.k>0;
               if NumPredX<MaxPH;
                  X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
               end;
               if NumPredX>0;
                  X = [X DSGEModel.PredictedX(:,1:NumPredX)];
               end;
            end;
            %
            % check the length of the conditioning sample
            %
            [status,NumPeriods] = CheckConditioningData(DSGEModel);
            %
            % check if we should adjust the Z matrix
            %
            if MaxPH<NumPeriods;
               NumPeriods = MaxPH;
            end;
            %
            % collect the conditional variables and the selected conditioning sample
            %
            Z = DSGEModel.Z(DSGEModel.ConditionalVariables,LastPeriod+1:LastPeriod+NumPeriods);
            if LastPeriod>=NumPeriods;
               U = DSGEModel.U(DSGEModel.ConditionalVariables,LastPeriod-NumPeriods+1:LastPeriod);
            else;
               %
               % we have to create artifical initial conditions for the conditioning variables
               %
               U = [DSGEModel.U(DSGEModel.ConditionalVariables,1)*ones(1,NumPeriods-LastPeriod) DSGEModel.U(DSGEModel.ConditionalVariables,1:LastPeriod)];
            end;
            %
            % check if we should annualize or not
            %
            if DSGEModel.RunDriver==0;
               if gcbo==controls.predict.conditional_original_postmode;
                  TransData = 0;
                  AnnualizeData = 0;
                  AnnualStr = 'original';
               elseif gcbo==controls.predict.conditional_annual_postmode;
                  TransData = 0;
                  AnnualizeData = 1;
                  AnnualStr = 'annual';
               elseif gcbo==controls.predict.conditional_transformed_postmode;
                  TransData = 1;
                  AnnualizeData = 0;
                  AnnualStr = 'transformed';
               end;
            else;
               if strcmp(lower(DSGEModel.answers{1}),'original')==1;
                  TransData = 0;
                  AnnualizeData = 0;
                  AnnualStr = 'original';
               elseif strcmp(lower(DSGEModel.answers{1}),'annual')==1;
                  TransData = 0;
                  AnnualizeData = 1;
                  AnnualStr = 'annual';
               else;
                  TransData = 1;
                  AnnualizeData = 0;
                  AnnualStr = 'transformed';
               end;
            end;
            %
            % determine how many prediction paths to use
            %
            NumPredPathsStr = get(controls.forecast.predpaths,'String');
            NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
            %
            % ask if we should conduct prediction event calculations
            %
            if DSGEModel.RunDriver==0;
               if NumPredPaths>1;
                  txt = 'Would you like YADA to calculate prediction event probabilities and perform risk analysis?';
                  answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
               else;
                  answer = 'No';
               end;
            else;
               if NumPredPaths>1;
                  answer = DSGEModel.answers{2};
               else;
                  answer = 'No';
               end;
            end;
            if strcmp(lower(answer),'yes')==1;
               if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                  DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
               end;
               %
               % make sure that the prediction event length does not exceed the maximum prediction horizon
               %
               for i=1:DSGEModel.n;
                  if DSGEModel.PredictionEvent(i,3)>MaxPH;
                     DSGEModel.PredictionEvent(i,3) = MaxPH;
                  end;
               end;
               %
               % display a dialog for setting up an prediction event
               %
               [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
               if strcmp(lower(action),'ok')==1;
                  DSGEModel.PredictionEvent = PredictionEvent;
                  DSGEModel.RunPredictionEvent = 1;
               else;
                  DSGEModel.RunPredictionEvent = 0;
               end;
            else;
               DSGEModel.RunPredictionEvent = 0;
            end;
            %
            % we can now compute the predictive distribution for the endogenous variables
            % up to period MaxPh
            %
            if DSGEModel.RandomNumberValue==1;
               randn('state',0);
            else;
               randn('state',sum(100*clock));
            end;
            %
            if DSGEModel.ShockControlMethod==1;
               [PredPaths,PredData,PredEventData,YObsEventData,MultiModestyStat,UniModestyStat,MeanUniModestyLZ] = DSGECondPredictionPathsTheta(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,' At Posterior Mode');
            elseif DSGEModel.ShockControlMethod==2;
               [PredPaths,PredData,PredEventData,YObsEventData,MultiModestyStat,UniModestyStat,MeanUniModestyLZ] = DSGECondPredictionPathsThetaWZ(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,' At Posterior Mode');
            else;
               %
               % check if the selected method can actually be used
               %
               CondTxt = '';
               if isempty(DSGEModel.MixedConditionalShocks)==1;
                  CondTxt = 'You haven''t selected any shocks for use which the distribution of a subset of the shocks conditioning method.';
               elseif length(DSGEModel.MixedConditionalShocks)<length(DSGEModel.ConditionalVariables);
                  CondTxt = ['The number of shocks you have selected to use to ensure that the conditioning assumptions are satisfied under the distribution of a subset of the shocks conditioning method is not sufficient. You need at least ' int2str(length(DSGEModel.ConditionalVariables)) ' such shocks.'];
               end;
               if isempty(CondTxt)==1;
                  [PredPaths,PredData,PredEventData,YObsEventData,MultiModestyStat,UniModestyStat,MeanUniModestyLZ] = DSGECondPredictionPathsThetaMixed(theta,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,' At Posterior Mode');
               else;
                  About(CondTxt,'information','Bad Shocks Selection - Distribution of Subset Shocks Method',300,550,CurrINI);
                  PredPaths = [];
               end;
            end;
            if isempty(PredPaths)==0;
               %
               % the computations went OK. Compute point estimates from predictive distribution and
               % quantiles
               %
               [MeanPrediction,Quantiles] = PredictionPathDistribution(PredPaths,DSGEModel.Percentiles,DSGEModel.ConfidenceRegionMethod);
               %
               % compute the mean error bias in percent
               %
               MeanErrorBias = max(max(abs((PredData.PredMean-MeanPrediction)./PredData.PredMean)));
               if DSGEModel.AdjustPredictionPaths==0;
                  %
                  % ask if the prediction distribution should be corrected
                  %
                  if DSGEModel.RunDriver==0;
                     txt = ['The absolute mean error bias from using the simulated draws is ' num2str(MeanErrorBias,'%0.4f') ' percent relative to the theoretical mean. Would you like to adjust that predictive distribution such that it matches the theoretical mean?'];
                     answer = Query(txt,'question',140,'Mean Error Bias - Conditional Predictive Distributions',500,'yes',CurrINI);
                  else;
                     answer = DSGEModel.answers{3};
                  end;
               else;
                  answer = 'Yes';
               end;
               AdjustMean = 0;
               if strcmp(lower(answer),'yes')==1;
                  %
                  % adjust the quantiles to match
                  %
                  for i=1:length(Quantiles);
                     OlVal = Quantiles(i).Quantile;
                     Quantiles(i).Quantile = Quantiles(i).Quantile+(PredData.PredMean-MeanPrediction);
                  end;
                  MeanPrediction = PredData.PredMean;
                  PredData.MeanPredPath = PredData.OrigPredMean;
                  AdjustMean = 1;
               end;
               %
               % compute the forecast errors based on the mean predictions
               %
               PredictionErrors = CalculatePredictionErrors(MeanPrediction,AnnualizeData,TransData,'DSGE',DSGEModel);
               %
               % check if we have modesty statistics to deal with
               %
               if AnnualizeData==0;
                  %
                  % check how often we have a greater value of column 1 than column 2 in MultiModestyStat
                  %
                  MultiPValue = sum(MultiModestyStat(:,1)<=MultiModestyStat(:,2))/NumPredPaths;
                  MeanMultiModesty = (1/NumPredPaths)*[sum(MultiModestyStat(:,1)) sum(MultiModestyStat(:,2))];
                  MeanUniModesty = zeros(1,DSGEModel.n);
                  for i=1:DSGEModel.n;
                     MeanUniModesty(1,i) = (1/NumPredPaths)*sum(UniModestyStat(:,i));
                  end;
                  if exist('YADAchi2cdf')==2;
                     ChiSqPValue = 1-YADAchi2cdf(MeanMultiModesty(1),DSGEModel.n);
                  else;
                     if exist('chi2cdf')==2;
                        ChiSqPValue = 1-chi2cdf(MeanMultiModesty(1),DSGEModel.n);
                     else;
                        ChiSqPValue = 1-YADACheapchi2cdf(MeanMultiModesty(1),DSGEModel.n);
                     end;
                  end;
                  PrintDSGEModestyStatistics(DSGEModel,CurrINI,'Posterior Mode',1,0,MaxPH,NumPeriods,1,NumPredPaths,MultiPValue,MeanMultiModesty,MeanUniModesty,MeanUniModestyLZ,PredData.etaShocks,PredData.ShockNames,'');
               else;
                  MultiPValue = [];
                  MeanMultiModesty = [];
                  MeanUniModesty = [];
                  ChiSqPValue = [];
               end;
               %
               % check if the user wants to save the data
               %
               if DSGEModel.RunDriver==0;
                  txt = ['Would you like to save the conditional predictive distributions for the ' AnnualStr ' data at posterior mode to file?'];
                  answer = Query(txt,'question',140,'Save - Conditional Predictive Distributions',500,'no',CurrINI);
                  drawnow;
               else;
                  answer = DSGEModel.answers{4};
               end;
               if strcmp(lower(answer),'yes')==1;
                  if DSGEModel.RunDriver==1;
                     SetLogText(strvcat('* Saving results to: ',['     ' DSGEModel.OutputDirectory]));
                  end;
                  [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,size(MeanPrediction,2));
                  file = FixFilePath([DSGEModel.OutputDirectory '\CondPredictiveDist-' int2str(DSGEModel.ShockControlMethod) '-' AnnualStr '-' num2str(MaxPH,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '-PosteriorMode.mat']);
                  YNames = DSGEModel.VariableNames;
                  PredMean = PredData.PredMean;
                  DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,PredEndYear,PredEndPeriod,DSGEModel.DataFrequency);
                  Y = DSGEModel.Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                  if (length(DateVector)>size(Y,2))&(TransData==0);
                     DateVector = DateVector(1,1:size(Y,2));
                  end;
                  ShockDateVector = DateVector(1,DSGEModel.KalmanFirstObservation:length(DateVector));
                  if FirstPeriod>=2;
                     YInitial = DSGEModel.Y(:,1:FirstPeriod-1);
                  else;
                     YInitial = [];
                  end;
                  %
                  A = PredData.A;
                  H = PredData.H;
                  R = PredData.R;
                  F = PredData.F;
                  B0 = PredData.B0;
                  %
                  % check if we should compute the shock scenarios for the predictions
                  %
                  if FileExist(FixFilePath([pwd '\addons\sss\DSGEPredictionShockScenarios.m']))==1;
                     if AdjustMean==1;
                        ShockScenarioResults = PredData.ShockScenarioResults;
                        if size(PredData.B0,2)==size(DSGEModel.StateShockNames,1);
                           [B0_h,KeepShocks] = RemoveRedundantColumns(PredData.B0);
                           ShockNames = DSGEModel.StateShockNames(KeepShocks,:);
                        else;
                           ShockNames = PredData.ShockNames;
                        end;
                        wtT = zeros(DSGEModel.n,MaxPH);
                     else;
                        if isempty(DSGEModel.X)==0;
                           [ShockScenarioResults,ShockNames,wtT,SmoothShocks] = DSGEPredictionShockScenarios(PredData.A,PredData.H,PredData.R,PredData.F,PredData.B0,DSGEModel,DSGEModel.Y(:,FirstPeriod:LastPeriod),PredData.MeanPredPath,DSGEModel.X(:,FirstPeriod:LastPeriod),X,AnnualizeData);
                        else;
                           [ShockScenarioResults,ShockNames,wtT,SmoothShocks] = DSGEPredictionShockScenarios(PredData.A,PredData.H,PredData.R,PredData.F,PredData.B0,DSGEModel,DSGEModel.Y(:,FirstPeriod:LastPeriod),PredData.MeanPredPath,[],X,AnnualizeData);
                        end;
                        if isempty(ShockNames)==1;
                           ShockNames = PredData.ShockNames;
                        end;
                     end;
                  else;
                     ShockScenarioResults = [];
                     if size(PredData.B0,2)==size(DSGEModel.StateShockNames,1);
                        [B0_h,KeepShocks] = RemoveRedundantColumns(PredData.B0);
                        ShockNames = DSGEModel.StateShockNames(KeepShocks,:);
                     else;
                        ShockNames = PredData.ShockNames;
                     end;
                     wtT = [];
                     SmoothShocks = [];
                  end;
                  %
                  % check if we should compute the observed variable scenario for the predictions
                  %
                  if (FileExist(FixFilePath([pwd '\addons\ovs\DSGEPredictionOVDecTheta.m']))==1)&(size(DSGEModel.Y>=LastPeriod+MaxPH));
                     if DSGEModel.RunDriver==0;
                        txt = ['Would you also like to compute and save observed variable decompositions for the ' AnnualStr ' data at posterior mode to file?'];
                        answer = Query(txt,'question',140,'Conditional Predictive Distributions - Posterior Mode',600,'yes',CurrINI);
                        drawnow;
                     else;
                        answer = DSGEModel.answers{5};
                     end;
                     if strcmp(lower(answer),'yes')==1;
                        if isempty(DSGEModel.X)==0;
                           XSample = DSGEModel.X(:,1:LastPeriod);
                        else;
                           XSample = [];
                        end;
                        [DecData,DecSteadyState,DecHist,DecMeasureError,DecShocks,DecStatus] = DSGEPredictionOVDecTheta(PredData.A,PredData.H,PredData.R,PredData.F,PredData.B0,[XSample X],LastPeriod+1,LastPeriod,MaxPH,0,DSGEModel,CurrINI);
                        if DecStatus==1;
                           [DecFullData,DecFullSteadyState,DecFullHist,DecFullMeasureError,DecFullShocks,DecStatus] = DSGEPredictionOVDecTheta(PredData.A,PredData.H,PredData.R,PredData.F,PredData.B0,[XSample X],1,LastPeriod,MaxPH,1,DSGEModel,CurrINI);
                        end;
                     else;
                        DecData = [];
                        DecSteadyState = [];
                        DecMeasureError = [];
                        DecHist = [];
                        DecShocks = [];
                        DecFullHist = [];
                        DecFullMeasureError = [];
                        DecFullShocks = [];
                        DecStatus = 0;
                     end;
                  else;
                     DecData = [];
                     DecSteadyState = [];
                     DecMeasureError = [];
                     DecHist = [];
                     DecShocks = [];
                     DecFullHist = [];
                     DecFullMeasureError = [];
                     DecFullShocks = [];
                     DecStatus = 0;
                  end;
                  %
                  if (FileExist(FixFilePath([pwd '\addons\sss\DSGEPredictionShockScenarios.m']))==1)&(NumPredX<MaxPH);
                     %
                     % matrices with observed data and exogenous variables over the prediction period.
                     %
                     if isempty(DSGEModel.X)==0;
                        DataX = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                     else;
                        DataX = [];
                     end;
                     DataY = DSGEModel.Y(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
                     %
                     % check if we should compute shock scenarios for the observed data over the prediction sample
                     %
                     if isempty(DSGEModel.X)==0;
                        [DataShockScenarioResults,DataShockNames,DatawtT,SmoothShocks,Yinit] = DSGEPredictionShockScenarios(PredData.A,PredData.H,PredData.R,PredData.F,PredData.B0,DSGEModel,DSGEModel.Y(:,FirstPeriod:LastPeriod),DataY,DSGEModel.X(:,FirstPeriod:LastPeriod),DataX,AnnualizeData);
                     else;
                        [DataShockScenarioResults,DataShockNames,DatawtT,SmoothShocks,Yinit] = DSGEPredictionShockScenarios(PredData.A,PredData.H,PredData.R,PredData.F,PredData.B0,DSGEModel,DSGEModel.Y(:,FirstPeriod:LastPeriod),DataY,[],DataX,AnnualizeData);
                     end;
                     if AnnualizeData==1;
                        DataY = Annualize([Yinit DataY],DSGEModel.annual,DSGEModel.annualscale);
                     end;
                  else;
                     DataY = [];
                     DataShockScenarioResults = [];
                     DatawtT = [];
                     SmoothShocks = [];
                  end;
                  %
                  ConditionalShockNames = DSGEModel.StateShockNames(DSGEModel.ConditionalShocks,:);
                  EstimationStartPeriod = DSGEModel.KalmanFirstObservation;
                  EstimationStartPeriodOrig = EstimationStartPeriod;
                  YOrig = Y;
                  DateVectorOrig = DateVector;
                  if AnnualizeData==1;
                     Y = Annualize(Y,DSGEModel.annual,DSGEModel.annualscale);
                     EstimationStartPeriod = max(1,EstimationStartPeriod-(length(DateVector)-size(Y,2)));
                     DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                  end;
                  %
                  if TransData==1;
                     [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
                     Y = YData';
                     if size(Y,2)==DSGEModel.T;
                        Y = Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                     else;
                        T2 = size(Y,2);
                        if (FirstPeriod-(DSGEModel.T-T2))>=1;
                           Y = Y(:,FirstPeriod-(DSGEModel.T-T2):min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                        else;
                           Y = Y(:,1:min((LastPeriod+MaxPH),size(DSGEModel.Y,2))-(DSGEModel.T-T2));
                           DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                        end;
                     end;
                  end;
                  %
                  % store conditing data to file
                  %
                  CondData = DSGEModel.Z(DSGEModel.ConditionalVariables,:);
                  CondInitialData = DSGEModel.U(DSGEModel.ConditionalVariables,:);
                  CondNames = DSGEModel.ZVariableNames;
                  %
                  ZData = Z;
                  UData = U(:,size(U,2));
                  K1 = DSGEModel.K1(:,DSGEModel.ConditionalVariables);
                  K2 = DSGEModel.K2(:,DSGEModel.ConditionalVariables);
                  ZNames = DSGEModel.ZVariableNames(DSGEModel.ConditionalVariables,:);
                  CondShockNames = DSGEModel.StateShockNames(DSGEModel.ConditionalShocks,:);
                  %
                  HistData = DSGEModel.Y(:,1:LastPeriod);
                  HistNames = DSGEModel.VariableNames;
                  YTransformation = DSGEModel.YTransformation;
                  PredMeanKsiStates = PredData.xiStates;
                  PredMeanEtaShocks = PredData.etaShocks;
                  KsiStates = PredData.KsitT;
                  StateVariableNames = DSGEModel.StateVariableNames;
                  KernelX = PredData.KernelX;
                  KernelY = PredData.KernelY;
                  %
                  ShockPaths = PredData.Shocks;
                  HistState = PredData.HistState;
                  MeasureErrorPaths = PredData.MeasError;
                  %
                  % we need a DateVector for all the data
                  %
                  HistDateVector = MakeDateVector(DSGEModel.BeginYear,DSGEModel.BeginPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency);
                  %
                  if (FileExist(FixFilePath([pwd '\addons\sss\DSGEPredictionShockScenarios.m']))==1)&(DecStatus==1);
                     if isempty(PredEventData)==1;
                        save(file,'A','H','R','F','B0','PredPaths','ShockPaths','MeasureErrorPaths','HistState','MeanPrediction','PredMean','PredMeanKsiStates','PredMeanEtaShocks','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','YInitial','Y','KsiStates','DateVector','YNames','StateVariableNames','ShockScenarioResults','ShockNames','ShockDateVector','SmoothShocks','wtT','DataY','DataShockScenarioResults','DatawtT','ConditionalShockNames','MeanMultiModesty','MultiPValue','ChiSqPValue','MeanUniModesty','MeanUniModestyLZ','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig','CondData','CondInitialData','CondNames','ZData','UData','ZNames','CondShockNames','K1','K2','HistData','HistNames','HistDateVector','YTransformation','DecData','DecSteadyState','DecHist','DecMeasureError','DecShocks','DecFullHist','DecFullMeasureError','DecFullShocks','FirstPeriod');
                     else;
                        save(file,'A','H','R','F','B0','PredPaths','ShockPaths','MeasureErrorPaths','HistState','MeanPrediction','PredMean','PredMeanKsiStates','PredMeanEtaShocks','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','YInitial','Y','KsiStates','DateVector','YNames','StateVariableNames','ShockScenarioResults','ShockNames','ShockDateVector','SmoothShocks','wtT','DataY','DataShockScenarioResults','DatawtT','ConditionalShockNames','MeanMultiModesty','MultiPValue','ChiSqPValue','MeanUniModesty','MeanUniModestyLZ','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig','CondData','CondInitialData','CondNames','ZData','UData','ZNames','CondShockNames','K1','K2','HistData','HistNames','HistDateVector','YTransformation','DecData','DecSteadyState','DecHist','DecMeasureError','DecShocks','DecFullHist','DecFullMeasureError','DecFullShocks','FirstPeriod','PredictionEvent','PredEventData','YObsEventData');
                     end;
                  else;
                     if isempty(PredEventData)==1;
                        save(file,'A','H','R','F','B0','PredPaths','ShockPaths','MeasureErrorPaths','HistState','MeanPrediction','PredMean','PredMeanKsiStates','PredMeanEtaShocks','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','YInitial','Y','KsiStates','DateVector','YNames','StateVariableNames','ShockNames','MeanMultiModesty','MultiPValue','ChiSqPValue','MeanUniModesty','MeanUniModestyLZ','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig','CondData','CondInitialData','CondNames','ZData','UData','ZNames','CondShockNames','K1','K2','HistData','HistNames','HistDateVector','YTransformation');
                     else;
                        save(file,'A','H','R','F','B0','PredPaths','ShockPaths','MeasureErrorPaths','HistState','MeanPrediction','PredMean','PredMeanKsiStates','PredMeanEtaShocks','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','YInitial','Y','KsiStates','DateVector','YNames','StateVariableNames','ShockNames','MeanMultiModesty','MultiPValue','ChiSqPValue','MeanUniModesty','MeanUniModestyLZ','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig','CondData','CondInitialData','CondNames','ZData','UData','ZNames','CondShockNames','K1','K2','HistData','HistNames','HistDateVector','YTransformation','PredictionEvent','PredEventData','YObsEventData');
                     end;
                  end;
                  %
                  % create a matlab m-file to read the output.
                  %
                  mfile = FixFilePath([DSGEModel.OutputDirectory '\CondPD' int2str(DSGEModel.ShockControlMethod) AnnualStr num2str(MaxPH,'%0.0f') DSGEModel.SubEndYear DSGEModel.SubEndPeriod 'PostMode.m']);
                  fid = fopen(mfile,'wt');
                  fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                  fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                  fprintf(fid,'%%\n%% M E A S U R E M E N T   E Q U A T I O N\n');
                  fprintf(fid,'%%\n%% matrix with parameters on exogenous variables\n%%\n');
                  fprintf(fid,'A = DataStructure.A;\n');
                  fprintf(fid,'%%\n%% matrix with parameters on state variables\n%%\n');
                  fprintf(fid,'H = DataStructure.H;\n');
                  fprintf(fid,'%%\n%% matrix with measurement error covariances\n%%\n');
                  fprintf(fid,'R = DataStructure.R;\n');
                  fprintf(fid,'%%\n%% S T A T E   E Q U A T I O N\n');
                  fprintf(fid,'%%\n%% matrix with state transition parameters\n%%\n');
                  fprintf(fid,'F = DataStructure.F;\n');
                  fprintf(fid,'%%\n%% matrix with shock parameters\n%%\n');
                  fprintf(fid,'B0 = DataStructure.B0;\n');
                  fprintf(fid,'%%\n%% 3D matrix with all the prediction paths for the observed variables\n%%\n');
                  fprintf(fid,'PredPaths = DataStructure.PredPaths;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                  fprintf(fid,'YNames = DataStructure.YNames;\n');
                  fprintf(fid,'%%\n%% string matrix with the names of the state variable variables\n%%\n');
                  fprintf(fid,'StateVariableNames = DataStructure.StateVariableNames;\n');
                  if AdjustMean==0;
                     fprintf(fid,'%%\n%% matrix with the mean of the simulated predictions of the observed variables\n%%\n');
                  else;
                     fprintf(fid,'%%\n%% matrix with the corrected mean of the simulated predictions of the observed variables\n%%\n');
                  end;
                  fprintf(fid,'MeanPrediction = DataStructure.MeanPrediction;\n');
                  fprintf(fid,'%%\n%% matrix with the population mean of the predictions of the observed variables\n%%\n');
                  fprintf(fid,'PredMean = DataStructure.PredMean;\n');
                  fprintf(fid,'%%\n%% matrix with the population mean of the predictions of the state variables\n%%\n');
                  fprintf(fid,'PredMeanKsiStates = DataStructure.PredMeanKsiStates;\n');
                  fprintf(fid,'%%\n%% matrix with the population mean of the predictions of the economic shocks\n%%\n');
                  fprintf(fid,'PredMeanEtaShocks = DataStructure.PredMeanEtaShocks;\n');
                  fprintf(fid,'%%\n%% matrix with the errors from the mean predictions of the observed variables\n%%\n');
                  fprintf(fid,'PredictionErrors = DataStructure.PredictionErrors;\n');
                  fprintf(fid,'%%\n%% vector structure with quantiles from the conditional predictive distribution\n%% the structure has %0.0f entries with fields "Quantile" and "percent"\n%% the first field is a matrix and the second a positive number between 0 and 100\n%%\n',length(Quantiles));
                  fprintf(fid,'Quantiles = DataStructure.Quantiles;\n');
                  if isempty(KernelX)==0;
                     fprintf(fid,'%%\n%% matrix with x-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                     fprintf(fid,'KernelX = DataStructure.KernelX;\n');
                     fprintf(fid,'%%\n%% matrix with y-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                     fprintf(fid,'KernelY = DataStructure.KernelY;\n');
                     KStr = 'KernelX (matrix with x-axis for kernel density estimates of marginal predictive distribution), KernelY (matrix with y-axis values for kernel density estimates of marginal predictive distribution), ';
                     KVal = 2;
                  else;
                     KStr = '';
                     KVal = 0;
                  end;
                  fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                  fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                  fprintf(fid,'%%\n%% observed variables\n%%\n');
                  fprintf(fid,'Y = DataStructure.Y;\n');
                  fprintf(fid,'%%\n%% smooth estimates of the state variables\n%%\n');
                  fprintf(fid,'KsiStates = DataStructure.KsiStates;\n');
                  fprintf(fid,'%%\n%% vector with dates for the observed variables\n%%\n');
                  fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                  fprintf(fid,'%%\n%% Names for the economic shocks\n%%\n');
                  fprintf(fid,'ShockNames = DataStructure.ShockNames;\n');
                  fprintf(fid,'%%\n%% Underlying draws of the economic shocks for all paths\n%%\n');
                  fprintf(fid,'ShockPaths = DataStructure.ShockPaths;\n');
                  fprintf(fid,'%%\n%% Underlying draws of the neasurement errors for all paths\n%%\n');
                  fprintf(fid,'MeasureErrorPaths = DataStructure.MeasureErrorPaths;\n');
                  fprintf(fid,'%%\n%% Underlying draws of the state variables before the predictions\n%%\n');
                  fprintf(fid,'HistState = DataStructure.HistState;\n');
                  fprintf(fid,'%%\n%% Conditioning data\n%%\n');
                  fprintf(fid,'ZData = DataStructure.ZData;\n');
                  fprintf(fid,'%%\n%% Initial values for conditioning data\n%%\n');
                  fprintf(fid,'UData = DataStructure.UData;\n');
                  fprintf(fid,'%%\n%% Names of conditioning variables\n%%\n');
                  fprintf(fid,'ZNames = DataStructure.ZNames;\n');
                  fprintf(fid,'%%\n%% Names of conditioning shocks\n%%\n');
                  fprintf(fid,'CondShockNames = DataStructure.CondShockNames;\n');
                  fprintf(fid,'%%\n%% K1 matrix for mapping the relation between conditioning data and observed variables\n%%\n');
                  fprintf(fid,'K1 = DataStructure.K1;\n');
                  fprintf(fid,'%%\n%% K2 matrix for mapping the relation between conditioning data and observed variables\n%%\n');
                  fprintf(fid,'K2 = DataStructure.K2;\n');
                  if (FileExist(FixFilePath([pwd '\addons\sss\DSGEPredictionShockScenarios.m']))==1)&(DecStatus==1);
                     fprintf(fid,'%%\n%% 3D matrix with shock scenarios over the prediction sample for the mean predictions\n%%\n');
                     fprintf(fid,'ShockScenarioResults = DataStructure.ShockScenarioResults;\n');
                     fprintf(fid,'%%\n%% estimates of the measurement errors over the prediction sample using the mean predictions\n%%\n');
                     fprintf(fid,'wtT = DataStructure.wtT;\n');
                     fprintf(fid,'%%\n%% string matrix with names of the economic shocks that are manipulated\n%% to achieve the conditioning assumptions\n%%\n');
                     fprintf(fid,'ConditionalShockNames = DataStructure.ConditionalShockNames;\n');
                     fprintf(fid,'%%\n%% The observed variables for the prediction sample\n%%\n');
                     fprintf(fid,'DataY = DataStructure.DataY;\n');
                     fprintf(fid,'%%\n%% 3D matrix with shock scenarios over the prediction sample for the observed data\n%%\n');
                     fprintf(fid,'DataShockScenarioResults = DataStructure.DataShockScenarioResults;\n');
                     fprintf(fid,'%%\n%% estimates of the measurement errors over the prediction sample using the observed data\n%%\n');
                     fprintf(fid,'DatawtT = DataStructure.DatawtT;\n');
                     fprintf(fid,'%%\n%% matrix with the observed variables for the estimation sample and the decomposition sample\n%%\n');
                     fprintf(fid,'DecData = DataStructure.DecData;\n');
                     fprintf(fid,'%%\n%% matrix with the share due to the steady state\n%%\n');
                     fprintf(fid,'DecSteadyState = DataStructure.DecSteadyState;\n');
                     fprintf(fid,'%%\n%% matrix with the share due to the history\n%%\n');
                     fprintf(fid,'DecHist = DataStructure.DecHist;\n');
                     fprintf(fid,'%%\n%% matrix with the share due to the measurement errors over the forecast horizon\n%%\n');
                     fprintf(fid,'DecMeasureError = DataStructure.DecMeasureError;\n');
                     fprintf(fid,'%%\n%% 3D matrix with the shares due to the economic shocks over the forecast horizon\n%%\n');
                     fprintf(fid,'DecShocks = DataStructure.DecShocks;\n');
                     fprintf(fid,'%%\n%% matrix with the share due to the initial state\n%%\n');
                     fprintf(fid,'DecFullHist = DataStructure.DecFullHist;\n');
                     fprintf(fid,'%%\n%% matrix with the share due to the measurement errors over the full sample\n%%\n');
                     fprintf(fid,'DecFullMeasureError = DataStructure.DecFullMeasureError;\n');
                     fprintf(fid,'%%\n%% 3D matrix with the shares due to the economic shocks over the full sample\n%%\n');
                     fprintf(fid,'DecFullShocks = DataStructure.DecFullShocks;\n');
                     fprintf(fid,'%%\n%% The first period in the sample to use with DecData\n%%\n');
                     fprintf(fid,'FirstPeriod = DataStructure.FirstPeriod;\n');
                     ShockStr = 'ShockScenarioResults (3D matrix of dimension nxhxq with the shocks scenarios for the mean predictions of the observed variables), wtT (matrix with estimated measurement errors over the prediction sample for the mean predictions of the observed variables), ConditionalShockNames (string matrix with names for the shocks used to achieve the conditioning assumptions), DataY (matrix with the observed data for the prediction sample), DataShockScenarioResults (3D matrix with shock scenarios for the observed variables over the prediction sample), DatawtT (estimates of the measurement errors over the prediction sample for the observed variables), DecData (matrix with the observed variables), DecSteadyState (matrix with the share of the data due to the steady state), DecHist (matrix with the share of the data due to history), DecMeasureError (matrix with the share of the data due to measurement errors over the prediction horizon), DecShocks (3D matrix with the shares of the data due to the economic shocks over the prediction horizon), DecFullHist (matrix with the share of the data due to the initial state), DecFullMeasureError (matrix with share of the data due to measurement errors over the full sample), DecFullShocks (3D matrix with share of data due to the economic shocks over the full sample), FirstPeriod (integer with the first period of the sample to use with DecData), ';
                     SSEntries = 15;
                  else;
                     ShockStr = '';
                     SSEntries = 0;
                  end;
                  if isempty(PredEventData)==0;
                     fprintf(fid,'%%\n%% matrix with the prediction event definitions. The first column\n%% holds the upper bound, the second column\n%% the lower bound, and third the length of the event.\n%%\n');
                     fprintf(fid,'PredictionEvent = DataStructure.PredictionEvent;\n');
                     fprintf(fid,'%%\n%% matrix with prediction event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                     fprintf(fid,'PredEventData = DataStructure.PredEventData;\n');
                     fprintf(fid,'%%\n%% matrix with observed event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                     fprintf(fid,'YObsEventData = DataStructure.YObsEventData;\n');
                     NumEntries = int2str(31+KVal+SSEntries);
                     ExtraEntry = 'PredictionEvent (matrix with the upper and lower bound of the event and the length of the event), PredEventData (matrix with the number of true events, the number of events below the lower bound for the event, the number of events above the upper bound for the event, the number of events tested in the columns, the sum and sum of squared deviations from lower bound when below lower bound, the sum and sum of squared deviations from upper bound when above upper bound), YObsEventData (matrix with the number of true events for prediction paths whose mean is the observed data, the number of events below the lower bound for the event, the number of events above the upper bound for the event, the number of events tested in the columns, the sum and sum of squared of deviations from lower bound when below lower bound, the sum and sum of squared of deviations from upper bound when above upper bound), ';
                  else;
                     NumEntries = int2str(28+KVal+SSEntries);
                     ExtraEntry = '';
                  end;
                  if FileExist(FixFilePath([pwd '\addons\sss\DSGEPredictionShockScenarios.m']))==0;
                     NumEntries = num2str(str2num(NumEntries)-7,'%0.0f');
                  end;
                  if AnnualizeData==0;
                     fprintf(fid,'%%\n%% vector with the mean of the multivariate modesty statistic and its reference statistic\n%%\n');
                     fprintf(fid,'MeanMultiModesty = DataStructure.MeanMultiModesty;\n');
                     fprintf(fid,'%%\n%% tail probability based on the reference statistic\n%%\n');
                     fprintf(fid,'MultiPValue = DataStructure.MultiPValue;\n');
                     fprintf(fid,'%%\n%% tail probability based on the chi-square distribution\n%%\n');
                     fprintf(fid,'ChiSqPValue = DataStructure.ChiSqPValue;\n');
                     fprintf(fid,'%%\n%% Adolfson, Lasen, Lind and Villani univariate modesty statistic\n%%\n');
                     fprintf(fid,'MeanUniModesty = DataStructure.MeanUniModesty;\n');
                     fprintf(fid,'%%\n%% Leeper and Zha univariate modesty statistic\n%%\n');
                     fprintf(fid,'MeanUniModestyLZ = DataStructure.MeanUniModestyLZ;\n');
                     NumEntries = num2str(str2num(NumEntries)+5,'%0.0f');
                     ExtraEntry = [ExtraEntry 'MeanMultiModesty (1x2 vector with the mean of the multivariate modesty statistic and the mean of the multivariate reference modesty statistic), MultiPValue (scalar with the tail probability of the modesty statistic), ChiSqPValue (scalar with the tail probability of the modesty statistic using the chi-square distribution), MeanUniModesty (vector with the univariate modesty statistic from ALLV), MeanUniModestyLZ (vector with the univariate Leeper-Zha modesty statistic), '];
                  end;
                  fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                  %
                  % end the script file
                  %
                  fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                  fclose(fid);
                  %
                  if DSGEModel.RunDriver==0;
                     txt = ['The conditional predictive distributions have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' NumEntries ' entries: the 5 state space matrices (A, H, R, F, B0), PredPaths (3D matrix with the prediction paths for the observed variables), YNames (string matrix with the names of the observed variables), StateVariableNames (string matrix with the names of the state variables), MeanPrediction (matrix with the selected mean predictions), PredMean (matrix with the population mean predictions), PredMeanKsiStates (matrix with the population mean state predictions), PredMeanEtaShocks (matrix with the population mean economic shock predictions), PredictionErrors (matrix with errors for the mean prediction), Quantiles (vector structure with 2 fields: Quantile and percent), ' KStr 'PredDateVector (vector with dates for the predictions), Y (matrix with the observed variables), KsiStates (matrix with the smooth estimates of the state variables), ShockNames (string matrix with the names for the economic shocks), ShockPaths (3D matrix with the underlying economic shocks for the prediction paths), MeasureErrorPaths (3D matrix with the underlying draws of the measurement errors for the prediction paths), HistState (matrix with the underlying draws of the state variables from the period prior to the predictions), ZData (matrix with conditioning variables), UData (vector with initial conditions for conditioning variables), ZNames (string matrix with names of conditioning variables), CondShockNames (string matrix with names of conditioning shocks), K1 (matrix for mapping the relation between conditioning data and observed variables), K2 (matrix for mapping the relation between conditioning data and observed variables), ' ShockStr ExtraEntry 'and DateVector (vector with dates for the observed variables). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                     About(txt,'information','Conditional Predictive Distributions - Posterior Mode',800,700,CurrINI);
                  end;
               end;
               if isempty(PredEventData)==0;
                  %
                  % write prediction event results to file
                  %
                  file = FixFilePath([DSGEModel.OutputDirectory '\CondPredictiveDist-' int2str(DSGEModel.ShockControlMethod) '-' AnnualStr '-' num2str(MaxPH,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '-PosteriorMode.txt']);
                  [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                  PrintPredictionEvent(file,DSGEModel.VariableNames,PredEventData,YObsEventData,DSGEModel.PredictionEvent,[PredStartYear ':' PredStartPeriod '-' PredEndYear ':' PredEndPeriod],MaxPH,NumPredPaths,1,CurrINI);
                  %
                  % displays the file if it exists
                  %
                  if FileExist(file)==1;
                     TextGUI(file,['Prediction Events - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Mode Parameter Values',50,CurrINI,1,0);
                  end;
               end;
               %
               % Open a dialog for displaying predictive distributions
               %
               if DSGEModel.RunDriver==0;
                  %
                  if size(PredData.A,1)==1;
                     ObsVarMean = PredData.A';
                  else;
                     ObsVarMean = [];
                  end;
                  CondPredictiveDistributionDLG('init',DSGEModel,CurrINI,MeanPrediction,ObsVarMean,Quantiles,PredData.KernelX,PredData.KernelY,'Posterior Mode','DSGE',AnnualStr,1);
               else;
                  SetLogText(strvcat('* Finished calculations.',' '));
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         set(controls.about,'UserData',0);
      end;
   case 'UnconPredPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         %
         % check if we should check transformations functions
         %
         if (isempty(ErrorStr)==1)&(gcbo==controls.predict.unconditional_transformed_posterior);
            DTStatus = VerifyDataTransformation(DSGEModel.VariableNames,DSGEModel.YTransformation,0);
            if DTStatus==1;
               [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
            else;
               ErrorStr = 'You haven''t specified all the necessary fields for computing transformations of the observed variables.';
               HeaderStr = 'Missing Transformation Information';
            end;
         end;
         %
         if strcmp(ErrorStr,'')==1;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            thetaMode = ModeData.thetaMode;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%               FirstPeriod = ModeData.DSGEModel.FirstPeriod;
%               LastPeriod = ModeData.DSGEModel.LastPeriod;
%            else;
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            %
            % check how many time periods to use for predictive distributions
            %
            [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
            %
            % matrix with exogenous variables
            %
            X = [];
            if DSGEModel.k>0;
               if NumPredX<MaxPH;
                  X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
               end;
               if NumPredX>0;
                  X = [X DSGEModel.PredictedX(:,1:NumPredX)];
               end;
            end;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Predictive Distributions','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            %
            %
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  NumDraws = length(LogPost);
                  clear('PostSample','LogPost','AcceptedDraws');
                  drawnow;
                  %
                  % initialize the random number generator
                  %
                  if DSGEModel.RandomNumberValue==1;
                     randn('state',0);
                     rand('state',0);
                  else;
                     randn('state',sum(100*clock));
                     rand('state',sum(100*clock));
                  end;
                  %
                  % select which posterior draws to use
                  %
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumDraws,:);
                  NumDraws = NumDraws-NumBurnin;
                  %
                  % check how many draws we should pick among these
                  %
                  PostDrawsUsageStr = get(controls.posterior.postdrawsusage,'String');
                  NumPostDrawsUsage = min(str2num(strrep(StringTrim(PostDrawsUsageStr(DSGEModel.PostDrawsUsageValue,:)),',','')),NumDraws);
                  %
                  % get the draws to use
                  %
                  if DSGEModel.PosteriorSampler<=7;
                     if DSGEModel.RandomizeDraws==0;
                        DrawFreq = round(NumDraws/NumPostDrawsUsage);
                        SelectDraws = (1:DrawFreq:NumDraws);
                        if length(SelectDraws)+1==NumPostDrawsUsage;
                           SelectDraws = [SelectDraws NumDraws];
                        elseif length(SelectDraws)>NumPostDrawsUsage;
                           SelectDraws = SelectDraws(1:NumPostDrawsUsage);
                        end;
                        thetaPostSample = thetaPostSample(SelectDraws,:);
                     else;
                        thetaPostSample = thetaPostSample(ceil(rand(NumPostDrawsUsage,1)*NumDraws),:);
                     end;
                  else;
                     txt = 'Would you like to use a sub-sample of the posterior draws when computing the predictive distribution?';
                     answer = Query(txt,'question',400,'Predictive Distributions - Posterior',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % select how many draws to use
                        %
                        SelectDraws = SampledPosteriorDraws(DSGEModel,CurrINI,'Predictive Distributions - Posterior',Weights,NumDraws,[]);
                        if isempty(SelectDraws)==1;
                           set(controls.about,'UserData',0);
                           return;
                        end;
                        thetaPostSample = thetaPostSample(SelectDraws,:);
                        NumPostDrawsUsage = length(SelectDraws);
                        if DSGEModel.PosteriorSampler~=9;
                           %
                           % fix the weights
                           %
                           Weights = Weights(SelectDraws,1);
                           Weights = Weights*length(Weights)/sum(Weights);
                        else;
                           if isempty(Weights)==0;
                              Weights = Weights(SelectDraws);
                           end;
                        end;
                     end;
                  end;
                  %
                  % are we using annualized data, transformed or the original
                  %
                  if gcbo==controls.predict.unconditional_original_posterior;
                     TransData = 0;
                     AnnualizeData = 0;
                     AnnualStr = 'original';
                     QueryHead = 'Predictive Distributions - Original Data';
                  elseif gcbo==controls.predict.unconditional_annual_posterior;
                     TransData = 0;
                     AnnualizeData = 1;
                     AnnualStr = 'annual';
                     QueryHead = 'Predictive Distributions - Annualized Data';
                  else;
                     TransData = 1;
                     AnnualizeData = 0;
                     AnnualStr = 'transformed';
                     QueryHead = 'Predictive Distributions - Transformed Data';
                  end;
                  %
                  % determine how many prediction paths to use
                  %
                  NumPredPathsStr = get(controls.forecast.predpaths,'String');
                  NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
                  %
                  % check if we have already stored results to disk
                  %
                  if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','','',DSGEModel.NameOfModel,MaxPH,NumPostDrawsUsage,NumPredPaths,AnnualizeData,TransData,CurrChain,1)==1;
                     txt = 'YADA has located results for the predictive distribution on disk. Would you like to use these results?';
                     answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  if strcmp(lower(answer),'yes')==1;
                     [PredEventData,PredictionEvent,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = LoadDSGEPredictionUncertainty(DSGEModel.OutputDirectory,'','',DSGEModel.NameOfModel,MaxPH,NumPostDrawsUsage,NumPredPaths,AnnualizeData,TransData,CurrChain,1);
                     DoneCalc = 1;
                  else;
                     %
                     % ask if we should conduct prediction event calculations
                     %
                     txt = 'Would you like YADA to calculate prediction event probabilities and perform risk analysis?';
                     answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                           DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                        end;
                        %
                        % make sure that the prediction event length does not exceed the maximum prediction horizon
                        %
                        for i=1:DSGEModel.n;
                           if DSGEModel.PredictionEvent(i,3)>MaxPH;
                              DSGEModel.PredictionEvent(i,3) = MaxPH;
                           end;
                        end;
                        %
                        % display a dialog for setting up an prediction event
                        %
                        [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                        if strcmp(lower(action),'ok')==1;
                           DSGEModel.PredictionEvent = PredictionEvent;
                           DSGEModel.RunPredictionEvent = 1;
                        else;
                           DSGEModel.RunPredictionEvent = 0;
                        end;
                     else;
                        DSGEModel.RunPredictionEvent = 0;
                     end;
                     %
                     % we can now compute the predictive distribution for the endogenous variables
                     % up to period MaxPH
                     %
                     [DoneCalc,PredEventData,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGEPredictionPaths(thetaPostSample,thetaMode,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights);
                  end;
                  %
                  % clear everything
                  %
                  clear('thetaPostSample');
                  %
                  % check if we should show any results
                  %
                  if DoneCalc==1;
                     %
                     % yes, now we need to calculate some distribution properties
                     %
                     [MeanPrediction,CovPrediction,Quantiles,KernelX,KernelY] = DSGEPredictionDistribution(DSGEModel.n,DSGEModel.OutputDirectory,'','',DSGEModel.NameOfModel,MaxPH,NumPostDrawsUsage,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights,DSGEModel.Percentiles,DSGEModel.VariableNames,DSGEModel.ConfidenceRegionMethod,CurrINI);
                     %
                     % compute the forecast errors based on the mean predictions
                     %
                     PredictionErrors = CalculatePredictionErrors(MeanPrediction,AnnualizeData,TransData,'DSGE',DSGEModel);
                     %
                     % check if the user wants to save the data
                     %
                     txt = ['Would you like to save the predictive distributions for the ' AnnualStr ' data to file?'];
                     answer = Query(txt,'question',140,'Save - Predictive Distributions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,size(MeanPrediction,2));
                        file = FixFilePath([DSGEModel.OutputDirectory '\PredictiveDist-' AnnualStr '-' num2str(CurrChain,'%0.0f') '-' num2str(MaxPH,'%0.0f') '-' num2str(NumPostDrawsUsage,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '.mat']);
                        YNames = DSGEModel.VariableNames;
                        DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,PredEndYear,PredEndPeriod,DSGEModel.DataFrequency);
                        Y = DSGEModel.Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                        if (length(DateVector)>size(Y,2))&(TransData==0);
                           DateVector = DateVector(1,1:size(Y,2));
                        end;
                        EstimationStartPeriod = DSGEModel.KalmanFirstObservation;
                        EstimationStartPeriodOrig = EstimationStartPeriod;
                        YOrig = Y;
                        DateVectorOrig = DateVector;
                        if AnnualizeData==1;
                           Y = Annualize(Y,DSGEModel.annual,DSGEModel.annualscale);
                           EstimationStartPeriod = max(1,EstimationStartPeriod-(length(DateVector)-size(Y,2)));
                           DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                        end;
                        if TransData==1;
                           [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
                           Y = YData';
                           if size(Y,2)==DSGEModel.T;
                              Y = Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                           else;
                              T2 = size(Y,2);
                              if (FirstPeriod-(DSGEModel.T-T2))>=1;
                                 Y = Y(:,FirstPeriod-(DSGEModel.T-T2):min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                              else;
                                 Y = Y(:,1:min((LastPeriod+MaxPH),size(DSGEModel.Y,2))-(DSGEModel.T-T2));
                                 DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                              end;
                           end;
                        end;
                        if isempty(PredEventData)==1;
                           save(file,'MeanPrediction','CovPrediction','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','StateCov','ShockCov','MeasureCov','ParameterCov','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig');
                        else;
                           save(file,'MeanPrediction','CovPrediction','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','StateCov','ShockCov','MeasureCov','ParameterCov','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig','PredictionEvent','PredEventData');
                        end;
                        %
                        % create a matlab m-file to read the output.
                        %
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\PD' num2str(CurrChain,'%0.0f') AnnualStr num2str(MaxPH,'%0.0f') num2str(NumPostDrawsUsage,'%0.0f') num2str(NumPredPaths,'%0.0f') DSGEModel.SubEndYear DSGEModel.SubEndPeriod '.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% matrix with the mean predictions of the observed variables\n%%\n');
                        fprintf(fid,'MeanPrediction = DataStructure.MeanPrediction;\n');
                        fprintf(fid,'%%\n%% 3D matrix (nxnxh) with the sample covariance of the predictions of the observed variables\n%%\n');
                        fprintf(fid,'CovPrediction = DataStructure.CovPrediction;\n');
                        fprintf(fid,'%%\n%% matrix with the errors from the mean predictions of the observed variables\n%%\n');
                        fprintf(fid,'PredictionErrors = DataStructure.PredictionErrors;\n');
                        fprintf(fid,'%%\n%% vector structure with quantiles from the predictive distribution\n%% the structure has %0.0f entries with fields "Quantile" and "percent"\n%% the first field is a matrix and the second a positive number between 0 and 100\n%%\n',length(Quantiles));
                        fprintf(fid,'Quantiles = DataStructure.Quantiles;\n');
                        fprintf(fid,'%%\n%% matrix with x-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                        fprintf(fid,'KernelX = DataStructure.KernelX;\n');
                        fprintf(fid,'%%\n%% matrix with y-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                        fprintf(fid,'KernelY = DataStructure.KernelY;\n');
                        fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                        fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                        fprintf(fid,'%%\n%% observed variables\n%%\n');
                        fprintf(fid,'Y = DataStructure.Y;\n');
                        fprintf(fid,'%%\n%% vector with dates for the observed variables\n%%\n');
                        fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                        if (AnnualizeData==0)&(TransData==0);
                           fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to state uncertainty\n%%\n');
                           fprintf(fid,'StateCov = DataStructure.StateCov;\n');
                           fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to shock uncertainty\n%%\n');
                           fprintf(fid,'ShockCov = DataStructure.ShockCov;\n');
                           fprintf(fid,'%%\n%% 2D Error covariance matrix (nxn) part due to measurement error uncertainty\n%%\n');
                           fprintf(fid,'MeasureCov = DataStructure.MeasureCov;\n');
                           fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to parameter uncertainty\n%%\n');
                           fprintf(fid,'ParameterCov = DataStructure.ParameterCov;\n');
                           CovDecompStr = 'StateCov (3D error covariance matrix with part due to state uncertainty), ShockCov (3D error covariance matrix with part due to shock uncertainty), MeasureCov (2D error covariance matrix with part due to measurement error uncertainty), ParameterCov (3D covariance matrix with part due to parameter uncertainty), ';
                        else;
                           CovDecompStr = '';
                        end;
                        if isempty(PredEventData)==0;
                           fprintf(fid,'%%\n%% matrix with the prediction event definitions. The first column\n%% holds the upper bound, the second column\n%% the lower bound, and third the length of the event.\n%%\n');
                           fprintf(fid,'PredictionEvent = DataStructure.PredictionEvent;\n');
                           fprintf(fid,'%%\n%% matrix with prediction event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                           fprintf(fid,'PredEventData = DataStructure.PredEventData;\n');
                           if (AnnualizeData==0)&(TransData==0);
                              NumEntries = '16';
                           else;
                              NumEntries = '12';
                           end;
                           ExtraEntry = 'PredictionEvent (matrix with the upper and lower bound of the event and the length of the event), PredEventData (matrix with the number of true events, the number of events below the lower bound for the event, the number of events above the upper bound for the event, the number of events tested in the columns, the sum and sum of squared deviations from lower bound when below lower bound, the sum and sum of squared deviations from upper bound when above upper bound), ';
                        else;
                           if (AnnualizeData==0)&(TransData==0);
                              NumEntries = '14';
                           else;
                              NumEntries = '10';
                           end;
                           ExtraEntry = '';
                        end;
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        %
                        txt = ['The predictive distributions have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' NumEntries ' entries: YNames (string matrix with the names of the observed variables), MeanPrediction (matrix with the mean predictions), CovPrediction (3D matrix with the sample covariances of the predictions), PredictionErrors (matrix with errors for the mean prediction), Quantiles (vector structure with 2 fields: Quantile and percent), KernelX (matrix with x-axis for kernel density estimates of marginal predictive distribution), KernelY (matrix with y-axis values for kernel density estimates of marginal predictive distribution), PredDateVector (vector with dates for the predictions), Y (matrix with the observed variables), ' CovDecompStr ExtraEntry 'and DateVector (vector with dates for the observed variables). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Predictive Distributions',500,600,CurrINI);
                     end;
                     if isempty(PredEventData)==0;
                        %
                        % write prediction event results to file
                        %
                        file = FixFilePath([DSGEModel.OutputDirectory '\PredictiveDist-' AnnualStr '-' num2str(CurrChain,'%0.0f') '-' num2str(MaxPH,'%0.0f') '-' num2str(NumPostDrawsUsage,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '.txt']);
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                        PrintPredictionEvent(file,DSGEModel.VariableNames,PredEventData,[],PredictionEvent,[PredStartYear ':' PredStartPeriod '-' PredEndYear ':' PredEndPeriod],MaxPH,NumPredPaths,NumPostDrawsUsage,CurrINI);
                        %
                        % displays the file if it exists
                        %
                        if FileExist(file)==1;
                           TextGUI(file,['Prediction Events - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution - Unconditional Predictions',50,CurrINI,1,0);
                        end;
                     end;
                     %
                     % summarize the information in the uncertainty variables more conveniently
                     %
                     if isempty(StateCov)==0;
                        [StateVar,ShockVar,MeasureVar,ParameterVar,TotalVar] = SummarizeDSGEPredictions(StateCov,ShockCov,MeasureCov,ParameterCov);
                        %
                        % Open a dialog for displaying predictive distributions
                        %
                        UData.StateVar = StateVar;
                        UData.ShockVar = ShockVar;
                        UData.MeasureVar = MeasureVar;
                        UData.ParameterVar = ParameterVar;
                        [UData.KernelX,UData.KernelY] = NormalDensityValues(MeanPrediction,TotalVar,2^8);
                     else;
                        UData = [];
                     end;
                     PredictiveDistributionDLG('init',DSGEModel,CurrINI,MeanPrediction,[],Quantiles,KernelX,KernelY,'','DSGE',AnnualStr,1,UData);
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ConPredPosteriorDist'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         %
         % check if we should check transformations functions
         %
         if (isempty(ErrorStr)==1)&(gcbo==controls.predict.conditional_transformed_posterior);
            DTStatus = VerifyDataTransformation(DSGEModel.VariableNames,DSGEModel.YTransformation,0);
            if DTStatus==1;
               [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
            else;
               ErrorStr = 'You haven''t specified all the necessary fields for computing transformations of the observed variables.';
               HeaderStr = 'Missing Transformation Information';
            end;
         end;
         %
         if strcmp(ErrorStr,'')==1;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%               FirstPeriod = ModeData.DSGEModel.FirstPeriod;
%               LastPeriod = ModeData.DSGEModel.LastPeriod;
%            else;
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            %
            % check how many time periods to use for predictive distributions
            %
            [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
            %
            % matrix with exogenous variables
            %
            X = [];
            if DSGEModel.k>0;
               if NumPredX<MaxPH;
                  X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
               end;
               if NumPredX>0;
                  X = [X DSGEModel.PredictedX(:,1:NumPredX)];
               end;
            end;
            %
            % check the length of the conditioning sample
            %
            [status,NumPeriods] = CheckConditioningData(DSGEModel);
            %
            % check if we should adjust the X matrix
            %
            if MaxPH<NumPeriods;
               NumPeriods = MaxPH;
            end;
            %
            % collect the conditional variables and the selected conditioning sample
            %
            Z = DSGEModel.Z(DSGEModel.ConditionalVariables,LastPeriod+1:LastPeriod+NumPeriods);
            if LastPeriod>=NumPeriods;
               U = DSGEModel.U(DSGEModel.ConditionalVariables,LastPeriod-NumPeriods+1:LastPeriod);
            else;
               %
               % we have to create artifical initial conditions for the conditioning variables
               %
               U = [DSGEModel.U(DSGEModel.ConditionalVariables,1)*ones(1,NumPeriods-LastPeriod) DSGEModel.U(DSGEModel.ConditionalVariables,1:LastPeriod)];
            end;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Conditional Predictive Distribution','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            %
            %
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  NumDraws = length(LogPost);
                  clear('PostSample','LogPost','AcceptedDraws');
                  drawnow;
                  %
                  % initialize the random number generator
                  %
                  if DSGEModel.RandomNumberValue==1;
                     randn('state',0);
                     rand('state',0);
                  else;
                     randn('state',sum(100*clock));
                     rand('state',sum(100*clock));
                  end;
                  %
                  % select which posterior draws to use
                  %
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumDraws,:);
                  NumDraws = NumDraws-NumBurnin;
                  %
                  % check how many draws we should pick among these
                  %
                  PostDrawsUsageStr = get(controls.posterior.postdrawsusage,'String');
                  NumPostDrawsUsage = min(str2num(strrep(StringTrim(PostDrawsUsageStr(DSGEModel.PostDrawsUsageValue,:)),',','')),NumDraws);
                  %
                  % get the draws to use
                  %
                  if DSGEModel.PosteriorSampler<=7;
                     if DSGEModel.RandomizeDraws==0;
                        DrawFreq = round(NumDraws/NumPostDrawsUsage);
                        SelectDraws = (1:DrawFreq:NumDraws);
                        if length(SelectDraws)+1==NumPostDrawsUsage;
                           SelectDraws = [SelectDraws NumDraws];
                        elseif length(SelectDraws)>NumPostDrawsUsage;
                           SelectDraws = SelectDraws(1:NumPostDrawsUsage);
                        end;
                        thetaPostSample = thetaPostSample(SelectDraws,:);
                     else;
                        thetaPostSample = thetaPostSample(ceil(rand(NumPostDrawsUsage,1)*NumDraws),:);
                     end;
                  else;
                     txt = 'Would you like to use a sub-sample of the posterior draws when computing the predictive distribution?';
                     answer = Query(txt,'question',400,'Predictive Distributions - Posterior',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % select how many draws to use
                        %
                        SelectDraws = SampledPosteriorDraws(DSGEModel,CurrINI,'Predictive Distributions - Posterior',Weights,NumDraws,[]);
                        if isempty(SelectDraws)==1;
                           set(controls.about,'UserData',0);
                           return;
                        end;
                        thetaPostSample = thetaPostSample(SelectDraws,:);
                        NumPostDrawsUsage = length(SelectDraws);
                        if DSGEModel.PosteriorSampler~=9;
                           %
                           % fix the weights
                           %
                           Weights = Weights(SelectDraws,1);
                           Weights = Weights*length(Weights)/sum(Weights);
                        else;
                           if isempty(Weights)==0;
                              Weights = Weights(SelectDraws);
                           end;
                        end;
                     end;
                  end;
                  %
                  % are we using annualized data or the original
                  %
                  if gcbo==controls.predict.conditional_original_posterior;
                     TransData = 0;
                     AnnualizeData = 0;
                     AnnualStr = 'original';
                     QueryHead = 'Conditional Predictive Distributions - Original Data';
                  elseif gcbo==controls.predict.conditional_annual_posterior;
                     TransData = 0;
                     AnnualizeData = 1;
                     AnnualStr = 'annual';
                     QueryHead = 'Conditional Predictive Distributions - Annualized Data';
                  else;
                     TransData = 1;
                     AnnualizeData = 0;
                     AnnualStr = 'transformed';
                     QueryHead = 'Conditional Predictive Distributions - Transformed Data';
                  end;
                  %
                  % check which method is used for dealing with the conditioning assumptions
                  %
                  if DSGEModel.ShockControlMethod==1;
                     ShockMethod = 'Direct-';
                  elseif DSGEModel.ShockControlMethod==2;
                     ShockMethod = 'WaggonerZha-';
                  else;
                     ShockMethod = 'Subset-';
                  end;
                  %
                  % determine how many prediction paths to use
                  %
                  NumPredPathsStr = get(controls.forecast.predpaths,'String');
                  NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
                  %
                  % check if we have already stored results to disk
                  %
                  if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumPostDrawsUsage,NumPredPaths,AnnualizeData,TransData,CurrChain,1)==1;
                     txt = 'YADA has located results for the conditional predictive distribution on disk. Would you like to use these results?';
                     answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                  else;
                     answer = 'No';
                  end;
                  if strcmp(lower(answer),'yes')==1;
                     [PredEventData,PredictionEvent,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = LoadDSGEPredictionUncertainty(DSGEModel.OutputDirectory,'Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumPostDrawsUsage,NumPredPaths,AnnualizeData,TransData,CurrChain,1);
                     DoneCalc = 1;
                  else;
                     %
                     % ask if we should conduct prediction event calculations
                     %
                     txt = 'Would you like YADA to calculate prediction event probabilities and perform risk analysis?';
                     answer = Query(txt,'question',140,'Prediction Events',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                           DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                        end;
                        %
                        % make sure that the prediction event length does not exceed the maximum prediction horizon
                        %
                        for i=1:DSGEModel.n;
                           if DSGEModel.PredictionEvent(i,3)>MaxPH;
                              DSGEModel.PredictionEvent(i,3) = MaxPH;
                           end;
                        end;
                        %
                        % display a dialog for setting up an prediction event
                        %
                        [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                        if strcmp(lower(action),'ok')==1;
                           DSGEModel.PredictionEvent = PredictionEvent;
                           DSGEModel.RunPredictionEvent = 1;
                        else;
                           DSGEModel.RunPredictionEvent = 0;
                        end;
                     else;
                        DSGEModel.RunPredictionEvent = 0;
                     end;
                     %
                     % we can now compute the predictive distribution for the endogenous variables
                     % up to period MaxPH
                     %
                     if DSGEModel.ShockControlMethod==1;
                        [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPaths(thetaPostSample,ModeData.thetaMode,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights);
                     elseif DSGEModel.ShockControlMethod==2;
                        [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsWZ(thetaPostSample,ModeData.thetaMode,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights);
                     else;
                        %
                        % check if the selected method can actually be used
                        %
                        CondTxt = '';
                        if isempty(DSGEModel.MixedConditionalShocks)==1;
                           CondTxt = 'You haven''t selected any shocks for use which the distribution of a subset of the shocks conditioning method.';
                        elseif length(DSGEModel.MixedConditionalShocks)<length(DSGEModel.ConditionalVariables);
                           CondTxt = ['The number of shocks you have selected to use to ensure that the conditioning assumptions are satisfied under the distribution of a subset of the shocks conditioning method is not sufficient. You need at least ' int2str(length(DSGEModel.ConditionalVariables)) ' such shocks.'];
                        end;
                        if isempty(CondTxt)==1;
                           [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsMixed(thetaPostSample,ModeData.thetaMode,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights);
                        else;
                           About(CondTxt,'information','Bad Shocks Selection - Distribution of Subset Shocks Method',300,550,CurrINI);
                           DoneCalc = 0;
                        end;
                     end;
                  end;
                  %
                  % clear everything
                  %
                  clear('thetaPostSample');
                  %
                  % check if we should show any results
                  %
                  if DoneCalc==1;
                     %
                     % yes, now we need to calculate some distribution properties
                     %
                     [MeanPrediction,CovPrediction,Quantiles,KernelX,KernelY] = DSGEPredictionDistribution(DSGEModel.n,DSGEModel.OutputDirectory,'Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumPostDrawsUsage,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights,DSGEModel.Percentiles,DSGEModel.VariableNames,DSGEModel.ConfidenceRegionMethod,CurrINI);
                     %
                     % compute the forecast errors based on the mean predictions
                     %
                     PredictionErrors = CalculatePredictionErrors(MeanPrediction,AnnualizeData,TransData,'DSGE',DSGEModel);
                     %
                     % check if we should evaluate modesty test data
                     %
                     if AnnualizeData==0;
                        [MultiPValue,MeanMultiModesty,MeanUniModesty,MeanUniModestyLZ] = DSGEModestyStatistics(DSGEModel.OutputDirectory,'DSGE',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumPostDrawsUsage,NumPredPaths,CurrChain,1,DSGEModel.n,'');
                        if exist('YADAchi2cdf')==2;
                           ChiSqPValue = 1-YADAchi2cdf(MeanMultiModesty(1),DSGEModel.n);
                        else;
                           if exist('chi2cdf')==2;
                              ChiSqPValue = 1-chi2cdf(MeanMultiModesty(1),DSGEModel.n);
                           else;
                              ChiSqPValue = 1-YADACheapchi2cdf(MeanMultiModesty(1),DSGEModel.n);
                           end;
                        end;
                        %
                        % print results to file
                        %
                        PrintDSGEModestyStatistics(DSGEModel,CurrINI,CurrChain,1,0,MaxPH,NumPeriods,NumPostDrawsUsage,NumPredPaths,MultiPValue,MeanMultiModesty,MeanUniModesty,MeanUniModestyLZ,ShockMean,ShockNames,'');
                     else;
                        ChiSqPValue = [];
                        MultiPValue = [];
                        MeanMultiModesty = [];
                        MeanUniModesty = [];
                        MeanUniModestyLZ = [];
                     end;
                     %
                     % check if the user wants to save the data
                     %
                     txt = ['Would you like to save the conditional predictive distributions for the ' AnnualStr ' data to file?'];
                     answer = Query(txt,'question',140,'Save - Conditional Predictive Distributions',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,size(MeanPrediction,2));
                        file = FixFilePath([DSGEModel.OutputDirectory '\CondPredictiveDist-' int2str(DSGEModel.ShockControlMethod) '-' AnnualStr '-' num2str(CurrChain,'%0.0f') '-' num2str(MaxPH,'%0.0f') '-' num2str(NumPostDrawsUsage,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '.mat']);
                        YNames = DSGEModel.VariableNames;
                        DateVector = MakeDateVector(DSGEModel.SubBeginYear,DSGEModel.SubBeginPeriod,PredEndYear,PredEndPeriod,DSGEModel.DataFrequency);
                        Y = DSGEModel.Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                        if (length(DateVector)>size(Y,2))&(TransData==0);
                           DateVector = DateVector(1,1:size(Y,2));
                        end;
                        EstimationStartPeriod = DSGEModel.KalmanFirstObservation;
                        EstimationStartPeriodOrig = EstimationStartPeriod;
                        YOrig = Y;
                        DateVectorOrig = DateVector;
                        if AnnualizeData==1;
                           Y = Annualize(Y,DSGEModel.annual,DSGEModel.annualscale);
                           EstimationStartPeriod = max(1,EstimationStartPeriod-(length(DateVector)-size(Y,2)));
                           DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                        end;
                        %
                        if TransData==1;
                           [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
                           Y = YData';
                           if size(Y,2)==DSGEModel.T;
                              Y = Y(:,FirstPeriod:min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                           else;
                              T2 = size(Y,2);
                              if (FirstPeriod-(DSGEModel.T-T2))>=1;
                                 Y = Y(:,FirstPeriod-(DSGEModel.T-T2):min((LastPeriod+MaxPH),size(DSGEModel.Y,2)));
                              else;
                                 Y = Y(:,1:min((LastPeriod+MaxPH),size(DSGEModel.Y,2))-(DSGEModel.T-T2));
                                 DateVector = DateVector(length(DateVector)-size(Y,2)+1:length(DateVector));
                              end;
                           end;
                        end;
                        %
                        if isempty(PredEventData)==1;
                           save(file,'MeanPrediction','CovPrediction','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','StateCov','ShockCov','MeasureCov','ParameterCov','MeanMultiModesty','MultiPValue','ChiSqPValue','MeanUniModesty','MeanUniModestyLZ','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig');
                        else;
                           save(file,'MeanPrediction','CovPrediction','PredictionErrors','Quantiles','KernelX','KernelY','PredDateVector','Y','DateVector','YNames','StateCov','ShockCov','MeasureCov','ParameterCov','MeanMultiModesty','MultiPValue','ChiSqPValue','MeanUniModesty','MeanUniModestyLZ','EstimationStartPeriod','EstimationStartPeriodOrig','YOrig','DateVectorOrig','PredictionEvent','PredEventData');
                        end;
                        %
                        % create a matlab m-file to read the output.
                        %
                        mfile = FixFilePath([DSGEModel.OutputDirectory '\CondPD' int2str(DSGEModel.ShockControlMethod) AnnualStr num2str(CurrChain,'%0.0f') num2str(MaxPH,'%0.0f') num2str(NumPostDrawsUsage,'%0.0f') num2str(NumPredPaths,'%0.0f') DSGEModel.SubEndYear DSGEModel.SubEndPeriod '.m']);
                        fid = fopen(mfile,'wt');
                        fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                        fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                        fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                        fprintf(fid,'YNames = DataStructure.YNames;\n');
                        fprintf(fid,'%%\n%% matrix with the mean predictions of the observed variables\n%%\n');
                        fprintf(fid,'MeanPrediction = DataStructure.MeanPrediction;\n');
                        fprintf(fid,'%%\n%% 3D matrix (nxnxh) with the sample covariance of the predictions of the observed variables\n%%\n');
                        fprintf(fid,'CovPrediction = DataStructure.CovPrediction;\n');
                        fprintf(fid,'%%\n%% matrix with the errors from the mean predictions of the observed variables\n%%\n');
                        fprintf(fid,'PredictionErrors = DataStructure.PredictionErrors;\n');
                        fprintf(fid,'%%\n%% vector structure with quantiles from the predictive distribution\n%% the structure has %0.0f entries with fields "Quantile" and "percent"\n%% the first field is a matrix and the second a positive number between 0 and 100\n%%\n',length(Quantiles));
                        fprintf(fid,'Quantiles = DataStructure.Quantiles;\n');
                        fprintf(fid,'%%\n%% matrix with x-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                        fprintf(fid,'KernelX = DataStructure.KernelX;\n');
                        fprintf(fid,'%%\n%% matrix with y-axis values for kernel density estimates of marginal predictive distribution\n%%\n');
                        fprintf(fid,'KernelY = DataStructure.KernelY;\n');
                        fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                        fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                        fprintf(fid,'%%\n%% observed variables\n%%\n');
                        fprintf(fid,'Y = DataStructure.Y;\n');
                        fprintf(fid,'%%\n%% vector with dates for the observed variables\n%%\n');
                        fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                        if (AnnualizeData==0)&(TransData==0);
                           fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to state uncertainty\n%%\n');
                           fprintf(fid,'StateCov = DataStructure.StateCov;\n');
                           fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to shock uncertainty\n%%\n');
                           fprintf(fid,'ShockCov = DataStructure.ShockCov;\n');
                           fprintf(fid,'%%\n%% 2D Error covariance matrix (nxn) part due to measurement error uncertainty\n%%\n');
                           fprintf(fid,'MeasureCov = DataStructure.MeasureCov;\n');
                           fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to parameter uncertainty\n%%\n');
                           fprintf(fid,'ParameterCov = DataStructure.ParameterCov;\n');
                           CovDecompStr = 'StateCov (3D error covariance matrix with part due to state uncertainty), ShockCov (3D error covariance matrix with part due to shock uncertainty), MeasureCov (2D error covariance matrix with part due to measurement error uncertainty), ParameterCov (3D covariance matrix with part due to parameter uncertainty), ';
                        else;
                           CovDecompStr = '';
                        end;
                        if isempty(PredEventData)==0;
                           fprintf(fid,'%%\n%% matrix with the prediction event definitions. The first column\n%% holds the upper bound, the second column\n%% the lower bound, and third the length of the event.\n%%\n');
                           fprintf(fid,'PredictionEvent = DataStructure.PredictionEvent;\n');
                           fprintf(fid,'%%\n%% matrix with prediction event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                           fprintf(fid,'PredEventData = DataStructure.PredEventData;\n');
                           if (AnnualizeData==0)&(TransData==0);
                              NumEntries = '16';
                           else;
                              NumEntries = '12';
                           end;
                           ExtraEntry = 'PredictionEvent (matrix with the upper and lower bound of the event and the length of the event), PredEventData (matrix with the number of true events, the number of events below the lower bound for the event, the number of events above the upper bound for the event, the number of events tested in the columns, the sum and sum of squared deviations from lower bound when below lower bound, the sum and sum of squared deviations from upper bound when above upper bound), ';
                        else;
                           if (AnnualizeData==0)&(TransData==0);
                              NumEntries = '14';
                           else;
                              NumEntries = '10';
                           end;
                           ExtraEntry = '';
                        end;
                        if AnnualizeData==0;
                           fprintf(fid,'%%\n%% vector with the mean of the multivariate modesty statistic and its reference statistic\n%%\n');
                           fprintf(fid,'MeanMultiModesty = DataStructure.MeanMultiModesty;\n');
                           fprintf(fid,'%%\n%% tail probability based on the reference statistic\n%%\n');
                           fprintf(fid,'MultiPValue = DataStructure.MultiPValue;\n');
                           fprintf(fid,'%%\n%% tail probability based on the chi-square distribution\n%%\n');
                           fprintf(fid,'ChiSqPValue = DataStructure.ChiSqPValue;\n');
                           fprintf(fid,'%%\n%% Adolfson, Lasen, Lind and Villani univariate modesty statistic\n%%\n');
                           fprintf(fid,'MeanUniModesty = DataStructure.MeanUniModesty;\n');
                           fprintf(fid,'%%\n%% Leeper and Zha univariate modesty statistic\n%%\n');
                           fprintf(fid,'MeanUniModestyLZ = DataStructure.MeanUniModestyLZ;\n');
                           NumEntries = num2str(str2num(NumEntries)+5,'%0.0f');
                           ExtraEntry = [ExtraEntry 'MeanMultiModesty (1x2 vector with the mean of the multivariate modesty statistic and the mean of the multivariate reference modesty statistic), MultiPValue (scalar with the tail probability of the modesty statistic), ChiSqPValue (scalar with the tail probability of the modesty statistic using the chi-square distribution), MeanUniModesty (vector with the univariate modesty statistic from ALLV), MeanUniModestyLZ (vector with the univariate Leeper-Zha modesty statistic), '];
                        end;
                        fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                        %
                        % end the script file
                        %
                        fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                        fclose(fid);
                        %
                        txt = ['The conditional predictive distributions have been saved to the file "' GetFilename(file) '" in the directory "' GetPath(file) '". The file contains ' NumEntries ' entries: YNames (string matrix with the names of the observed variables), MeanPrediction (matrix with the mean predictions), CovPrediction (3D matrix with the sample covariances of the predictions), PredictionErrors (matrix with errors for the mean predictions), Quantiles (vector structure with 2 fields: Quantile and percent), KernelX (matrix with x-axis for kernel density estimates of marginal predictive distribution), KernelY (matrix with y-axis values for kernel density estimates of marginal predictive distribution), PredDateVector (vector with dates for the predictions), Y (matrix) with the observed variables, ' CovDecompStr ExtraEntry 'and DateVector (vector with dates for the observed variables). To access these data you may run the matlab script file "' GetFilename(mfile) '".'];
                        About(txt,'information','Conditional Predictive Distributions',500,600,CurrINI);
                     end;
                     if isempty(PredEventData)==0;
                        %
                        % write prediction event results to file
                        %
                        file = FixFilePath([DSGEModel.OutputDirectory '\CondPredictiveDist-' int2str(DSGEModel.ShockControlMethod) '-' AnnualStr '-' num2str(CurrChain,'%0.0f') '-' num2str(MaxPH,'%0.0f') '-' num2str(NumPostDrawsUsage,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '.txt']);
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                        PrintPredictionEvent(file,DSGEModel.VariableNames,PredEventData,[],PredictionEvent,[PredStartYear ':' PredStartPeriod '-' PredEndYear ':' PredEndPeriod],MaxPH,NumPredPaths,NumPostDrawsUsage,CurrINI);
                        %
                        % displays the file if it exists
                        %
                        if FileExist(file)==1;
                           TextGUI(file,['Prediction Events - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution - Conditional Predictions',50,CurrINI,1,0);
                        end;
                     end;
                     %
                     % summarize the information in the uncertainty variables more conveniently
                     %
                     if isempty(StateCov)==0;
                        [StateVar,ShockVar,MeasureVar,ParameterVar,TotalVar] = SummarizeDSGEPredictions(StateCov,ShockCov,MeasureCov,ParameterCov);
                        %
                        % Open a dialog for displaying predictive distributions
                        %
                        UData.StateVar = StateVar;
                        UData.ShockVar = ShockVar;
                        UData.MeasureVar = MeasureVar;
                        UData.ParameterVar = ParameterVar;
                        [UData.KernelX,UData.KernelY] = NormalDensityValues(MeanPrediction,TotalVar,2^8);
                     else;
                        UData = [];
                     end;
                     %
                     % make sure that UData is empty until the forecast error variance decompositions have been solved
                     % under conditional forecasting
                     %
                     CondPredictiveDistributionDLG('init',DSGEModel,CurrINI,MeanPrediction,[],Quantiles,KernelX,KernelY,'','DSGE',AnnualStr,1,UData);
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'UnconPredictionEvent'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         %
         % check if we should check transformations functions
         %
         if (isempty(ErrorStr)==1)&(gcbo==controls.predict.unconditional_transformed_predevent);
            DTStatus = VerifyDataTransformation(DSGEModel.VariableNames,DSGEModel.YTransformation,0);
            if DTStatus==1;
               [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
            else;
               ErrorStr = 'You haven''t specified all the necessary fields for computing transformations of the observed variables.';
               HeaderStr = 'Missing Transformation Information';
            end;
         end;
         %
         if strcmp(ErrorStr,'')==1;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
            thetaMode = ModeData.thetaMode;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%               FirstPeriod = ModeData.DSGEModel.FirstPeriod;
%               LastPeriod = ModeData.DSGEModel.LastPeriod;
%            else;
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            %
            % check how many time periods to use for predictive distributions
            %
            [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
            %
            % matrix with exogenous variables
            %
            X = [];
            if DSGEModel.k>0;
               if NumPredX<MaxPH;
                  X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
               end;
               if NumPredX>0;
                  X = [X DSGEModel.PredictedX(:,1:NumPredX)];
               end;
            end;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Prediction Event','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            %
            %
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  NumDraws = length(LogPost);
                  clear('PostSample','LogPost','AcceptedDraws');
                  drawnow;
                  %
                  % initialize the random number generator
                  %
                  if DSGEModel.RandomNumberValue==1;
                     randn('state',0);
                     rand('state',0);
                  else;
                     randn('state',sum(100*clock));
                     rand('state',sum(100*clock));
                  end;
                  %
                  % select which posterior draws to use
                  %
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumDraws,:);
                  NumDraws = NumDraws-NumBurnin;
                  %
                  % check how many draws we should pick among these
                  %
                  if DSGEModel.PosteriorSampler<=7;
                     PostDrawsUsageStr = get(controls.posterior.postdrawsusage,'String');
                     NumPostDrawsUsage = min(str2num(strrep(StringTrim(PostDrawsUsageStr(DSGEModel.PostDrawsUsageValue,:)),',','')),NumDraws);
                     %
                     % get the draws to use
                     %
                     if DSGEModel.RandomizeDraws==0;
                        DrawFreq = round(NumDraws/NumPostDrawsUsage);
                        SelectDraws = (1:DrawFreq:NumDraws);
                        if length(SelectDraws)+1==NumPostDrawsUsage;
                           SelectDraws = [SelectDraws NumDraws];
                        elseif length(SelectDraws)>NumPostDrawsUsage;
                           SelectDraws = SelectDraws(1:NumPostDrawsUsage);
                        end;
                        thetaPostSample = thetaPostSample(SelectDraws,:);
                     else;
                        thetaPostSample = thetaPostSample(ceil(rand(NumPostDrawsUsage,1)*NumDraws),:);
                     end;
                  else;
                     txt = 'Would you like to use a sub-sample of the posterior draws when computing the predictive distribution?';
                     answer = Query(txt,'question',400,'Prediction Event - Posterior',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % select how many draws to use
                        %
                        SelectDraws = SampledPosteriorDraws(DSGEModel,CurrINI,'Prediction Event - Posterior',Weights,NumDraws,[]);
                        if isempty(SelectDraws)==1;
                           set(controls.about,'UserData',0);
                           return;
                        end;
                        thetaPostSample = thetaPostSample(SelectDraws,:);
                        NumPostDrawsUsage = length(SelectDraws);
                        if DSGEModel.PosteriorSampler~=9;
                           %
                           % fix the weights
                           %
                           Weights = Weights(SelectDraws,1);
                           Weights = Weights*length(Weights)/sum(Weights);
                        else;
                           if isempty(Weights)==0;
                              Weights = Weights(SelectDraws);
                           end;
                        end;
                     end;
                  end;
                  %
                  % are we using annualized data or the original
                  %
                  if gcbo==controls.predict.unconditional_original_predevent;
                     TransData = 0;
                     AnnualizeData = 0;
                     AnnualStr = 'original';
                     QueryHead = 'Predictive Distributions - Original Data';
                  elseif gcbo==controls.predict.unconditional_annual_predevent;
                     TransData = 0;
                     AnnualizeData = 1;
                     AnnualStr = 'annual';
                     QueryHead = 'Predictive Distributions - Annualized Data';
                  else;
                     TransData = 1;
                     AnnualizeData = 0;
                     AnnualStr = 'transformed';
                     QueryHead = 'Predictive Distributions - Transformed Data';
                  end;
                  %
                  % prediction event calculations
                  %
                  if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                     DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                  end;
                  %
                  % make sure that the prediction event length does not exceed the maximum prediction horizon
                  %
                  for i=1:DSGEModel.n;
                     if DSGEModel.PredictionEvent(i,3)>MaxPH;
                        DSGEModel.PredictionEvent(i,3) = MaxPH;
                     end;
                  end;
                  %
                  % display a dialog for setting up an prediction event
                  %
                  [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                  %
                  % check if user cancelled or not
                  %
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PredictionEvent = PredictionEvent;
                     DSGEModel.RunPredictionEvent = 1;
                     %
                     % determine how many prediction paths to use
                     %
                     NumPredPathsStr = get(controls.forecast.predpaths,'String');
                     NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
                     %
                     % check if we have already stored results to disk
                     %
                     if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','','',DSGEModel.NameOfModel,MaxPH,NumPostDrawsUsage,NumPredPaths,AnnualizeData,TransData,CurrChain,1)==1;
                        txt = 'YADA has located results for the predictive distribution on disk. Would you like to use these results?';
                        answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                     else;
                        answer = 'No';
                     end;
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % compute the prediction event results
                        %
                        PredEventData = LoadDSGEPredictionPaths(DSGEModel.PredictionEvent,DSGEModel.OutputDirectory,'','',DSGEModel.NameOfModel,MaxPH,NumPostDrawsUsage,NumPredPaths,AnnualizeData,TransData,CurrChain,CurrINI,Weights);
                        DoneCalc = 1;
                     else;
                        %
                        % we can now compute the predictive distribution for the endogenous variables
                        % up to period MaxPH
                        %
                        [DoneCalc,PredEventData,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGEPredictionPaths(thetaPostSample,thetaMode,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1,Weights);
                     end;
                     %
                     % clear everything
                     %
                     clear('thetaPostSample');
                     %
                     % check if we should show any results
                     %
                     if DoneCalc==1;
                        %
                        % check if summary results from the predictive distribution have been saved to mat-file
                        %
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                        file = FixFilePath([DSGEModel.OutputDirectory '\PredictiveDist-' AnnualStr '-' num2str(CurrChain,'%0.0f') '-' num2str(MaxPH,'%0.0f') '-' num2str(NumPostDrawsUsage,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '.mat']);
                        if FileExist(file)==1;
                           save(file,'PredictionEvent','PredEventData','-APPEND');
                           %
                           % create a matlab m-file to read the output.
                           %
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\PD' num2str(CurrChain,'%0.0f') AnnualStr num2str(MaxPH,'%0.0f') num2str(NumPostDrawsUsage,'%0.0f') num2str(NumPredPaths,'%0.0f') DSGEModel.SubEndYear DSGEModel.SubEndPeriod '.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                           fprintf(fid,'YNames = DataStructure.YNames;\n');
                           fprintf(fid,'%%\n%% matrix with the mean predictions of the observed variables\n%%\n');
                           fprintf(fid,'MeanPrediction = DataStructure.MeanPrediction;\n');
                           fprintf(fid,'%%\n%% matrix with the errors from the mean predictions of the observed variables\n%%\n');
                           fprintf(fid,'PredictionErrors = DataStructure.PredictionErrors;\n');
                           fprintf(fid,'%%\n%% vector structure with quantiles from the predictive distribution\n%% the structure has %0.0f entries with fields "Quantile" and "percent"\n%% the first field is a matrix and the second a positive number between 0 and 100\n%%\n',length(DSGEModel.Percentiles));
                           fprintf(fid,'Quantiles = DataStructure.Quantiles;\n');
                           fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                           fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                           fprintf(fid,'%%\n%% observed variables\n%%\n');
                           fprintf(fid,'Y = DataStructure.Y;\n');
                           fprintf(fid,'%%\n%% vector with dates for the observed variables\n%%\n');
                           fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                           if AnnualizeData==0;
                              fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to state uncertainty\n%%\n');
                              fprintf(fid,'StateCov = DataStructure.StateCov;\n');
                              fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to shock uncertainty\n%%\n');
                              fprintf(fid,'ShockCov = DataStructure.ShockCov;\n');
                              fprintf(fid,'%%\n%% 2D Error covariance matrix (nxn) part due to measurement error uncertainty\n%%\n');
                              fprintf(fid,'MeasureCov = DataStructure.MeasureCov;\n');
                              fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to parameter uncertainty\n%%\n');
                              fprintf(fid,'ParameterCov = DataStructure.ParameterCov;\n');
                           end;
                           fprintf(fid,'%%\n%% matrix with the prediction event definitions. The first column\n%% holds the upper bound, the second column\n%% the lower bound, and third the length of the event.\n%%\n');
                           fprintf(fid,'PredictionEvent = DataStructure.PredictionEvent;\n');
                           fprintf(fid,'%%\n%% matrix with prediction event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                           fprintf(fid,'PredEventData = DataStructure.PredEventData;\n');
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                        end;
                        %
                        % write prediction event results to file
                        %
                        file = FixFilePath([DSGEModel.OutputDirectory '\PredictiveDist-' AnnualStr '-' num2str(CurrChain,'%0.0f') '-' num2str(MaxPH,'%0.0f') '-' num2str(NumPostDrawsUsage,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '.txt']);
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                        PrintPredictionEvent(file,DSGEModel.VariableNames,PredEventData,[],PredictionEvent,[PredStartYear ':' PredStartPeriod '-' PredEndYear ':' PredEndPeriod],MaxPH,NumPredPaths,NumPostDrawsUsage,CurrINI);
                        %
                        % displays the file if it exists
                        %
                        if FileExist(file)==1;
                           TextGUI(file,['Prediction Events - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution - Unconditional Predictions',50,CurrINI,1,0);
                        end;
                     end;
                  else;
                     %
                     % make sure that the draws are cleared from memory
                     %
                     clear('thetaPostSample');
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ConPredictionEvent'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % first attempt to load some posterior mode data
         %
         ModeFile = FixFilePath([DSGEModel.OutputDirectory '\mode\PosteriorMode-' DSGEModel.NameOfModel '.mat']);
         ErrorStr = '';
         HeaderStr = 'YADA - Bad MAT File';
         if MatlabNumber>=8.0;
            try;
               ModeData = load(ModeFile);
            catch ME;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError(ME)];
            end;
         else;
            try;
               ModeData = load(ModeFile);
            catch;
               ErrorStr = ['Unable to load the file "' ModeFile '". Message caught is: ' YADALastError];
            end;
         end;
         %
         % check if we should check transformations functions
         %
         if (isempty(ErrorStr)==1)&(gcbo==controls.predict.conditional_transformed_predevent);
            DTStatus = VerifyDataTransformation(DSGEModel.VariableNames,DSGEModel.YTransformation,0);
            if DTStatus==1;
               [YTStatus,YData,ErrorStr,HeaderStr] = CalcTransformData(DSGEModel.VariableNames,DSGEModel.Y',DSGEModel.YTransformation,DSGEModel.YTransMatrix);
            else;
               ErrorStr = 'You haven''t specified all the necessary fields for computing transformations of the observed variables.';
               HeaderStr = 'Missing Transformation Information';
            end;
         end;
         %
         if strcmp(ErrorStr,'')==1;
            thetaPositions = ModeData.thetaPositions;
            ModelParameters = ModeData.ModelParameters;
%            if isfield(ModeData,'KalmanFirstObservation')==1;
%               DSGEModel.KalmanFirstObservation = ModeData.KalmanFirstObservation;
%               FirstPeriod = ModeData.DSGEModel.FirstPeriod;
%               LastPeriod = ModeData.DSGEModel.LastPeriod;
%            else;
               [FirstPeriod,LastPeriod] = CreateSubSample(DSGEModel);
%               DSGEModel.KalmanFirstObservation = round(((DSGEModel.InitializeKalman-1)/100)*(LastPeriod-FirstPeriod+1))+1;
%            end;
            %
            % check how many time periods to use for predictive distributions
            %
            [MaxPH,NumPredX] = CalcMaxPredictionHorizon(DSGEModel.MaxForecastHorizon,DSGEModel.DataFrequency,DSGEModel.EndYear,DSGEModel.EndPeriod,DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,size(DSGEModel.PredictedX,2));
            %
            % matrix with exogenous variables
            %
            X = [];
            if DSGEModel.k>0;
               if NumPredX<MaxPH;
                  X = DSGEModel.X(:,LastPeriod+1:LastPeriod+(MaxPH-NumPredX));
               end;
               if NumPredX>0;
                  X = [X DSGEModel.PredictedX(:,1:NumPredX)];
               end;
            end;
            %
            % check the length of the conditioning sample
            %
            [status,NumPeriods] = CheckConditioningData(DSGEModel);
            %
            % check if we should adjust the X matrix
            %
            if MaxPH<NumPeriods;
               NumPeriods = MaxPH;
            end;
            %
            % collect the conditional variables and the selected conditioning sample
            %
            Z = DSGEModel.Z(DSGEModel.ConditionalVariables,LastPeriod+1:LastPeriod+NumPeriods);
            if LastPeriod>=NumPeriods;
               U = DSGEModel.U(DSGEModel.ConditionalVariables,LastPeriod-NumPeriods+1:LastPeriod);
            else;
               %
               % we have to create artifical initial conditions for the conditioning variables
               %
               U = [DSGEModel.U(DSGEModel.ConditionalVariables,1)*ones(1,NumPeriods-LastPeriod) DSGEModel.U(DSGEModel.ConditionalVariables,1:LastPeriod)];
            end;;
            %
            % if there are multiple chains, ask which one to load
            %
            ChainsStr = get(controls.posterior.chains,'String');
            NumChains = str2num(StringTrim(ChainsStr(DSGEModel.ParallelChainsValue,:)));
            %
            if NumChains>1;
               %
               % ask which chain to load
               %
               ChainsStr = '';
               for i=1:NumChains;
                  ChainsStr = strvcat(ChainsStr,['Posterior chain number ' num2str(i,'%0.0f')]);
               end;
               [action,CurrChain] = SelectionDlg(ChainsStr,1,'Select the posterior draws chain to load','MCMC Chain Selection','Prediction Event','','',CurrINI);
            else;
               CurrChain = 1;
               action = 'ok';
            end;
            %
            %
            if strcmp(lower(action),'cancel')==0;
               %
               % check if the data actually exists
               %
               if VerifyDSGEPosteriorDraws(DSGEModel,CurrChain,controls)==1;
                  %
                  % load the data
                  %
                  [PostSample,thetaPostSample,LogPost,AcceptedDraws,NumBurnin,Weights] = LoadDSGEPosteriorDraws(DSGEModel,CurrINI,CurrChain);
                  NumDraws = length(LogPost);
                  clear('PostSample','LogPost','AcceptedDraws');
                  drawnow;
                  %
                  % initialize the random number generator
                  %
                  if DSGEModel.RandomNumberValue==1;
                     randn('state',0);
                     rand('state',0);
                  else;
                     randn('state',sum(100*clock));
                     rand('state',sum(100*clock));
                  end;
                  %
                  % select which posterior draws to use
                  %
                  thetaPostSample = thetaPostSample(NumBurnin+1:NumDraws,:);
                  NumDraws = NumDraws-NumBurnin;
                  %
                  % check how many draws we should pick among these
                  %
                  if DSGEModel.PosteriorSampler<=7;
                     PostDrawsUsageStr = get(controls.posterior.postdrawsusage,'String');
                     NumPostDrawsUsage = min(str2num(strrep(StringTrim(PostDrawsUsageStr(DSGEModel.PostDrawsUsageValue,:)),',','')),NumDraws);
                     %
                     % get the draws to use
                     %
                     if DSGEModel.RandomizeDraws==0;
                        DrawFreq = round(NumDraws/NumPostDrawsUsage);
                        SelectDraws = (1:DrawFreq:NumDraws);
                        if length(SelectDraws)+1==NumPostDrawsUsage;
                           SelectDraws = [SelectDraws NumDraws];
                        elseif length(SelectDraws)>NumPostDrawsUsage;
                           SelectDraws = SelectDraws(1:NumPostDrawsUsage);
                        end;
                        thetaPostSample = thetaPostSample(SelectDraws,:);
                     else;
                        thetaPostSample = thetaPostSample(ceil(rand(NumPostDrawsUsage,1)*NumDraws),:);
                     end;
                  else;
                     txt = 'Would you like to use a sub-sample of the posterior draws when computing the predictive distribution?';
                     answer = Query(txt,'question',400,'Prediction Event - Posterior',500,'no',CurrINI);
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % select how many draws to use
                        %
                        SelectDraws = SampledPosteriorDraws(DSGEModel,CurrINI,'Prediction Event - Posterior',Weights,NumDraws,[]);
                        if isempty(SelectDraws)==1;
                           set(controls.about,'UserData',0);
                           return;
                        end;
                        thetaPostSample = thetaPostSample(SelectDraws,:);
                        NumPostDrawsUsage = length(SelectDraws);
                        if DSGEModel.PosteriorSampler~=9;
                           %
                           % fix the weights
                           %
                           Weights = Weights(SelectDraws,1);
                           Weights = Weights*length(Weights)/sum(Weights);
                        else;
                           if isempty(Weights)==0;
                              Weights = Weights(SelectDraws);
                           end;
                        end;
                     end;
                  end;
                  %
                  % are we using annualized data or the original
                  %
                  if gcbo==controls.predict.conditional_original_predevent;
                     TransData = 0;
                     AnnualizeData = 0;
                     AnnualStr = 'original';
                     QueryHead = 'Conditional Predictive Distributions - Original Data';
                  elseif gcbo==controls.predict.conditional_annual_predevent;
                     TransData = 0;
                     AnnualizeData = 1;
                     AnnualStr = 'annual';
                     QueryHead = 'Conditional Predictive Distributions - Annualized Data';
                  else;
                     TransData = 1;
                     AnnualizeData = 0;
                     AnnualStr = 'transformed';
                     QueryHead = 'Conditional Predictive Distributions - Transformed Data';
                  end;
                  %
                  % prediction event calculations
                  %
                  if (isfield(DSGEModel,'PredictionEvent')==0)|(isempty(DSGEModel.PredictionEvent)==1)|(size(DSGEModel.PredictionEvent,1)~=DSGEModel.n)|(size(DSGEModel.PredictionEvent,2)~=3);
                     DSGEModel.PredictionEvent = [Inf*ones(DSGEModel.n,1) zeros(DSGEModel.n,1) ones(DSGEModel.n,1)];
                  end;
                  %
                  % make sure that the prediction event length does not exceed the maximum prediction horizon
                  %
                  for i=1:DSGEModel.n;
                     if DSGEModel.PredictionEvent(i,3)>MaxPH;
                        DSGEModel.PredictionEvent(i,3) = MaxPH;
                     end;
                  end;
                  %
                  % display a dialog for setting up an prediction event
                  %
                  [action,PredictionEvent] = PredictionEventDLG('init',DSGEModel.VariableNames,DSGEModel.PredictionEvent,MaxPH,CurrINI);
                  %
                  % check if user cancelled or not
                  %
                  if strcmp(lower(action),'ok')==1;
                     DSGEModel.PredictionEvent = PredictionEvent;
                     DSGEModel.RunPredictionEvent = 1;
                     %
                     % check which method is used for dealing with the conditioning assumptions
                     %
                     if DSGEModel.ShockControlMethod==1;
                        ShockMethod = 'Direct-';
                     elseif DSGEModel.ShockControlMethod==2;
                        ShockMethod = 'WaggonerZha-';
                     else;
                        ShockMethod = 'Subset-';
                     end;
                     %
                     % determine how many prediction paths to use
                     %
                     NumPredPathsStr = get(controls.forecast.predpaths,'String');
                     NumPredPaths = str2num(strrep(strrep(strrep(StringTrim(NumPredPathsStr(DSGEModel.NumPredPathsValue,:)),'path',''),'s',''),',',''));
                     %
                     % check if we have already stored results to disk
                     %
                     if PredictionsExist(DSGEModel.OutputDirectory,'DSGE','Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumPostDrawsUsage,NumPredPaths,AnnualizeData,TransData,CurrChain,1)==1;
                        txt = 'YADA has located results for the conditional predictive distribution on disk. Would you like to use these results?';
                        answer = Query(txt,'question',150,QueryHead,450,'no',CurrINI);
                     else;
                        answer = 'No';
                     end;
                     if strcmp(lower(answer),'yes')==1;
                        %
                        % compute the prediction event results
                        %
                        PredEventData = LoadDSGEPredictionPaths(DSGEModel.PredictionEvent,DSGEModel.OutputDirectory,'Cond',ShockMethod,DSGEModel.NameOfModel,MaxPH,NumPostDrawsUsage,NumPredPaths,AnnualizeData,TransData,CurrChain,CurrINI,Weights);
                        DoneCalc = 1;
                     else;
                        %
                        % we can now compute the predictive distribution for the endogenous variables
                        % up to period MaxPH
                        %
                        if DSGEModel.ShockControlMethod==1;
                           [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPaths(thetaPostSample,ModeData.thetaMode,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1);
                        elseif DSGEModel.ShockControlMethod==2;
                           [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsWZ(thetaPostSample,ModeData.thetaMode,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1);
                        else;
                           %
                           % check if the selected method can actually be used
                           %
                           CondTxt = '';
                           if isempty(DSGEModel.MixedConditionalShocks)==1;
                              CondTxt = 'You haven''t selected any shocks for use which the distribution of a subset of the shocks conditioning method.';
                           elseif length(DSGEModel.MixedConditionalShocks)<length(DSGEModel.ConditionalVariables);
                              CondTxt = ['The number of shocks you have selected to use to ensure that the conditioning assumptions are satisfied under the distribution of a subset of the shocks conditioning method is not sufficient. You need at least ' int2str(length(DSGEModel.ConditionalVariables)) ' such shocks.'];
                           end;
                           if isempty(CondTxt)==1;
                              [DoneCalc,PredEventData,ShockMean,ShockNames,StateCov,ShockCov,MeasureCov,ParameterCov] = DSGECondPredictionPathsMixed(thetaPostSample,ModeData.thetaMode,thetaPositions,ModelParameters,DSGEModel,CurrINI,X,Z,U,MaxPH,NumPredPaths,AnnualizeData,TransData,CurrChain,1);
                           else;
                              About(CondTxt,'information','Bad Shocks Selection - Distribution of Subset Shocks Method',300,550,CurrINI);
                              DoneCalc = 0;
                           end;
                        end;
                     end;
                     %
                     % clear everything
                     %
                     clear('thetaPostSample');
                     %
                     % check if we should show any results
                     %
                     if DoneCalc==1;
                        %
                        % check if summary results already exist on disk
                        %
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod,PredDateVector] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                        file = FixFilePath([DSGEModel.OutputDirectory '\CondPredictiveDist-' int2str(DSGEModel.ShockControlMethod) '-' AnnualStr '-' num2str(CurrChain,'%0.0f') '-' num2str(MaxPH,'%0.0f') '-' num2str(NumPostDrawsUsage,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '.mat']);
                        if FileExist(file)==1;
                           save(file,'PredictionEvent','PredEventData','-APPEND');
                           %
                           % create a matlab m-file to read the output.
                           %
                           mfile = FixFilePath([DSGEModel.OutputDirectory '\CondPD' int2str(DSGEModel.ShockControlMethod) AnnualStr num2str(CurrChain,'%0.0f') num2str(MaxPH,'%0.0f') num2str(NumPostDrawsUsage,'%0.0f') num2str(NumPredPaths,'%0.0f') DSGEModel.SubEndYear DSGEModel.SubEndPeriod '.m']);
                           fid = fopen(mfile,'wt');
                           fprintf(fid,['%%\n%% load the data in ' GetFilename(file) '\n%%\n']);
                           fprintf(fid,'DataStructure = load(''%s'');\n',GetFilename(file));
                           fprintf(fid,'%%\n%% string matrix with the names of the observed variables\n%%\n');
                           fprintf(fid,'YNames = DataStructure.YNames;\n');
                           fprintf(fid,'%%\n%% matrix with the mean predictions of the observed variables\n%%\n');
                           fprintf(fid,'MeanPrediction = DataStructure.MeanPrediction;\n');
                           fprintf(fid,'%%\n%% matrix with the errors from the mean predictions of the observed variables\n%%\n');
                           fprintf(fid,'PredictionErrors = DataStructure.PredictionErrors;\n');
                           fprintf(fid,'%%\n%% vector structure with quantiles from the predictive distribution\n%% the structure has %0.0f entries with fields "Quantile" and "percent"\n%% the first field is a matrix and the second a positive number between 0 and 100\n%%\n',length(DSGEModel.Percentiles));
                           fprintf(fid,'Quantiles = DataStructure.Quantiles;\n');
                           fprintf(fid,'%%\n%% vector with dates for the predictions\n%%\n');
                           fprintf(fid,'PredDateVector = DataStructure.PredDateVector;\n');
                           fprintf(fid,'%%\n%% observed variables\n%%\n');
                           fprintf(fid,'Y = DataStructure.Y;\n');
                           fprintf(fid,'%%\n%% vector with dates for the observed variables\n%%\n');
                           fprintf(fid,'DateVector = DataStructure.DateVector;\n');
                           if (AnnualizeData==0)&(TransData==0);
                              fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to state uncertainty\n%%\n');
                              fprintf(fid,'StateCov = DataStructure.StateCov;\n');
                              fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to shock uncertainty\n%%\n');
                              fprintf(fid,'ShockCov = DataStructure.ShockCov;\n');
                              fprintf(fid,'%%\n%% 2D Error covariance matrix (nxn) part due to measurement error uncertainty\n%%\n');
                              fprintf(fid,'MeasureCov = DataStructure.MeasureCov;\n');
                              fprintf(fid,'%%\n%% 3D Error covariance matrix (nxnxh) part due to parameter uncertainty\n%%\n');
                              fprintf(fid,'ParameterCov = DataStructure.ParameterCov;\n');
                           end;
                           fprintf(fid,'%%\n%% matrix with the prediction event definitions. The first column\n%% holds the upper bound, the second column\n%% the lower bound, and third the length of the event.\n%%\n');
                           fprintf(fid,'PredictionEvent = DataStructure.PredictionEvent;\n');
                           fprintf(fid,'%%\n%% matrix with prediction event data. First column holds the number of true\%% events, the second the number of times below the lower bound of the event,\n%% the third the number of times above the upper bound of the event, the\n%% fourth the number of events, the fifth and sixth the sum and sum of\n%% squared deviations from the lower bound when below, and the seventh and\n%% eighth the sum and sum of squared deviations from the upper bound when above\n%%\n');
                           fprintf(fid,'PredEventData = DataStructure.PredEventData;\n');
                           if AnnualizeData==0;
                              fprintf(fid,'%%\n%% vector with the mean of the multivariate modesty statistic and its reference statistic\n%%\n');
                              fprintf(fid,'MeanMultiModesty = DataStructure.MeanMultiModesty;\n');
                              fprintf(fid,'%%\n%% tail probability based on the reference statistic\n%%\n');
                              fprintf(fid,'MultiPValue = DataStructure.MultiPValue;\n');
                              fprintf(fid,'%%\n%% tail probability based on the chi-square distribution\n%%\n');
                              fprintf(fid,'ChiSqPValue = DataStructure.ChiSqPValue;\n');
                              fprintf(fid,'%%\n%% Adolfson, Lasen, Lind and Villani univariate modesty statistic\n%%\n');
                              fprintf(fid,'MeanUniModesty = DataStructure.MeanUniModesty;\n');
                              fprintf(fid,'%%\n%% Leeper and Zha univariate modesty statistic\n%%\n');
                              fprintf(fid,'MeanUniModestyLZ = DataStructure.MeanUniModestyLZ;\n');
                           end;
                           fprintf(fid,'%%\n%% Add your own commands below\n%%\n\n\n');
                           %
                           % end the script file
                           %
                           fprintf(fid,'%%\n%% Created by YADA on %s\n%%\n',datestr(now,0));
                           fclose(fid);
                        end;
                        %
                        % write prediction event results to file
                        %
                        file = FixFilePath([DSGEModel.OutputDirectory '\CondPredictiveDist-' int2str(DSGEModel.ShockControlMethod) '-' AnnualStr '-' num2str(CurrChain,'%0.0f') '-' num2str(MaxPH,'%0.0f') '-' num2str(NumPostDrawsUsage,'%0.0f') '.' num2str(NumPredPaths,'%0.0f') '-' DSGEModel.SubEndYear '.' DSGEModel.SubEndPeriod '.txt']);
                        [PredStartYear,PredStartPeriod,PredEndYear,PredEndPeriod] = CreatePredictionSample(DSGEModel.SubEndYear,DSGEModel.SubEndPeriod,DSGEModel.DataFrequency,MaxPH);
                        PrintPredictionEvent(file,DSGEModel.VariableNames,PredEventData,[],PredictionEvent,[PredStartYear ':' PredStartPeriod '-' PredEndYear ':' PredEndPeriod],MaxPH,NumPredPaths,NumPostDrawsUsage,CurrINI);
                        %
                        % displays the file if it exists
                        %
                        if FileExist(file)==1;
                           TextGUI(file,['Prediction Events - ' DSGEModel.NameOfModel],[(CurrINI.scrsz(3)-1000)/2 50 1000 CurrINI.scrsz(4)-100],'Posterior Distribution - Conditional Predictions',50,CurrINI,1,0);
                        end;
                     end;
                  else;
                     %
                     % make sure that the posterior draws are released from memory
                     %
                     clear('thetaPostSample');
                  end;
               else;
                  txt = ['Some of the files for loading the posterior data for chain number ' num2str(CurrChain,'%0.0f') ' are not available.'];
                  About(txt,'error','Missing Posterior Draws',150,500,CurrINI);
               end;
            end;
         else;
            About(ErrorStr,'information',HeaderStr,500,600,CurrINI);
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'ViewActuals'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         % open the graph actuals data dialog
         %
         GraphActualsDataDLG('init',CurrINI,DSGEModel);
         %
         set(controls.about,'UserData',0);
      end;
end;
set(controls.open,'UserData',DSGEModel);
set(controls.filemenu,'UserData',CurrINI);
%
% make sure that controls are enabled and disabled as they should
%
YADAEnableControls(DSGEModel,controls);

%
% end of ForecastToolsMenuFunctions.m
%
